package Data::FR::Town;

use 5.006;
use strict;
use warnings;
use Carp;

=head1 NAME

Data::FR::Town - Provides data about french town (INSEE code, ZIP/postal code, name...)

=head1 VERSION

Version 0.01

=cut

our $VERSION = '0.02';

our %TOWNS;

=head1 SYNOPSIS

This module provides basic data about french towns.

    use Data::FR::Town;

    # Multiple ways to get the same town
    my $town1 = Data::FR::Town->new( {insee => "01001"});
    my $town2 = Data::FR::Town->new( {zip => "01400"});
    my $town3 = Data::FR::Town->find( {insee => "01001"});
    my $town3 = Data::FR::Town->find( {zip => "01400"});

    Now you can get data about the selected town, using the getters :

    my $zip = $town1->zip();
    my $name = $town1->name();
    my $cname = $town1->cname();
    ...

=head1 SUBROUTINES/METHODS

=head2 new ( \%params )

Return a town object selected through the specified parameters.

%params accept two valid keys : 'insee' and 'zip' to specfy the town.

=cut

sub new {
    my $class  = shift;
    my $params = shift;

    my $self = bless {}, $class;

    for my $line (<DATA>) {
        chomp $line;

        my ( $insee, $article, $name, $cname, $zip, $dep, $depname, $origin ) = split ';', $line;

        $class::TOWNS{insee}{$insee}{article} = $article;
        $class::TOWNS{insee}{$insee}{name}    = $name;
        $class::TOWNS{insee}{$insee}{cname}   = $cname;
        $class::TOWNS{insee}{$insee}{zip}     = $zip;
        $class::TOWNS{insee}{$insee}{dep}     = $dep;
        $class::TOWNS{insee}{$insee}{depname} = $depname;
        $class::TOWNS{insee}{$insee}{origin}  = $origin;
        $class::TOWNS{zip}{$zip}              = $class::TOWNS->{insee}{$insee};

    }

    for my $param ( keys %{$params} ) {
        if ( $param =~ /insee/ ) {
            return $class->find( { insee => $params->{$param} } );
        } elsif ( $param =~ /zip/ ) {
            return $class->find( { zip => $params->{$param} } );

        } else {
            croak "Unknown parameter : $param";
        }
    }

    return bless $self, $class;
}

=head2 find ( \%params )

Return a town object selected through the specified parameters.

%params accept two valid keys : 'insee' and 'zip' to specfy the town.

=cut

sub find {
    my $class  = shift;
    my $params = shift;

    $class = ref $class if ref $class;

    for my $param ( keys %$params ) {
        if ( $class::TOWNS{$param}{ $params->{$param} } ) {
            return bless $class::TOWNS{$param}{ $params->{$param} }, $class;
        } else {
            croak "Unknown parameter : $param" unless $param =~ /(zip|insee)/;
            return undef;
        }
    }
}

=head2 insee ()

Return the INSEE code associated to this town

=cut

sub insee {
    my $self = shift;

    return $self->{insee};
}

=head2 zip ()

Return the zip/postal code associated to this town

=cut

sub zip {
    my $self = shift;

    return $self->{zip};
}

=head2 article ()

Return the article associated to this town, as some french town may have one.
(La Courneuve)

=cut

sub article {
    my $self = shift;

    return $self->{article};
}

=head2 name ()

Return the name of the town
The first letter is uppercased the other ones are lowercase

=cut

sub name {
    my $self = shift;

    return $self->{name};
}

=head2 cname ()

Return the capitalized name of the town
All letters are (non accentuated) uppercase.

=cut

sub cname {
    my $self = shift;

    return $self->{cname};
}

=head2 dep ()

Return the department's number

=cut

sub dep {
    my $self = shift;

    return $self->{dep};
}

=head2 depname ()

Return the department's name

=cut

sub depname {
    my $self = shift;

    return $self->{depname};
}

=head1 DISCLAIMER

This version is based on the data from the INSEE site :
http://www.insee.fr/fr/methodes/nomenclatures/cog/telechargement/2012/txt/comsimp2012.zip

As this data is free and quite stable, the information about the INSEE
code, name are quite accurate.

The information about the postal/zip code is however much more difficult to
get AND subject to change.

I'll try to keep the postal/zip codes up to date, but anyone knowing a way to get
automatically these data could greatly contribute by telling it (or providing the data)

Don't hesitate to contact me on this subject.


Arnaud (Arhuman) ASSAD, C<< <arhuman at gmail.com> >>

=head1 AUTHOR

Arnaud (Arhuman) ASSAD, C<< <arhuman at gmail.com> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-data-fr-town at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Data-FR-Town>.  I will be notified, and then you'll

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Data::FR::Town


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Data-FR-Town>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Data-FR-Town>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Data-FR-Town>

=item * Search CPAN

L<http://search.cpan.org/dist/Data-FR-Town/>

=back


=head1 ACKNOWLEDGEMENTS


=head1 LICENSE AND COPYRIGHT

Copyright 2012 Arnaud (Arhuman) ASSAD.

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.


=cut

1;    # End of Data::FR::Town

__DATA__
01001;L';Abergement-Clémenciat;ABERGEMENT-CLEMENCIAT;01400;01;AIN;1
01002;L';Abergement-de-Varey;ABERGEMENT-DE-VAREY;01640;01;AIN;1
01004;;Ambérieu-en-Bugey;AMBERIEU-EN-BUGEY;01500;01;AIN;1
01005;;Ambérieux-en-Dombes;AMBERIEUX-EN-DOMBES;01330;01;AIN;1
01006;;Ambléon;AMBLEON;01300;01;AIN;1
01007;;Ambronay;AMBRONAY;01500;01;AIN;1
01008;;Ambutrix;AMBUTRIX;01500;01;AIN;1
01009;;Andert-et-Condon;ANDERT-ET-CONDON;01300;01;AIN;1
01010;;Anglefort;ANGLEFORT;01350;01;AIN;1
01011;;Apremont;APREMONT;01100;01;AIN;1
01012;;Aranc;ARANC;01110;01;AIN;1
01013;;Arandas;ARANDAS;01230;01;AIN;1
01014;;Arbent;ARBENT;01100;01;AIN;1
01015;;Arbignieu;ARBIGNIEU;01300;01;AIN;1
01016;;Arbigny;ARBIGNY;01190;01;AIN;1
01017;;Argis;ARGIS;01230;01;AIN;1
01019;;Armix;ARMIX;01510;01;AIN;1
01021;;Ars-sur-Formans;ARS-SUR-FORMANS;01480;01;AIN;1
01022;;Artemare;ARTEMARE;01510;01;AIN;1
01023;;Asnières-sur-Saône;ASNIERES-SUR-SAONE;01570;01;AIN;1
01024;;Attignat;ATTIGNAT;01340;01;AIN;1
01025;;Bâgé-la-Ville;BAGE-LA-VILLE;01380;01;AIN;1
01026;;Bâgé-le-Châtel;BAGE-LE-CHATEL;01380;01;AIN;1
01027;;Balan;BALAN;01360;01;AIN;1
01028;;Baneins;BANEINS;01990;01;AIN;1
01029;;Beaupont;BEAUPONT;01270;01;AIN;1
01030;;Beauregard;BEAUREGARD;01480;01;AIN;1
01031;;Bellignat;BELLIGNAT;01810;01;AIN;1
01032;;Béligneux;BELIGNEUX;01360;01;AIN;1
01033;;Bellegarde-sur-Valserine;BELLEGARDE-SUR-VALSERINE;01200;01;AIN;1
01034;;Belley;BELLEY;01300;01;AIN;1
01035;;Belleydoux;BELLEYDOUX;01130;01;AIN;1
01036;;Belmont-Luthézieu;BELMONT-LUTHEZIEU;01260;01;AIN;1
01037;;Bénonces;BENONCES;01470;01;AIN;1
01038;;Bény;BENY;01370;01;AIN;1
01039;;Béon;BEON;01350;01;AIN;1
01040;;Béréziat;BEREZIAT;01340;01;AIN;1
01041;;Bettant;BETTANT;01500;01;AIN;1
01042;;Bey;BEY;01290;01;AIN;1
01043;;Beynost;BEYNOST;01700;01;AIN;1
01044;;Billiat;BILLIAT;01200;01;AIN;1
01045;;Birieux;BIRIEUX;01330;01;AIN;1
01046;;Biziat;BIZIAT;01290;01;AIN;1
01047;;Blyes;BLYES;01150;01;AIN;1
01049;La;Boisse;BOISSE;01120;01;AIN;1
01050;;Boissey;BOISSEY;01190;01;AIN;1
01051;;Bolozon;BOLOZON;01450;01;AIN;1
01052;;Bouligneux;BOULIGNEUX;01330;01;AIN;1
01053;;Bourg-en-Bresse;BOURG-EN-BRESSE;01000;01;AIN;1
01054;;Bourg-Saint-Christophe;BOURG-SAINT-CHRISTOPHE;01800;01;AIN;1
01056;;Boyeux-Saint-Jérôme;BOYEUX-SAINT-JEROME;01640;01;AIN;1
01057;;Boz;BOZ;01190;01;AIN;1
01058;;Brégnier-Cordon;BREGNIER-CORDON;01300;01;AIN;1
01059;;Brénaz;BRENAZ;01260;01;AIN;1
01060;;Brénod;BRENOD;01110;01;AIN;1
01061;;Brens;BRENS;01300;01;AIN;1
01062;;Bressolles;BRESSOLLES;01360;01;AIN;1
01063;;Brion;BRION;01460;01;AIN;1
01064;;Briord;BRIORD;01470;01;AIN;1
01065;;Buellas;BUELLAS;01310;01;AIN;1
01066;La;Burbanche;BURBANCHE;01510;01;AIN;1
01067;;Ceignes;CEIGNES;01430;01;AIN;1
01068;;Cerdon;CERDON;01450;01;AIN;1
01069;;Certines;CERTINES;01240;01;AIN;1
01071;;Cessy;CESSY;01170;01;AIN;1
01072;;Ceyzériat;CEYZERIAT;01250;01;AIN;1
01073;;Ceyzérieu;CEYZERIEU;01350;01;AIN;1
01074;;Chalamont;CHALAMONT;01320;01;AIN;1
01075;;Chaleins;CHALEINS;01480;01;AIN;1
01076;;Chaley;CHALEY;01230;01;AIN;1
01077;;Challes-la-Montagne;CHALLES-LA-MONTAGNE;01450;01;AIN;1
01078;;Challex;CHALLEX;01630;01;AIN;1
01079;;Champagne-en-Valromey;CHAMPAGNE-EN-VALROMEY;01260;01;AIN;1
01080;;Champdor;CHAMPDOR;01110;01;AIN;1
01081;;Champfromier;CHAMPFROMIER;01410;01;AIN;1
01082;;Chanay;CHANAY;01420;01;AIN;1
01083;;Chaneins;CHANEINS;01990;01;AIN;1
01084;;Chanoz-Châtenay;CHANOZ-CHATENAY;01400;01;AIN;1
01085;La;Chapelle-du-Châtelard;CHAPELLE-DU-CHATELARD;01240;01;AIN;1
01087;;Charix;CHARIX;01130;01;AIN;1
01088;;Charnoz-sur-Ain;CHARNOZ-SUR-AIN;01800;01;AIN;1
01089;;Château-Gaillard;CHATEAU-GAILLARD;01500;01;AIN;1
01090;;Châtenay;CHATENAY;01320;01;AIN;1
01091;;Châtillon-en-Michaille;CHATILLON-EN-MICHAILLE;01200;01;AIN;1
01092;;Châtillon-la-Palud;CHATILLON-LA-PALUD;01320;01;AIN;1
01093;;Châtillon-sur-Chalaronne;CHATILLON-SUR-CHALARONNE;01400;01;AIN;1
01094;;Chavannes-sur-Reyssouze;CHAVANNES-SUR-REYSSOUZE;01190;01;AIN;1
01095;;Chavannes-sur-Suran;CHAVANNES-SUR-SURAN;01250;01;AIN;1
01096;;Chaveyriat;CHAVEYRIAT;01660;01;AIN;1
01097;;Chavornay;CHAVORNAY;01510;01;AIN;1
01098;;Chazey-Bons;CHAZEY-BONS;01300;01;AIN;1
01099;;Chazey-sur-Ain;CHAZEY-SUR-AIN;01150;01;AIN;1
01100;;Cheignieu-la-Balme;CHEIGNIEU-LA-BALME;01510;01;AIN;1
01101;;Chevillard;CHEVILLARD;01430;01;AIN;1
01102;;Chevroux;CHEVROUX;01190;01;AIN;1
01103;;Chevry;CHEVRY;01170;01;AIN;1
01104;;Chézery-Forens;CHEZERY-FORENS;01200;01;AIN;1
01105;;Civrieux;CIVRIEUX;01390;01;AIN;1
01106;;Cize;CIZE;01250;01;AIN;1
01107;;Cleyzieu;CLEYZIEU;01230;01;AIN;1
01108;;Coligny;COLIGNY;01270;01;AIN;1
01109;;Collonges;COLLONGES;01550;01;AIN;1
01110;;Colomieu;COLOMIEU;01300;01;AIN;1
01111;;Conand;CONAND;01230;01;AIN;1
01112;;Condamine;CONDAMINE;01430;01;AIN;1
01113;;Condeissiat;CONDEISSIAT;01400;01;AIN;1
01114;;Confort;CONFORT;01200;01;AIN;1
01115;;Confrançon;CONFRANCON;01310;01;AIN;1
01116;;Contrevoz;CONTREVOZ;01300;01;AIN;1
01117;;Conzieu;CONZIEU;01300;01;AIN;1
01118;;Corbonod;CORBONOD;01420;01;AIN;1
01119;;Corcelles;CORCELLES;01110;01;AIN;1
01121;;Corlier;CORLIER;01110;01;AIN;1
01122;;Cormaranche-en-Bugey;CORMARANCHE-EN-BUGEY;01110;01;AIN;1
01123;;Cormoranche-sur-Saône;CORMORANCHE-SUR-SAONE;01290;01;AIN;1
01124;;Cormoz;CORMOZ;01560;01;AIN;1
01125;;Corveissiat;CORVEISSIAT;01250;01;AIN;1
01127;;Courmangoux;COURMANGOUX;01370;01;AIN;1
01128;;Courtes;COURTES;01560;01;AIN;1
01129;;Crans;CRANS;01320;01;AIN;1
01130;;Cras-sur-Reyssouze;CRAS-SUR-REYSSOUZE;01340;01;AIN;1
01133;;Cressin-Rochefort;CRESSIN-ROCHEFORT;01350;01;AIN;1
01134;;Crottet;CROTTET;01620;01;AIN;1
01135;;Crozet;CROZET;01170;01;AIN;1
01136;;Cruzilles-lès-Mépillat;CRUZILLES-LES-MEPILLAT;01290;01;AIN;1
01138;;Culoz;CULOZ;01350;01;AIN;1
01139;;Curciat-Dongalon;CURCIAT-DONGALON;01560;01;AIN;1
01140;;Curtafond;CURTAFOND;01310;01;AIN;1
01141;;Cuzieu;CUZIEU;01300;01;AIN;1
01142;;Dagneux;DAGNEUX;01120;01;AIN;1
01143;;Divonne-les-Bains;DIVONNE-LES-BAINS;01220;01;AIN;1
01144;;Dommartin;DOMMARTIN;01380;01;AIN;1
01145;;Dompierre-sur-Veyle;DOMPIERRE-SUR-VEYLE;01240;01;AIN;1
01146;;Dompierre-sur-Chalaronne;DOMPIERRE-SUR-CHALARONNE;01400;01;AIN;1
01147;;Domsure;DOMSURE;01270;01;AIN;1
01148;;Dortan;DORTAN;01590;01;AIN;1
01149;;Douvres;DOUVRES;01500;01;AIN;1
01150;;Drom;DROM;01250;01;AIN;1
01151;;Druillat;DRUILLAT;01160;01;AIN;1
01152;;Échallon;ECHALLON;01130;01;AIN;1
01153;;Échenevex;ECHENEVEX;01170;01;AIN;1
01154;;Étrez;ETREZ;01340;01;AIN;1
01155;;Évosges;EVOSGES;01230;01;AIN;1
01156;;Faramans;FARAMANS;01800;01;AIN;1
01157;;Fareins;FAREINS;01480;01;AIN;1
01158;;Farges;FARGES;01550;01;AIN;1
01159;;Feillens;FEILLENS;01570;01;AIN;1
01160;;Ferney-Voltaire;FERNEY-VOLTAIRE;01210;01;AIN;1
01162;;Flaxieu;FLAXIEU;01350;01;AIN;1
01163;;Foissiat;FOISSIAT;01340;01;AIN;1
01165;;Francheleins;FRANCHELEINS;01090;01;AIN;1
01166;;Frans;FRANS;01480;01;AIN;1
01167;;Garnerans;GARNERANS;01140;01;AIN;1
01169;;Genouilleux;GENOUILLEUX;01090;01;AIN;1
01170;;Béard-Géovreissiat;BEARD-GEOVREISSIAT;01460;01;AIN;1
01171;;Géovreisset;GEOVREISSET;01100;01;AIN;1
01172;;Germagnat;GERMAGNAT;01250;01;AIN;1
01173;;Gex;GEX;01170;01;AIN;1
01174;;Giron;GIRON;01130;01;AIN;1
01175;;Gorrevod;GORREVOD;01190;01;AIN;1
01176;Le;Grand-Abergement;GRAND-ABERGEMENT;01260;01;AIN;1
01177;;Grand-Corent;GRAND-CORENT;01250;01;AIN;1
01179;;Grièges;GRIEGES;01290;01;AIN;1
01180;;Grilly;GRILLY;01220;01;AIN;1
01181;;Groissiat;GROISSIAT;01810;01;AIN;1
01182;;Groslée;GROSLEE;01680;01;AIN;1
01183;;Guéreins;GUEREINS;01090;01;AIN;1
01184;;Hautecourt-Romanèche;HAUTECOURT-ROMANECHE;01250;01;AIN;1
01185;;Hauteville-Lompnes;HAUTEVILLE-LOMPNES;01110;01;AIN;1
01186;;Hostiaz;HOSTIAZ;01110;01;AIN;1
01187;;Hotonnes;HOTONNES;01260;01;AIN;1
01188;;Illiat;ILLIAT;01140;01;AIN;1
01189;;Injoux-Génissiat;INJOUX-GENISSIAT;01200;01;AIN;1
01190;;Innimond;INNIMOND;01680;01;AIN;1
01191;;Izenave;IZENAVE;01430;01;AIN;1
01192;;Izernore;IZERNORE;01580;01;AIN;1
01193;;Izieu;IZIEU;01300;01;AIN;1
01194;;Jassans-Riottier;JASSANS-RIOTTIER;01480;01;AIN;1
01195;;Jasseron;JASSERON;01250;01;AIN;1
01196;;Jayat;JAYAT;01340;01;AIN;1
01197;;Journans;JOURNANS;01250;01;AIN;1
01198;;Joyeux;JOYEUX;01800;01;AIN;1
01199;;Jujurieux;JUJURIEUX;01640;01;AIN;1
01200;;Labalme;LABALME;01450;01;AIN;1
01202;;Lagnieu;LAGNIEU;01150;01;AIN;1
01203;;Laiz;LAIZ;01290;01;AIN;1
01204;;Lalleyriat;LALLEYRIAT;01130;01;AIN;1
01205;;Lancrans;LANCRANS;01200;01;AIN;1
01206;;Lantenay;LANTENAY;01430;01;AIN;1
01207;;Lapeyrouse;LAPEYROUSE;01330;01;AIN;1
01208;;Lavours;LAVOURS;01350;01;AIN;1
01209;;Léaz;LEAZ;01200;01;AIN;1
01210;;Lélex;LELEX;01410;01;AIN;1
01211;;Lent;LENT;01240;01;AIN;1
01212;;Lescheroux;LESCHEROUX;01560;01;AIN;1
01213;;Leyment;LEYMENT;01150;01;AIN;1
01214;;Leyssard;LEYSSARD;01450;01;AIN;1
01215;;Lhôpital;LHOPITAL;01420;01;AIN;1
01216;;Lhuis;LHUIS;01680;01;AIN;1
01218;;Lochieu;LOCHIEU;01260;01;AIN;1
01219;;Lompnas;LOMPNAS;01680;01;AIN;1
01221;;Lompnieu;LOMPNIEU;01260;01;AIN;1
01224;;Loyettes;LOYETTES;01360;01;AIN;1
01225;;Lurcy;LURCY;01090;01;AIN;1
01227;;Magnieu;MAGNIEU;01300;01;AIN;1
01228;;Maillat;MAILLAT;01430;01;AIN;1
01229;;Malafretaz;MALAFRETAZ;01340;01;AIN;1
01230;;Mantenay-Montlin;MANTENAY-MONTLIN;01560;01;AIN;1
01231;;Manziat;MANZIAT;01570;01;AIN;1
01232;;Marboz;MARBOZ;01851;01;AIN;1
01233;;Marchamp;MARCHAMP;01680;01;AIN;1
01234;;Marignieu;MARIGNIEU;01300;01;AIN;1
01235;;Marlieux;MARLIEUX;01240;01;AIN;1
01236;;Marsonnas;MARSONNAS;01340;01;AIN;1
01237;;Martignat;MARTIGNAT;01810;01;AIN;1
01238;;Massieux;MASSIEUX;01600;01;AIN;1
01239;;Massignieu-de-Rives;MASSIGNIEU-DE-RIVES;01300;01;AIN;1
01240;;Matafelon-Granges;MATAFELON-GRANGES;01580;01;AIN;1
01241;;Meillonnas;MEILLONNAS;01370;01;AIN;1
01242;;Mérignat;MERIGNAT;01450;01;AIN;1
01243;;Messimy-sur-Saône;MESSIMY-SUR-SAONE;01480;01;AIN;1
01244;;Meximieux;MEXIMIEUX;01800;01;AIN;1
01245;;Bohas-Meyriat-Rignat;BOHAS-MEYRIAT-RIGNAT;01250;01;AIN;1
01246;;Mézériat;MEZERIAT;01660;01;AIN;1
01247;;Mijoux;MIJOUX;01170;01;AIN;1
01248;;Mionnay;MIONNAY;01390;01;AIN;1
01249;;Miribel;MIRIBEL;01700;01;AIN;1
01250;;Misérieux;MISERIEUX;01600;01;AIN;1
01252;;Mogneneins;MOGNENEINS;01140;01;AIN;1
01254;;Montagnat;MONTAGNAT;01250;01;AIN;1
01255;;Montagnieu;MONTAGNIEU;01470;01;AIN;1
01257;;Montanges;MONTANGES;01200;01;AIN;1
01258;;Montceaux;MONTCEAUX;01090;01;AIN;1
01259;;Montcet;MONTCET;01310;01;AIN;1
01260;Le;Montellier;MONTELLIER;01800;01;AIN;1
01261;;Monthieux;MONTHIEUX;01390;01;AIN;1
01262;;Montluel;MONTLUEL;01120;01;AIN;1
01263;;Montmerle-sur-Saône;MONTMERLE-SUR-SAONE;01090;01;AIN;1
01264;;Montracol;MONTRACOL;01310;01;AIN;1
01265;;Montréal-la-Cluse;MONTREAL-LA-CLUSE;01460;01;AIN;1
01266;;Montrevel-en-Bresse;MONTREVEL-EN-BRESSE;01340;01;AIN;1
01267;;Nurieux-Volognat;NURIEUX-VOLOGNAT;01460;01;AIN;1
01268;;Murs-et-Gélignieux;MURS-ET-GELIGNIEUX;01300;01;AIN;1
01269;;Nantua;NANTUA;01130;01;AIN;1
01271;;Nattages;NATTAGES;01300;01;AIN;1
01272;;Neuville-les-Dames;NEUVILLE-LES-DAMES;01400;01;AIN;1
01273;;Neuville-sur-Ain;NEUVILLE-SUR-AIN;01160;01;AIN;1
01274;Les;Neyrolles;NEYROLLES;01130;01;AIN;1
01275;;Neyron;NEYRON;01700;01;AIN;1
01276;;Niévroz;NIEVROZ;01120;01;AIN;1
01277;;Nivollet-Montgriffon;NIVOLLET-MONTGRIFFON;01230;01;AIN;1
01279;;Oncieu;ONCIEU;01230;01;AIN;1
01280;;Ordonnaz;ORDONNAZ;01510;01;AIN;1
01281;;Ornex;ORNEX;01210;01;AIN;1
01282;;Outriaz;OUTRIAZ;01430;01;AIN;1
01283;;Oyonnax;OYONNAX;01100;01;AIN;1
01284;;Ozan;OZAN;01190;01;AIN;1
01285;;Parcieux;PARCIEUX;01600;01;AIN;1
01286;;Parves;PARVES;01300;01;AIN;1
01288;;Péron;PERON;01630;01;AIN;1
01289;;Péronnas;PERONNAS;01960;01;AIN;1
01290;;Pérouges;PEROUGES;01800;01;AIN;1
01291;;Perrex;PERREX;01540;01;AIN;1
01292;Le;Petit-Abergement;PETIT-ABERGEMENT;01260;01;AIN;1
01293;;Peyriat;PEYRIAT;01430;01;AIN;1
01294;;Peyrieu;PEYRIEU;01300;01;AIN;1
01295;;Peyzieux-sur-Saône;PEYZIEUX-SUR-SAONE;01140;01;AIN;1
01296;;Pirajoux;PIRAJOUX;01270;01;AIN;1
01297;;Pizay;PIZAY;01120;01;AIN;1
01298;;Plagne;PLAGNE;01130;01;AIN;1
01299;Le;Plantay;PLANTAY;01330;01;AIN;1
01300;Le;Poizat;POIZAT;01130;01;AIN;1
01301;;Polliat;POLLIAT;01310;01;AIN;1
01302;;Pollieu;POLLIEU;01350;01;AIN;1
01303;;Poncin;PONCIN;01450;01;AIN;1
01304;;Pont-d'Ain;PONT-D'AIN;01160;01;AIN;1
01305;;Pont-de-Vaux;PONT-DE-VAUX;01190;01;AIN;1
01306;;Pont-de-Veyle;PONT-DE-VEYLE;01290;01;AIN;1
01307;;Port;PORT;01460;01;AIN;1
01308;;Pougny;POUGNY;01550;01;AIN;1
01309;;Pouillat;POUILLAT;01250;01;AIN;1
01310;;Prémeyzel;PREMEYZEL;01300;01;AIN;1
01311;;Prémillieu;PREMILLIEU;01510;01;AIN;1
01312;;Pressiat;PRESSIAT;01370;01;AIN;1
01313;;Prévessin-Moëns;PREVESSIN-MOENS;01280;01;AIN;1
01314;;Priay;PRIAY;01160;01;AIN;1
01316;;Pugieu;PUGIEU;01510;01;AIN;1
01317;;Ramasse;RAMASSE;01250;01;AIN;1
01318;;Rancé;RANCE;01390;01;AIN;1
01319;;Relevant;RELEVANT;01990;01;AIN;1
01320;;Replonges;REPLONGES;01620;01;AIN;1
01321;;Revonnas;REVONNAS;01250;01;AIN;1
01322;;Reyrieux;REYRIEUX;01600;01;AIN;1
01323;;Reyssouze;REYSSOUZE;01190;01;AIN;1
01325;;Rignieux-le-Franc;RIGNIEUX-LE-FRANC;01800;01;AIN;1
01328;;Romans;ROMANS;01400;01;AIN;1
01329;;Rossillon;ROSSILLON;01510;01;AIN;1
01330;;Ruffieu;RUFFIEU;01260;01;AIN;1
01331;;Saint-Alban;SAINT-ALBAN;01450;01;AIN;1
01332;;Saint-André-de-Bâgé;SAINT-ANDRE-DE-BAGE;01380;01;AIN;1
01333;;Saint-André-de-Corcy;SAINT-ANDRE-DE-CORCY;01390;01;AIN;1
01334;;Saint-André-d'Huiriat;SAINT-ANDRE-D'HUIRIAT;01290;01;AIN;1
01335;;Saint-André-le-Bouchoux;SAINT-ANDRE-LE-BOUCHOUX;01240;01;AIN;1
01336;;Saint-André-sur-Vieux-Jonc;SAINT-ANDRE-SUR-VIEUX-JONC;01240;01;AIN;1
01337;;Saint-Bénigne;SAINT-BENIGNE;01190;01;AIN;1
01338;;Saint-Benoît;SAINT-BENOIT;01300;01;AIN;1
01339;;Saint-Bernard;SAINT-BERNARD;01600;01;AIN;1
01340;;Saint-Bois;SAINT-BOIS;01300;01;AIN;1
01341;;Saint-Champ;SAINT-CHAMP;01300;01;AIN;1
01342;;Sainte-Croix;SAINTE-CROIX;01120;01;AIN;1
01343;;Saint-Cyr-sur-Menthon;SAINT-CYR-SUR-MENTHON;01380;01;AIN;1
01344;;Saint-Denis-lès-Bourg;SAINT-DENIS-LES-BOURG;01000;01;AIN;1
01345;;Saint-Denis-en-Bugey;SAINT-DENIS-EN-BUGEY;01500;01;AIN;1
01346;;Saint-Didier-d'Aussiat;SAINT-DIDIER-D'AUSSIAT;01340;01;AIN;1
01347;;Saint-Didier-de-Formans;SAINT-DIDIER-DE-FORMANS;01600;01;AIN;1
01348;;Saint-Didier-sur-Chalaronne;SAINT-DIDIER-SUR-CHALARONNE;01140;01;AIN;1
01349;;Saint-Éloi;SAINT-ELOI;01800;01;AIN;1
01350;;Saint-Étienne-du-Bois;SAINT-ETIENNE-DU-BOIS;01370;01;AIN;1
01351;;Saint-Étienne-sur-Chalaronne;SAINT-ETIENNE-SUR-CHALARONNE;01140;01;AIN;1
01352;;Saint-Étienne-sur-Reyssouze;SAINT-ETIENNE-SUR-REYSSOUZE;01190;01;AIN;1
01353;;Sainte-Euphémie;SAINTE-EUPHEMIE;01600;01;AIN;1
01354;;Saint-Genis-Pouilly;SAINT-GENIS-POUILLY;01630;01;AIN;1
01355;;Saint-Genis-sur-Menthon;SAINT-GENIS-SUR-MENTHON;01380;01;AIN;1
01356;;Saint-Georges-sur-Renon;SAINT-GEORGES-SUR-RENON;01400;01;AIN;1
01357;;Saint-Germain-de-Joux;SAINT-GERMAIN-DE-JOUX;01130;01;AIN;1
01358;;Saint-Germain-les-Paroisses;SAINT-GERMAIN-LES-PAROISSES;01300;01;AIN;1
01359;;Saint-Germain-sur-Renon;SAINT-GERMAIN-SUR-RENON;01240;01;AIN;1
01360;;Saint-Jean-de-Gonville;SAINT-JEAN-DE-GONVILLE;01630;01;AIN;1
01361;;Saint-Jean-de-Niost;SAINT-JEAN-DE-NIOST;01800;01;AIN;1
01362;;Saint-Jean-de-Thurigneux;SAINT-JEAN-DE-THURIGNEUX;01390;01;AIN;1
01363;;Saint-Jean-le-Vieux;SAINT-JEAN-LE-VIEUX;01640;01;AIN;1
01364;;Saint-Jean-sur-Reyssouze;SAINT-JEAN-SUR-REYSSOUZE;01560;01;AIN;1
01365;;Saint-Jean-sur-Veyle;SAINT-JEAN-SUR-VEYLE;01290;01;AIN;1
01366;;Sainte-Julie;SAINTE-JULIE;01150;01;AIN;1
01367;;Saint-Julien-sur-Reyssouze;SAINT-JULIEN-SUR-REYSSOUZE;01560;01;AIN;1
01368;;Saint-Julien-sur-Veyle;SAINT-JULIEN-SUR-VEYLE;01540;01;AIN;1
01369;;Saint-Just;SAINT-JUST;01250;01;AIN;1
01370;;Saint-Laurent-sur-Saône;SAINT-LAURENT-SUR-SAONE;01620;01;AIN;1
01371;;Saint-Marcel;SAINT-MARCEL;01390;01;AIN;1
01372;;Saint-Martin-de-Bavel;SAINT-MARTIN-DE-BAVEL;01510;01;AIN;1
01373;;Saint-Martin-du-Frêne;SAINT-MARTIN-DU-FRENE;01430;01;AIN;1
01374;;Saint-Martin-du-Mont;SAINT-MARTIN-DU-MONT;01160;01;AIN;1
01375;;Saint-Martin-le-Châtel;SAINT-MARTIN-LE-CHATEL;01310;01;AIN;1
01376;;Saint-Maurice-de-Beynost;SAINT-MAURICE-DE-BEYNOST;01700;01;AIN;1
01378;;Saint-Maurice-de-Gourdans;SAINT-MAURICE-DE-GOURDANS;01800;01;AIN;1
01379;;Saint-Maurice-de-Rémens;SAINT-MAURICE-DE-REMENS;01500;01;AIN;1
01380;;Saint-Nizier-le-Bouchoux;SAINT-NIZIER-LE-BOUCHOUX;01560;01;AIN;1
01381;;Saint-Nizier-le-Désert;SAINT-NIZIER-LE-DESERT;01320;01;AIN;1
01382;;Sainte-Olive;SAINTE-OLIVE;01330;01;AIN;1
01383;;Saint-Paul-de-Varax;SAINT-PAUL-DE-VARAX;01240;01;AIN;1
01384;;Saint-Rambert-en-Bugey;SAINT-RAMBERT-EN-BUGEY;01230;01;AIN;1
01385;;Saint-Rémy;SAINT-REMY;01310;01;AIN;1
01386;;Saint-Sorlin-en-Bugey;SAINT-SORLIN-EN-BUGEY;01150;01;AIN;1
01387;;Saint-Sulpice;SAINT-SULPICE;01340;01;AIN;1
01388;;Saint-Trivier-de-Courtes;SAINT-TRIVIER-DE-COURTES;01560;01;AIN;1
01389;;Saint-Trivier-sur-Moignans;SAINT-TRIVIER-SUR-MOIGNANS;01990;01;AIN;1
01390;;Saint-Vulbas;SAINT-VULBAS;01150;01;AIN;1
01391;;Salavre;SALAVRE;01270;01;AIN;1
01392;;Samognat;SAMOGNAT;01580;01;AIN;1
01393;;Sandrans;SANDRANS;01400;01;AIN;1
01396;;Sault-Brénaz;SAULT-BRENAZ;01150;01;AIN;1
01397;;Sauverny;SAUVERNY;01220;01;AIN;1
01398;;Savigneux;SAVIGNEUX;01480;01;AIN;1
01399;;Ségny;SEGNY;01170;01;AIN;1
01400;;Seillonnaz;SEILLONNAZ;01470;01;AIN;1
01401;;Sergy;SERGY;01630;01;AIN;1
01402;;Sermoyer;SERMOYER;01190;01;AIN;1
01403;;Serrières-de-Briord;SERRIERES-DE-BRIORD;01470;01;AIN;1
01404;;Serrières-sur-Ain;SERRIERES-SUR-AIN;01450;01;AIN;1
01405;;Servas;SERVAS;01240;01;AIN;1
01406;;Servignat;SERVIGNAT;01560;01;AIN;1
01407;;Seyssel;SEYSSEL;01420;01;AIN;1
01408;;Simandre-sur-Suran;SIMANDRE-SUR-SURAN;01250;01;AIN;1
01409;;Songieu;SONGIEU;01260;01;AIN;1
01410;;Sonthonnax-la-Montagne;SONTHONNAX-LA-MONTAGNE;01580;01;AIN;1
01411;;Souclin;SOUCLIN;01150;01;AIN;1
01412;;Sulignat;SULIGNAT;01400;01;AIN;1
01413;;Surjoux;SURJOUX;01420;01;AIN;1
01414;;Sutrieu;SUTRIEU;01260;01;AIN;1
01415;;Talissieu;TALISSIEU;01510;01;AIN;1
01416;;Tenay;TENAY;01230;01;AIN;1
01417;;Thézillieu;THEZILLIEU;01110;01;AIN;1
01418;;Thil;THIL;01120;01;AIN;1
01419;;Thoiry;THOIRY;01710;01;AIN;1
01420;;Thoissey;THOISSEY;01140;01;AIN;1
01421;;Torcieu;TORCIEU;01230;01;AIN;1
01422;;Tossiat;TOSSIAT;01250;01;AIN;1
01423;;Toussieux;TOUSSIEUX;01600;01;AIN;1
01424;;Tramoyes;TRAMOYES;01390;01;AIN;1
01425;La;Tranclière;TRANCLIERE;01160;01;AIN;1
01426;;Treffort-Cuisiat;TREFFORT-CUISIAT;01370;01;AIN;1
01427;;Trévoux;TREVOUX;01600;01;AIN;1
01428;;Valeins;VALEINS;01140;01;AIN;1
01429;;Vandeins;VANDEINS;01660;01;AIN;1
01430;;Varambon;VARAMBON;01160;01;AIN;1
01431;;Vaux-en-Bugey;VAUX-EN-BUGEY;01150;01;AIN;1
01432;;Verjon;VERJON;01270;01;AIN;1
01433;;Vernoux;VERNOUX;01560;01;AIN;1
01434;;Versailleux;VERSAILLEUX;01330;01;AIN;1
01435;;Versonnex;VERSONNEX;01210;01;AIN;1
01436;;Vesancy;VESANCY;01170;01;AIN;1
01437;;Vescours;VESCOURS;01560;01;AIN;1
01439;;Vésines;VESINES;01570;01;AIN;1
01441;;Vieu-d'Izenave;VIEU-D'IZENAVE;01430;01;AIN;1
01442;;Vieu;VIEU;01260;01;AIN;1
01443;;Villars-les-Dombes;VILLARS-LES-DOMBES;01330;01;AIN;1
01444;;Villebois;VILLEBOIS;01150;01;AIN;1
01445;;Villemotier;VILLEMOTIER;01270;01;AIN;1
01446;;Villeneuve;VILLENEUVE;01480;01;AIN;1
01447;;Villereversure;VILLEREVERSURE;01250;01;AIN;1
01448;;Villes;VILLES;01200;01;AIN;1
01449;;Villette-sur-Ain;VILLETTE-SUR-AIN;01320;01;AIN;1
01450;;Villieu-Loyes-Mollon;VILLIEU-LOYES-MOLLON;01800;01;AIN;1
01451;;Viriat;VIRIAT;01440;01;AIN;1
01452;;Virieu-le-Grand;VIRIEU-LE-GRAND;01510;01;AIN;1
01453;;Virieu-le-Petit;VIRIEU-LE-PETIT;01260;01;AIN;1
01454;;Virignin;VIRIGNIN;01300;01;AIN;1
01456;;Vongnes;VONGNES;01350;01;AIN;1
01457;;Vonnas;VONNAS;01540;01;AIN;1
02001;;Abbécourt;ABBECOURT;02300;02;AISNE;1
02002;;Achery;ACHERY;02800;02;AISNE;1
02003;;Acy;ACY;02200;02;AISNE;1
02004;;Agnicourt-et-Séchelles;AGNICOURT-ET-SECHELLES;02340;02;AISNE;1
02005;;Aguilcourt;AGUILCOURT;02190;02;AISNE;1
02006;;Aisonville-et-Bernoville;AISONVILLE-ET-BERNOVILLE;02110;02;AISNE;1
02007;;Aizelles;AIZELLES;02820;02;AISNE;1
02008;;Aizy-Jouy;AIZY-JOUY;02370;02;AISNE;1
02009;;Alaincourt;ALAINCOURT;02240;02;AISNE;1
02010;;Allemant;ALLEMANT;02320;02;AISNE;1
02011;;Ambleny;AMBLENY;02290;02;AISNE;1
02012;;Ambrief;AMBRIEF;02200;02;AISNE;1
02013;;Amifontaine;AMIFONTAINE;02190;02;AISNE;1
02014;;Amigny-Rouy;AMIGNY-ROUY;02700;02;AISNE;1
02015;;Ancienville;ANCIENVILLE;02600;02;AISNE;1
02016;;Andelain;ANDELAIN;02800;02;AISNE;1
02017;;Anguilcourt-le-Sart;ANGUILCOURT-LE-SART;02800;02;AISNE;1
02018;;Anizy-le-Château;ANIZY-LE-CHATEAU;02320;02;AISNE;1
02019;;Annois;ANNOIS;02480;02;AISNE;1
02020;;Any-Martin-Rieux;ANY-MARTIN-RIEUX;02500;02;AISNE;1
02021;;Archon;ARCHON;02360;02;AISNE;1
02022;;Arcy-Sainte-Restitue;ARCY-SAINTE-RESTITUE;02130;02;AISNE;1
02023;;Armentières-sur-Ourcq;ARMENTIERES-SUR-OURCQ;02210;02;AISNE;1
02024;;Arrancy;ARRANCY;02860;02;AISNE;1
02025;;Artemps;ARTEMPS;02480;02;AISNE;1
02026;;Artonges;ARTONGES;02330;02;AISNE;1
02027;;Assis-sur-Serre;ASSIS-SUR-SERRE;02270;02;AISNE;1
02028;;Athies-sous-Laon;ATHIES-SOUS-LAON;02840;02;AISNE;1
02029;;Attilly;ATTILLY;02490;02;AISNE;1
02030;;Aubencheul-aux-Bois;AUBENCHEUL-AUX-BOIS;02420;02;AISNE;1
02031;;Aubenton;AUBENTON;02500;02;AISNE;1
02032;;Aubigny-aux-Kaisnes;AUBIGNY-AUX-KAISNES;02590;02;AISNE;1
02033;;Aubigny-en-Laonnois;AUBIGNY-EN-LAONNOIS;02820;02;AISNE;1
02034;;Audignicourt;AUDIGNICOURT;02300;02;AISNE;1
02035;;Audigny;AUDIGNY;02120;02;AISNE;1
02036;;Augy;AUGY;02220;02;AISNE;1
02037;;Aulnois-sous-Laon;AULNOIS-SOUS-LAON;02000;02;AISNE;1
02038;Les;Autels;AUTELS;02360;02;AISNE;1
02039;;Autremencourt;AUTREMENCOURT;02250;02;AISNE;1
02040;;Autreppes;AUTREPPES;02580;02;AISNE;1
02041;;Autreville;AUTREVILLE;02300;02;AISNE;1
02042;;Azy-sur-Marne;AZY-SUR-MARNE;02400;02;AISNE;1
02043;;Bagneux;BAGNEUX;02290;02;AISNE;1
02044;;Bancigny;BANCIGNY;02140;02;AISNE;1
02046;;Barenton-Bugny;BARENTON-BUGNY;02000;02;AISNE;1
02047;;Barenton-Cel;BARENTON-CEL;02000;02;AISNE;1
02048;;Barenton-sur-Serre;BARENTON-SUR-SERRE;02270;02;AISNE;1
02049;;Barisis;BARISIS;02700;02;AISNE;1
02050;;Barzy-en-Thiérache;BARZY-EN-THIERACHE;02170;02;AISNE;1
02051;;Barzy-sur-Marne;BARZY-SUR-MARNE;02850;02;AISNE;1
02052;;Bassoles-Aulers;BASSOLES-AULERS;02380;02;AISNE;1
02053;;Baulne-en-Brie;BAULNE-EN-BRIE;02330;02;AISNE;1
02054;;Bazoches-sur-Vesles;BAZOCHES-SUR-VESLES;02220;02;AISNE;1
02055;;Beaumé;BEAUME;02500;02;AISNE;1
02056;;Beaumont-en-Beine;BEAUMONT-EN-BEINE;02300;02;AISNE;1
02057;;Beaurevoir;BEAUREVOIR;02110;02;AISNE;1
02058;;Beaurieux;BEAURIEUX;02160;02;AISNE;1
02059;;Beautor;BEAUTOR;02800;02;AISNE;1
02060;;Beauvois-en-Vermandois;BEAUVOIS-EN-VERMANDOIS;02590;02;AISNE;1
02061;;Becquigny;BECQUIGNY;02110;02;AISNE;1
02062;;Belleau;BELLEAU;02400;02;AISNE;1
02063;;Bellenglise;BELLENGLISE;02420;02;AISNE;1
02064;;Belleu;BELLEU;02200;02;AISNE;1
02065;;Bellicourt;BELLICOURT;02420;02;AISNE;1
02066;;Benay;BENAY;02440;02;AISNE;1
02067;;Bergues-sur-Sambre;BERGUES-SUR-SAMBRE;02450;02;AISNE;1
02068;;Berlancourt;BERLANCOURT;02250;02;AISNE;1
02069;;Berlise;BERLISE;02340;02;AISNE;1
02070;;Bernot;BERNOT;02120;02;AISNE;1
02071;;Berny-Rivière;BERNY-RIVIERE;02290;02;AISNE;1
02072;;Berrieux;BERRIEUX;02820;02;AISNE;1
02073;;Berry-au-Bac;BERRY-AU-BAC;02190;02;AISNE;1
02074;;Bertaucourt-Epourdon;BERTAUCOURT-EPOURDON;02800;02;AISNE;1
02075;;Berthenicourt;BERTHENICOURT;02240;02;AISNE;1
02076;;Bertricourt;BERTRICOURT;02190;02;AISNE;1
02077;;Berzy-le-Sec;BERZY-LE-SEC;02200;02;AISNE;1
02078;;Besmé;BESME;02300;02;AISNE;1
02079;;Besmont;BESMONT;02500;02;AISNE;1
02080;;Besny-et-Loizy;BESNY-ET-LOIZY;02870;02;AISNE;1
02081;;Béthancourt-en-Vaux;BETHANCOURT-EN-VAUX;02300;02;AISNE;1
02082;;Beugneux;BEUGNEUX;02210;02;AISNE;1
02083;;Beuvardes;BEUVARDES;02130;02;AISNE;1
02084;;Bézu-le-Guéry;BEZU-LE-GUERY;02310;02;AISNE;1
02085;;Bézu-Saint-Germain;BEZU-SAINT-GERMAIN;02400;02;AISNE;1
02086;;Bichancourt;BICHANCOURT;02300;02;AISNE;1
02087;;Bieuxy;BIEUXY;02290;02;AISNE;1
02088;;Bièvres;BIEVRES;02860;02;AISNE;1
02089;;Billy-sur-Aisne;BILLY-SUR-AISNE;02200;02;AISNE;1
02090;;Billy-sur-Ourcq;BILLY-SUR-OURCQ;02210;02;AISNE;1
02091;;Blanzy-lès-Fismes;BLANZY-LES-FISMES;02160;02;AISNE;1
02093;;Blérancourt;BLERANCOURT;02300;02;AISNE;1
02094;;Blesmes;BLESMES;02400;02;AISNE;1
02095;;Bohain-en-Vermandois;BOHAIN-EN-VERMANDOIS;02110;02;AISNE;1
02096;;Bois-lès-Pargny;BOIS-LES-PARGNY;02270;02;AISNE;1
02097;;Boncourt;BONCOURT;02350;02;AISNE;1
02098;;Bonneil;BONNEIL;02400;02;AISNE;1
02099;;Bonnesvalyn;BONNESVALYN;02400;02;AISNE;1
02100;;Bony;BONY;02420;02;AISNE;1
02101;;Bosmont-sur-Serre;BOSMONT-SUR-SERRE;02250;02;AISNE;1
02102;;Bouconville-Vauclair;BOUCONVILLE-VAUCLAIR;02860;02;AISNE;1
02103;;Boué;BOUE;02450;02;AISNE;1
02104;;Bouffignereux;BOUFFIGNEREUX;02160;02;AISNE;1
02105;;Bouresches;BOURESCHES;02400;02;AISNE;1
02106;;Bourg-et-Comin;BOURG-ET-COMIN;02160;02;AISNE;1
02107;;Bourguignon-sous-Coucy;BOURGUIGNON-SOUS-COUCY;02300;02;AISNE;1
02108;;Bourguignon-sous-Montbavin;BOURGUIGNON-SOUS-MONTBAVIN;02000;02;AISNE;1
02109;La;Bouteille;BOUTEILLE;02140;02;AISNE;1
02110;;Braine;BRAINE;02220;02;AISNE;1
02111;;Brancourt-en-Laonnois;BRANCOURT-EN-LAONNOIS;02320;02;AISNE;1
02112;;Brancourt-le-Grand;BRANCOURT-LE-GRAND;02110;02;AISNE;1
02114;;Brasles;BRASLES;02400;02;AISNE;1
02115;;Braye-en-Laonnois;BRAYE-EN-LAONNOIS;02000;02;AISNE;1
02116;;Braye-en-Thiérache;BRAYE-EN-THIERACHE;02140;02;AISNE;1
02117;;Bray-Saint-Christophe;BRAY-SAINT-CHRISTOPHE;02480;02;AISNE;1
02118;;Braye;BRAYE;02880;02;AISNE;1
02119;;Brécy;BRECY;02210;02;AISNE;1
02120;;Brenelle;BRENELLE;02220;02;AISNE;1
02121;;Breny;BRENY;02210;02;AISNE;1
02122;;Brie;BRIE;02870;02;AISNE;1
02123;;Brissay-Choigny;BRISSAY-CHOIGNY;02240;02;AISNE;1
02124;;Brissy-Hamégicourt;BRISSY-HAMEGICOURT;02240;02;AISNE;1
02125;;Brumetz;BRUMETZ;02810;02;AISNE;1
02126;;Brunehamel;BRUNEHAMEL;02360;02;AISNE;1
02127;;Bruyères-sur-Fère;BRUYERES-SUR-FERE;02130;02;AISNE;1
02128;;Bruyères-et-Montbérault;BRUYERES-ET-MONTBERAULT;02860;02;AISNE;1
02129;;Bruys;BRUYS;02220;02;AISNE;1
02130;;Bucilly;BUCILLY;02500;02;AISNE;1
02131;;Bucy-le-Long;BUCY-LE-LONG;02880;02;AISNE;1
02132;;Bucy-lès-Cerny;BUCY-LES-CERNY;02870;02;AISNE;1
02133;;Bucy-lès-Pierrepont;BUCY-LES-PIERREPONT;02350;02;AISNE;1
02134;;Buire;BUIRE;02500;02;AISNE;1
02135;;Buironfosse;BUIRONFOSSE;02620;02;AISNE;1
02136;;Burelles;BURELLES;02140;02;AISNE;1
02137;;Bussiares;BUSSIARES;02810;02;AISNE;1
02138;;Buzancy;BUZANCY;02200;02;AISNE;1
02139;;Caillouël-Crépigny;CAILLOUEL-CREPIGNY;02300;02;AISNE;1
02140;;Camelin;CAMELIN;02300;02;AISNE;1
02141;La;Capelle;CAPELLE;02260;02;AISNE;1
02142;;Castres;CASTRES;02680;02;AISNE;1
02143;Le;Catelet;CATELET;02420;02;AISNE;1
02144;;Caulaincourt;CAULAINCOURT;02490;02;AISNE;1
02145;;Caumont;CAUMONT;02300;02;AISNE;1
02146;;Celles-lès-Condé;CELLES-LES-CONDE;02330;02;AISNE;1
02147;La;Celle-sous-Montmirail;CELLE-SOUS-MONTMIRAIL;02540;02;AISNE;1
02148;;Celles-sur-Aisne;CELLES-SUR-AISNE;02370;02;AISNE;1
02149;;Cerizy;CERIZY;02240;02;AISNE;1
02150;;Cerny-en-Laonnois;CERNY-EN-LAONNOIS;02860;02;AISNE;1
02151;;Cerny-lès-Bucy;CERNY-LES-BUCY;02870;02;AISNE;1
02152;;Cerseuil;CERSEUIL;02220;02;AISNE;1
02153;;Cessières;CESSIERES;02320;02;AISNE;1
02154;;Chacrise;CHACRISE;02200;02;AISNE;1
02155;;Chaillevois;CHAILLEVOIS;02000;02;AISNE;1
02156;;Chalandry;CHALANDRY;02270;02;AISNE;1
02157;;Chambry;CHAMBRY;02000;02;AISNE;1
02158;;Chamouille;CHAMOUILLE;02860;02;AISNE;1
02159;;Champs;CHAMPS;02670;02;AISNE;1
02160;;Chaourse;CHAOURSE;02340;02;AISNE;1
02161;La;Chapelle-Monthodon;CHAPELLE-MONTHODON;02330;02;AISNE;1
02162;La;Chapelle-sur-Chézy;CHAPELLE-SUR-CHEZY;02570;02;AISNE;1
02163;;Charly-sur-Marne;CHARLY-SUR-MARNE;02310;02;AISNE;1
02164;Le;Charmel;CHARMEL;02850;02;AISNE;1
02165;;Charmes;CHARMES;02800;02;AISNE;1
02166;;Chartèves;CHARTEVES;02400;02;AISNE;1
02167;;Chassemy;CHASSEMY;02370;02;AISNE;1
02168;;Château-Thierry;CHATEAU-THIERRY;02400;02;AISNE;1
02169;;Châtillon-lès-Sons;CHATILLON-LES-SONS;02270;02;AISNE;1
02170;;Châtillon-sur-Oise;CHATILLON-SUR-OISE;02240;02;AISNE;1
02171;;Chaudardes;CHAUDARDES;02160;02;AISNE;1
02172;;Chaudun;CHAUDUN;02200;02;AISNE;1
02173;;Chauny;CHAUNY;02300;02;AISNE;1
02174;;Chavignon;CHAVIGNON;02000;02;AISNE;1
02175;;Chavigny;CHAVIGNY;02880;02;AISNE;1
02176;;Chavonne;CHAVONNE;02370;02;AISNE;1
02177;;Chérêt;CHERET;02860;02;AISNE;1
02178;;Chermizy-Ailles;CHERMIZY-AILLES;02860;02;AISNE;1
02179;;Chéry-Chartreuve;CHERY-CHARTREUVE;02220;02;AISNE;1
02180;;Chéry-lès-Pouilly;CHERY-LES-POUILLY;02000;02;AISNE;1
02181;;Chéry-lès-Rozoy;CHERY-LES-ROZOY;02360;02;AISNE;1
02182;;Chevennes;CHEVENNES;02250;02;AISNE;1
02183;;Chevregny;CHEVREGNY;02000;02;AISNE;1
02184;;Chevresis-Monceau;CHEVRESIS-MONCEAU;02270;02;AISNE;1
02185;;Chézy-en-Orxois;CHEZY-EN-ORXOIS;02810;02;AISNE;1
02186;;Chézy-sur-Marne;CHEZY-SUR-MARNE;02570;02;AISNE;1
02187;;Chierry;CHIERRY;02400;02;AISNE;1
02188;;Chigny;CHIGNY;02120;02;AISNE;1
02189;;Chivres-en-Laonnois;CHIVRES-EN-LAONNOIS;02350;02;AISNE;1
02190;;Chivres-Val;CHIVRES-VAL;02880;02;AISNE;1
02191;;Chivy-lès-Étouvelles;CHIVY-LES-ETOUVELLES;02000;02;AISNE;1
02192;;Chouy;CHOUY;02210;02;AISNE;1
02193;;Cierges;CIERGES;02130;02;AISNE;1
02194;;Cilly;CILLY;02250;02;AISNE;1
02195;;Ciry-Salsogne;CIRY-SALSOGNE;02220;02;AISNE;1
02196;;Clacy-et-Thierret;CLACY-ET-THIERRET;02000;02;AISNE;1
02197;;Clairfontaine;CLAIRFONTAINE;02260;02;AISNE;1
02198;;Clamecy;CLAMECY;02880;02;AISNE;1
02199;;Clastres;CLASTRES;02440;02;AISNE;1
02200;;Clermont-les-Fermes;CLERMONT-LES-FERMES;02340;02;AISNE;1
02201;;Cœuvres-et-Valsery;COEUVRES-ET-VALSERY;02600;02;AISNE;1
02203;;Coincy;COINCY;02210;02;AISNE;1
02204;;Coingt;COINGT;02360;02;AISNE;1
02205;;Colligis-Crandelain;COLLIGIS-CRANDELAIN;02860;02;AISNE;1
02206;;Colonfay;COLONFAY;02120;02;AISNE;1
02207;;Commenchon;COMMENCHON;02300;02;AISNE;1
02208;;Concevreux;CONCEVREUX;02160;02;AISNE;1
02209;;Condé-en-Brie;CONDE-EN-BRIE;02330;02;AISNE;1
02210;;Condé-sur-Aisne;CONDE-SUR-AISNE;02370;02;AISNE;1
02211;;Condé-sur-Suippe;CONDE-SUR-SUIPPE;02190;02;AISNE;1
02212;;Condren;CONDREN;02700;02;AISNE;1
02213;;Connigis;CONNIGIS;02330;02;AISNE;1
02214;;Contescourt;CONTESCOURT;02680;02;AISNE;1
02215;;Corbeny;CORBENY;02820;02;AISNE;1
02216;;Corcy;CORCY;02600;02;AISNE;1
02217;;Coucy-le-Château-Auffrique;COUCY-LE-CHATEAU-AUFFRIQUE;02380;02;AISNE;1
02218;;Coucy-lès-Eppes;COUCY-LES-EPPES;02840;02;AISNE;1
02219;;Coucy-la-Ville;COUCY-LA-VILLE;02380;02;AISNE;1
02220;;Coulonges-Cohan;COULONGES-COHAN;02130;02;AISNE;1
02221;;Coupru;COUPRU;02310;02;AISNE;1
02222;;Courbes;COURBES;02800;02;AISNE;1
02223;;Courboin;COURBOIN;02330;02;AISNE;1
02224;;Courcelles-sur-Vesle;COURCELLES-SUR-VESLE;02220;02;AISNE;1
02225;;Courchamps;COURCHAMPS;02810;02;AISNE;1
02226;;Courmelles;COURMELLES;02200;02;AISNE;1
02227;;Courmont;COURMONT;02130;02;AISNE;1
02228;;Courtemont-Varennes;COURTEMONT-VARENNES;02850;02;AISNE;1
02229;;Courtrizy-et-Fussigny;COURTRIZY-ET-FUSSIGNY;02820;02;AISNE;1
02230;;Couvrelles;COUVRELLES;02220;02;AISNE;1
02231;;Couvron-et-Aumencourt;COUVRON-ET-AUMENCOURT;02270;02;AISNE;1
02232;;Coyolles;COYOLLES;02600;02;AISNE;1
02233;;Cramaille;CRAMAILLE;02130;02;AISNE;1
02234;;Craonne;CRAONNE;02160;02;AISNE;1
02235;;Craonnelle;CRAONNELLE;02160;02;AISNE;1
02236;;Crécy-au-Mont;CRECY-AU-MONT;02380;02;AISNE;1
02237;;Crécy-sur-Serre;CRECY-SUR-SERRE;02270;02;AISNE;1
02238;;Crépy;CREPY;02870;02;AISNE;1
02239;;Crézancy;CREZANCY;02650;02;AISNE;1
02240;;Croix-Fonsomme;CROIX-FONSOMME;02110;02;AISNE;1
02241;La;Croix-sur-Ourcq;CROIX-SUR-OURCQ;02210;02;AISNE;1
02242;;Crouttes-sur-Marne;CROUTTES-SUR-MARNE;02310;02;AISNE;1
02243;;Crouy;CROUY;02880;02;AISNE;1
02244;;Crupilly;CRUPILLY;02120;02;AISNE;1
02245;;Cuffies;CUFFIES;02880;02;AISNE;1
02246;;Cugny;CUGNY;02480;02;AISNE;1
02248;;Cuirieux;CUIRIEUX;02350;02;AISNE;1
02249;;Cuiry-Housse;CUIRY-HOUSSE;02220;02;AISNE;1
02250;;Cuiry-lès-Chaudardes;CUIRY-LES-CHAUDARDES;02160;02;AISNE;1
02251;;Cuiry-lès-Iviers;CUIRY-LES-IVIERS;02360;02;AISNE;1
02252;;Cuissy-et-Geny;CUISSY-ET-GENY;02160;02;AISNE;1
02253;;Cuisy-en-Almont;CUISY-EN-ALMONT;02200;02;AISNE;1
02254;;Cutry;CUTRY;02600;02;AISNE;1
02255;;Cys-la-Commune;CYS-LA-COMMUNE;02220;02;AISNE;1
02256;;Dagny-Lambercy;DAGNY-LAMBERCY;02140;02;AISNE;1
02257;;Dallon;DALLON;02680;02;AISNE;1
02258;;Dammard;DAMMARD;02470;02;AISNE;1
02259;;Dampleux;DAMPLEUX;02600;02;AISNE;1
02260;;Danizy;DANIZY;02800;02;AISNE;1
02261;;Dercy;DERCY;02270;02;AISNE;1
02262;;Deuillet;DEUILLET;02700;02;AISNE;1
02263;;Dhuizel;DHUIZEL;02220;02;AISNE;1
02264;;Dizy-le-Gros;DIZY-LE-GROS;02340;02;AISNE;1
02265;;Dohis;DOHIS;02360;02;AISNE;1
02266;;Dolignon;DOLIGNON;02360;02;AISNE;1
02267;;Dommiers;DOMMIERS;02600;02;AISNE;1
02268;;Domptin;DOMPTIN;02310;02;AISNE;1
02269;;Dorengt;DORENGT;02450;02;AISNE;1
02270;;Douchy;DOUCHY;02590;02;AISNE;1
02271;;Dravegny;DRAVEGNY;02130;02;AISNE;1
02272;;Droizy;DROIZY;02210;02;AISNE;1
02273;;Dury;DURY;02480;02;AISNE;1
02274;;Ébouleau;EBOULEAU;02350;02;AISNE;1
02275;;Effry;EFFRY;02500;02;AISNE;1
02276;;Englancourt;ENGLANCOURT;02260;02;AISNE;1
02277;;Épagny;EPAGNY;02290;02;AISNE;1
02278;;Éparcy;EPARCY;02500;02;AISNE;1
02279;;Épaux-Bézu;EPAUX-BEZU;02400;02;AISNE;1
02280;;Épieds;EPIEDS;02400;02;AISNE;1
02281;L';Épine-aux-Bois;EPINE-AUX-BOIS;02540;02;AISNE;1
02282;;Eppes;EPPES;02840;02;AISNE;1
02283;;Erlon;ERLON;02250;02;AISNE;1
02284;;Erloy;ERLOY;02260;02;AISNE;1
02286;;Esquéhéries;ESQUEHERIES;02170;02;AISNE;1
02287;;Essigny-le-Grand;ESSIGNY-LE-GRAND;02690;02;AISNE;1
02288;;Essigny-le-Petit;ESSIGNY-LE-PETIT;02100;02;AISNE;1
02289;;Essises;ESSISES;02570;02;AISNE;1
02290;;Essômes-sur-Marne;ESSOMES-SUR-MARNE;02400;02;AISNE;1
02291;;Estrées;ESTREES;02420;02;AISNE;1
02292;;Étampes-sur-Marne;ETAMPES-SUR-MARNE;02400;02;AISNE;1
02293;;Étaves-et-Bocquiaux;ETAVES-ET-BOCQUIAUX;02110;02;AISNE;1
02294;;Étouvelles;ETOUVELLES;02000;02;AISNE;1
02295;;Étréaupont;ETREAUPONT;02580;02;AISNE;1
02296;;Étreillers;ETREILLERS;02590;02;AISNE;1
02297;;Étrépilly;ETREPILLY;02400;02;AISNE;1
02298;;Étreux;ETREUX;02510;02;AISNE;1
02299;;Évergnicourt;EVERGNICOURT;02190;02;AISNE;1
02301;;Faucoucourt;FAUCOUCOURT;02320;02;AISNE;1
02302;;Faverolles;FAVEROLLES;02600;02;AISNE;1
02303;;Fayet;FAYET;02100;02;AISNE;1
02304;La;Fère;FERE;02800;02;AISNE;1
02305;;Fère-en-Tardenois;FERE-EN-TARDENOIS;02130;02;AISNE;1
02306;La;Ferté-Chevresis;FERTE-CHEVRESIS;02270;02;AISNE;1
02307;La;Ferté-Milon;FERTE-MILON;02460;02;AISNE;1
02308;;Fesmy-le-Sart;FESMY-LE-SART;02450;02;AISNE;1
02309;;Festieux;FESTIEUX;02840;02;AISNE;1
02310;;Fieulaine;FIEULAINE;02110;02;AISNE;1
02311;;Filain;FILAIN;02000;02;AISNE;1
02312;La;Flamengrie;FLAMENGRIE;02260;02;AISNE;1
02313;;Flavigny-le-Grand-et-Beaurain;FLAVIGNY-LE-GRAND-ET-BEAURAIN;02120;02;AISNE;1
02315;;Flavy-le-Martel;FLAVY-LE-MARTEL;02520;02;AISNE;1
02316;;Fleury;FLEURY;02600;02;AISNE;1
02317;;Fluquières;FLUQUIERES;02590;02;AISNE;1
02318;;Folembray;FOLEMBRAY;02670;02;AISNE;1
02319;;Fonsomme;FONSOMME;02110;02;AISNE;1
02320;;Fontaine-lès-Clercs;FONTAINE-LES-CLERCS;02680;02;AISNE;1
02321;;Fontaine-lès-Vervins;FONTAINE-LES-VERVINS;02140;02;AISNE;1
02322;;Fontaine-Notre-Dame;FONTAINE-NOTRE-DAME;02110;02;AISNE;1
02323;;Fontaine-Uterte;FONTAINE-UTERTE;02110;02;AISNE;1
02324;;Fontenelle;FONTENELLE;02170;02;AISNE;1
02325;;Fontenelle-en-Brie;FONTENELLE-EN-BRIE;02540;02;AISNE;1
02326;;Fontenoy;FONTENOY;02290;02;AISNE;1
02327;;Foreste;FORESTE;02590;02;AISNE;1
02328;;Fossoy;FOSSOY;02650;02;AISNE;1
02329;;Fourdrain;FOURDRAIN;02870;02;AISNE;1
02330;;Francilly-Selency;FRANCILLY-SELENCY;02760;02;AISNE;1
02331;;Franqueville;FRANQUEVILLE;02140;02;AISNE;1
02332;;Fresnes-en-Tardenois;FRESNES-EN-TARDENOIS;02130;02;AISNE;1
02333;;Fresnes;FRESNES;02380;02;AISNE;1
02334;;Fresnoy-le-Grand;FRESNOY-LE-GRAND;02230;02;AISNE;1
02335;;Fressancourt;FRESSANCOURT;02800;02;AISNE;1
02336;;Frières-Faillouël;FRIERES-FAILLOUEL;02700;02;AISNE;1
02337;;Froidestrées;FROIDESTREES;02260;02;AISNE;1
02338;;Froidmont-Cohartille;FROIDMONT-COHARTILLE;02270;02;AISNE;1
02339;;Gandelu;GANDELU;02810;02;AISNE;1
02340;;Gauchy;GAUCHY;02430;02;AISNE;1
02341;;Gercy;GERCY;02140;02;AISNE;1
02342;;Gergny;GERGNY;02260;02;AISNE;1
02343;;Germaine;GERMAINE;02590;02;AISNE;1
02344;;Gernicourt;GERNICOURT;02160;02;AISNE;1
02345;;Gibercourt;GIBERCOURT;02440;02;AISNE;1
02346;;Gizy;GIZY;02350;02;AISNE;1
02347;;Gland;GLAND;02400;02;AISNE;1
02348;;Glennes;GLENNES;02160;02;AISNE;1
02349;;Goudelancourt-lès-Berrieux;GOUDELANCOURT-LES-BERRIEUX;02820;02;AISNE;1
02350;;Goudelancourt-lès-Pierrepont;GOUDELANCOURT-LES-PIERREPONT;02350;02;AISNE;1
02351;;Goussancourt;GOUSSANCOURT;02130;02;AISNE;1
02352;;Gouy;GOUY;02420;02;AISNE;1
02353;;Grandlup-et-Fay;GRANDLUP-ET-FAY;02350;02;AISNE;1
02354;;Grandrieux;GRANDRIEUX;02360;02;AISNE;1
02355;;Gricourt;GRICOURT;02100;02;AISNE;1
02356;;Grisolles;GRISOLLES;02210;02;AISNE;1
02357;;Gronard;GRONARD;02140;02;AISNE;1
02358;;Grougis;GROUGIS;02110;02;AISNE;1
02359;;Grugies;GRUGIES;02680;02;AISNE;1
02360;;Guignicourt;GUIGNICOURT;02190;02;AISNE;1
02361;;Guise;GUISE;02120;02;AISNE;1
02362;;Guivry;GUIVRY;02300;02;AISNE;1
02363;;Guny;GUNY;02300;02;AISNE;1
02364;;Guyencourt;GUYENCOURT;02160;02;AISNE;1
02366;;Hannapes;HANNAPES;02510;02;AISNE;1
02367;;Happencourt;HAPPENCOURT;02480;02;AISNE;1
02368;;Haramont;HARAMONT;02600;02;AISNE;1
02369;;Harcigny;HARCIGNY;02140;02;AISNE;1
02370;;Hargicourt;HARGICOURT;02420;02;AISNE;1
02371;;Harly;HARLY;02100;02;AISNE;1
02372;;Hartennes-et-Taux;HARTENNES-ET-TAUX;02210;02;AISNE;1
02373;;Hary;HARY;02140;02;AISNE;1
02374;;Lehaucourt;LEHAUCOURT;02420;02;AISNE;1
02375;;Hautevesnes;HAUTEVESNES;02810;02;AISNE;1
02376;;Hauteville;HAUTEVILLE;02120;02;AISNE;1
02377;;Haution;HAUTION;02140;02;AISNE;1
02378;La;Hérie;HERIE;02500;02;AISNE;1
02379;Le;Hérie-la-Viéville;HERIE-LA-VIEVILLE;02120;02;AISNE;1
02380;;Hinacourt;HINACOURT;02440;02;AISNE;1
02381;;Hirson;HIRSON;02500;02;AISNE;1
02382;;Holnon;HOLNON;02760;02;AISNE;1
02383;;Homblières;HOMBLIERES;02720;02;AISNE;1
02384;;Houry;HOURY;02140;02;AISNE;1
02385;;Housset;HOUSSET;02250;02;AISNE;1
02386;;Iron;IRON;02510;02;AISNE;1
02387;;Itancourt;ITANCOURT;02240;02;AISNE;1
02388;;Iviers;IVIERS;02360;02;AISNE;1
02389;;Jaulgonne;JAULGONNE;02850;02;AISNE;1
02390;;Jeancourt;JEANCOURT;02490;02;AISNE;1
02391;;Jeantes;JEANTES;02140;02;AISNE;1
02392;;Joncourt;JONCOURT;02420;02;AISNE;1
02393;;Jouaignes;JOUAIGNES;02220;02;AISNE;1
02395;;Jumencourt;JUMENCOURT;02380;02;AISNE;1
02396;;Jumigny;JUMIGNY;02160;02;AISNE;1
02397;;Jussy;JUSSY;02480;02;AISNE;1
02398;;Juvigny;JUVIGNY;02880;02;AISNE;1
02399;;Juvincourt-et-Damary;JUVINCOURT-ET-DAMARY;02190;02;AISNE;1
02400;;Laffaux;LAFFAUX;02880;02;AISNE;1
02401;;Laigny;LAIGNY;02140;02;AISNE;1
02402;;Lanchy;LANCHY;02590;02;AISNE;1
02403;;Landifay-et-Bertaignemont;LANDIFAY-ET-BERTAIGNEMONT;02120;02;AISNE;1
02404;;Landouzy-la-Cour;LANDOUZY-LA-COUR;02140;02;AISNE;1
02405;;Landouzy-la-Ville;LANDOUZY-LA-VILLE;02140;02;AISNE;1
02406;;Landricourt;LANDRICOURT;02380;02;AISNE;1
02407;;Laniscourt;LANISCOURT;02000;02;AISNE;1
02408;;Laon;LAON;02000;02;AISNE;1
02409;;Lappion;LAPPION;02150;02;AISNE;1
02410;;Largny-sur-Automne;LARGNY-SUR-AUTOMNE;02600;02;AISNE;1
02411;;Latilly;LATILLY;02210;02;AISNE;1
02412;;Launoy;LAUNOY;02210;02;AISNE;1
02413;;Laval-en-Laonnois;LAVAL-EN-LAONNOIS;02860;02;AISNE;1
02414;;Lavaqueresse;LAVAQUERESSE;02450;02;AISNE;1
02415;;Laversine;LAVERSINE;02600;02;AISNE;1
02416;;Lemé;LEME;02140;02;AISNE;1
02417;;Lempire;LEMPIRE;02420;02;AISNE;1
02418;;Lerzy;LERZY;02260;02;AISNE;1
02419;;Leschelle;LESCHELLE;02170;02;AISNE;1
02420;;Lesdins;LESDINS;02100;02;AISNE;1
02421;;Lesges;LESGES;02220;02;AISNE;1
02422;;Lesquielles-Saint-Germain;LESQUIELLES-SAINT-GERMAIN;02120;02;AISNE;1
02423;;Leuilly-sous-Coucy;LEUILLY-SOUS-COUCY;02380;02;AISNE;1
02424;;Leury;LEURY;02880;02;AISNE;1
02425;;Leuze;LEUZE;02500;02;AISNE;1
02426;;Levergies;LEVERGIES;02420;02;AISNE;1
02427;;Lhuys;LHUYS;02220;02;AISNE;1
02428;;Licy-Clignon;LICY-CLIGNON;02810;02;AISNE;1
02429;;Lierval;LIERVAL;02860;02;AISNE;1
02430;;Liesse-Notre-Dame;LIESSE-NOTRE-DAME;02350;02;AISNE;1
02431;;Liez;LIEZ;02700;02;AISNE;1
02432;;Limé;LIME;02220;02;AISNE;1
02433;;Lislet;LISLET;02340;02;AISNE;1
02434;;Lizy;LIZY;02320;02;AISNE;1
02435;;Logny-lès-Aubenton;LOGNY-LES-AUBENTON;02500;02;AISNE;1
02438;;Longpont;LONGPONT;02600;02;AISNE;1
02439;;Longueval-Barbonval;LONGUEVAL-BARBONVAL;02160;02;AISNE;1
02440;;Lor;LOR;02190;02;AISNE;1
02441;;Louâtre;LOUATRE;02600;02;AISNE;1
02442;;Loupeigne;LOUPEIGNE;02130;02;AISNE;1
02443;;Lucy-le-Bocage;LUCY-LE-BOCAGE;02400;02;AISNE;1
02444;;Lugny;LUGNY;02140;02;AISNE;1
02445;;Luzoir;LUZOIR;02500;02;AISNE;1
02446;;Ly-Fontaine;LY-FONTAINE;02440;02;AISNE;1
02447;;Maast-et-Violaine;MAAST-ET-VIOLAINE;02220;02;AISNE;1
02448;;Mâchecourt;MACHECOURT;02350;02;AISNE;1
02449;;Macogny;MACOGNY;02470;02;AISNE;1
02450;;Macquigny;MACQUIGNY;02120;02;AISNE;1
02451;;Magny-la-Fosse;MAGNY-LA-FOSSE;02420;02;AISNE;1
02452;;Maissemy;MAISSEMY;02490;02;AISNE;1
02453;;Maizy;MAIZY;02160;02;AISNE;1
02454;La;Malmaison;MALMAISON;02190;02;AISNE;1
02455;;Malzy;MALZY;02120;02;AISNE;1
02456;;Manicamp;MANICAMP;02300;02;AISNE;1
02457;;Marchais;MARCHAIS;02350;02;AISNE;1
02458;;Marchais-en-Brie;MARCHAIS-EN-BRIE;02540;02;AISNE;1
02459;;Marcy;MARCY;02720;02;AISNE;1
02460;;Marcy-sous-Marle;MARCY-SOUS-MARLE;02250;02;AISNE;1
02461;;Marest-Dampcourt;MAREST-DAMPCOURT;02300;02;AISNE;1
02462;;Mareuil-en-Dôle;MAREUIL-EN-DOLE;02130;02;AISNE;1
02463;;Marfontaine;MARFONTAINE;02140;02;AISNE;1
02464;;Margival;MARGIVAL;02880;02;AISNE;1
02465;;Marigny-en-Orxois;MARIGNY-EN-ORXOIS;02810;02;AISNE;1
02466;;Marizy-Sainte-Geneviève;MARIZY-SAINTE-GENEVIEVE;02470;02;AISNE;1
02467;;Marizy-Saint-Mard;MARIZY-SAINT-MARD;02470;02;AISNE;1
02468;;Marle;MARLE;02250;02;AISNE;1
02469;;Marly-Gomont;MARLY-GOMONT;02120;02;AISNE;1
02470;;Martigny;MARTIGNY;02500;02;AISNE;1
02471;;Martigny-Courpierre;MARTIGNY-COURPIERRE;02860;02;AISNE;1
02472;;Mauregny-en-Haye;MAUREGNY-EN-HAYE;02820;02;AISNE;1
02473;;Mayot;MAYOT;02800;02;AISNE;1
02474;;Mennessis;MENNESSIS;02700;02;AISNE;1
02475;;Menneville;MENNEVILLE;02190;02;AISNE;1
02476;;Mennevret;MENNEVRET;02630;02;AISNE;1
02477;;Mercin-et-Vaux;MERCIN-ET-VAUX;02200;02;AISNE;1
02478;;Merlieux-et-Fouquerolles;MERLIEUX-ET-FOUQUEROLLES;02000;02;AISNE;1
02479;;Merval;MERVAL;02160;02;AISNE;1
02480;;Mesbrecourt-Richecourt;MESBRECOURT-RICHECOURT;02270;02;AISNE;1
02481;;Mesnil-Saint-Laurent;MESNIL-SAINT-LAURENT;02720;02;AISNE;1
02482;;Meurival;MEURIVAL;02160;02;AISNE;1
02483;;Mézières-sur-Oise;MEZIERES-SUR-OISE;02240;02;AISNE;1
02484;;Mézy-Moulins;MEZY-MOULINS;02650;02;AISNE;1
02485;;Missy-aux-Bois;MISSY-AUX-BOIS;02200;02;AISNE;1
02486;;Missy-lès-Pierrepont;MISSY-LES-PIERREPONT;02350;02;AISNE;1
02487;;Missy-sur-Aisne;MISSY-SUR-AISNE;02880;02;AISNE;1
02488;;Molain;MOLAIN;02110;02;AISNE;1
02489;;Molinchart;MOLINCHART;02000;02;AISNE;1
02490;;Monampteuil;MONAMPTEUIL;02000;02;AISNE;1
02491;;Monceau-le-Neuf-et-Faucouzy;MONCEAU-LE-NEUF-ET-FAUCOUZY;02270;02;AISNE;1
02492;;Monceau-lès-Leups;MONCEAU-LES-LEUPS;02270;02;AISNE;1
02493;;Monceau-le-Waast;MONCEAU-LE-WAAST;02840;02;AISNE;1
02494;;Monceau-sur-Oise;MONCEAU-SUR-OISE;02120;02;AISNE;1
02495;;Mondrepuis;MONDREPUIS;02500;02;AISNE;1
02496;;Monnes;MONNES;02470;02;AISNE;1
02497;;Mons-en-Laonnois;MONS-EN-LAONNOIS;02000;02;AISNE;1
02498;;Montaigu;MONTAIGU;02820;02;AISNE;1
02499;;Montbavin;MONTBAVIN;02000;02;AISNE;1
02500;;Montbrehain;MONTBREHAIN;02110;02;AISNE;1
02501;;Montchâlons;MONTCHALONS;02860;02;AISNE;1
02502;;Montcornet;MONTCORNET;02340;02;AISNE;1
02503;;Mont-d'Origny;MONT-D'ORIGNY;02390;02;AISNE;1
02504;;Montescourt-Lizerolles;MONTESCOURT-LIZEROLLES;02440;02;AISNE;1
02505;;Montfaucon;MONTFAUCON;02540;02;AISNE;1
02506;;Montgobert;MONTGOBERT;02600;02;AISNE;1
02507;;Montgru-Saint-Hilaire;MONTGRU-SAINT-HILAIRE;02210;02;AISNE;1
02508;;Monthenault;MONTHENAULT;02860;02;AISNE;1
02509;;Monthiers;MONTHIERS;02400;02;AISNE;1
02510;;Monthurel;MONTHUREL;02330;02;AISNE;1
02511;;Montigny-en-Arrouaise;MONTIGNY-EN-ARROUAISE;02110;02;AISNE;1
02512;;Montigny-l'Allier;MONTIGNY-L'ALLIER;02810;02;AISNE;1
02513;;Montigny-le-Franc;MONTIGNY-LE-FRANC;02250;02;AISNE;1
02514;;Montigny-Lengrain;MONTIGNY-LENGRAIN;02290;02;AISNE;1
02515;;Montigny-lès-Condé;MONTIGNY-LES-CONDE;02330;02;AISNE;1
02516;;Montigny-sous-Marle;MONTIGNY-SOUS-MARLE;02250;02;AISNE;1
02517;;Montigny-sur-Crécy;MONTIGNY-SUR-CRECY;02270;02;AISNE;1
02518;;Montlevon;MONTLEVON;02330;02;AISNE;1
02519;;Montloué;MONTLOUE;02340;02;AISNE;1
02520;;Mont-Notre-Dame;MONT-NOTRE-DAME;02220;02;AISNE;1
02521;;Montreuil-aux-Lions;MONTREUIL-AUX-LIONS;02310;02;AISNE;1
02522;;Mont-Saint-Jean;MONT-SAINT-JEAN;02360;02;AISNE;1
02523;;Mont-Saint-Martin;MONT-SAINT-MARTIN;02220;02;AISNE;1
02524;;Mont-Saint-Père;MONT-SAINT-PERE;02400;02;AISNE;1
02525;;Morcourt;MORCOURT;02100;02;AISNE;1
02526;;Morgny-en-Thiérache;MORGNY-EN-THIERACHE;02360;02;AISNE;1
02527;;Morsain;MORSAIN;02290;02;AISNE;1
02528;;Mortefontaine;MORTEFONTAINE;02600;02;AISNE;1
02529;;Mortiers;MORTIERS;02270;02;AISNE;1
02530;;Moulins;MOULINS;02160;02;AISNE;1
02531;;Moussy-Verneuil;MOUSSY-VERNEUIL;02160;02;AISNE;1
02532;;Moÿ-de-l'Aisne;MOY-DE-L'AISNE;02610;02;AISNE;1
02533;;Muret-et-Crouttes;MURET-ET-CROUTTES;02210;02;AISNE;1
02534;;Muscourt;MUSCOURT;02160;02;AISNE;1
02535;;Nampcelles-la-Cour;NAMPCELLES-LA-COUR;02140;02;AISNE;1
02536;;Nampteuil-sous-Muret;NAMPTEUIL-SOUS-MURET;02200;02;AISNE;1
02537;;Nanteuil-la-Fosse;NANTEUIL-LA-FOSSE;02880;02;AISNE;1
02538;;Nanteuil-Notre-Dame;NANTEUIL-NOTRE-DAME;02210;02;AISNE;1
02539;;Nauroy;NAUROY;02420;02;AISNE;1
02540;;Nesles-la-Montagne;NESLES-LA-MONTAGNE;02400;02;AISNE;1
02541;;Neufchâtel-sur-Aisne;NEUFCHATEL-SUR-AISNE;02190;02;AISNE;1
02542;;Neuflieux;NEUFLIEUX;02300;02;AISNE;1
02543;;Neuilly-Saint-Front;NEUILLY-SAINT-FRONT;02470;02;AISNE;1
02544;;Neuve-Maison;NEUVE-MAISON;02500;02;AISNE;1
02545;La;Neuville-Bosmont;NEUVILLE-BOSMONT;02250;02;AISNE;1
02546;La;Neuville-en-Beine;NEUVILLE-EN-BEINE;02300;02;AISNE;1
02547;La;Neuville-Housset;NEUVILLE-HOUSSET;02250;02;AISNE;1
02548;La;Neuville-lès-Dorengt;NEUVILLE-LES-DORENGT;02450;02;AISNE;1
02549;;Neuville-Saint-Amand;NEUVILLE-SAINT-AMAND;02100;02;AISNE;1
02550;;Neuville-sur-Ailette;NEUVILLE-SUR-AILETTE;02860;02;AISNE;1
02551;;Neuville-sur-Margival;NEUVILLE-SUR-MARGIVAL;02880;02;AISNE;1
02552;;Neuvillette;NEUVILLETTE;02390;02;AISNE;1
02553;;Nizy-le-Comte;NIZY-LE-COMTE;02150;02;AISNE;1
02554;;Nogentel;NOGENTEL;02400;02;AISNE;1
02555;;Nogent-l'Artaud;NOGENT-L'ARTAUD;02310;02;AISNE;1
02556;;Noircourt;NOIRCOURT;02340;02;AISNE;1
02557;;Noroy-sur-Ourcq;NOROY-SUR-OURCQ;02600;02;AISNE;1
02558;Le;Nouvion-en-Thiérache;NOUVION-EN-THIERACHE;02170;02;AISNE;1
02559;;Nouvion-et-Catillon;NOUVION-ET-CATILLON;02270;02;AISNE;1
02560;;Nouvion-le-Comte;NOUVION-LE-COMTE;02800;02;AISNE;1
02561;;Nouvion-le-Vineux;NOUVION-LE-VINEUX;02860;02;AISNE;1
02562;;Nouvron-Vingré;NOUVRON-VINGRE;02290;02;AISNE;1
02563;;Noyales;NOYALES;02120;02;AISNE;1
02564;;Noyant-et-Aconin;NOYANT-ET-ACONIN;02200;02;AISNE;1
02565;;Œuilly;OEUILLY;02160;02;AISNE;1
02566;;Ognes;OGNES;02300;02;AISNE;1
02567;;Ohis;OHIS;02500;02;AISNE;1
02568;;Oigny-en-Valois;OIGNY-EN-VALOIS;02600;02;AISNE;1
02569;;Oisy;OISY;02450;02;AISNE;1
02570;;Ollezy;OLLEZY;02480;02;AISNE;1
02571;;Omissy;OMISSY;02100;02;AISNE;1
02572;;Orainville;ORAINVILLE;02190;02;AISNE;1
02573;;Orgeval;ORGEVAL;02860;02;AISNE;1
02574;;Origny-en-Thiérache;ORIGNY-EN-THIERACHE;02550;02;AISNE;1
02575;;Origny-Sainte-Benoite;ORIGNY-SAINTE-BENOITE;02390;02;AISNE;1
02576;;Osly-Courtil;OSLY-COURTIL;02290;02;AISNE;1
02577;;Ostel;OSTEL;02370;02;AISNE;1
02578;;Oulches-la-Vallée-Foulon;OULCHES-LA-VALLEE-FOULON;02160;02;AISNE;1
02579;;Oulchy-la-Ville;OULCHY-LA-VILLE;02210;02;AISNE;1
02580;;Oulchy-le-Château;OULCHY-LE-CHATEAU;02210;02;AISNE;1
02581;;Paars;PAARS;02220;02;AISNE;1
02582;;Paissy;PAISSY;02160;02;AISNE;1
02583;;Pancy-Courtecon;PANCY-COURTECON;02860;02;AISNE;1
02584;;Papleux;PAPLEUX;02260;02;AISNE;1
02585;;Parcy-et-Tigny;PARCY-ET-TIGNY;02210;02;AISNE;1
02586;;Parfondeval;PARFONDEVAL;02360;02;AISNE;1
02587;;Parfondru;PARFONDRU;02840;02;AISNE;1
02588;;Pargnan;PARGNAN;02160;02;AISNE;1
02589;;Pargny-Filain;PARGNY-FILAIN;02000;02;AISNE;1
02590;;Pargny-la-Dhuys;PARGNY-LA-DHUYS;02330;02;AISNE;1
02591;;Pargny-les-Bois;PARGNY-LES-BOIS;02270;02;AISNE;1
02592;;Parpeville;PARPEVILLE;02240;02;AISNE;1
02593;;Pasly;PASLY;02200;02;AISNE;1
02594;;Passy-en-Valois;PASSY-EN-VALOIS;02470;02;AISNE;1
02595;;Passy-sur-Marne;PASSY-SUR-MARNE;02850;02;AISNE;1
02596;;Pavant;PAVANT;02310;02;AISNE;1
02597;;Perles;PERLES;02160;02;AISNE;1
02598;;Pernant;PERNANT;02200;02;AISNE;1
02599;;Pierremande;PIERREMANDE;02300;02;AISNE;1
02600;;Pierrepont;PIERREPONT;02350;02;AISNE;1
02601;;Pignicourt;PIGNICOURT;02190;02;AISNE;1
02602;;Pinon;PINON;02320;02;AISNE;1
02604;;Pithon;PITHON;02480;02;AISNE;1
02605;;Pleine-Selve;PLEINE-SELVE;02240;02;AISNE;1
02606;Le;Plessier-Huleu;PLESSIER-HULEU;02210;02;AISNE;1
02607;;Ploisy;PLOISY;02200;02;AISNE;1
02608;;Plomion;PLOMION;02140;02;AISNE;1
02609;;Ployart-et-Vaurseine;PLOYART-ET-VAURSEINE;02860;02;AISNE;1
02610;;Pommiers;POMMIERS;02200;02;AISNE;1
02612;;Pont-Arcy;PONT-ARCY;02160;02;AISNE;1
02613;;Pontavert;PONTAVERT;02160;02;AISNE;1
02614;;Pontru;PONTRU;02490;02;AISNE;1
02615;;Pontruet;PONTRUET;02490;02;AISNE;1
02616;;Pont-Saint-Mard;PONT-SAINT-MARD;02380;02;AISNE;1
02617;;Pouilly-sur-Serre;POUILLY-SUR-SERRE;02270;02;AISNE;1
02618;;Prémont;PREMONT;02110;02;AISNE;1
02619;;Prémontré;PREMONTRE;02320;02;AISNE;1
02620;;Presles-et-Boves;PRESLES-ET-BOVES;02370;02;AISNE;1
02621;;Presles-et-Thierny;PRESLES-ET-THIERNY;02860;02;AISNE;1
02622;;Priez;PRIEZ;02470;02;AISNE;1
02623;;Prisces;PRISCES;02140;02;AISNE;1
02624;;Proisy;PROISY;02120;02;AISNE;1
02625;;Proix;PROIX;02120;02;AISNE;1
02626;;Prouvais;PROUVAIS;02190;02;AISNE;1
02627;;Proviseux-et-Plesnoy;PROVISEUX-ET-PLESNOY;02190;02;AISNE;1
02628;;Puiseux-en-Retz;PUISEUX-EN-RETZ;02600;02;AISNE;1
02629;;Puisieux-et-Clanlieu;PUISIEUX-ET-CLANLIEU;02120;02;AISNE;1
02631;;Quierzy;QUIERZY;02300;02;AISNE;1
02632;;Quincy-Basse;QUINCY-BASSE;02380;02;AISNE;1
02633;;Quincy-sous-le-Mont;QUINCY-SOUS-LE-MONT;02220;02;AISNE;1
02634;;Raillimont;RAILLIMONT;02360;02;AISNE;1
02635;;Ramicourt;RAMICOURT;02110;02;AISNE;1
02636;;Regny;REGNY;02240;02;AISNE;1
02637;;Remaucourt;REMAUCOURT;02100;02;AISNE;1
02638;;Remies;REMIES;02270;02;AISNE;1
02639;;Remigny;REMIGNY;02440;02;AISNE;1
02640;;Renansart;RENANSART;02240;02;AISNE;1
02641;;Renneval;RENNEVAL;02340;02;AISNE;1
02642;;Résigny;RESIGNY;02360;02;AISNE;1
02643;;Ressons-le-Long;RESSONS-LE-LONG;02290;02;AISNE;1
02644;;Retheuil;RETHEUIL;02600;02;AISNE;1
02645;;Reuilly-Sauvigny;REUILLY-SAUVIGNY;02850;02;AISNE;1
02646;;Révillon;REVILLON;02160;02;AISNE;1
02647;;Ribeauville;RIBEAUVILLE;02110;02;AISNE;1
02648;;Ribemont;RIBEMONT;02240;02;AISNE;1
02649;;Rocourt-Saint-Martin;ROCOURT-SAINT-MARTIN;02210;02;AISNE;1
02650;;Rocquigny;ROCQUIGNY;02260;02;AISNE;1
02651;;Rogécourt;ROGECOURT;02800;02;AISNE;1
02652;;Rogny;ROGNY;02140;02;AISNE;1
02653;;Romeny-sur-Marne;ROMENY-SUR-MARNE;02310;02;AISNE;1
02654;;Romery;ROMERY;02120;02;AISNE;1
02655;;Ronchères;RONCHERES;02130;02;AISNE;1
02656;;Roucy;ROUCY;02160;02;AISNE;1
02657;;Rougeries;ROUGERIES;02140;02;AISNE;1
02658;;Roupy;ROUPY;02590;02;AISNE;1
02659;;Rouvroy;ROUVROY;02100;02;AISNE;1
02660;;Rouvroy-sur-Serre;ROUVROY-SUR-SERRE;02360;02;AISNE;1
02661;;Royaucourt-et-Chailvet;ROYAUCOURT-ET-CHAILVET;02000;02;AISNE;1
02662;;Rozet-Saint-Albin;ROZET-SAINT-ALBIN;02210;02;AISNE;1
02663;;Rozières-sur-Crise;ROZIERES-SUR-CRISE;02200;02;AISNE;1
02664;;Rozoy-Bellevalle;ROZOY-BELLEVALLE;02540;02;AISNE;1
02665;;Grand-Rozoy;GRAND-ROZOY;02210;02;AISNE;1
02666;;Rozoy-sur-Serre;ROZOY-SUR-SERRE;02360;02;AISNE;1
02667;;Saconin-et-Breuil;SACONIN-ET-BREUIL;02200;02;AISNE;1
02668;;Sains-Richaumont;SAINS-RICHAUMONT;02120;02;AISNE;1
02669;;Saint-Agnan;SAINT-AGNAN;02330;02;AISNE;1
02670;;Saint-Algis;SAINT-ALGIS;02260;02;AISNE;1
02671;;Saint-Aubin;SAINT-AUBIN;02300;02;AISNE;1
02672;;Saint-Bandry;SAINT-BANDRY;02290;02;AISNE;1
02673;;Saint-Christophe-à-Berry;SAINT-CHRISTOPHE-A-BERRY;02290;02;AISNE;1
02674;;Saint-Clément;SAINT-CLEMENT;02360;02;AISNE;1
02675;;Sainte-Croix;SAINTE-CROIX;02820;02;AISNE;1
02676;;Saint-Erme-Outre-et-Ramecourt;SAINT-ERME-OUTRE-ET-RAMECOURT;02820;02;AISNE;1
02677;;Saint-Eugène;SAINT-EUGENE;02330;02;AISNE;1
02678;;Sainte-Geneviève;SAINTE-GENEVIEVE;02340;02;AISNE;1
02679;;Saint-Gengoulph;SAINT-GENGOULPH;02810;02;AISNE;1
02680;;Saint-Gobain;SAINT-GOBAIN;02410;02;AISNE;1
02681;;Saint-Gobert;SAINT-GOBERT;02140;02;AISNE;1
02682;;Saint-Mard;SAINT-MARD;02220;02;AISNE;1
02683;;Saint-Martin-Rivière;SAINT-MARTIN-RIVIERE;02110;02;AISNE;1
02684;;Saint-Michel;SAINT-MICHEL;02830;02;AISNE;1
02685;;Saint-Nicolas-aux-Bois;SAINT-NICOLAS-AUX-BOIS;02410;02;AISNE;1
02686;;Saint-Paul-aux-Bois;SAINT-PAUL-AUX-BOIS;02300;02;AISNE;1
02687;;Saint-Pierre-Aigle;SAINT-PIERRE-AIGLE;02600;02;AISNE;1
02688;;Saint-Pierre-lès-Franqueville;SAINT-PIERRE-LES-FRANQUEVILLE;02140;02;AISNE;1
02689;;Saint-Pierremont;SAINT-PIERREMONT;02250;02;AISNE;1
02690;;Sainte-Preuve;SAINTE-PREUVE;02350;02;AISNE;1
02691;;Saint-Quentin;SAINT-QUENTIN;02100;02;AISNE;1
02693;;Saint-Rémy-Blanzy;SAINT-REMY-BLANZY;02210;02;AISNE;1
02694;;Saint-Simon;SAINT-SIMON;02640;02;AISNE;1
02695;;Saint-Thibaut;SAINT-THIBAUT;02220;02;AISNE;1
02696;;Saint-Thomas;SAINT-THOMAS;02820;02;AISNE;1
02697;;Samoussy;SAMOUSSY;02840;02;AISNE;1
02698;;Sancy-les-Cheminots;SANCY-LES-CHEMINOTS;02880;02;AISNE;1
02699;;Saponay;SAPONAY;02130;02;AISNE;1
02701;;Saulchery;SAULCHERY;02310;02;AISNE;1
02702;;Savy;SAVY;02590;02;AISNE;1
02703;;Seboncourt;SEBONCOURT;02110;02;AISNE;1
02704;;Selens;SELENS;02300;02;AISNE;1
02705;La;Selve;SELVE;02150;02;AISNE;1
02706;;Septmonts;SEPTMONTS;02200;02;AISNE;1
02707;;Septvaux;SEPTVAUX;02410;02;AISNE;1
02708;;Sequehart;SEQUEHART;02420;02;AISNE;1
02709;;Serain;SERAIN;02110;02;AISNE;1
02710;;Seraucourt-le-Grand;SERAUCOURT-LE-GRAND;02790;02;AISNE;1
02711;;Serches;SERCHES;02220;02;AISNE;1
02712;;Sergy;SERGY;02130;02;AISNE;1
02713;;Seringes-et-Nesles;SERINGES-ET-NESLES;02130;02;AISNE;1
02714;;Sermoise;SERMOISE;02220;02;AISNE;1
02715;;Serval;SERVAL;02160;02;AISNE;1
02716;;Servais;SERVAIS;02700;02;AISNE;1
02717;;Séry-lès-Mézières;SERY-LES-MEZIERES;02240;02;AISNE;1
02718;;Silly-la-Poterie;SILLY-LA-POTERIE;02460;02;AISNE;1
02719;;Sinceny;SINCENY;02300;02;AISNE;1
02720;;Sissonne;SISSONNE;02150;02;AISNE;1
02721;;Sissy;SISSY;02240;02;AISNE;1
02722;;Soissons;SOISSONS;02200;02;AISNE;1
02723;;Soize;SOIZE;02340;02;AISNE;1
02724;;Sommelans;SOMMELANS;02470;02;AISNE;1
02725;;Sommeron;SOMMERON;02260;02;AISNE;1
02726;;Sommette-Eaucourt;SOMMETTE-EAUCOURT;02480;02;AISNE;1
02727;;Sons-et-Ronchères;SONS-ET-RONCHERES;02270;02;AISNE;1
02728;;Sorbais;SORBAIS;02580;02;AISNE;1
02729;;Soucy;SOUCY;02600;02;AISNE;1
02730;;Soupir;SOUPIR;02160;02;AISNE;1
02731;Le;Sourd;SOURD;02140;02;AISNE;1
02732;;Surfontaine;SURFONTAINE;02240;02;AISNE;1
02733;;Suzy;SUZY;02320;02;AISNE;1
02734;;Taillefontaine;TAILLEFONTAINE;02600;02;AISNE;1
02735;;Tannières;TANNIERES;02220;02;AISNE;1
02736;;Tartiers;TARTIERS;02290;02;AISNE;1
02737;;Tavaux-et-Pontséricourt;TAVAUX-ET-PONTSERICOURT;02250;02;AISNE;1
02738;;Tergnier;TERGNIER;02700;02;AISNE;1
02739;;Terny-Sorny;TERNY-SORNY;02880;02;AISNE;1
02740;;Thenailles;THENAILLES;02140;02;AISNE;1
02741;;Thenelles;THENELLES;02390;02;AISNE;1
02742;;Thiernu;THIERNU;02250;02;AISNE;1
02743;Le;Thuel;THUEL;02340;02;AISNE;1
02744;;Torcy-en-Valois;TORCY-EN-VALOIS;02810;02;AISNE;1
02745;;Toulis-et-Attencourt;TOULIS-ET-ATTENCOURT;02250;02;AISNE;1
02746;;Travecy;TRAVECY;02800;02;AISNE;1
02747;;Trefcon;TREFCON;02490;02;AISNE;1
02748;;Trélou-sur-Marne;TRELOU-SUR-MARNE;02850;02;AISNE;1
02749;;Troësnes;TROESNES;02460;02;AISNE;1
02750;;Trosly-Loire;TROSLY-LOIRE;02300;02;AISNE;1
02751;;Trucy;TRUCY;02860;02;AISNE;1
02752;;Tugny-et-Pont;TUGNY-ET-PONT;02640;02;AISNE;1
02753;;Tupigny;TUPIGNY;02120;02;AISNE;1
02754;;Ugny-le-Gay;UGNY-LE-GAY;02300;02;AISNE;1
02755;;Urcel;URCEL;02000;02;AISNE;1
02756;;Urvillers;URVILLERS;02690;02;AISNE;1
02757;;Vadencourt;VADENCOURT;02120;02;AISNE;1
02758;;Vailly-sur-Aisne;VAILLY-SUR-AISNE;02370;02;AISNE;1
02759;La;Vallée-au-Blé;VALLEE-AU-BLE;02140;02;AISNE;1
02760;La;Vallée-Mulâtre;VALLEE-MULATRE;02110;02;AISNE;1
02761;;Variscourt;VARISCOURT;02190;02;AISNE;1
02762;;Vassens;VASSENS;02290;02;AISNE;1
02763;;Vasseny;VASSENY;02220;02;AISNE;1
02764;;Vassogne;VASSOGNE;02160;02;AISNE;1
02765;;Vaucelles-et-Beffecourt;VAUCELLES-ET-BEFFECOURT;02000;02;AISNE;1
02766;;Vaudesson;VAUDESSON;02320;02;AISNE;1
02767;;Vauxrezis;VAUXREZIS;02200;02;AISNE;1
02768;;Vauxaillon;VAUXAILLON;02320;02;AISNE;1
02769;;Vaux-Andigny;VAUX-ANDIGNY;02110;02;AISNE;1
02770;;Vauxbuin;VAUXBUIN;02200;02;AISNE;1
02771;;Vauxcéré;VAUXCERE;02160;02;AISNE;1
02772;;Vaux-en-Vermandois;VAUX-EN-VERMANDOIS;02590;02;AISNE;1
02773;;Vauxtin;VAUXTIN;02220;02;AISNE;1
02774;;Vendelles;VENDELLES;02490;02;AISNE;1
02775;;Vendeuil;VENDEUIL;02800;02;AISNE;1
02776;;Vendhuile;VENDHUILE;02420;02;AISNE;1
02777;;Vendières;VENDIERES;02540;02;AISNE;1
02778;;Vendresse-Beaulne;VENDRESSE-BEAULNE;02160;02;AISNE;1
02779;;Vénérolles;VENEROLLES;02510;02;AISNE;1
02780;;Venizel;VENIZEL;02200;02;AISNE;1
02781;;Verdilly;VERDILLY;02400;02;AISNE;1
02782;Le;Verguier;VERGUIER;02490;02;AISNE;1
02783;;Grand-Verly;GRAND-VERLY;02120;02;AISNE;1
02784;;Petit-Verly;PETIT-VERLY;02630;02;AISNE;1
02785;;Vermand;VERMAND;02490;02;AISNE;1
02786;;Verneuil-sous-Coucy;VERNEUIL-SOUS-COUCY;02380;02;AISNE;1
02787;;Verneuil-sur-Serre;VERNEUIL-SUR-SERRE;02000;02;AISNE;1
02788;;Versigny;VERSIGNY;02800;02;AISNE;1
02789;;Vervins;VERVINS;02140;02;AISNE;1
02790;;Vesles-et-Caumont;VESLES-ET-CAUMONT;02350;02;AISNE;1
02791;;Veslud;VESLUD;02840;02;AISNE;1
02792;;Veuilly-la-Poterie;VEUILLY-LA-POTERIE;02810;02;AISNE;1
02793;;Vézaponin;VEZAPONIN;02290;02;AISNE;1
02794;;Vézilly;VEZILLY;02130;02;AISNE;1
02795;;Vic-sur-Aisne;VIC-SUR-AISNE;02290;02;AISNE;1
02796;;Vichel-Nanteuil;VICHEL-NANTEUIL;02210;02;AISNE;1
02797;;Viel-Arcy;VIEL-ARCY;02160;02;AISNE;1
02798;;Viels-Maisons;VIELS-MAISONS;02540;02;AISNE;1
02799;;Vierzy;VIERZY;02210;02;AISNE;1
02800;;Viffort;VIFFORT;02540;02;AISNE;1
02801;;Vigneux-Hocquet;VIGNEUX-HOCQUET;02340;02;AISNE;1
02802;La;Ville-aux-Bois-lès-Dizy;VILLE-AUX-BOIS-LES-DIZY;02340;02;AISNE;1
02803;La;Ville-aux-Bois-lès-Pontavert;VILLE-AUX-BOIS-LES-PONTAVERT;02160;02;AISNE;1
02804;;Villemontoire;VILLEMONTOIRE;02210;02;AISNE;1
02805;;Villeneuve-Saint-Germain;VILLENEUVE-SAINT-GERMAIN;02200;02;AISNE;1
02806;;Villeneuve-sur-Fère;VILLENEUVE-SUR-FERE;02130;02;AISNE;1
02807;;Villequier-Aumont;VILLEQUIER-AUMONT;02300;02;AISNE;1
02808;;Villeret;VILLERET;02420;02;AISNE;1
02809;;Villers-Agron-Aiguizy;VILLERS-AGRON-AIGUIZY;02130;02;AISNE;1
02810;;Villers-Cotterêts;VILLERS-COTTERETS;02600;02;AISNE;1
02811;;Villers-en-Prayères;VILLERS-EN-PRAYERES;02160;02;AISNE;1
02812;;Villers-Hélon;VILLERS-HELON;02600;02;AISNE;1
02813;;Villers-le-Sec;VILLERS-LE-SEC;02240;02;AISNE;1
02814;;Villers-lès-Guise;VILLERS-LES-GUISE;02120;02;AISNE;1
02815;;Villers-Saint-Christophe;VILLERS-SAINT-CHRISTOPHE;02590;02;AISNE;1
02816;;Villers-sur-Fère;VILLERS-SUR-FERE;02130;02;AISNE;1
02817;;Ville-Savoye;VILLE-SAVOYE;02220;02;AISNE;1
02818;;Villiers-Saint-Denis;VILLIERS-SAINT-DENIS;02310;02;AISNE;1
02819;;Vincy-Reuil-et-Magny;VINCY-REUIL-ET-MAGNY;02340;02;AISNE;1
02820;;Viry-Noureuil;VIRY-NOUREUIL;02300;02;AISNE;1
02821;;Vivaise;VIVAISE;02870;02;AISNE;1
02822;;Vivières;VIVIERES;02600;02;AISNE;1
02823;;Voharies;VOHARIES;02140;02;AISNE;1
02824;;Vorges;VORGES;02860;02;AISNE;1
02826;;Voulpaix;VOULPAIX;02140;02;AISNE;1
02827;;Voyenne;VOYENNE;02250;02;AISNE;1
02828;;Vregny;VREGNY;02880;02;AISNE;1
02829;;Vuillery;VUILLERY;02880;02;AISNE;1
02830;;Wassigny;WASSIGNY;02630;02;AISNE;1
02831;;Watigny;WATIGNY;02830;02;AISNE;1
02832;;Wiège-Faty;WIEGE-FATY;02120;02;AISNE;1
02833;;Wimy;WIMY;02500;02;AISNE;1
02834;;Wissignicourt;WISSIGNICOURT;02320;02;AISNE;1
03001;;Abrest;ABREST;03200;03;ALLIER;1
03002;;Agonges;AGONGES;03210;03;ALLIER;1
03003;;Ainay-le-Château;AINAY-LE-CHATEAU;03360;03;ALLIER;1
03004;;Andelaroche;ANDELAROCHE;03120;03;ALLIER;1
03005;;Archignat;ARCHIGNAT;03380;03;ALLIER;1
03006;;Arfeuilles;ARFEUILLES;03640;03;ALLIER;1
03007;;Arpheuilles-Saint-Priest;ARPHEUILLES-SAINT-PRIEST;03420;03;ALLIER;1
03008;;Arronnes;ARRONNES;03250;03;ALLIER;1
03009;;Aubigny;AUBIGNY;03460;03;ALLIER;1
03010;;Audes;AUDES;03190;03;ALLIER;1
03011;;Aurouër;AUROUER;03460;03;ALLIER;1
03012;;Autry-Issards;AUTRY-ISSARDS;03210;03;ALLIER;1
03013;;Avermes;AVERMES;03000;03;ALLIER;1
03014;;Avrilly;AVRILLY;03130;03;ALLIER;1
03015;;Bagneux;BAGNEUX;03460;03;ALLIER;1
03016;;Barberier;BARBERIER;03140;03;ALLIER;1
03017;;Barrais-Bussolles;BARRAIS-BUSSOLLES;03120;03;ALLIER;1
03018;;Bayet;BAYET;03500;03;ALLIER;1
03019;;Beaulon;BEAULON;03230;03;ALLIER;1
03020;;Beaune-d'Allier;BEAUNE-D'ALLIER;03390;03;ALLIER;1
03021;;Bègues;BEGUES;03800;03;ALLIER;1
03022;;Bellenaves;BELLENAVES;03330;03;ALLIER;1
03023;;Bellerive-sur-Allier;BELLERIVE-SUR-ALLIER;03700;03;ALLIER;1
03024;;Bert;BERT;03130;03;ALLIER;1
03025;;Bessay-sur-Allier;BESSAY-SUR-ALLIER;03340;03;ALLIER;1
03026;;Besson;BESSON;03210;03;ALLIER;1
03027;;Bézenet;BEZENET;03170;03;ALLIER;1
03028;;Billezois;BILLEZOIS;03120;03;ALLIER;1
03029;;Billy;BILLY;03260;03;ALLIER;1
03030;;Biozat;BIOZAT;03800;03;ALLIER;1
03031;;Bizeneuille;BIZENEUILLE;03170;03;ALLIER;1
03032;;Blomard;BLOMARD;03390;03;ALLIER;1
03033;;Bost;BOST;03300;03;ALLIER;1
03034;;Boucé;BOUCE;03150;03;ALLIER;1
03035;Le;Bouchaud;BOUCHAUD;03130;03;ALLIER;1
03036;;Bourbon-l'Archambault;BOURBON-L'ARCHAMBAULT;03160;03;ALLIER;1
03037;;Braize;BRAIZE;03360;03;ALLIER;1
03038;;Bransat;BRANSAT;03500;03;ALLIER;1
03039;;Bresnay;BRESNAY;03210;03;ALLIER;1
03040;;Bressolles;BRESSOLLES;03000;03;ALLIER;1
03041;Le;Brethon;BRETHON;03350;03;ALLIER;1
03042;Le;Breuil;BREUIL;03120;03;ALLIER;1
03043;;Broût-Vernet;BROUT-VERNET;03110;03;ALLIER;1
03044;;Brugheas;BRUGHEAS;03700;03;ALLIER;1
03045;;Busset;BUSSET;03270;03;ALLIER;1
03046;;Buxières-les-Mines;BUXIERES-LES-MINES;03440;03;ALLIER;1
03047;La;Celle;CELLE;03600;03;ALLIER;1
03048;;Cérilly;CERILLY;03350;03;ALLIER;1
03049;;Cesset;CESSET;03500;03;ALLIER;1
03050;La;Chabanne;CHABANNE;03250;03;ALLIER;1
03051;;Chambérat;CHAMBERAT;03370;03;ALLIER;1
03052;;Chamblet;CHAMBLET;03170;03;ALLIER;1
03053;;Chantelle;CHANTELLE;03140;03;ALLIER;1
03054;;Chapeau;CHAPEAU;03340;03;ALLIER;1
03055;La;Chapelaude;CHAPELAUDE;03380;03;ALLIER;1
03056;La;Chapelle;CHAPELLE;03300;03;ALLIER;1
03057;La;Chapelle-aux-Chasses;CHAPELLE-AUX-CHASSES;03230;03;ALLIER;1
03058;;Chappes;CHAPPES;03390;03;ALLIER;1
03059;;Chareil-Cintrat;CHAREIL-CINTRAT;03140;03;ALLIER;1
03060;;Charmeil;CHARMEIL;03110;03;ALLIER;1
03061;;Charmes;CHARMES;03800;03;ALLIER;1
03062;;Charroux;CHARROUX;03140;03;ALLIER;1
03063;;Chassenard;CHASSENARD;03510;03;ALLIER;1
03064;;Château-sur-Allier;CHATEAU-SUR-ALLIER;03320;03;ALLIER;1
03065;;Châtel-de-Neuvre;CHATEL-DE-NEUVRE;03500;03;ALLIER;1
03066;;Châtel-Montagne;CHATEL-MONTAGNE;03250;03;ALLIER;1
03067;;Châtelperron;CHATELPERRON;03220;03;ALLIER;1
03068;;Châtelus;CHATELUS;03640;03;ALLIER;1
03069;;Châtillon;CHATILLON;03210;03;ALLIER;1
03070;;Chavenon;CHAVENON;03440;03;ALLIER;1
03071;;Chavroches;CHAVROCHES;03220;03;ALLIER;1
03072;;Chazemais;CHAZEMAIS;03370;03;ALLIER;1
03073;;Chemilly;CHEMILLY;03210;03;ALLIER;1
03074;;Chevagnes;CHEVAGNES;03230;03;ALLIER;1
03075;;Chezelle;CHEZELLE;03140;03;ALLIER;1
03076;;Chézy;CHEZY;03230;03;ALLIER;1
03077;;Chirat-l'Église;CHIRAT-L'EGLISE;03330;03;ALLIER;1
03078;;Chouvigny;CHOUVIGNY;03450;03;ALLIER;1
03079;;Cindré;CINDRE;03220;03;ALLIER;1
03080;;Cognat-Lyonne;COGNAT-LYONNE;03110;03;ALLIER;1
03081;;Colombier;COLOMBIER;03600;03;ALLIER;1
03082;;Commentry;COMMENTRY;03600;03;ALLIER;1
03083;;Contigny;CONTIGNY;03500;03;ALLIER;1
03084;;Cosne-d'Allier;COSNE-D'ALLIER;03430;03;ALLIER;1
03085;;Coulandon;COULANDON;03000;03;ALLIER;1
03086;;Coulanges;COULANGES;03470;03;ALLIER;1
03087;;Couleuvre;COULEUVRE;03320;03;ALLIER;1
03088;;Courçais;COURCAIS;03370;03;ALLIER;1
03089;;Coutansouze;COUTANSOUZE;03330;03;ALLIER;1
03090;;Couzon;COUZON;03160;03;ALLIER;1
03091;;Créchy;CRECHY;03150;03;ALLIER;1
03092;;Cressanges;CRESSANGES;03240;03;ALLIER;1
03093;;Creuzier-le-Neuf;CREUZIER-LE-NEUF;03300;03;ALLIER;1
03094;;Creuzier-le-Vieux;CREUZIER-LE-VIEUX;03300;03;ALLIER;1
03095;;Cusset;CUSSET;03300;03;ALLIER;1
03096;;Deneuille-lès-Chantelle;DENEUILLE-LES-CHANTELLE;03140;03;ALLIER;1
03097;;Deneuille-les-Mines;DENEUILLE-LES-MINES;03170;03;ALLIER;1
03098;;Désertines;DESERTINES;03630;03;ALLIER;1
03099;;Deux-Chaises;DEUX-CHAISES;03240;03;ALLIER;1
03100;;Diou;DIOU;03290;03;ALLIER;1
03101;;Domérat;DOMERAT;03410;03;ALLIER;1
03102;;Dompierre-sur-Besbre;DOMPIERRE-SUR-BESBRE;03290;03;ALLIER;1
03103;Le;Donjon;DONJON;03130;03;ALLIER;1
03104;;Doyet;DOYET;03170;03;ALLIER;1
03105;;Droiturier;DROITURIER;03120;03;ALLIER;1
03106;;Durdat-Larequille;DURDAT-LAREQUILLE;03310;03;ALLIER;1
03107;;Ébreuil;EBREUIL;03450;03;ALLIER;1
03108;;Échassières;ECHASSIERES;03330;03;ALLIER;1
03109;;Escurolles;ESCUROLLES;03110;03;ALLIER;1
03110;;Espinasse-Vozelle;ESPINASSE-VOZELLE;03110;03;ALLIER;1
03111;;Estivareilles;ESTIVAREILLES;03190;03;ALLIER;1
03112;;Étroussat;ETROUSSAT;03140;03;ALLIER;1
03113;;Ferrières-sur-Sichon;FERRIERES-SUR-SICHON;03250;03;ALLIER;1
03114;La;Ferté-Hauterive;FERTE-HAUTERIVE;03340;03;ALLIER;1
03115;;Fleuriel;FLEURIEL;03140;03;ALLIER;1
03116;;Fourilles;FOURILLES;03140;03;ALLIER;1
03117;;Franchesse;FRANCHESSE;03160;03;ALLIER;1
03118;;Gannat;GANNAT;03800;03;ALLIER;1
03119;;Gannay-sur-Loire;GANNAY-SUR-LOIRE;03230;03;ALLIER;1
03120;;Garnat-sur-Engièvre;GARNAT-SUR-ENGIEVRE;03230;03;ALLIER;1
03121;;Gennetines;GENNETINES;03400;03;ALLIER;1
03122;;Gipcy;GIPCY;03210;03;ALLIER;1
03123;;Givarlais;GIVARLAIS;03190;03;ALLIER;1
03124;;Gouise;GOUISE;03340;03;ALLIER;1
03125;La;Guillermie;GUILLERMIE;03250;03;ALLIER;1
03126;;Hauterive;HAUTERIVE;03270;03;ALLIER;1
03127;;Hérisson;HERISSON;03190;03;ALLIER;1
03128;;Huriel;HURIEL;03380;03;ALLIER;1
03129;;Hyds;HYDS;03600;03;ALLIER;1
03130;;Isle-et-Bardais;ISLE-ET-BARDAIS;03360;03;ALLIER;1
03131;;Isserpent;ISSERPENT;03120;03;ALLIER;1
03132;;Jaligny-sur-Besbre;JALIGNY-SUR-BESBRE;03220;03;ALLIER;1
03133;;Jenzat;JENZAT;03800;03;ALLIER;1
03134;;Laféline;LAFELINE;03500;03;ALLIER;1
03135;;Lalizolle;LALIZOLLE;03450;03;ALLIER;1
03136;;Lamaids;LAMAIDS;03380;03;ALLIER;1
03137;;Langy;LANGY;03150;03;ALLIER;1
03138;;Lapalisse;LAPALISSE;03120;03;ALLIER;1
03139;;Laprugne;LAPRUGNE;03250;03;ALLIER;1
03140;;Lavault-Sainte-Anne;LAVAULT-SAINTE-ANNE;03310;03;ALLIER;1
03141;;Lavoine;LAVOINE;03250;03;ALLIER;1
03142;;Lenax;LENAX;03130;03;ALLIER;1
03143;;Lételon;LETELON;03360;03;ALLIER;1
03144;;Liernolles;LIERNOLLES;03130;03;ALLIER;1
03145;;Lignerolles;LIGNEROLLES;03410;03;ALLIER;1
03146;;Limoise;LIMOISE;03320;03;ALLIER;1
03147;;Loddes;LODDES;03130;03;ALLIER;1
03148;;Loriges;LORIGES;03500;03;ALLIER;1
03149;;Louchy-Montfand;LOUCHY-MONTFAND;03500;03;ALLIER;1
03150;;Louroux-Bourbonnais;LOUROUX-BOURBONNAIS;03350;03;ALLIER;1
03151;;Louroux-de-Beaune;LOUROUX-DE-BEAUNE;03600;03;ALLIER;1
03152;;Louroux-de-Bouble;LOUROUX-DE-BOUBLE;03330;03;ALLIER;1
03153;;Louroux-Hodement;LOUROUX-HODEMENT;03190;03;ALLIER;1
03154;;Luneau;LUNEAU;03130;03;ALLIER;1
03155;;Lurcy-Lévis;LURCY-LEVIS;03320;03;ALLIER;1
03156;;Lusigny;LUSIGNY;03230;03;ALLIER;1
03157;;Magnet;MAGNET;03260;03;ALLIER;1
03158;;Maillet;MAILLET;03190;03;ALLIER;1
03159;;Malicorne;MALICORNE;03600;03;ALLIER;1
03160;;Marcenat;MARCENAT;03260;03;ALLIER;1
03161;;Marcillat-en-Combraille;MARCILLAT-EN-COMBRAILLE;03420;03;ALLIER;1
03162;;Marigny;MARIGNY;03210;03;ALLIER;1
03163;;Mariol;MARIOL;03270;03;ALLIER;1
03164;Le;Mayet-d'École;MAYET-D'ECOLE;03800;03;ALLIER;1
03165;Le;Mayet-de-Montagne;MAYET-DE-MONTAGNE;03250;03;ALLIER;1
03166;;Mazerier;MAZERIER;03800;03;ALLIER;1
03167;;Mazirat;MAZIRAT;03420;03;ALLIER;1
03168;;Meaulne;MEAULNE;03360;03;ALLIER;1
03169;;Meillard;MEILLARD;03500;03;ALLIER;1
03170;;Meillers;MEILLERS;03210;03;ALLIER;1
03171;;Mercy;MERCY;03340;03;ALLIER;1
03172;;Mesples;MESPLES;03370;03;ALLIER;1
03173;;Molinet;MOLINET;03510;03;ALLIER;1
03174;;Molles;MOLLES;03300;03;ALLIER;1
03175;;Monestier;MONESTIER;03140;03;ALLIER;1
03176;;Monétay-sur-Allier;MONETAY-SUR-ALLIER;03500;03;ALLIER;1
03177;;Monétay-sur-Loire;MONETAY-SUR-LOIRE;03470;03;ALLIER;1
03178;;Montaiguët-en-Forez;MONTAIGUET-EN-FOREZ;03130;03;ALLIER;1
03179;;Montaigu-le-Blin;MONTAIGU-LE-BLIN;03150;03;ALLIER;1
03180;;Montbeugny;MONTBEUGNY;03340;03;ALLIER;1
03181;;Montcombroux-les-Mines;MONTCOMBROUX-LES-MINES;03130;03;ALLIER;1
03182;;Monteignet-sur-l'Andelot;MONTEIGNET-SUR-L'ANDELOT;03800;03;ALLIER;1
03183;Le;Montet;MONTET;03240;03;ALLIER;1
03184;;Montilly;MONTILLY;03000;03;ALLIER;1
03185;;Montluçon;MONTLUCON;03100;03;ALLIER;1
03186;;Montmarault;MONTMARAULT;03390;03;ALLIER;1
03187;;Montoldre;MONTOLDRE;03150;03;ALLIER;1
03188;;Montord;MONTORD;03500;03;ALLIER;1
03189;;Montvicq;MONTVICQ;03170;03;ALLIER;1
03190;;Moulins;MOULINS;03000;03;ALLIER;1
03191;;Murat;MURAT;03390;03;ALLIER;1
03192;;Nades;NADES;03450;03;ALLIER;1
03193;;Nassigny;NASSIGNY;03190;03;ALLIER;1
03194;;Naves;NAVES;03330;03;ALLIER;1
03195;;Néris-les-Bains;NERIS-LES-BAINS;03310;03;ALLIER;1
03196;;Neuilly-en-Donjon;NEUILLY-EN-DONJON;03130;03;ALLIER;1
03197;;Neuilly-le-Réal;NEUILLY-LE-REAL;03340;03;ALLIER;1
03198;;Neure;NEURE;03320;03;ALLIER;1
03200;;Neuvy;NEUVY;03000;03;ALLIER;1
03201;;Nizerolles;NIZEROLLES;03250;03;ALLIER;1
03202;;Noyant-d'Allier;NOYANT-D'ALLIER;03210;03;ALLIER;1
03203;;Paray-le-Frésil;PARAY-LE-FRESIL;03230;03;ALLIER;1
03204;;Paray-sous-Briailles;PARAY-SOUS-BRIAILLES;03500;03;ALLIER;1
03205;;Périgny;PERIGNY;03120;03;ALLIER;1
03206;La;Petite-Marche;PETITE-MARCHE;03420;03;ALLIER;1
03207;;Pierrefitte-sur-Loire;PIERREFITTE-SUR-LOIRE;03470;03;ALLIER;1
03208;Le;Pin;PIN;03130;03;ALLIER;1
03209;;Poëzat;POEZAT;03800;03;ALLIER;1
03210;;Pouzy-Mésangy;POUZY-MESANGY;03320;03;ALLIER;1
03211;;Prémilhat;PREMILHAT;03410;03;ALLIER;1
03212;;Quinssaines;QUINSSAINES;03380;03;ALLIER;1
03213;;Reugny;REUGNY;03190;03;ALLIER;1
03214;;Rocles;ROCLES;03240;03;ALLIER;1
03215;;Rongères;RONGERES;03150;03;ALLIER;1
03216;;Ronnet;RONNET;03420;03;ALLIER;1
03217;;Saint-Angel;SAINT-ANGEL;03170;03;ALLIER;1
03218;;Saint-Aubin-le-Monial;SAINT-AUBIN-LE-MONIAL;03160;03;ALLIER;1
03219;;Saint-Bonnet-de-Four;SAINT-BONNET-DE-FOUR;03390;03;ALLIER;1
03220;;Saint-Bonnet-de-Rochefort;SAINT-BONNET-DE-ROCHEFORT;03800;03;ALLIER;1
03221;;Saint-Bonnet-Tronçais;SAINT-BONNET-TRONCAIS;03360;03;ALLIER;1
03222;;Saint-Caprais;SAINT-CAPRAIS;03190;03;ALLIER;1
03223;;Saint-Christophe;SAINT-CHRISTOPHE;03120;03;ALLIER;1
03224;;Saint-Clément;SAINT-CLEMENT;03250;03;ALLIER;1
03225;;Saint-Désiré;SAINT-DESIRE;03370;03;ALLIER;1
03226;;Saint-Didier-en-Donjon;SAINT-DIDIER-EN-DONJON;03130;03;ALLIER;1
03227;;Saint-Didier-la-Forêt;SAINT-DIDIER-LA-FORET;03110;03;ALLIER;1
03228;;Saint-Éloy-d'Allier;SAINT-ELOY-D'ALLIER;03370;03;ALLIER;1
03229;;Saint-Ennemond;SAINT-ENNEMOND;03400;03;ALLIER;1
03230;;Saint-Étienne-de-Vicq;SAINT-ETIENNE-DE-VICQ;03300;03;ALLIER;1
03231;;Saint-Fargeol;SAINT-FARGEOL;03420;03;ALLIER;1
03232;;Saint-Félix;SAINT-FELIX;03260;03;ALLIER;1
03233;;Saint-Genest;SAINT-GENEST;03310;03;ALLIER;1
03234;;Saint-Gérand-de-Vaux;SAINT-GERAND-DE-VAUX;03340;03;ALLIER;1
03235;;Saint-Gérand-le-Puy;SAINT-GERAND-LE-PUY;03150;03;ALLIER;1
03236;;Saint-Germain-des-Fossés;SAINT-GERMAIN-DES-FOSSES;03260;03;ALLIER;1
03237;;Saint-Germain-de-Salles;SAINT-GERMAIN-DE-SALLES;03140;03;ALLIER;1
03238;;Saint-Hilaire;SAINT-HILAIRE;03440;03;ALLIER;1
03239;;Saint-Léger-sur-Vouzance;SAINT-LEGER-SUR-VOUZANCE;03130;03;ALLIER;1
03240;;Saint-Léon;SAINT-LEON;03220;03;ALLIER;1
03241;;Saint-Léopardin-d'Augy;SAINT-LEOPARDIN-D'AUGY;03160;03;ALLIER;1
03242;;Saint-Loup;SAINT-LOUP;03150;03;ALLIER;1
03243;;Saint-Marcel-en-Murat;SAINT-MARCEL-EN-MURAT;03390;03;ALLIER;1
03244;;Saint-Marcel-en-Marcillat;SAINT-MARCEL-EN-MARCILLAT;03420;03;ALLIER;1
03245;;Saint-Martin-des-Lais;SAINT-MARTIN-DES-LAIS;03230;03;ALLIER;1
03246;;Saint-Martinien;SAINT-MARTINIEN;03380;03;ALLIER;1
03247;;Saint-Menoux;SAINT-MENOUX;03210;03;ALLIER;1
03248;;Saint-Nicolas-des-Biefs;SAINT-NICOLAS-DES-BIEFS;03250;03;ALLIER;1
03249;;Saint-Palais;SAINT-PALAIS;03370;03;ALLIER;1
03250;;Saint-Pierre-Laval;SAINT-PIERRE-LAVAL;42620;03;LOIRE;1
03251;;Saint-Plaisir;SAINT-PLAISIR;03160;03;ALLIER;1
03252;;Saint-Pont;SAINT-PONT;03110;03;ALLIER;1
03253;;Saint-Pourçain-sur-Besbre;SAINT-POURCAIN-SUR-BESBRE;03290;03;ALLIER;1
03254;;Saint-Pourçain-sur-Sioule;SAINT-POURCAIN-SUR-SIOULE;03500;03;ALLIER;1
03255;;Saint-Priest-d'Andelot;SAINT-PRIEST-D'ANDELOT;03800;03;ALLIER;1
03256;;Saint-Priest-en-Murat;SAINT-PRIEST-EN-MURAT;03390;03;ALLIER;1
03257;;Saint-Prix;SAINT-PRIX;03120;03;ALLIER;1
03258;;Saint-Rémy-en-Rollat;SAINT-REMY-EN-ROLLAT;03110;03;ALLIER;1
03259;;Saint-Sauvier;SAINT-SAUVIER;03370;03;ALLIER;1
03260;;Saint-Sornin;SAINT-SORNIN;03240;03;ALLIER;1
03261;;Sainte-Thérence;SAINTE-THERENCE;03420;03;ALLIER;1
03262;;Saint-Victor;SAINT-VICTOR;03410;03;ALLIER;1
03263;;Saint-Voir;SAINT-VOIR;03220;03;ALLIER;1
03264;;Saint-Yorre;SAINT-YORRE;03270;03;ALLIER;1
03265;;Saligny-sur-Roudon;SALIGNY-SUR-ROUDON;03470;03;ALLIER;1
03266;;Sanssat;SANSSAT;03150;03;ALLIER;1
03267;;Saulcet;SAULCET;03500;03;ALLIER;1
03268;;Saulzet;SAULZET;03800;03;ALLIER;1
03269;;Sauvagny;SAUVAGNY;03430;03;ALLIER;1
03270;;Sazeret;SAZERET;03390;03;ALLIER;1
03271;;Serbannes;SERBANNES;03110;03;ALLIER;1
03272;;Servilly;SERVILLY;03120;03;ALLIER;1
03273;;Seuillet;SEUILLET;03260;03;ALLIER;1
03274;;Sorbier;SORBIER;03220;03;ALLIER;1
03275;;Souvigny;SOUVIGNY;03210;03;ALLIER;1
03276;;Sussat;SUSSAT;03450;03;ALLIER;1
03277;;Target;TARGET;03140;03;ALLIER;1
03278;;Taxat-Senat;TAXAT-SENAT;03140;03;ALLIER;1
03279;;Teillet-Argenty;TEILLET-ARGENTY;03410;03;ALLIER;1
03280;;Terjat;TERJAT;03420;03;ALLIER;1
03281;Le;Theil;THEIL;03240;03;ALLIER;1
03282;;Theneuille;THENEUILLE;03350;03;ALLIER;1
03283;;Thiel-sur-Acolin;THIEL-SUR-ACOLIN;03230;03;ALLIER;1
03284;;Thionne;THIONNE;03220;03;ALLIER;1
03285;;Tortezais;TORTEZAIS;03430;03;ALLIER;1
03286;;Toulon-sur-Allier;TOULON-SUR-ALLIER;03400;03;ALLIER;1
03287;;Treban;TREBAN;03240;03;ALLIER;1
03288;;Treignat;TREIGNAT;03380;03;ALLIER;1
03289;;Treteau;TRETEAU;03220;03;ALLIER;1
03290;;Trévol;TREVOL;03460;03;ALLIER;1
03291;;Trézelles;TREZELLES;03220;03;ALLIER;1
03292;;Tronget;TRONGET;03240;03;ALLIER;1
03293;;Urçay;URCAY;03360;03;ALLIER;1
03294;;Ussel-d'Allier;USSEL-D'ALLIER;03140;03;ALLIER;1
03295;;Valignat;VALIGNAT;03330;03;ALLIER;1
03296;;Valigny;VALIGNY;03360;03;ALLIER;1
03297;;Vallon-en-Sully;VALLON-EN-SULLY;03190;03;ALLIER;1
03298;;Varennes-sur-Allier;VARENNES-SUR-ALLIER;03150;03;ALLIER;1
03299;;Varennes-sur-Tèche;VARENNES-SUR-TECHE;03220;03;ALLIER;1
03300;;Vaumas;VAUMAS;03220;03;ALLIER;1
03301;;Vaux;VAUX;03190;03;ALLIER;1
03302;;Veauce;VEAUCE;03450;03;ALLIER;1
03303;;Venas;VENAS;03190;03;ALLIER;1
03304;;Vendat;VENDAT;03110;03;ALLIER;1
03305;;Verneix;VERNEIX;03190;03;ALLIER;1
03306;Le;Vernet;VERNET;03200;03;ALLIER;1
03307;;Verneuil-en-Bourbonnais;VERNEUIL-EN-BOURBONNAIS;03500;03;ALLIER;1
03308;;Vernusse;VERNUSSE;03390;03;ALLIER;1
03309;Le;Veurdre;VEURDRE;03320;03;ALLIER;1
03310;;Vichy;VICHY;03200;03;ALLIER;1
03311;;Vicq;VICQ;03450;03;ALLIER;1
03312;;Vieure;VIEURE;03430;03;ALLIER;1
03313;Le;Vilhain;VILHAIN;03350;03;ALLIER;1
03314;;Villebret;VILLEBRET;03310;03;ALLIER;1
03315;;Villefranche-d'Allier;VILLEFRANCHE-D'ALLIER;03430;03;ALLIER;1
03316;;Villeneuve-sur-Allier;VILLENEUVE-SUR-ALLIER;03460;03;ALLIER;1
03317;;Viplaix;VIPLAIX;03370;03;ALLIER;1
03318;;Vitray;VITRAY;03360;03;ALLIER;1
03319;;Voussac;VOUSSAC;03140;03;ALLIER;1
03320;;Ygrande;YGRANDE;03160;03;ALLIER;1
03321;;Yzeure;YZEURE;03400;03;ALLIER;1
04001;;Aiglun;AIGLUN;04510;04;ALPES DE HAUTE PROVENCE;1
04004;;Allemagne-en-Provence;ALLEMAGNE-EN-PROVENCE;04550;04;ALPES DE HAUTE PROVENCE;1
04005;;Allons;ALLONS;04170;04;ALPES DE HAUTE PROVENCE;1
04006;;Allos;ALLOS;04260;04;ALPES DE HAUTE PROVENCE;1
04007;;Angles;ANGLES;04170;04;ALPES DE HAUTE PROVENCE;1
04008;;Annot;ANNOT;04240;04;ALPES DE HAUTE PROVENCE;1
04009;;Archail;ARCHAIL;04420;04;ALPES DE HAUTE PROVENCE;1
04012;;Aubenas-les-Alpes;AUBENAS-LES-ALPES;04110;04;ALPES DE HAUTE PROVENCE;1
04013;;Aubignosc;AUBIGNOSC;04200;04;ALPES DE HAUTE PROVENCE;1
04016;;Authon;AUTHON;04200;04;ALPES DE HAUTE PROVENCE;1
04017;;Auzet;AUZET;04140;04;ALPES DE HAUTE PROVENCE;1
04018;;Banon;BANON;04150;04;ALPES DE HAUTE PROVENCE;1
04019;;Barcelonnette;BARCELONNETTE;04400;04;ALPES DE HAUTE PROVENCE;1
04020;;Barles;BARLES;04140;04;ALPES DE HAUTE PROVENCE;1
04021;;Barras;BARRAS;04380;04;ALPES DE HAUTE PROVENCE;1
04022;;Barrême;BARREME;04330;04;ALPES DE HAUTE PROVENCE;1
04023;;Bayons;BAYONS;04250;04;ALPES DE HAUTE PROVENCE;1
04024;;Beaujeu;BEAUJEU;04420;04;ALPES DE HAUTE PROVENCE;1
04025;;Beauvezer;BEAUVEZER;04370;04;ALPES DE HAUTE PROVENCE;1
04026;;Bellaffaire;BELLAFFAIRE;04250;04;ALPES DE HAUTE PROVENCE;1
04027;;Bevons;BEVONS;04200;04;ALPES DE HAUTE PROVENCE;1
04028;;Beynes;BEYNES;04270;04;ALPES DE HAUTE PROVENCE;1
04030;;Blieux;BLIEUX;04330;04;ALPES DE HAUTE PROVENCE;1
04031;;Bras-d'Asse;BRAS-D'ASSE;04270;04;ALPES DE HAUTE PROVENCE;1
04032;;Braux;BRAUX;04240;04;ALPES DE HAUTE PROVENCE;1
04033;La;Bréole;BREOLE;04340;04;ALPES DE HAUTE PROVENCE;1
04034;La;Brillanne;BRILLANNE;04700;04;ALPES DE HAUTE PROVENCE;1
04035;;Brunet;BRUNET;04210;04;ALPES DE HAUTE PROVENCE;1
04036;Le;Brusquet;BRUSQUET;04420;04;ALPES DE HAUTE PROVENCE;1
04037;Le;Caire;CAIRE;04250;04;ALPES DE HAUTE PROVENCE;1
04039;;Castellane;CASTELLANE;04120;04;ALPES DE HAUTE PROVENCE;1
04040;Le;Castellard-Mélan;CASTELLARD-MELAN;04380;04;ALPES DE HAUTE PROVENCE;1
04041;Le;Castellet;CASTELLET;04700;04;ALPES DE HAUTE PROVENCE;1
04042;;Castellet-lès-Sausses;CASTELLET-LES-SAUSSES;04320;04;ALPES DE HAUTE PROVENCE;1
04043;;Val-de-Chalvagne;VAL-DE-CHALVAGNE;04320;04;ALPES DE HAUTE PROVENCE;1
04045;;Céreste;CERESTE;04280;04;ALPES DE HAUTE PROVENCE;1
04046;Le;Chaffaut-Saint-Jurson;CHAFFAUT-SAINT-JURSON;04510;04;ALPES DE HAUTE PROVENCE;1
04047;;Champtercier;CHAMPTERCIER;04660;04;ALPES DE HAUTE PROVENCE;1
04049;;Château-Arnoux-Saint-Auban;CHATEAU-ARNOUX-SAINT-AUBAN;04160;04;ALPES DE HAUTE PROVENCE;1
04050;;Châteaufort;CHATEAUFORT;04250;04;ALPES DE HAUTE PROVENCE;1
04051;;Châteauneuf-Miravail;CHATEAUNEUF-MIRAVAIL;04200;04;ALPES DE HAUTE PROVENCE;1
04053;;Châteauneuf-Val-Saint-Donat;CHATEAUNEUF-VAL-SAINT-DONAT;04200;04;ALPES DE HAUTE PROVENCE;1
04054;;Châteauredon;CHATEAUREDON;04270;04;ALPES DE HAUTE PROVENCE;1
04055;;Chaudon-Norante;CHAUDON-NORANTE;04330;04;ALPES DE HAUTE PROVENCE;1
04057;;Clamensane;CLAMENSANE;04250;04;ALPES DE HAUTE PROVENCE;1
04058;;Claret;CLARET;05110;04;HAUTES ALPES;1
04059;;Clumanc;CLUMANC;04330;04;ALPES DE HAUTE PROVENCE;1
04061;;Colmars;COLMARS;04370;04;ALPES DE HAUTE PROVENCE;1
04062;La;Condamine-Châtelard;CONDAMINE-CHATELARD;04530;04;ALPES DE HAUTE PROVENCE;1
04063;;Corbières;CORBIERES;04220;04;ALPES DE HAUTE PROVENCE;1
04065;;Cruis;CRUIS;04230;04;ALPES DE HAUTE PROVENCE;1
04066;;Curbans;CURBANS;05110;04;HAUTES ALPES;1
04067;;Curel;CUREL;04200;04;ALPES DE HAUTE PROVENCE;1
04068;;Dauphin;DAUPHIN;04300;04;ALPES DE HAUTE PROVENCE;1
04069;;Demandolx;DEMANDOLX;04120;04;ALPES DE HAUTE PROVENCE;1
04070;;Digne-les-Bains;DIGNE-LES-BAINS;04000;04;ALPES DE HAUTE PROVENCE;1
04072;;Draix;DRAIX;04420;04;ALPES DE HAUTE PROVENCE;1
04073;;Enchastrayes;ENCHASTRAYES;04400;04;ALPES DE HAUTE PROVENCE;1
04074;;Entrages;ENTRAGES;04000;04;ALPES DE HAUTE PROVENCE;1
04075;;Entrepierres;ENTREPIERRES;04200;04;ALPES DE HAUTE PROVENCE;1
04076;;Entrevaux;ENTREVAUX;04320;04;ALPES DE HAUTE PROVENCE;1
04077;;Entrevennes;ENTREVENNES;04700;04;ALPES DE HAUTE PROVENCE;1
04079;L';Escale;ESCALE;04160;04;ALPES DE HAUTE PROVENCE;1
04081;;Esparron-de-Verdon;ESPARRON-DE-VERDON;04550;04;ALPES DE HAUTE PROVENCE;1
04084;;Estoublon;ESTOUBLON;04270;04;ALPES DE HAUTE PROVENCE;1
04085;;Faucon-du-Caire;FAUCON-DU-CAIRE;04250;04;ALPES DE HAUTE PROVENCE;1
04086;;Faucon-de-Barcelonnette;FAUCON-DE-BARCELONNETTE;04400;04;ALPES DE HAUTE PROVENCE;1
04087;;Fontienne;FONTIENNE;04230;04;ALPES DE HAUTE PROVENCE;1
04088;;Forcalquier;FORCALQUIER;04300;04;ALPES DE HAUTE PROVENCE;1
04090;Le;Fugeret;FUGERET;04240;04;ALPES DE HAUTE PROVENCE;1
04091;;Ganagobie;GANAGOBIE;04310;04;ALPES DE HAUTE PROVENCE;1
04092;La;Garde;GARDE;04120;04;ALPES DE HAUTE PROVENCE;1
04093;;Gigors;GIGORS;04250;04;ALPES DE HAUTE PROVENCE;1
04094;;Gréoux-les-Bains;GREOUX-LES-BAINS;04800;04;ALPES DE HAUTE PROVENCE;1
04095;L';Hospitalet;HOSPITALET;04150;04;ALPES DE HAUTE PROVENCE;1
04096;;Jausiers;JAUSIERS;04850;04;ALPES DE HAUTE PROVENCE;1
04097;La;Javie;JAVIE;04420;04;ALPES DE HAUTE PROVENCE;1
04099;;Lambruisse;LAMBRUISSE;04170;04;ALPES DE HAUTE PROVENCE;1
04100;;Larche;LARCHE;04540;04;ALPES DE HAUTE PROVENCE;1
04101;;Lardiers;LARDIERS;04230;04;ALPES DE HAUTE PROVENCE;1
04102;Le;Lauzet-Ubaye;LAUZET-UBAYE;04340;04;ALPES DE HAUTE PROVENCE;1
04104;;Limans;LIMANS;04300;04;ALPES DE HAUTE PROVENCE;1
04106;;Lurs;LURS;04700;04;ALPES DE HAUTE PROVENCE;1
04107;;Majastres;MAJASTRES;04270;04;ALPES DE HAUTE PROVENCE;1
04108;;Malijai;MALIJAI;04350;04;ALPES DE HAUTE PROVENCE;1
04109;;Mallefougasse-Augès;MALLEFOUGASSE-AUGES;04230;04;ALPES DE HAUTE PROVENCE;1
04110;;Mallemoisson;MALLEMOISSON;04510;04;ALPES DE HAUTE PROVENCE;1
04111;;Mane;MANE;04300;04;ALPES DE HAUTE PROVENCE;1
04112;;Manosque;MANOSQUE;04100;04;ALPES DE HAUTE PROVENCE;1
04113;;Marcoux;MARCOUX;04420;04;ALPES DE HAUTE PROVENCE;1
04115;;Méailles;MEAILLES;04240;04;ALPES DE HAUTE PROVENCE;1
04116;Les;Mées;MEES;04190;04;ALPES DE HAUTE PROVENCE;1
04118;;Melve;MELVE;04250;04;ALPES DE HAUTE PROVENCE;1
04120;;Meyronnes;MEYRONNES;04540;04;ALPES DE HAUTE PROVENCE;1
04121;;Mézel;MEZEL;04270;04;ALPES DE HAUTE PROVENCE;1
04122;;Mirabeau;MIRABEAU;04510;04;ALPES DE HAUTE PROVENCE;1
04123;;Mison;MISON;04200;04;ALPES DE HAUTE PROVENCE;1
04124;;Montagnac-Montpezat;MONTAGNAC-MONTPEZAT;04500;04;ALPES DE HAUTE PROVENCE;1
04126;;Montclar;MONTCLAR;04140;04;ALPES DE HAUTE PROVENCE;1
04127;;Montfort;MONTFORT;04600;04;ALPES DE HAUTE PROVENCE;1
04128;;Montfuron;MONTFURON;04110;04;ALPES DE HAUTE PROVENCE;1
04129;;Montjustin;MONTJUSTIN;04110;04;ALPES DE HAUTE PROVENCE;1
04130;;Montlaux;MONTLAUX;04230;04;ALPES DE HAUTE PROVENCE;1
04132;;Montsalier;MONTSALIER;04150;04;ALPES DE HAUTE PROVENCE;1
04133;;Moriez;MORIEZ;04170;04;ALPES DE HAUTE PROVENCE;1
04134;La;Motte-du-Caire;MOTTE-DU-CAIRE;04250;04;ALPES DE HAUTE PROVENCE;1
04135;;Moustiers-Sainte-Marie;MOUSTIERS-SAINTE-MARIE;04360;04;ALPES DE HAUTE PROVENCE;1
04136;La;Mure-Argens;MURE-ARGENS;04170;04;ALPES DE HAUTE PROVENCE;1
04137;;Nibles;NIBLES;04250;04;ALPES DE HAUTE PROVENCE;1
04138;;Niozelles;NIOZELLES;04300;04;ALPES DE HAUTE PROVENCE;1
04139;;Noyers-sur-Jabron;NOYERS-SUR-JABRON;04200;04;ALPES DE HAUTE PROVENCE;1
04140;Les;Omergues;OMERGUES;04200;04;ALPES DE HAUTE PROVENCE;1
04141;;Ongles;ONGLES;04230;04;ALPES DE HAUTE PROVENCE;1
04142;;Oppedette;OPPEDETTE;04110;04;ALPES DE HAUTE PROVENCE;1
04143;;Oraison;ORAISON;04700;04;ALPES DE HAUTE PROVENCE;1
04144;La;Palud-sur-Verdon;PALUD-SUR-VERDON;04120;04;ALPES DE HAUTE PROVENCE;1
04145;;Peipin;PEIPIN;04200;04;ALPES DE HAUTE PROVENCE;1
04148;;Peyroules;PEYROULES;04120;04;ALPES DE HAUTE PROVENCE;1
04149;;Peyruis;PEYRUIS;04310;04;ALPES DE HAUTE PROVENCE;1
04150;;Piégut;PIEGUT;05130;04;HAUTES ALPES;1
04151;;Pierrerue;PIERRERUE;04300;04;ALPES DE HAUTE PROVENCE;1
04152;;Pierrevert;PIERREVERT;04860;04;ALPES DE HAUTE PROVENCE;1
04154;;Pontis;PONTIS;05160;04;HAUTES ALPES;1
04155;;Prads-Haute-Bléone;PRADS-HAUTE-BLEONE;04420;04;ALPES DE HAUTE PROVENCE;1
04156;;Puimichel;PUIMICHEL;04700;04;ALPES DE HAUTE PROVENCE;1
04157;;Puimoisson;PUIMOISSON;04410;04;ALPES DE HAUTE PROVENCE;1
04158;;Quinson;QUINSON;04500;04;ALPES DE HAUTE PROVENCE;1
04159;;Redortiers;REDORTIERS;04150;04;ALPES DE HAUTE PROVENCE;1
04160;;Reillanne;REILLANNE;04110;04;ALPES DE HAUTE PROVENCE;1
04161;;Méolans-Revel;MEOLANS-REVEL;04340;04;ALPES DE HAUTE PROVENCE;1
04162;;Revest-des-Brousses;REVEST-DES-BROUSSES;04150;04;ALPES DE HAUTE PROVENCE;1
04163;;Revest-du-Bion;REVEST-DU-BION;04150;04;ALPES DE HAUTE PROVENCE;1
04164;;Revest-Saint-Martin;REVEST-SAINT-MARTIN;04230;04;ALPES DE HAUTE PROVENCE;1
04166;;Riez;RIEZ;04500;04;ALPES DE HAUTE PROVENCE;1
04167;La;Robine-sur-Galabre;ROBINE-SUR-GALABRE;04000;04;ALPES DE HAUTE PROVENCE;1
04169;La;Rochegiron;ROCHEGIRON;04150;04;ALPES DE HAUTE PROVENCE;1
04170;La;Rochette;ROCHETTE;06260;04;ALPES MARITIMES;1
04171;;Rougon;ROUGON;04120;04;ALPES DE HAUTE PROVENCE;1
04172;;Roumoules;ROUMOULES;04500;04;ALPES DE HAUTE PROVENCE;1
04173;;Saint-André-les-Alpes;SAINT-ANDRE-LES-ALPES;04170;04;ALPES DE HAUTE PROVENCE;1
04174;;Saint-Benoît;SAINT-BENOIT;04240;04;ALPES DE HAUTE PROVENCE;1
04175;;Sainte-Croix-à-Lauze;SAINTE-CROIX-A-LAUZE;04110;04;ALPES DE HAUTE PROVENCE;1
04176;;Sainte-Croix-du-Verdon;SAINTE-CROIX-DU-VERDON;04500;04;ALPES DE HAUTE PROVENCE;1
04177;;Hautes-Duyes;HAUTES-DUYES;04380;04;ALPES DE HAUTE PROVENCE;1
04178;;Saint-Étienne-les-Orgues;SAINT-ETIENNE-LES-ORGUES;04230;04;ALPES DE HAUTE PROVENCE;1
04179;;Saint-Geniez;SAINT-GENIEZ;04200;04;ALPES DE HAUTE PROVENCE;1
04180;;Saint-Jacques;SAINT-JACQUES;04330;04;ALPES DE HAUTE PROVENCE;1
04181;;Saint-Jeannet;SAINT-JEANNET;04270;04;ALPES DE HAUTE PROVENCE;1
04182;;Saint-Julien-d'Asse;SAINT-JULIEN-D'ASSE;04270;04;ALPES DE HAUTE PROVENCE;1
04183;;Saint-Julien-du-Verdon;SAINT-JULIEN-DU-VERDON;04170;04;ALPES DE HAUTE PROVENCE;1
04184;;Saint-Jurs;SAINT-JURS;04410;04;ALPES DE HAUTE PROVENCE;1
04186;;Saint-Laurent-du-Verdon;SAINT-LAURENT-DU-VERDON;04500;04;ALPES DE HAUTE PROVENCE;1
04187;;Saint-Lions;SAINT-LIONS;04330;04;ALPES DE HAUTE PROVENCE;1
04188;;Saint-Maime;SAINT-MAIME;04300;04;ALPES DE HAUTE PROVENCE;1
04189;;Saint-Martin-de-Brômes;SAINT-MARTIN-DE-BROMES;04800;04;ALPES DE HAUTE PROVENCE;1
04190;;Saint-Martin-les-Eaux;SAINT-MARTIN-LES-EAUX;04870;04;ALPES DE HAUTE PROVENCE;1
04191;;Saint-Martin-lès-Seyne;SAINT-MARTIN-LES-SEYNE;04460;04;ALPES DE HAUTE PROVENCE;1
04192;;Saint-Michel-l'Observatoire;SAINT-MICHEL-L'OBSERVATOIRE;04870;04;ALPES DE HAUTE PROVENCE;1
04193;;Saint-Paul-sur-Ubaye;SAINT-PAUL-SUR-UBAYE;04530;04;ALPES DE HAUTE PROVENCE;1
04194;;Saint-Pierre;SAINT-PIERRE;06260;04;ALPES MARITIMES;1
04195;;Saint-Pons;SAINT-PONS;04400;04;ALPES DE HAUTE PROVENCE;1
04197;;Sainte-Tulle;SAINTE-TULLE;04220;04;ALPES DE HAUTE PROVENCE;1
04198;;Saint-Vincent-les-Forts;SAINT-VINCENT-LES-FORTS;04340;04;ALPES DE HAUTE PROVENCE;1
04199;;Saint-Vincent-sur-Jabron;SAINT-VINCENT-SUR-JABRON;04200;04;ALPES DE HAUTE PROVENCE;1
04200;;Salignac;SALIGNAC;04290;04;ALPES DE HAUTE PROVENCE;1
04201;;Saumane;SAUMANE;04150;04;ALPES DE HAUTE PROVENCE;1
04202;;Sausses;SAUSSES;04320;04;ALPES DE HAUTE PROVENCE;1
04203;;Selonnet;SELONNET;04460;04;ALPES DE HAUTE PROVENCE;1
04204;;Senez;SENEZ;04330;04;ALPES DE HAUTE PROVENCE;1
04205;;Seyne;SEYNE;04140;04;ALPES DE HAUTE PROVENCE;1
04206;;Sigonce;SIGONCE;04300;04;ALPES DE HAUTE PROVENCE;1
04207;;Sigoyer;SIGOYER;04200;04;ALPES DE HAUTE PROVENCE;1
04208;;Simiane-la-Rotonde;SIMIANE-LA-ROTONDE;04150;04;ALPES DE HAUTE PROVENCE;1
04209;;Sisteron;SISTERON;04200;04;ALPES DE HAUTE PROVENCE;1
04210;;Soleilhas;SOLEILHAS;04120;04;ALPES DE HAUTE PROVENCE;1
04211;;Sourribes;SOURRIBES;04290;04;ALPES DE HAUTE PROVENCE;1
04214;;Tartonne;TARTONNE;04330;04;ALPES DE HAUTE PROVENCE;1
04216;;Thèze;THEZE;04200;04;ALPES DE HAUTE PROVENCE;1
04217;;Thoard;THOARD;04380;04;ALPES DE HAUTE PROVENCE;1
04218;;Thorame-Basse;THORAME-BASSE;04170;04;ALPES DE HAUTE PROVENCE;1
04219;;Thorame-Haute;THORAME-HAUTE;04170;04;ALPES DE HAUTE PROVENCE;1
04220;Les;Thuiles;THUILES;04400;04;ALPES DE HAUTE PROVENCE;1
04222;;Turriers;TURRIERS;04250;04;ALPES DE HAUTE PROVENCE;1
04224;;Ubraye;UBRAYE;04240;04;ALPES DE HAUTE PROVENCE;1
04226;;Uvernet-Fours;UVERNET-FOURS;04400;04;ALPES DE HAUTE PROVENCE;1
04227;;Vachères;VACHERES;04110;04;ALPES DE HAUTE PROVENCE;1
04228;;Valavoire;VALAVOIRE;04250;04;ALPES DE HAUTE PROVENCE;1
04229;;Valbelle;VALBELLE;04200;04;ALPES DE HAUTE PROVENCE;1
04230;;Valensole;VALENSOLE;04210;04;ALPES DE HAUTE PROVENCE;1
04231;;Valernes;VALERNES;04200;04;ALPES DE HAUTE PROVENCE;1
04233;;Vaumeilh;VAUMEILH;04200;04;ALPES DE HAUTE PROVENCE;1
04234;;Venterol;VENTEROL;05130;04;HAUTES ALPES;1
04235;;Verdaches;VERDACHES;04140;04;ALPES DE HAUTE PROVENCE;1
04236;;Vergons;VERGONS;04170;04;ALPES DE HAUTE PROVENCE;1
04237;Le;Vernet;VERNET;04140;04;ALPES DE HAUTE PROVENCE;1
04240;;Villars-Colmars;VILLARS-COLMARS;04640;04;ALPES DE HAUTE PROVENCE;1
04241;;Villemus;VILLEMUS;04110;04;ALPES DE HAUTE PROVENCE;1
04242;;Villeneuve;VILLENEUVE;04180;04;ALPES DE HAUTE PROVENCE;1
04244;;Volonne;VOLONNE;04290;04;ALPES DE HAUTE PROVENCE;1
04245;;Volx;VOLX;04130;04;ALPES DE HAUTE PROVENCE;1
05001;;Abriès;ABRIES;05460;05;HAUTES ALPES;1
05002;;Agnières-en-Dévoluy;AGNIERES-EN-DEVOLUY;05250;05;HAUTES ALPES;1
05003;;Aiguilles;AIGUILLES;05470;05;HAUTES ALPES;1
05004;;Ancelle;ANCELLE;05260;05;HAUTES ALPES;1
05005;;Antonaves;ANTONAVES;05300;05;HAUTES ALPES;1
05006;L';Argentière-la-Bessée;ARGENTIERE-LA-BESSEE;05120;05;HAUTES ALPES;1
05007;;Arvieux;ARVIEUX;05350;05;HAUTES ALPES;1
05008;;Aspremont;ASPREMONT;05140;05;HAUTES ALPES;1
05009;;Aspres-lès-Corps;ASPRES-LES-CORPS;05800;05;HAUTES ALPES;1
05010;;Aspres-sur-Buëch;ASPRES-SUR-BUECH;05140;05;HAUTES ALPES;1
05011;;Avançon;AVANCON;05230;05;HAUTES ALPES;1
05012;;Baratier;BARATIER;05200;05;HAUTES ALPES;1
05013;;Barcillonnette;BARCILLONNETTE;05110;05;HAUTES ALPES;1
05014;;Barret-sur-Méouge;BARRET-SUR-MEOUGE;05300;05;HAUTES ALPES;1
05016;La;Bâtie-Montsaléon;BATIE-MONTSALEON;05700;05;HAUTES ALPES;1
05017;La;Bâtie-Neuve;BATIE-NEUVE;05230;05;HAUTES ALPES;1
05018;La;Bâtie-Vieille;BATIE-VIEILLE;05000;05;HAUTES ALPES;1
05019;La;Beaume;BEAUME;05140;05;HAUTES ALPES;1
05020;;Bénévent-et-Charbillac;BENEVENT-ET-CHARBILLAC;05500;05;HAUTES ALPES;1
05021;Le;Bersac;BERSAC;05700;05;HAUTES ALPES;1
05022;;Bréziers;BREZIERS;05190;05;HAUTES ALPES;1
05023;;Briançon;BRIANCON;05100;05;HAUTES ALPES;1
05024;;Bruis;BRUIS;05150;05;HAUTES ALPES;1
05025;;Buissard;BUISSARD;05500;05;HAUTES ALPES;1
05026;;Ceillac;CEILLAC;05600;05;HAUTES ALPES;1
05027;;Cervières;CERVIERES;05100;05;HAUTES ALPES;1
05028;;Chabestan;CHABESTAN;05400;05;HAUTES ALPES;1
05029;;Chabottes;CHABOTTES;05260;05;HAUTES ALPES;1
05031;;Champcella;CHAMPCELLA;05310;05;HAUTES ALPES;1
05032;;Champoléon;CHAMPOLEON;05260;05;HAUTES ALPES;1
05033;;Chanousse;CHANOUSSE;05700;05;HAUTES ALPES;1
05034;;Châteauneuf-de-Chabre;CHATEAUNEUF-DE-CHABRE;05300;05;HAUTES ALPES;1
05035;;Châteauneuf-d'Oze;CHATEAUNEUF-D'OZE;05400;05;HAUTES ALPES;1
05036;;Châteauroux-les-Alpes;CHATEAUROUX-LES-ALPES;05380;05;HAUTES ALPES;1
05037;;Châteauvieux;CHATEAUVIEUX;05000;05;HAUTES ALPES;1
05038;;Château-Ville-Vieille;CHATEAU-VILLE-VIEILLE;05460;05;HAUTES ALPES;1
05039;;Chauffayer;CHAUFFAYER;05800;05;HAUTES ALPES;1
05040;;Chorges;CHORGES;05230;05;HAUTES ALPES;1
05042;La;Cluse;CLUSE;05250;05;HAUTES ALPES;1
05043;Les;Costes;COSTES;05500;05;HAUTES ALPES;1
05044;;Crévoux;CREVOUX;05200;05;HAUTES ALPES;1
05045;;Crots;CROTS;05200;05;HAUTES ALPES;1
05046;;Embrun;EMBRUN;05200;05;HAUTES ALPES;1
05047;;Éourres;EOURRES;26560;05;DROME;1
05048;L';Épine;EPINE;05700;05;HAUTES ALPES;1
05049;;Esparron;ESPARRON;05110;05;HAUTES ALPES;1
05050;;Espinasses;ESPINASSES;05190;05;HAUTES ALPES;1
05051;;Étoile-Saint-Cyrice;ETOILE-SAINT-CYRICE;05700;05;HAUTES ALPES;1
05052;;Eygliers;EYGLIERS;05600;05;HAUTES ALPES;1
05053;;Eyguians;EYGUIANS;05300;05;HAUTES ALPES;1
05054;La;Fare-en-Champsaur;FARE-EN-CHAMPSAUR;05500;05;HAUTES ALPES;1
05055;La;Faurie;FAURIE;05140;05;HAUTES ALPES;1
05056;;Forest-Saint-Julien;FOREST-SAINT-JULIEN;05260;05;HAUTES ALPES;1
05057;;Fouillouse;FOUILLOUSE;05130;05;HAUTES ALPES;1
05058;;Freissinières;FREISSINIERES;05310;05;HAUTES ALPES;1
05059;La;Freissinouse;FREISSINOUSE;05000;05;HAUTES ALPES;1
05060;;Furmeyer;FURMEYER;05400;05;HAUTES ALPES;1
05061;;Gap;GAP;05000;05;HAUTES ALPES;1
05062;Le;Glaizil;GLAIZIL;05800;05;HAUTES ALPES;1
05063;La;Grave;GRAVE;05320;05;HAUTES ALPES;1
05064;La;Chapelle-en-Valgaudémar;CHAPELLE-EN-VALGAUDEMAR;05800;05;HAUTES ALPES;1
05065;;Guillestre;GUILLESTRE;05600;05;HAUTES ALPES;1
05066;La;Haute-Beaume;HAUTE-BEAUME;05140;05;HAUTES ALPES;1
05067;Les;Infournas;INFOURNAS;05500;05;HAUTES ALPES;1
05068;;Jarjayes;JARJAYES;05130;05;HAUTES ALPES;1
05069;;Lagrand;LAGRAND;05300;05;HAUTES ALPES;1
05070;;Laragne-Montéglin;LARAGNE-MONTEGLIN;05300;05;HAUTES ALPES;1
05071;;Lardier-et-Valença;LARDIER-ET-VALENCA;05110;05;HAUTES ALPES;1
05072;;Laye;LAYE;05500;05;HAUTES ALPES;1
05073;;Lazer;LAZER;05300;05;HAUTES ALPES;1
05074;;Lettret;LETTRET;05130;05;HAUTES ALPES;1
05075;;Manteyer;MANTEYER;05400;05;HAUTES ALPES;1
05076;;Méreuil;MEREUIL;05700;05;HAUTES ALPES;1
05077;;Molines-en-Queyras;MOLINES-EN-QUEYRAS;05350;05;HAUTES ALPES;1
05078;;Monêtier-Allemont;MONETIER-ALLEMONT;05110;05;HAUTES ALPES;1
05079;Le;Monêtier-les-Bains;MONETIER-LES-BAINS;05220;05;HAUTES ALPES;1
05080;;Montbrand;MONTBRAND;05140;05;HAUTES ALPES;1
05081;;Montclus;MONTCLUS;05700;05;HAUTES ALPES;1
05082;;Mont-Dauphin;MONT-DAUPHIN;05600;05;HAUTES ALPES;1
05084;;Montgardin;MONTGARDIN;05230;05;HAUTES ALPES;1
05085;;Montgenèvre;MONTGENEVRE;05100;05;HAUTES ALPES;1
05086;;Montjay;MONTJAY;05150;05;HAUTES ALPES;1
05087;;Montmaur;MONTMAUR;05400;05;HAUTES ALPES;1
05088;;Montmorin;MONTMORIN;05150;05;HAUTES ALPES;1
05089;;Montrond;MONTROND;05700;05;HAUTES ALPES;1
05090;La;Motte-en-Champsaur;MOTTE-EN-CHAMPSAUR;05500;05;HAUTES ALPES;1
05091;;Moydans;MOYDANS;05150;05;HAUTES ALPES;1
05092;;Neffes;NEFFES;05000;05;HAUTES ALPES;1
05093;;Névache;NEVACHE;05100;05;HAUTES ALPES;1
05094;;Nossage-et-Bénévent;NOSSAGE-ET-BENEVENT;05700;05;HAUTES ALPES;1
05095;Le;Noyer;NOYER;05500;05;HAUTES ALPES;1
05096;;Orcières;ORCIERES;05170;05;HAUTES ALPES;1
05097;;Orpierre;ORPIERRE;05700;05;HAUTES ALPES;1
05098;Les;Orres;ORRES;05200;05;HAUTES ALPES;1
05099;;Oze;OZE;05400;05;HAUTES ALPES;1
05100;;Pelleautier;PELLEAUTIER;05000;05;HAUTES ALPES;1
05101;;Pelvoux;PELVOUX;05340;05;HAUTES ALPES;1
05102;La;Piarre;PIARRE;05700;05;HAUTES ALPES;1
05103;Le;Poët;POET;05300;05;HAUTES ALPES;1
05104;;Poligny;POLIGNY;05500;05;HAUTES ALPES;1
05106;;Prunières;PRUNIERES;05230;05;HAUTES ALPES;1
05107;;Puy-Saint-André;PUY-SAINT-ANDRE;05100;05;HAUTES ALPES;1
05108;;Puy-Saint-Eusèbe;PUY-SAINT-EUSEBE;05200;05;HAUTES ALPES;1
05109;;Puy-Saint-Pierre;PUY-SAINT-PIERRE;05100;05;HAUTES ALPES;1
05110;;Puy-Saint-Vincent;PUY-SAINT-VINCENT;05290;05;HAUTES ALPES;1
05111;;Puy-Sanières;PUY-SANIERES;05200;05;HAUTES ALPES;1
05112;;Rabou;RABOU;05400;05;HAUTES ALPES;1
05113;;Rambaud;RAMBAUD;05000;05;HAUTES ALPES;1
05114;;Réallon;REALLON;05160;05;HAUTES ALPES;1
05115;;Remollon;REMOLLON;05190;05;HAUTES ALPES;1
05116;;Réotier;REOTIER;05600;05;HAUTES ALPES;1
05117;;Ribeyret;RIBEYRET;05150;05;HAUTES ALPES;1
05118;;Ribiers;RIBIERS;05300;05;HAUTES ALPES;1
05119;;Risoul;RISOUL;05600;05;HAUTES ALPES;1
05120;;Ristolas;RISTOLAS;05460;05;HAUTES ALPES;1
05121;;Rochebrune;ROCHEBRUNE;05190;05;HAUTES ALPES;1
05122;La;Roche-de-Rame;ROCHE-DE-RAME;05310;05;HAUTES ALPES;1
05123;La;Roche-des-Arnauds;ROCHE-DES-ARNAUDS;05400;05;HAUTES ALPES;1
05124;La;Rochette;ROCHETTE;05000;05;HAUTES ALPES;1
05126;;Rosans;ROSANS;05150;05;HAUTES ALPES;1
05127;;Rousset;ROUSSET;05190;05;HAUTES ALPES;1
05128;;Saint-André-d'Embrun;SAINT-ANDRE-D'EMBRUN;05200;05;HAUTES ALPES;1
05129;;Saint-André-de-Rosans;SAINT-ANDRE-DE-ROSANS;05150;05;HAUTES ALPES;1
05130;;Saint-Apollinaire;SAINT-APOLLINAIRE;05160;05;HAUTES ALPES;1
05131;;Saint-Auban-d'Oze;SAINT-AUBAN-D'OZE;05400;05;HAUTES ALPES;1
05132;;Saint-Bonnet-en-Champsaur;SAINT-BONNET-EN-CHAMPSAUR;05500;05;HAUTES ALPES;1
05133;;Saint-Chaffrey;SAINT-CHAFFREY;05330;05;HAUTES ALPES;1
05134;;Saint-Clément-sur-Durance;SAINT-CLEMENT-SUR-DURANCE;05600;05;HAUTES ALPES;1
05135;;Sainte-Colombe;SAINTE-COLOMBE;05700;05;HAUTES ALPES;1
05136;;Saint-Crépin;SAINT-CREPIN;05600;05;HAUTES ALPES;1
05138;;Saint-Disdier;SAINT-DISDIER;05250;05;HAUTES ALPES;1
05139;;Saint-Étienne-en-Dévoluy;SAINT-ETIENNE-EN-DEVOLUY;05250;05;HAUTES ALPES;1
05140;;Saint-Étienne-le-Laus;SAINT-ETIENNE-LE-LAUS;05130;05;HAUTES ALPES;1
05141;;Saint-Eusèbe-en-Champsaur;SAINT-EUSEBE-EN-CHAMPSAUR;05500;05;HAUTES ALPES;1
05142;;Saint-Firmin;SAINT-FIRMIN;05800;05;HAUTES ALPES;1
05143;;Saint-Genis;SAINT-GENIS;05300;05;HAUTES ALPES;1
05144;;Saint-Jacques-en-Valgodemard;SAINT-JACQUES-EN-VALGODEMARD;05800;05;HAUTES ALPES;1
05145;;Saint-Jean-Saint-Nicolas;SAINT-JEAN-SAINT-NICOLAS;05260;05;HAUTES ALPES;1
05146;;Saint-Julien-en-Beauchêne;SAINT-JULIEN-EN-BEAUCHENE;05140;05;HAUTES ALPES;1
05147;;Saint-Julien-en-Champsaur;SAINT-JULIEN-EN-CHAMPSAUR;05500;05;HAUTES ALPES;1
05148;;Saint-Laurent-du-Cros;SAINT-LAURENT-DU-CROS;05500;05;HAUTES ALPES;1
05149;;Saint-Léger-les-Mélèzes;SAINT-LEGER-LES-MELEZES;05260;05;HAUTES ALPES;1
05150;;Sainte-Marie;SAINTE-MARIE;05150;05;HAUTES ALPES;1
05151;;Saint-Martin-de-Queyrières;SAINT-MARTIN-DE-QUEYRIERES;05120;05;HAUTES ALPES;1
05152;;Saint-Maurice-en-Valgodemard;SAINT-MAURICE-EN-VALGODEMARD;05800;05;HAUTES ALPES;1
05153;;Saint-Michel-de-Chaillol;SAINT-MICHEL-DE-CHAILLOL;05260;05;HAUTES ALPES;1
05154;;Saint-Pierre-d'Argençon;SAINT-PIERRE-D'ARGENCON;05140;05;HAUTES ALPES;1
05155;;Saint-Pierre-Avez;SAINT-PIERRE-AVEZ;05300;05;HAUTES ALPES;1
05156;;Saint-Sauveur;SAINT-SAUVEUR;05200;05;HAUTES ALPES;1
05157;;Saint-Véran;SAINT-VERAN;05350;05;HAUTES ALPES;1
05158;Le;Saix;SAIX;05400;05;HAUTES ALPES;1
05159;;Saléon;SALEON;05300;05;HAUTES ALPES;1
05160;;Salérans;SALERANS;05300;05;HAUTES ALPES;1
05161;La;Salle-les-Alpes;SALLE-LES-ALPES;05240;05;HAUTES ALPES;1
05162;La;Saulce;SAULCE;05110;05;HAUTES ALPES;1
05163;Le;Sauze-du-Lac;SAUZE-DU-LAC;05160;05;HAUTES ALPES;1
05164;;Savines-le-Lac;SAVINES-LE-LAC;05160;05;HAUTES ALPES;1
05165;;Savournon;SAVOURNON;05700;05;HAUTES ALPES;1
05166;;Serres;SERRES;05700;05;HAUTES ALPES;1
05167;;Sigottier;SIGOTTIER;05700;05;HAUTES ALPES;1
05168;;Sigoyer;SIGOYER;05130;05;HAUTES ALPES;1
05169;;Sorbiers;SORBIERS;05150;05;HAUTES ALPES;1
05170;;Tallard;TALLARD;05130;05;HAUTES ALPES;1
05171;;Théus;THEUS;05190;05;HAUTES ALPES;1
05172;;Trescléoux;TRESCLEOUX;05700;05;HAUTES ALPES;1
05173;;Upaix;UPAIX;05300;05;HAUTES ALPES;1
05174;;Val-des-Prés;VAL-DES-PRES;05100;05;HAUTES ALPES;1
05175;;Vallouise;VALLOUISE;05290;05;HAUTES ALPES;1
05176;;Valserres;VALSERRES;05130;05;HAUTES ALPES;1
05177;;Vars;VARS;05560;05;HAUTES ALPES;1
05178;;Ventavon;VENTAVON;05300;05;HAUTES ALPES;1
05179;;Veynes;VEYNES;05400;05;HAUTES ALPES;1
05180;Les;Vigneaux;VIGNEAUX;05120;05;HAUTES ALPES;1
05181;;Villar-d'Arêne;VILLAR-D'ARENE;05480;05;HAUTES ALPES;1
05182;;Villar-Loubière;VILLAR-LOUBIERE;05800;05;HAUTES ALPES;1
05183;;Villar-Saint-Pancrace;VILLAR-SAINT-PANCRACE;05100;05;HAUTES ALPES;1
05184;;Vitrolles;VITROLLES;05110;05;HAUTES ALPES;1
06001;;Aiglun;AIGLUN;06910;06;ALPES MARITIMES;1
06002;;Amirat;AMIRAT;06910;06;ALPES MARITIMES;1
06003;;Andon;ANDON;06750;06;ALPES MARITIMES;1
06004;;Antibes;ANTIBES;06600;06;ALPES MARITIMES;1
06005;;Ascros;ASCROS;06260;06;ALPES MARITIMES;1
06006;;Aspremont;ASPREMONT;06790;06;ALPES MARITIMES;1
06007;;Auribeau-sur-Siagne;AURIBEAU-SUR-SIAGNE;06810;06;ALPES MARITIMES;1
06008;;Auvare;AUVARE;06260;06;ALPES MARITIMES;1
06009;;Bairols;BAIROLS;06420;06;ALPES MARITIMES;1
06010;Le;Bar-sur-Loup;BAR-SUR-LOUP;06620;06;ALPES MARITIMES;1
06011;;Beaulieu-sur-Mer;BEAULIEU-SUR-MER;06310;06;ALPES MARITIMES;1
06012;;Beausoleil;BEAUSOLEIL;06240;06;ALPES MARITIMES;1
06013;;Belvédère;BELVEDERE;06450;06;ALPES MARITIMES;1
06014;;Bendejun;BENDEJUN;06390;06;ALPES MARITIMES;1
06015;;Berre-les-Alpes;BERRE-LES-ALPES;06390;06;ALPES MARITIMES;1
06016;;Beuil;BEUIL;06470;06;ALPES MARITIMES;1
06017;;Bézaudun-les-Alpes;BEZAUDUN-LES-ALPES;06510;06;ALPES MARITIMES;1
06018;;Biot;BIOT;06410;06;ALPES MARITIMES;1
06019;;Blausasc;BLAUSASC;06440;06;ALPES MARITIMES;1
06020;La;Bollène-Vésubie;BOLLENE-VESUBIE;06450;06;ALPES MARITIMES;1
06021;;Bonson;BONSON;06830;06;ALPES MARITIMES;1
06022;;Bouyon;BOUYON;06510;06;ALPES MARITIMES;1
06023;;Breil-sur-Roya;BREIL-SUR-ROYA;06540;06;ALPES MARITIMES;1
06024;;Briançonnet;BRIANCONNET;06850;06;ALPES MARITIMES;1
06025;Le;Broc;BROC;06510;06;ALPES MARITIMES;1
06026;;Cabris;CABRIS;06530;06;ALPES MARITIMES;1
06027;;Cagnes-sur-Mer;CAGNES-SUR-MER;06800;06;ALPES MARITIMES;1
06028;;Caille;CAILLE;06750;06;ALPES MARITIMES;1
06029;;Cannes;CANNES;06400;06;ALPES MARITIMES;1
06030;Le;Cannet;CANNET;06110;06;ALPES MARITIMES;1
06031;;Cantaron;CANTARON;06340;06;ALPES MARITIMES;1
06032;;Cap-d'Ail;CAP-D'AIL;06320;06;ALPES MARITIMES;1
06033;;Carros;CARROS;06510;06;ALPES MARITIMES;1
06034;;Castagniers;CASTAGNIERS;06670;06;ALPES MARITIMES;1
06035;;Castellar;CASTELLAR;06500;06;ALPES MARITIMES;1
06036;;Castillon;CASTILLON;06500;06;ALPES MARITIMES;1
06037;;Caussols;CAUSSOLS;06460;06;ALPES MARITIMES;1
06038;;Châteauneuf-Grasse;CHATEAUNEUF-GRASSE;06740;06;ALPES MARITIMES;1
06039;;Châteauneuf-Villevieille;CHATEAUNEUF-VILLEVIEILLE;06390;06;ALPES MARITIMES;1
06040;;Châteauneuf-d'Entraunes;CHATEAUNEUF-D'ENTRAUNES;06470;06;ALPES MARITIMES;1
06041;;Cipières;CIPIERES;06620;06;ALPES MARITIMES;1
06042;;Clans;CLANS;06420;06;ALPES MARITIMES;1
06043;;Coaraze;COARAZE;06390;06;ALPES MARITIMES;1
06044;La;Colle-sur-Loup;COLLE-SUR-LOUP;06480;06;ALPES MARITIMES;1
06045;;Collongues;COLLONGUES;06910;06;ALPES MARITIMES;1
06046;;Colomars;COLOMARS;06670;06;ALPES MARITIMES;1
06047;;Conségudes;CONSEGUDES;06510;06;ALPES MARITIMES;1
06048;;Contes;CONTES;06390;06;ALPES MARITIMES;1
06049;;Courmes;COURMES;06620;06;ALPES MARITIMES;1
06050;;Coursegoules;COURSEGOULES;06140;06;ALPES MARITIMES;1
06051;La;Croix-sur-Roudoule;CROIX-SUR-ROUDOULE;06260;06;ALPES MARITIMES;1
06052;;Cuébris;CUEBRIS;06910;06;ALPES MARITIMES;1
06053;;Daluis;DALUIS;06470;06;ALPES MARITIMES;1
06054;;Drap;DRAP;06340;06;ALPES MARITIMES;1
06055;;Duranus;DURANUS;06670;06;ALPES MARITIMES;1
06056;;Entraunes;ENTRAUNES;06470;06;ALPES MARITIMES;1
06057;L';Escarène;ESCARENE;06440;06;ALPES MARITIMES;1
06058;;Escragnolles;ESCRAGNOLLES;06460;06;ALPES MARITIMES;1
06059;;Èze;EZE;06360;06;ALPES MARITIMES;1
06060;;Falicon;FALICON;06950;06;ALPES MARITIMES;1
06061;Les;Ferres;FERRES;06510;06;ALPES MARITIMES;1
06062;;Fontan;FONTAN;06540;06;ALPES MARITIMES;1
06063;;Gars;GARS;06850;06;ALPES MARITIMES;1
06064;;Gattières;GATTIERES;06510;06;ALPES MARITIMES;1
06065;La;Gaude;GAUDE;06610;06;ALPES MARITIMES;1
06066;;Gilette;GILETTE;06830;06;ALPES MARITIMES;1
06067;;Gorbio;GORBIO;06500;06;ALPES MARITIMES;1
06068;;Gourdon;GOURDON;06620;06;ALPES MARITIMES;1
06069;;Grasse;GRASSE;06130;06;ALPES MARITIMES;1
06070;;Gréolières;GREOLIERES;06620;06;ALPES MARITIMES;1
06071;;Guillaumes;GUILLAUMES;06470;06;ALPES MARITIMES;1
06072;;Ilonse;ILONSE;06420;06;ALPES MARITIMES;1
06073;;Isola;ISOLA;06420;06;ALPES MARITIMES;1
06074;;Lantosque;LANTOSQUE;06450;06;ALPES MARITIMES;1
06075;;Levens;LEVENS;06670;06;ALPES MARITIMES;1
06076;;Lieuche;LIEUCHE;06260;06;ALPES MARITIMES;1
06077;;Lucéram;LUCERAM;06440;06;ALPES MARITIMES;1
06078;;Malaussène;MALAUSSENE;06710;06;ALPES MARITIMES;1
06079;;Mandelieu-la-Napoule;MANDELIEU-LA-NAPOULE;06210;06;ALPES MARITIMES;1
06080;;Marie;MARIE;06420;06;ALPES MARITIMES;1
06081;Le;Mas;MAS;06910;06;ALPES MARITIMES;1
06082;;Massoins;MASSOINS;06710;06;ALPES MARITIMES;1
06083;;Menton;MENTON;06500;06;ALPES MARITIMES;1
06084;;Mouans-Sartoux;MOUANS-SARTOUX;06370;06;ALPES MARITIMES;1
06085;;Mougins;MOUGINS;06250;06;ALPES MARITIMES;1
06086;;Moulinet;MOULINET;06380;06;ALPES MARITIMES;1
06087;Les;Mujouls;MUJOULS;06910;06;ALPES MARITIMES;1
06088;;Nice;NICE;06000;06;ALPES MARITIMES;1
06089;;Opio;OPIO;06650;06;ALPES MARITIMES;1
06090;;Pégomas;PEGOMAS;06580;06;ALPES MARITIMES;1
06091;;Peille;PEILLE;06440;06;ALPES MARITIMES;1
06092;;Peillon;PEILLON;06440;06;ALPES MARITIMES;1
06093;La;Penne;PENNE;06260;06;ALPES MARITIMES;1
06094;;Péone;PEONE;06470;06;ALPES MARITIMES;1
06095;;Peymeinade;PEYMEINADE;06530;06;ALPES MARITIMES;1
06096;;Pierlas;PIERLAS;06260;06;ALPES MARITIMES;1
06097;;Pierrefeu;PIERREFEU;06910;06;ALPES MARITIMES;1
06098;;Puget-Rostang;PUGET-ROSTANG;06260;06;ALPES MARITIMES;1
06099;;Puget-Théniers;PUGET-THENIERS;06260;06;ALPES MARITIMES;1
06100;;Revest-les-Roches;REVEST-LES-ROCHES;06830;06;ALPES MARITIMES;1
06101;;Rigaud;RIGAUD;06260;06;ALPES MARITIMES;1
06102;;Rimplas;RIMPLAS;06420;06;ALPES MARITIMES;1
06103;;Roquebillière;ROQUEBILLIERE;06450;06;ALPES MARITIMES;1
06104;;Roquebrune-Cap-Martin;ROQUEBRUNE-CAP-MARTIN;06190;06;ALPES MARITIMES;1
06105;;Roquefort-les-Pins;ROQUEFORT-LES-PINS;06330;06;ALPES MARITIMES;1
06106;;Roquesteron;ROQUESTERON;06910;06;ALPES MARITIMES;1
06107;;Roquestéron-Grasse;ROQUESTERON-GRASSE;06910;06;ALPES MARITIMES;1
06108;La;Roquette-sur-Siagne;ROQUETTE-SUR-SIAGNE;06550;06;ALPES MARITIMES;1
06109;La;Roquette-sur-Var;ROQUETTE-SUR-VAR;06670;06;ALPES MARITIMES;1
06110;;Roubion;ROUBION;06420;06;ALPES MARITIMES;1
06111;;Roure;ROURE;06420;06;ALPES MARITIMES;1
06112;Le;Rouret;ROURET;06650;06;ALPES MARITIMES;1
06113;;Sainte-Agnès;SAINTE-AGNES;06500;06;ALPES MARITIMES;1
06114;;Saint-André-de-la-Roche;SAINT-ANDRE-DE-LA-ROCHE;06730;06;ALPES MARITIMES;1
06115;;Saint-Antonin;SAINT-ANTONIN;06260;06;ALPES MARITIMES;1
06116;;Saint-Auban;SAINT-AUBAN;06850;06;ALPES MARITIMES;1
06117;;Saint-Blaise;SAINT-BLAISE;06670;06;ALPES MARITIMES;1
06118;;Saint-Cézaire-sur-Siagne;SAINT-CEZAIRE-SUR-SIAGNE;06780;06;ALPES MARITIMES;1
06119;;Saint-Dalmas-le-Selvage;SAINT-DALMAS-LE-SELVAGE;06660;06;ALPES MARITIMES;1
06120;;Saint-Étienne-de-Tinée;SAINT-ETIENNE-DE-TINEE;06660;06;ALPES MARITIMES;1
06121;;Saint-Jean-Cap-Ferrat;SAINT-JEAN-CAP-FERRAT;06230;06;ALPES MARITIMES;1
06122;;Saint-Jeannet;SAINT-JEANNET;06640;06;ALPES MARITIMES;1
06123;;Saint-Laurent-du-Var;SAINT-LAURENT-DU-VAR;06700;06;ALPES MARITIMES;1
06124;;Saint-Léger;SAINT-LEGER;06260;06;ALPES MARITIMES;1
06125;;Saint-Martin-d'Entraunes;SAINT-MARTIN-D'ENTRAUNES;06470;06;ALPES MARITIMES;1
06126;;Saint-Martin-du-Var;SAINT-MARTIN-DU-VAR;06670;06;ALPES MARITIMES;1
06127;;Saint-Martin-Vésubie;SAINT-MARTIN-VESUBIE;06450;06;ALPES MARITIMES;1
06128;;Saint-Paul-de-Vence;SAINT-PAUL-DE-VENCE;06570;06;ALPES MARITIMES;1
06129;;Saint-Sauveur-sur-Tinée;SAINT-SAUVEUR-SUR-TINEE;06420;06;ALPES MARITIMES;1
06130;;Saint-Vallier-de-Thiey;SAINT-VALLIER-DE-THIEY;06460;06;ALPES MARITIMES;1
06131;;Sallagriffon;SALLAGRIFFON;06910;06;ALPES MARITIMES;1
06132;;Saorge;SAORGE;06540;06;ALPES MARITIMES;1
06133;;Sauze;SAUZE;06470;06;ALPES MARITIMES;1
06134;;Séranon;SERANON;06750;06;ALPES MARITIMES;1
06135;;Sigale;SIGALE;06910;06;ALPES MARITIMES;1
06136;;Sospel;SOSPEL;06380;06;ALPES MARITIMES;1
06137;;Spéracèdes;SPERACEDES;06530;06;ALPES MARITIMES;1
06138;;Théoule-sur-Mer;THEOULE-SUR-MER;06590;06;ALPES MARITIMES;1
06139;;Thiéry;THIERY;06710;06;ALPES MARITIMES;1
06140;Le;Tignet;TIGNET;06530;06;ALPES MARITIMES;1
06141;;Toudon;TOUDON;06830;06;ALPES MARITIMES;1
06142;;Touët-de-l'Escarène;TOUET-DE-L'ESCARENE;06440;06;ALPES MARITIMES;1
06143;;Touët-sur-Var;TOUET-SUR-VAR;06710;06;ALPES MARITIMES;1
06144;La;Tour;TOUR;06710;06;ALPES MARITIMES;1
06145;;Tourette-du-Château;TOURETTE-DU-CHATEAU;06830;06;ALPES MARITIMES;1
06146;;Tournefort;TOURNEFORT;06710;06;ALPES MARITIMES;1
06147;;Tourrette-Levens;TOURRETTE-LEVENS;06690;06;ALPES MARITIMES;1
06148;;Tourrettes-sur-Loup;TOURRETTES-SUR-LOUP;06140;06;ALPES MARITIMES;1
06149;La;Trinité;TRINITE;06340;06;ALPES MARITIMES;1
06150;La;Turbie;TURBIE;06320;06;ALPES MARITIMES;1
06151;;Utelle;UTELLE;06450;06;ALPES MARITIMES;1
06152;;Valbonne;VALBONNE;06560;06;ALPES MARITIMES;1
06153;;Valdeblore;VALDEBLORE;06420;06;ALPES MARITIMES;1
06154;;Valderoure;VALDEROURE;06750;06;ALPES MARITIMES;1
06155;;Vallauris;VALLAURIS;06220;06;ALPES MARITIMES;1
06156;;Venanson;VENANSON;06450;06;ALPES MARITIMES;1
06157;;Vence;VENCE;06140;06;ALPES MARITIMES;1
06158;;Villars-sur-Var;VILLARS-SUR-VAR;06710;06;ALPES MARITIMES;1
06159;;Villefranche-sur-Mer;VILLEFRANCHE-SUR-MER;06230;06;ALPES MARITIMES;1
06160;;Villeneuve-d'Entraunes;VILLENEUVE-D'ENTRAUNES;06470;06;ALPES MARITIMES;1
06161;;Villeneuve-Loubet;VILLENEUVE-LOUBET;06270;06;ALPES MARITIMES;1
06162;La;Brigue;BRIGUE;06430;06;ALPES MARITIMES;1
06163;;Tende;TENDE;06430;06;ALPES MARITIMES;1
07001;;Accons;ACCONS;07160;07;ARDECHE;1
07002;;Ailhon;AILHON;07200;07;ARDECHE;1
07003;;Aizac;AIZAC;07530;07;ARDECHE;1
07004;;Ajoux;AJOUX;07000;07;ARDECHE;1
07005;;Alba-la-Romaine;ALBA-LA-ROMAINE;07400;07;ARDECHE;1
07006;;Albon-d'Ardèche;ALBON-D'ARDECHE;07190;07;ARDECHE;1
07007;;Alboussière;ALBOUSSIERE;07440;07;ARDECHE;1
07008;;Alissas;ALISSAS;07210;07;ARDECHE;1
07009;;Andance;ANDANCE;07340;07;ARDECHE;1
07010;;Annonay;ANNONAY;07100;07;ARDECHE;1
07011;;Antraigues-sur-Volane;ANTRAIGUES-SUR-VOLANE;07530;07;ARDECHE;1
07012;;Arcens;ARCENS;07310;07;ARDECHE;1
07013;;Ardoix;ARDOIX;07290;07;ARDECHE;1
07014;;Arlebosc;ARLEBOSC;07410;07;ARDECHE;1
07015;;Arras-sur-Rhône;ARRAS-SUR-RHONE;07370;07;ARDECHE;1
07016;;Asperjoc;ASPERJOC;07600;07;ARDECHE;1
07017;Les;Assions;ASSIONS;07140;07;ARDECHE;1
07018;;Astet;ASTET;07330;07;ARDECHE;1
07019;;Aubenas;AUBENAS;07200;07;ARDECHE;1
07020;;Aubignas;AUBIGNAS;07400;07;ARDECHE;1
07022;;Baix;BAIX;07210;07;ARDECHE;1
07023;;Balazuc;BALAZUC;07120;07;ARDECHE;1
07024;;Banne;BANNE;07460;07;ARDECHE;1
07025;;Barnas;BARNAS;07330;07;ARDECHE;1
07026;Le;Béage;BEAGE;07630;07;ARDECHE;1
07027;;Beauchastel;BEAUCHASTEL;07800;07;ARDECHE;1
07028;;Beaulieu;BEAULIEU;07460;07;ARDECHE;1
07029;;Beaumont;BEAUMONT;07110;07;ARDECHE;1
07030;;Beauvène;BEAUVENE;07190;07;ARDECHE;1
07031;;Berrias-et-Casteljau;BERRIAS-ET-CASTELJAU;07460;07;ARDECHE;1
07032;;Berzème;BERZEME;07580;07;ARDECHE;1
07033;;Bessas;BESSAS;07150;07;ARDECHE;1
07034;;Bidon;BIDON;07700;07;ARDECHE;1
07035;;Boffres;BOFFRES;07440;07;ARDECHE;1
07036;;Bogy;BOGY;07340;07;ARDECHE;1
07037;;Borée;BOREE;07310;07;ARDECHE;1
07038;;Borne;BORNE;07590;07;ARDECHE;1
07039;;Bozas;BOZAS;07410;07;ARDECHE;1
07040;;Boucieu-le-Roi;BOUCIEU-LE-ROI;07270;07;ARDECHE;1
07041;;Boulieu-lès-Annonay;BOULIEU-LES-ANNONAY;07100;07;ARDECHE;1
07042;;Bourg-Saint-Andéol;BOURG-SAINT-ANDEOL;07700;07;ARDECHE;1
07044;;Brossainc;BROSSAINC;07340;07;ARDECHE;1
07045;;Burzet;BURZET;07450;07;ARDECHE;1
07047;;Cellier-du-Luc;CELLIER-DU-LUC;07590;07;ARDECHE;1
07048;;Chalencon;CHALENCON;07240;07;ARDECHE;1
07049;Le;Chambon;CHAMBON;07160;07;ARDECHE;1
07050;;Chambonas;CHAMBONAS;07140;07;ARDECHE;1
07051;;Champagne;CHAMPAGNE;07340;07;ARDECHE;1
07052;;Champis;CHAMPIS;07440;07;ARDECHE;1
07053;;Chandolas;CHANDOLAS;07230;07;ARDECHE;1
07054;;Chanéac;CHANEAC;07310;07;ARDECHE;1
07055;;Charmes-sur-Rhône;CHARMES-SUR-RHONE;07800;07;ARDECHE;1
07056;;Charnas;CHARNAS;07340;07;ARDECHE;1
07058;;Chassiers;CHASSIERS;07110;07;ARDECHE;1
07059;;Châteaubourg;CHATEAUBOURG;07130;07;ARDECHE;1
07060;;Châteauneuf-de-Vernoux;CHATEAUNEUF-DE-VERNOUX;07240;07;ARDECHE;1
07061;;Chauzon;CHAUZON;07120;07;ARDECHE;1
07062;;Chazeaux;CHAZEAUX;07110;07;ARDECHE;1
07063;;Cheminas;CHEMINAS;07300;07;ARDECHE;1
07064;Le;Cheylard;CHEYLARD;07160;07;ARDECHE;1
07065;;Chirols;CHIROLS;07380;07;ARDECHE;1
07066;;Chomérac;CHOMERAC;07210;07;ARDECHE;1
07067;;Colombier-le-Cardinal;COLOMBIER-LE-CARDINAL;07430;07;ARDECHE;1
07068;;Colombier-le-Jeune;COLOMBIER-LE-JEUNE;07270;07;ARDECHE;1
07069;;Colombier-le-Vieux;COLOMBIER-LE-VIEUX;07410;07;ARDECHE;1
07070;;Cornas;CORNAS;07130;07;ARDECHE;1
07071;;Coucouron;COUCOURON;07470;07;ARDECHE;1
07072;;Coux;COUX;07000;07;ARDECHE;1
07073;Le;Crestet;CRESTET;07270;07;ARDECHE;1
07074;;Creysseilles;CREYSSEILLES;07000;07;ARDECHE;1
07075;;Cros-de-Géorand;CROS-DE-GEORAND;07510;07;ARDECHE;1
07076;;Cruas;CRUAS;07350;07;ARDECHE;1
07077;;Darbres;DARBRES;07170;07;ARDECHE;1
07078;;Davézieux;DAVEZIEUX;07430;07;ARDECHE;1
07079;;Désaignes;DESAIGNES;07570;07;ARDECHE;1
07080;;Devesset;DEVESSET;07320;07;ARDECHE;1
07081;;Dompnac;DOMPNAC;07260;07;ARDECHE;1
07082;;Dornas;DORNAS;07160;07;ARDECHE;1
07083;;Dunière-sur-Eyrieux;DUNIERE-SUR-EYRIEUX;07360;07;ARDECHE;1
07084;;Eclassan;ECLASSAN;07370;07;ARDECHE;1
07085;;Empurany;EMPURANY;07270;07;ARDECHE;1
07086;;Étables;ETABLES;07300;07;ARDECHE;1
07087;;Fabras;FABRAS;07380;07;ARDECHE;1
07088;;Faugères;FAUGERES;07230;07;ARDECHE;1
07089;;Félines;FELINES;07340;07;ARDECHE;1
07090;;Flaviac;FLAVIAC;07000;07;ARDECHE;1
07091;;Fons;FONS;07200;07;ARDECHE;1
07092;;Freyssenet;FREYSSENET;07000;07;ARDECHE;1
07093;;Genestelle;GENESTELLE;07530;07;ARDECHE;1
07094;;Gilhac-et-Bruzac;GILHAC-ET-BRUZAC;07800;07;ARDECHE;1
07095;;Gilhoc-sur-Ormèze;GILHOC-SUR-ORMEZE;07270;07;ARDECHE;1
07096;;Gluiras;GLUIRAS;07190;07;ARDECHE;1
07097;;Glun;GLUN;07300;07;ARDECHE;1
07098;;Gourdon;GOURDON;07000;07;ARDECHE;1
07099;;Gras;GRAS;07700;07;ARDECHE;1
07100;;Gravières;GRAVIERES;07140;07;ARDECHE;1
07101;;Grospierres;GROSPIERRES;07120;07;ARDECHE;1
07102;;Guilherand-Granges;GUILHERAND-GRANGES;07500;07;ARDECHE;1
07103;;Intres;INTRES;07310;07;ARDECHE;1
07104;;Issamoulenc;ISSAMOULENC;07190;07;ARDECHE;1
07105;;Issanlas;ISSANLAS;07510;07;ARDECHE;1
07106;;Issarlès;ISSARLES;07470;07;ARDECHE;1
07107;;Jaujac;JAUJAC;07380;07;ARDECHE;1
07108;;Jaunac;JAUNAC;07160;07;ARDECHE;1
07109;;Joannas;JOANNAS;07110;07;ARDECHE;1
07110;;Joyeuse;JOYEUSE;07260;07;ARDECHE;1
07111;;Juvinas;JUVINAS;07600;07;ARDECHE;1
07112;;Labastide-sur-Bésorgues;LABASTIDE-SUR-BESORGUES;07600;07;ARDECHE;1
07113;;Labastide-de-Virac;LABASTIDE-DE-VIRAC;07150;07;ARDECHE;1
07114;;Labatie-d'Andaure;LABATIE-D'ANDAURE;07570;07;ARDECHE;1
07115;;Labeaume;LABEAUME;07120;07;ARDECHE;1
07116;;Labégude;LABEGUDE;07200;07;ARDECHE;1
07117;;Lablachère;LABLACHERE;07230;07;ARDECHE;1
07118;;Laboule;LABOULE;07110;07;ARDECHE;1
07119;Le;Lac-d'Issarlès;LAC-D'ISSARLES;07470;07;ARDECHE;1
07120;;Lachamp-Raphaël;LACHAMP-RAPHAEL;07530;07;ARDECHE;1
07121;;Lachapelle-Graillouse;LACHAPELLE-GRAILLOUSE;07470;07;ARDECHE;1
07122;;Lachapelle-sous-Aubenas;LACHAPELLE-SOUS-AUBENAS;07200;07;ARDECHE;1
07123;;Lachapelle-sous-Chanéac;LACHAPELLE-SOUS-CHANEAC;07310;07;ARDECHE;1
07124;;Lafarre;LAFARRE;07520;07;ARDECHE;1
07126;;Lagorce;LAGORCE;07150;07;ARDECHE;1
07127;;Lalevade-d'Ardèche;LALEVADE-D'ARDECHE;07380;07;ARDECHE;1
07128;;Lalouvesc;LALOUVESC;07520;07;ARDECHE;1
07129;;Lamastre;LAMASTRE;07270;07;ARDECHE;1
07130;;Lanarce;LANARCE;07660;07;ARDECHE;1
07131;;Lanas;LANAS;07200;07;ARDECHE;1
07132;;Largentière;LARGENTIERE;07110;07;ARDECHE;1
07133;;Larnas;LARNAS;07220;07;ARDECHE;1
07134;;Laurac-en-Vivarais;LAURAC-EN-VIVARAIS;07110;07;ARDECHE;1
07135;;Laval-d'Aurelle;LAVAL-D'AURELLE;07590;07;ARDECHE;1
07136;;Laveyrune;LAVEYRUNE;48250;07;LOZERE;1
07137;;Lavillatte;LAVILLATTE;07660;07;ARDECHE;1
07138;;Lavilledieu;LAVILLEDIEU;07170;07;ARDECHE;1
07139;;Laviolle;LAVIOLLE;07530;07;ARDECHE;1
07140;;Lemps;LEMPS;07300;07;ARDECHE;1
07141;;Lentillères;LENTILLERES;07200;07;ARDECHE;1
07142;;Lespéron;LESPERON;07660;07;ARDECHE;1
07143;;Limony;LIMONY;07340;07;ARDECHE;1
07144;;Loubaresse;LOUBARESSE;07110;07;ARDECHE;1
07145;;Lussas;LUSSAS;07170;07;ARDECHE;1
07146;;Lyas;LYAS;07000;07;ARDECHE;1
07147;;Malarce-sur-la-Thines;MALARCE-SUR-LA-THINES;07140;07;ARDECHE;1
07148;;Malbosc;MALBOSC;07140;07;ARDECHE;1
07149;;Marcols-les-Eaux;MARCOLS-LES-EAUX;07190;07;ARDECHE;1
07150;;Mariac;MARIAC;07160;07;ARDECHE;1
07151;;Mars;MARS;07320;07;ARDECHE;1
07152;;Mauves;MAUVES;07300;07;ARDECHE;1
07153;;Mayres;MAYRES;07330;07;ARDECHE;1
07154;;Mazan-l'Abbaye;MAZAN-L'ABBAYE;07510;07;ARDECHE;1
07155;;Mercuer;MERCUER;07200;07;ARDECHE;1
07156;;Meyras;MEYRAS;07380;07;ARDECHE;1
07157;;Meysse;MEYSSE;07400;07;ARDECHE;1
07158;;Mézilhac;MEZILHAC;07530;07;ARDECHE;1
07159;;Mirabel;MIRABEL;07170;07;ARDECHE;1
07160;;Monestier;MONESTIER;07690;07;ARDECHE;1
07161;;Montpezat-sous-Bauzon;MONTPEZAT-SOUS-BAUZON;07560;07;ARDECHE;1
07162;;Montréal;MONTREAL;07110;07;ARDECHE;1
07163;;Montselgues;MONTSELGUES;07140;07;ARDECHE;1
07165;;Nonières;NONIERES;07160;07;ARDECHE;1
07166;;Nozières;NOZIERES;07270;07;ARDECHE;1
07167;Les;Ollières-sur-Eyrieux;OLLIERES-SUR-EYRIEUX;07360;07;ARDECHE;1
07168;;Orgnac-l'Aven;ORGNAC-L'AVEN;07150;07;ARDECHE;1
07169;;Ozon;OZON;07370;07;ARDECHE;1
07170;;Pailharès;PAILHARES;07410;07;ARDECHE;1
07171;;Payzac;PAYZAC;07230;07;ARDECHE;1
07172;;Peaugres;PEAUGRES;07340;07;ARDECHE;1
07173;;Péreyres;PEREYRES;07450;07;ARDECHE;1
07174;;Peyraud;PEYRAUD;07340;07;ARDECHE;1
07175;Le;Plagnal;PLAGNAL;07590;07;ARDECHE;1
07176;;Planzolles;PLANZOLLES;07230;07;ARDECHE;1
07177;;Plats;PLATS;07300;07;ARDECHE;1
07178;;Pont-de-Labeaume;PONT-DE-LABEAUME;07380;07;ARDECHE;1
07179;;Pourchères;POURCHERES;07000;07;ARDECHE;1
07181;Le;Pouzin;POUZIN;07250;07;ARDECHE;1
07182;;Prades;PRADES;07380;07;ARDECHE;1
07183;;Pradons;PRADONS;07120;07;ARDECHE;1
07184;;Pranles;PRANLES;07000;07;ARDECHE;1
07185;;Préaux;PREAUX;07290;07;ARDECHE;1
07186;;Privas;PRIVAS;07000;07;ARDECHE;1
07187;;Prunet;PRUNET;07110;07;ARDECHE;1
07188;;Quintenas;QUINTENAS;07290;07;ARDECHE;1
07189;;Ribes;RIBES;07260;07;ARDECHE;1
07190;;Rochecolombe;ROCHECOLOMBE;07200;07;ARDECHE;1
07191;;Rochemaure;ROCHEMAURE;07400;07;ARDECHE;1
07192;;Rochepaule;ROCHEPAULE;07320;07;ARDECHE;1
07193;;Rocher;ROCHER;07110;07;ARDECHE;1
07194;;Rochessauve;ROCHESSAUVE;07210;07;ARDECHE;1
07195;La;Rochette;ROCHETTE;07310;07;ARDECHE;1
07196;;Rocles;ROCLES;07110;07;ARDECHE;1
07197;;Roiffieux;ROIFFIEUX;07100;07;ARDECHE;1
07198;;Rompon;ROMPON;07250;07;ARDECHE;1
07199;;Rosières;ROSIERES;07260;07;ARDECHE;1
07200;Le;Roux;ROUX;07560;07;ARDECHE;1
07201;;Ruoms;RUOMS;07120;07;ARDECHE;1
07202;;Sablières;SABLIERES;07260;07;ARDECHE;1
07203;;Sagnes-et-Goudoulet;SAGNES-ET-GOUDOULET;07450;07;ARDECHE;1
07204;;Saint-Agrève;SAINT-AGREVE;07320;07;ARDECHE;1
07205;;Saint-Alban-d'Ay;SAINT-ALBAN-D'AY;07790;07;ARDECHE;1
07206;;Saint-Alban-en-Montagne;SAINT-ALBAN-EN-MONTAGNE;07590;07;ARDECHE;1
07207;;Saint-Alban-Auriolles;SAINT-ALBAN-AURIOLLES;07120;07;ARDECHE;1
07208;;Saint-Andéol-de-Berg;SAINT-ANDEOL-DE-BERG;07170;07;ARDECHE;1
07209;;Saint-Andéol-de-Fourchades;SAINT-ANDEOL-DE-FOURCHADES;07160;07;ARDECHE;1
07210;;Saint-Andéol-de-Vals;SAINT-ANDEOL-DE-VALS;07600;07;ARDECHE;1
07211;;Saint-André-de-Cruzières;SAINT-ANDRE-DE-CRUZIERES;07460;07;ARDECHE;1
07212;;Saint-André-en-Vivarais;SAINT-ANDRE-EN-VIVARAIS;07690;07;ARDECHE;1
07213;;Saint-André-Lachamp;SAINT-ANDRE-LACHAMP;07230;07;ARDECHE;1
07214;;Saint-Apollinaire-de-Rias;SAINT-APOLLINAIRE-DE-RIAS;07240;07;ARDECHE;1
07215;;Saint-Barthélemy-le-Meil;SAINT-BARTHELEMY-LE-MEIL;07160;07;ARDECHE;1
07216;;Saint-Barthélemy-Grozon;SAINT-BARTHELEMY-GROZON;07270;07;ARDECHE;1
07217;;Saint-Barthélemy-le-Plain;SAINT-BARTHELEMY-LE-PLAIN;07300;07;ARDECHE;1
07218;;Saint-Basile;SAINT-BASILE;07270;07;ARDECHE;1
07219;;Saint-Bauzile;SAINT-BAUZILE;07210;07;ARDECHE;1
07220;;Saint-Christol;SAINT-CHRISTOL;07160;07;ARDECHE;1
07221;;Saint-Cierge-la-Serre;SAINT-CIERGE-LA-SERRE;07800;07;ARDECHE;1
07222;;Saint-Cierge-sous-le-Cheylard;SAINT-CIERGE-SOUS-LE-CHEYLARD;07160;07;ARDECHE;1
07223;;Saint-Cirgues-de-Prades;SAINT-CIRGUES-DE-PRADES;07380;07;ARDECHE;1
07224;;Saint-Cirgues-en-Montagne;SAINT-CIRGUES-EN-MONTAGNE;07510;07;ARDECHE;1
07225;;Saint-Clair;SAINT-CLAIR;07430;07;ARDECHE;1
07226;;Saint-Clément;SAINT-CLEMENT;07310;07;ARDECHE;1
07227;;Saint-Cyr;SAINT-CYR;07430;07;ARDECHE;1
07228;;Saint-Désirat;SAINT-DESIRAT;07340;07;ARDECHE;1
07229;;Saint-Didier-sous-Aubenas;SAINT-DIDIER-SOUS-AUBENAS;07200;07;ARDECHE;1
07230;;Saint-Étienne-de-Boulogne;SAINT-ETIENNE-DE-BOULOGNE;07200;07;ARDECHE;1
07231;;Saint-Étienne-de-Fontbellon;SAINT-ETIENNE-DE-FONTBELLON;07200;07;ARDECHE;1
07232;;Saint-Étienne-de-Lugdarès;SAINT-ETIENNE-DE-LUGDARES;07590;07;ARDECHE;1
07233;;Saint-Étienne-de-Serre;SAINT-ETIENNE-DE-SERRE;07190;07;ARDECHE;1
07234;;Saint-Étienne-de-Valoux;SAINT-ETIENNE-DE-VALOUX;07340;07;ARDECHE;1
07235;;Sainte-Eulalie;SAINTE-EULALIE;07510;07;ARDECHE;1
07236;;Saint-Félicien;SAINT-FELICIEN;07410;07;ARDECHE;1
07237;;Saint-Fortunat-sur-Eyrieux;SAINT-FORTUNAT-SUR-EYRIEUX;07360;07;ARDECHE;1
07238;;Saint-Genest-de-Beauzon;SAINT-GENEST-DE-BEAUZON;07230;07;ARDECHE;1
07239;;Saint-Genest-Lachamp;SAINT-GENEST-LACHAMP;07160;07;ARDECHE;1
07240;;Saint-Georges-les-Bains;SAINT-GEORGES-LES-BAINS;07800;07;ARDECHE;1
07241;;Saint-Germain;SAINT-GERMAIN;07170;07;ARDECHE;1
07242;;Saint-Gineis-en-Coiron;SAINT-GINEIS-EN-COIRON;07580;07;ARDECHE;1
07243;;Saint-Jacques-d'Atticieux;SAINT-JACQUES-D'ATTICIEUX;07340;07;ARDECHE;1
07244;;Saint-Jean-Chambre;SAINT-JEAN-CHAMBRE;07240;07;ARDECHE;1
07245;;Saint-Jean-de-Muzols;SAINT-JEAN-DE-MUZOLS;07300;07;ARDECHE;1
07247;;Saint-Jean-le-Centenier;SAINT-JEAN-LE-CENTENIER;07580;07;ARDECHE;1
07248;;Saint-Jean-Roure;SAINT-JEAN-ROURE;07160;07;ARDECHE;1
07249;;Saint-Jeure-d'Andaure;SAINT-JEURE-D'ANDAURE;07320;07;ARDECHE;1
07250;;Saint-Jeure-d'Ay;SAINT-JEURE-D'AY;07290;07;ARDECHE;1
07251;;Saint-Joseph-des-Bancs;SAINT-JOSEPH-DES-BANCS;07530;07;ARDECHE;1
07252;;Saint-Julien-Boutières;SAINT-JULIEN-BOUTIERES;07310;07;ARDECHE;1
07253;;Saint-Julien-du-Gua;SAINT-JULIEN-DU-GUA;07190;07;ARDECHE;1
07254;;Saint-Julien-du-Serre;SAINT-JULIEN-DU-SERRE;07200;07;ARDECHE;1
07255;;Saint-Julien-en-Saint-Alban;SAINT-JULIEN-EN-SAINT-ALBAN;07000;07;ARDECHE;1
07256;;Saint-Julien-Labrousse;SAINT-JULIEN-LABROUSSE;07160;07;ARDECHE;1
07257;;Saint-Julien-le-Roux;SAINT-JULIEN-LE-ROUX;07240;07;ARDECHE;1
07258;;Saint-Julien-Vocance;SAINT-JULIEN-VOCANCE;07690;07;ARDECHE;1
07259;;Saint-Just-d'Ardèche;SAINT-JUST-D'ARDECHE;07700;07;ARDECHE;1
07260;;Saint-Lager-Bressac;SAINT-LAGER-BRESSAC;07210;07;ARDECHE;1
07261;;Saint-Laurent-du-Pape;SAINT-LAURENT-DU-PAPE;07800;07;ARDECHE;1
07262;;Saint-Laurent-les-Bains;SAINT-LAURENT-LES-BAINS;07590;07;ARDECHE;1
07263;;Saint-Laurent-sous-Coiron;SAINT-LAURENT-SOUS-COIRON;07170;07;ARDECHE;1
07264;;Saint-Marcel-d'Ardèche;SAINT-MARCEL-D'ARDECHE;07700;07;ARDECHE;1
07265;;Saint-Marcel-lès-Annonay;SAINT-MARCEL-LES-ANNONAY;07100;07;ARDECHE;1
07266;;Sainte-Marguerite-Lafigère;SAINTE-MARGUERITE-LAFIGERE;07140;07;ARDECHE;1
07267;;Saint-Martial;SAINT-MARTIAL;07310;07;ARDECHE;1
07268;;Saint-Martin-d'Ardèche;SAINT-MARTIN-D'ARDECHE;07700;07;ARDECHE;1
07269;;Saint-Martin-de-Valamas;SAINT-MARTIN-DE-VALAMAS;07310;07;ARDECHE;1
07270;;Saint-Martin-sur-Lavezon;SAINT-MARTIN-SUR-LAVEZON;07400;07;ARDECHE;1
07272;;Saint-Maurice-d'Ardèche;SAINT-MAURICE-D'ARDECHE;07200;07;ARDECHE;1
07273;;Saint-Maurice-d'Ibie;SAINT-MAURICE-D'IBIE;07170;07;ARDECHE;1
07274;;Saint-Maurice-en-Chalencon;SAINT-MAURICE-EN-CHALENCON;07190;07;ARDECHE;1
07275;;Saint-Mélany;SAINT-MELANY;07260;07;ARDECHE;1
07276;;Saint-Michel-d'Aurance;SAINT-MICHEL-D'AURANCE;07160;07;ARDECHE;1
07277;;Saint-Michel-de-Boulogne;SAINT-MICHEL-DE-BOULOGNE;07200;07;ARDECHE;1
07278;;Saint-Michel-de-Chabrillanoux;SAINT-MICHEL-DE-CHABRILLANOUX;07360;07;ARDECHE;1
07279;;Saint-Montan;SAINT-MONTAN;07220;07;ARDECHE;1
07280;;Saint-Paul-le-Jeune;SAINT-PAUL-LE-JEUNE;07460;07;ARDECHE;1
07281;;Saint-Péray;SAINT-PERAY;07130;07;ARDECHE;1
07282;;Saint-Pierre-de-Colombier;SAINT-PIERRE-DE-COLOMBIER;07450;07;ARDECHE;1
07283;;Saint-Pierre-la-Roche;SAINT-PIERRE-LA-ROCHE;07400;07;ARDECHE;1
07284;;Saint-Pierre-Saint-Jean;SAINT-PIERRE-SAINT-JEAN;07140;07;ARDECHE;1
07285;;Saint-Pierre-sur-Doux;SAINT-PIERRE-SUR-DOUX;07520;07;ARDECHE;1
07286;;Saint-Pierreville;SAINT-PIERREVILLE;07190;07;ARDECHE;1
07287;;Saint-Pons;SAINT-PONS;07580;07;ARDECHE;1
07288;;Saint-Priest;SAINT-PRIEST;07000;07;ARDECHE;1
07289;;Saint-Privat;SAINT-PRIVAT;07200;07;ARDECHE;1
07290;;Saint-Prix;SAINT-PRIX;07270;07;ARDECHE;1
07291;;Saint-Remèze;SAINT-REMEZE;07700;07;ARDECHE;1
07292;;Saint-Romain-d'Ay;SAINT-ROMAIN-D'AY;07290;07;ARDECHE;1
07293;;Saint-Romain-de-Lerps;SAINT-ROMAIN-DE-LERPS;07130;07;ARDECHE;1
07294;;Saint-Sauveur-de-Cruzières;SAINT-SAUVEUR-DE-CRUZIERES;07460;07;ARDECHE;1
07295;;Saint-Sauveur-de-Montagut;SAINT-SAUVEUR-DE-MONTAGUT;07190;07;ARDECHE;1
07296;;Saint-Sernin;SAINT-SERNIN;07200;07;ARDECHE;1
07297;;Saint-Sylvestre;SAINT-SYLVESTRE;07440;07;ARDECHE;1
07298;;Saint-Symphorien-sous-Chomérac;SAINT-SYMPHORIEN-SOUS-CHOMERAC;07210;07;ARDECHE;1
07299;;Saint-Symphorien-de-Mahun;SAINT-SYMPHORIEN-DE-MAHUN;07290;07;ARDECHE;1
07300;;Saint-Thomé;SAINT-THOME;07220;07;ARDECHE;1
07301;;Saint-Victor;SAINT-VICTOR;07410;07;ARDECHE;1
07302;;Saint-Vincent-de-Barrès;SAINT-VINCENT-DE-BARRES;07210;07;ARDECHE;1
07303;;Saint-Vincent-de-Durfort;SAINT-VINCENT-DE-DURFORT;07360;07;ARDECHE;1
07304;;Salavas;SALAVAS;07150;07;ARDECHE;1
07305;Les;Salelles;SALELLES;07140;07;ARDECHE;1
07306;;Sampzon;SAMPZON;07120;07;ARDECHE;1
07307;;Sanilhac;SANILHAC;07110;07;ARDECHE;1
07308;;Sarras;SARRAS;07370;07;ARDECHE;1
07309;;Satillieu;SATILLIEU;07290;07;ARDECHE;1
07310;;Savas;SAVAS;07430;07;ARDECHE;1
07311;;Sceautres;SCEAUTRES;07400;07;ARDECHE;1
07312;;Sécheras;SECHERAS;07610;07;ARDECHE;1
07313;;Serrières;SERRIERES;07340;07;ARDECHE;1
07314;;Silhac;SILHAC;07240;07;ARDECHE;1
07315;La;Souche;SOUCHE;07380;07;ARDECHE;1
07316;;Soyons;SOYONS;07130;07;ARDECHE;1
07317;;Talencieux;TALENCIEUX;07340;07;ARDECHE;1
07318;;Tauriers;TAURIERS;07110;07;ARDECHE;1
07319;Le;Teil;TEIL;07400;07;ARDECHE;1
07321;;Thorrenc;THORRENC;07340;07;ARDECHE;1
07322;;Thueyts;THUEYTS;07330;07;ARDECHE;1
07323;;Toulaud;TOULAUD;07130;07;ARDECHE;1
07324;;Tournon-sur-Rhône;TOURNON-SUR-RHONE;07300;07;ARDECHE;1
07325;;Ucel;UCEL;07200;07;ARDECHE;1
07326;;Usclades-et-Rieutord;USCLADES-ET-RIEUTORD;07510;07;ARDECHE;1
07327;;Uzer;UZER;07110;07;ARDECHE;1
07328;;Vagnas;VAGNAS;07150;07;ARDECHE;1
07329;;Valgorge;VALGORGE;07110;07;ARDECHE;1
07330;;Vallon-Pont-d'Arc;VALLON-PONT-D'ARC;07150;07;ARDECHE;1
07331;;Vals-les-Bains;VALS-LES-BAINS;07600;07;ARDECHE;1
07332;;Valvignères;VALVIGNERES;07400;07;ARDECHE;1
07333;;Vanosc;VANOSC;07690;07;ARDECHE;1
07334;Les;Vans;VANS;07140;07;ARDECHE;1
07335;;Vaudevant;VAUDEVANT;07410;07;ARDECHE;1
07336;;Vernon;VERNON;07260;07;ARDECHE;1
07337;;Vernosc-lès-Annonay;VERNOSC-LES-ANNONAY;07430;07;ARDECHE;1
07338;;Vernoux-en-Vivarais;VERNOUX-EN-VIVARAIS;07240;07;ARDECHE;1
07339;;Vesseaux;VESSEAUX;07200;07;ARDECHE;1
07340;;Veyras;VEYRAS;07000;07;ARDECHE;1
07341;;Villeneuve-de-Berg;VILLENEUVE-DE-BERG;07170;07;ARDECHE;1
07342;;Villevocance;VILLEVOCANCE;07690;07;ARDECHE;1
07343;;Vinezac;VINEZAC;07110;07;ARDECHE;1
07344;;Vinzieux;VINZIEUX;07340;07;ARDECHE;1
07345;;Vion;VION;07610;07;ARDECHE;1
07346;;Viviers;VIVIERS;07220;07;ARDECHE;1
07347;;Vocance;VOCANCE;07690;07;ARDECHE;1
07348;;Vogüé;VOGUE;07200;07;ARDECHE;1
07349;La;Voulte-sur-Rhône;VOULTE-SUR-RHONE;07800;07;ARDECHE;1
08001;;Acy-Romance;ACY-ROMANCE;08300;08;ARDENNES;1
08003;;Aiglemont;AIGLEMONT;08090;08;ARDENNES;1
08004;;Aire;AIRE;08190;08;ARDENNES;1
08005;;Alincourt;ALINCOURT;08310;08;ARDENNES;1
08006;;Alland'Huy-et-Sausseuil;ALLAND'HUY-ET-SAUSSEUIL;08130;08;ARDENNES;1
08007;Les;Alleux;ALLEUX;08400;08;ARDENNES;1
08008;;Amagne;AMAGNE;08300;08;ARDENNES;1
08009;;Amblimont;AMBLIMONT;08210;08;ARDENNES;1
08010;;Ambly-Fleury;AMBLY-FLEURY;08130;08;ARDENNES;1
08011;;Anchamps;ANCHAMPS;08500;08;ARDENNES;1
08013;;Angecourt;ANGECOURT;08450;08;ARDENNES;1
08014;;Annelles;ANNELLES;08310;08;ARDENNES;1
08015;;Antheny;ANTHENY;08260;08;ARDENNES;1
08016;;Aouste;AOUSTE;08290;08;ARDENNES;1
08017;;Apremont;APREMONT;08250;08;ARDENNES;1
08018;;Ardeuil-et-Montfauxelles;ARDEUIL-ET-MONTFAUXELLES;08400;08;ARDENNES;1
08019;Les;Grandes-Armoises;GRANDES-ARMOISES;08390;08;ARDENNES;1
08020;Les;Petites-Armoises;PETITES-ARMOISES;08390;08;ARDENNES;1
08021;;Arnicourt;ARNICOURT;08300;08;ARDENNES;1
08022;;Arreux;ARREUX;08090;08;ARDENNES;1
08023;;Artaise-le-Vivier;ARTAISE-LE-VIVIER;08390;08;ARDENNES;1
08024;;Asfeld;ASFELD;08190;08;ARDENNES;1
08025;;Attigny;ATTIGNY;08130;08;ARDENNES;1
08026;;Aubigny-les-Pothées;AUBIGNY-LES-POTHEES;08150;08;ARDENNES;1
08027;;Auboncourt-Vauzelles;AUBONCOURT-VAUZELLES;08270;08;ARDENNES;1
08028;;Aubrives;AUBRIVES;08320;08;ARDENNES;1
08029;;Auflance;AUFLANCE;08370;08;ARDENNES;1
08030;;Auge;AUGE;08380;08;ARDENNES;1
08031;;Aure;AURE;08400;08;ARDENNES;1
08032;;Aussonce;AUSSONCE;08310;08;ARDENNES;1
08033;;Authe;AUTHE;08240;08;ARDENNES;1
08034;;Autrecourt-et-Pourron;AUTRECOURT-ET-POURRON;08210;08;ARDENNES;1
08035;;Autruche;AUTRUCHE;08240;08;ARDENNES;1
08036;;Autry;AUTRY;08250;08;ARDENNES;1
08037;;Auvillers-les-Forges;AUVILLERS-LES-FORGES;08260;08;ARDENNES;1
08038;;Avançon;AVANCON;08300;08;ARDENNES;1
08039;;Avaux;AVAUX;08190;08;ARDENNES;1
08040;Les;Ayvelles;AYVELLES;08000;08;ARDENNES;1
08041;;Baâlons;BAALONS;08430;08;ARDENNES;1
08042;;Balaives-et-Butz;BALAIVES-ET-BUTZ;08160;08;ARDENNES;1
08043;;Balan;BALAN;08200;08;ARDENNES;1
08044;;Balham;BALHAM;08190;08;ARDENNES;1
08045;;Ballay;BALLAY;08400;08;ARDENNES;1
08046;;Banogne-Recouvrance;BANOGNE-RECOUVRANCE;08220;08;ARDENNES;1
08047;;Barbaise;BARBAISE;08430;08;ARDENNES;1
08048;;Barby;BARBY;08300;08;ARDENNES;1
08049;;Bar-lès-Buzancy;BAR-LES-BUZANCY;08240;08;ARDENNES;1
08052;;Bayonville;BAYONVILLE;08240;08;ARDENNES;1
08053;;Bazeilles;BAZEILLES;08140;08;ARDENNES;1
08055;;Beaumont-en-Argonne;BEAUMONT-EN-ARGONNE;08210;08;ARDENNES;1
08056;;Beffu-et-le-Morthomme;BEFFU-ET-LE-MORTHOMME;08250;08;ARDENNES;1
08057;;Belleville-et-Châtillon-sur-Bar;BELLEVILLE-ET-CHATILLON-SUR-BAR;08240;08;ARDENNES;1
08058;;Belval;BELVAL;08090;08;ARDENNES;1
08059;;Belval-Bois-des-Dames;BELVAL-BOIS-DES-DAMES;08240;08;ARDENNES;1
08060;;Bergnicourt;BERGNICOURT;08300;08;ARDENNES;1
08061;La;Berlière;BERLIERE;08240;08;ARDENNES;1
08062;;Bertoncourt;BERTONCOURT;08300;08;ARDENNES;1
08063;La;Besace;BESACE;08450;08;ARDENNES;1
08064;;Biermes;BIERMES;08300;08;ARDENNES;1
08065;;Bièvres;BIEVRES;08370;08;ARDENNES;1
08066;;Bignicourt;BIGNICOURT;08310;08;ARDENNES;1
08067;;Blagny;BLAGNY;08110;08;ARDENNES;1
08069;;Blanchefosse-et-Bay;BLANCHEFOSSE-ET-BAY;08290;08;ARDENNES;1
08070;;Blanzy-la-Salonnaise;BLANZY-LA-SALONNAISE;08190;08;ARDENNES;1
08071;;Blombay;BLOMBAY;08260;08;ARDENNES;1
08072;;Bosseval-et-Briancourt;BOSSEVAL-ET-BRIANCOURT;08350;08;ARDENNES;1
08073;;Bossus-lès-Rumigny;BOSSUS-LES-RUMIGNY;08290;08;ARDENNES;1
08074;;Bouconville;BOUCONVILLE;08250;08;ARDENNES;1
08075;;Boult-aux-Bois;BOULT-AUX-BOIS;08240;08;ARDENNES;1
08076;;Boulzicourt;BOULZICOURT;08410;08;ARDENNES;1
08077;;Bourcq;BOURCQ;08400;08;ARDENNES;1
08078;;Bourg-Fidèle;BOURG-FIDELE;08230;08;ARDENNES;1
08079;;Boutancourt;BOUTANCOURT;08160;08;ARDENNES;1
08080;;Bouvellemont;BOUVELLEMONT;08430;08;ARDENNES;1
08081;;Bogny-sur-Meuse;BOGNY-SUR-MEUSE;08120;08;ARDENNES;1
08082;;Brécy-Brières;BRECY-BRIERES;08400;08;ARDENNES;1
08083;;Brévilly;BREVILLY;08140;08;ARDENNES;1
08084;;Brienne-sur-Aisne;BRIENNE-SUR-AISNE;08190;08;ARDENNES;1
08085;;Brieulles-sur-Bar;BRIEULLES-SUR-BAR;08240;08;ARDENNES;1
08086;;Briquenay;BRIQUENAY;08240;08;ARDENNES;1
08087;;Brognon;BROGNON;08380;08;ARDENNES;1
08088;;Bulson;BULSON;08450;08;ARDENNES;1
08089;;Buzancy;BUZANCY;08240;08;ARDENNES;1
08090;;Carignan;CARIGNAN;08110;08;ARDENNES;1
08092;;Cauroy;CAUROY;08310;08;ARDENNES;1
08094;;Cernion;CERNION;08260;08;ARDENNES;1
08095;;Chagny;CHAGNY;08430;08;ARDENNES;1
08096;;Chalandry-Elaire;CHALANDRY-ELAIRE;08160;08;ARDENNES;1
08097;;Challerange;CHALLERANGE;08400;08;ARDENNES;1
08098;;Champigneulle;CHAMPIGNEULLE;08250;08;ARDENNES;1
08099;;Champigneul-sur-Vence;CHAMPIGNEUL-SUR-VENCE;08430;08;ARDENNES;1
08100;;Champlin;CHAMPLIN;08260;08;ARDENNES;1
08101;La;Chapelle;CHAPELLE;08200;08;ARDENNES;1
08102;;Chappes;CHAPPES;08220;08;ARDENNES;1
08103;;Charbogne;CHARBOGNE;08130;08;ARDENNES;1
08104;;Chardeny;CHARDENY;08400;08;ARDENNES;1
08105;;Charleville-Mézières;CHARLEVILLE-MEZIERES;08000;08;ARDENNES;1
08106;;Charnois;CHARNOIS;08600;08;ARDENNES;1
08107;;Château-Porcien;CHATEAU-PORCIEN;08360;08;ARDENNES;1
08109;;Chatel-Chéhéry;CHATEL-CHEHERY;08250;08;ARDENNES;1
08110;Le;Châtelet-sur-Sormonne;CHATELET-SUR-SORMONNE;08150;08;ARDENNES;1
08111;Le;Châtelet-sur-Retourne;CHATELET-SUR-RETOURNE;08300;08;ARDENNES;1
08113;;Chaumont-Porcien;CHAUMONT-PORCIEN;08220;08;ARDENNES;1
08114;;Chéhéry;CHEHERY;08350;08;ARDENNES;1
08115;;Chémery-sur-Bar;CHEMERY-SUR-BAR;08450;08;ARDENNES;1
08116;Le;Chesne;CHESNE;08390;08;ARDENNES;1
08117;;Chesnois-Auboncourt;CHESNOIS-AUBONCOURT;08270;08;ARDENNES;1
08119;;Cheveuges;CHEVEUGES;08350;08;ARDENNES;1
08120;;Chevières;CHEVIERES;08250;08;ARDENNES;1
08121;;Chilly;CHILLY;08260;08;ARDENNES;1
08122;;Chooz;CHOOZ;08600;08;ARDENNES;1
08123;;Chuffilly-Roche;CHUFFILLY-ROCHE;08130;08;ARDENNES;1
08124;;Clavy-Warby;CLAVY-WARBY;08560;08;ARDENNES;1
08125;;Cliron;CLIRON;08090;08;ARDENNES;1
08126;;Condé-lès-Herpy;CONDE-LES-HERPY;08360;08;ARDENNES;1
08128;;Condé-lès-Autry;CONDE-LES-AUTRY;08250;08;ARDENNES;1
08130;;Contreuve;CONTREUVE;08400;08;ARDENNES;1
08131;;Cornay;CORNAY;08250;08;ARDENNES;1
08132;;Corny-Machéroménil;CORNY-MACHEROMENIL;08270;08;ARDENNES;1
08133;;Coucy;COUCY;08300;08;ARDENNES;1
08134;;Coulommes-et-Marqueny;COULOMMES-ET-MARQUENY;08130;08;ARDENNES;1
08135;La;Croix-aux-Bois;CROIX-AUX-BOIS;08400;08;ARDENNES;1
08136;;Daigny;DAIGNY;08140;08;ARDENNES;1
08137;;Damouzy;DAMOUZY;08090;08;ARDENNES;1
08138;Les;Deux-Villes;DEUX-VILLES;08110;08;ARDENNES;1
08139;;Deville;DEVILLE;08800;08;ARDENNES;1
08140;;Dom-le-Mesnil;DOM-LE-MESNIL;08160;08;ARDENNES;1
08141;;Dommery;DOMMERY;08460;08;ARDENNES;1
08142;;Donchery;DONCHERY;08350;08;ARDENNES;1
08143;;Doumely-Bégny;DOUMELY-BEGNY;08220;08;ARDENNES;1
08144;;Doux;DOUX;08300;08;ARDENNES;1
08145;;Douzy;DOUZY;08140;08;ARDENNES;1
08146;;Draize;DRAIZE;08220;08;ARDENNES;1
08147;;Dricourt;DRICOURT;08310;08;ARDENNES;1
08148;L';Écaille;ECAILLE;08300;08;ARDENNES;1
08149;L';Échelle;ECHELLE;08150;08;ARDENNES;1
08150;;Écly;ECLY;08300;08;ARDENNES;1
08151;;Écordal;ECORDAL;08130;08;ARDENNES;1
08152;;Élan;ELAN;08160;08;ARDENNES;1
08153;;Escombres-et-le-Chesnois;ESCOMBRES-ET-LE-CHESNOIS;08110;08;ARDENNES;1
08154;;Estrebay;ESTREBAY;08260;08;ARDENNES;1
08155;;Étalle;ETALLE;08260;08;ARDENNES;1
08156;;Éteignières;ETEIGNIERES;08260;08;ARDENNES;1
08158;;Étrépigny;ETREPIGNY;08160;08;ARDENNES;1
08159;;Euilly-et-Lombut;EUILLY-ET-LOMBUT;08210;08;ARDENNES;1
08160;;Évigny;EVIGNY;08090;08;ARDENNES;1
08161;;Exermont;EXERMONT;08250;08;ARDENNES;1
08162;;Fagnon;FAGNON;08090;08;ARDENNES;1
08163;;Faissault;FAISSAULT;08270;08;ARDENNES;1
08164;;Falaise;FALAISE;08400;08;ARDENNES;1
08165;;Faux;FAUX;08270;08;ARDENNES;1
08166;;Fépin;FEPIN;08170;08;ARDENNES;1
08167;La;Férée;FEREE;08290;08;ARDENNES;1
08168;La;Ferté-sur-Chiers;FERTE-SUR-CHIERS;08370;08;ARDENNES;1
08169;;Flaignes-Havys;FLAIGNES-HAVYS;08260;08;ARDENNES;1
08170;;Fleigneux;FLEIGNEUX;08200;08;ARDENNES;1
08171;;Fléville;FLEVILLE;08250;08;ARDENNES;1
08172;;Fligny;FLIGNY;08380;08;ARDENNES;1
08173;;Flize;FLIZE;08160;08;ARDENNES;1
08174;;Floing;FLOING;08200;08;ARDENNES;1
08175;;Foisches;FOISCHES;08600;08;ARDENNES;1
08176;;Fossé;FOSSE;08240;08;ARDENNES;1
08178;;Fraillicourt;FRAILLICOURT;08220;08;ARDENNES;1
08179;;Francheval;FRANCHEVAL;08140;08;ARDENNES;1
08180;La;Francheville;FRANCHEVILLE;08000;08;ARDENNES;1
08182;Le;Fréty;FRETY;08290;08;ARDENNES;1
08183;;Fromelennes;FROMELENNES;08600;08;ARDENNES;1
08184;;Fromy;FROMY;08370;08;ARDENNES;1
08185;;Fumay;FUMAY;08170;08;ARDENNES;1
08186;;Germont;GERMONT;08240;08;ARDENNES;1
08187;;Gernelle;GERNELLE;08440;08;ARDENNES;1
08188;;Gespunsart;GESPUNSART;08700;08;ARDENNES;1
08189;;Girondelle;GIRONDELLE;08260;08;ARDENNES;1
08190;;Givet;GIVET;08600;08;ARDENNES;1
08191;;Givonne;GIVONNE;08200;08;ARDENNES;1
08192;;Givron;GIVRON;08220;08;ARDENNES;1
08193;;Givry;GIVRY;08130;08;ARDENNES;1
08194;;Glaire;GLAIRE;08200;08;ARDENNES;1
08195;;Gomont;GOMONT;08190;08;ARDENNES;1
08196;;Grandchamp;GRANDCHAMP;08270;08;ARDENNES;1
08197;;Grandham;GRANDHAM;08250;08;ARDENNES;1
08198;;Grandpré;GRANDPRE;08250;08;ARDENNES;1
08199;La;Grandville;GRANDVILLE;08700;08;ARDENNES;1
08200;;Grivy-Loisy;GRIVY-LOISY;08400;08;ARDENNES;1
08201;;Gruyères;GRUYERES;08430;08;ARDENNES;1
08202;;Gué-d'Hossus;GUE-D'HOSSUS;08230;08;ARDENNES;1
08203;;Guignicourt-sur-Vence;GUIGNICOURT-SUR-VENCE;08430;08;ARDENNES;1
08204;;Guincourt;GUINCOURT;08130;08;ARDENNES;1
08205;;Hagnicourt;HAGNICOURT;08430;08;ARDENNES;1
08206;;Ham-les-Moines;HAM-LES-MOINES;08090;08;ARDENNES;1
08207;;Ham-sur-Meuse;HAM-SUR-MEUSE;08600;08;ARDENNES;1
08208;;Hannappes;HANNAPPES;08290;08;ARDENNES;1
08209;;Hannogne-Saint-Martin;HANNOGNE-SAINT-MARTIN;08160;08;ARDENNES;1
08210;;Hannogne-Saint-Rémy;HANNOGNE-SAINT-REMY;08220;08;ARDENNES;1
08211;;Haraucourt;HARAUCOURT;08450;08;ARDENNES;1
08212;;Harcy;HARCY;08150;08;ARDENNES;1
08214;;Hargnies;HARGNIES;08170;08;ARDENNES;1
08215;;Harricourt;HARRICOURT;08240;08;ARDENNES;1
08216;;Haudrecy;HAUDRECY;08090;08;ARDENNES;1
08217;;Haulmé;HAULME;08800;08;ARDENNES;1
08218;Les;Hautes-Rivières;HAUTES-RIVIERES;08800;08;ARDENNES;1
08219;;Hauteville;HAUTEVILLE;08300;08;ARDENNES;1
08220;;Hauviné;HAUVINE;08310;08;ARDENNES;1
08222;;Haybes;HAYBES;08170;08;ARDENNES;1
08223;;Herbeuval;HERBEUVAL;08370;08;ARDENNES;1
08225;;Herpy-l'Arlésienne;HERPY-L'ARLESIENNE;08360;08;ARDENNES;1
08226;;Hierges;HIERGES;08320;08;ARDENNES;1
08228;La;Horgne;HORGNE;08430;08;ARDENNES;1
08229;;Houdilcourt;HOUDILCOURT;08190;08;ARDENNES;1
08230;;Houldizy;HOULDIZY;08090;08;ARDENNES;1
08232;;Illy;ILLY;08200;08;ARDENNES;1
08233;;Imécourt;IMECOURT;08240;08;ARDENNES;1
08234;;Inaumont;INAUMONT;08300;08;ARDENNES;1
08235;;Issancourt-et-Rumel;ISSANCOURT-ET-RUMEL;08440;08;ARDENNES;1
08236;;Jandun;JANDUN;08430;08;ARDENNES;1
08237;;Joigny-sur-Meuse;JOIGNY-SUR-MEUSE;08700;08;ARDENNES;1
08238;;Jonval;JONVAL;08130;08;ARDENNES;1
08239;;Juniville;JUNIVILLE;08310;08;ARDENNES;1
08240;;Justine-Herbigny;JUSTINE-HERBIGNY;08270;08;ARDENNES;1
08242;;Laifour;LAIFOUR;08800;08;ARDENNES;1
08243;;Lalobbe;LALOBBE;08460;08;ARDENNES;1
08244;;Lametz;LAMETZ;08130;08;ARDENNES;1
08245;;Lançon;LANCON;08250;08;ARDENNES;1
08246;;Landres-et-Saint-Georges;LANDRES-ET-SAINT-GEORGES;08240;08;ARDENNES;1
08247;;Landrichamps;LANDRICHAMPS;08600;08;ARDENNES;1
08248;;Launois-sur-Vence;LAUNOIS-SUR-VENCE;08430;08;ARDENNES;1
08249;;Laval-Morency;LAVAL-MORENCY;08150;08;ARDENNES;1
08250;;Leffincourt;LEFFINCOURT;08310;08;ARDENNES;1
08251;;Lépron-les-Vallées;LEPRON-LES-VALLEES;08150;08;ARDENNES;1
08252;;Létanne;LETANNE;08210;08;ARDENNES;1
08254;;Liart;LIART;08290;08;ARDENNES;1
08255;;Linay;LINAY;08110;08;ARDENNES;1
08256;;Liry;LIRY;08400;08;ARDENNES;1
08257;;Logny-Bogny;LOGNY-BOGNY;08150;08;ARDENNES;1
08259;;Longwé;LONGWE;08400;08;ARDENNES;1
08260;;Lonny;LONNY;08150;08;ARDENNES;1
08261;;Louvergny;LOUVERGNY;08390;08;ARDENNES;1
08262;;Lucquy;LUCQUY;08300;08;ARDENNES;1
08263;;Lumes;LUMES;08440;08;ARDENNES;1
08264;;Machault;MACHAULT;08310;08;ARDENNES;1
08267;;Mairy;MAIRY;08140;08;ARDENNES;1
08268;;Maisoncelle-et-Villers;MAISONCELLE-ET-VILLERS;08450;08;ARDENNES;1
08269;;Malandry;MALANDRY;08370;08;ARDENNES;1
08271;;Manre;MANRE;08400;08;ARDENNES;1
08272;;Maranwez;MARANWEZ;08460;08;ARDENNES;1
08273;;Marby;MARBY;08260;08;ARDENNES;1
08274;;Marcq;MARCQ;08250;08;ARDENNES;1
08275;;Margny;MARGNY;08370;08;ARDENNES;1
08276;;Margut;MARGUT;08370;08;ARDENNES;1
08277;;Marlemont;MARLEMONT;08290;08;ARDENNES;1
08278;;Marquigny;MARQUIGNY;08390;08;ARDENNES;1
08279;;Mars-sous-Bourcq;MARS-SOUS-BOURCQ;08400;08;ARDENNES;1
08280;;Marvaux-Vieux;MARVAUX-VIEUX;08400;08;ARDENNES;1
08281;;Matton-et-Clémency;MATTON-ET-CLEMENCY;08110;08;ARDENNES;1
08282;;Maubert-Fontaine;MAUBERT-FONTAINE;08260;08;ARDENNES;1
08283;;Mazerny;MAZERNY;08430;08;ARDENNES;1
08284;Les;Mazures;MAZURES;08500;08;ARDENNES;1
08286;;Ménil-Annelles;MENIL-ANNELLES;08310;08;ARDENNES;1
08287;;Ménil-Lépinois;MENIL-LEPINOIS;08310;08;ARDENNES;1
08288;;Mesmont;MESMONT;08270;08;ARDENNES;1
08289;;Messincourt;MESSINCOURT;08110;08;ARDENNES;1
08291;;Mogues;MOGUES;08110;08;ARDENNES;1
08293;;Moiry;MOIRY;08370;08;ARDENNES;1
08294;La;Moncelle;MONCELLE;08140;08;ARDENNES;1
08295;;Mondigny;MONDIGNY;08430;08;ARDENNES;1
08296;;Montcheutin;MONTCHEUTIN;08250;08;ARDENNES;1
08297;;Montcornet;MONTCORNET;08090;08;ARDENNES;1
08298;;Montcy-Notre-Dame;MONTCY-NOTRE-DAME;08090;08;ARDENNES;1
08300;Le;Mont-Dieu;MONT-DIEU;08390;08;ARDENNES;1
08301;;Montgon;MONTGON;08390;08;ARDENNES;1
08302;;Monthermé;MONTHERME;08800;08;ARDENNES;1
08303;;Monthois;MONTHOIS;08400;08;ARDENNES;1
08304;;Montigny-sur-Meuse;MONTIGNY-SUR-MEUSE;08170;08;ARDENNES;1
08305;;Montigny-sur-Vence;MONTIGNY-SUR-VENCE;08430;08;ARDENNES;1
08306;;Mont-Laurent;MONT-LAURENT;08130;08;ARDENNES;1
08307;;Montmeillant;MONTMEILLANT;08220;08;ARDENNES;1
08308;;Mont-Saint-Martin;MONT-SAINT-MARTIN;08400;08;ARDENNES;1
08309;;Mont-Saint-Remy;MONT-SAINT-REMY;08310;08;ARDENNES;1
08310;;Mouron;MOURON;08250;08;ARDENNES;1
08311;;Mouzon;MOUZON;08210;08;ARDENNES;1
08312;;Murtin-et-Bogny;MURTIN-ET-BOGNY;08150;08;ARDENNES;1
08313;;Nanteuil-sur-Aisne;NANTEUIL-SUR-AISNE;08300;08;ARDENNES;1
08314;;Neuflize;NEUFLIZE;08300;08;ARDENNES;1
08315;;Neufmaison;NEUFMAISON;08560;08;ARDENNES;1
08316;;Neufmanil;NEUFMANIL;08700;08;ARDENNES;1
08317;La;Neuville-à-Maire;NEUVILLE-A-MAIRE;08450;08;ARDENNES;1
08318;La;Neuville-aux-Joûtes;NEUVILLE-AUX-JOUTES;08380;08;ARDENNES;1
08319;;Neuville-lez-Beaulieu;NEUVILLE-LEZ-BEAULIEU;08380;08;ARDENNES;1
08320;La;Neuville-en-Tourne-à-Fuy;NEUVILLE-EN-TOURNE-A-FUY;08310;08;ARDENNES;1
08321;;Neuville-Day;NEUVILLE-DAY;08130;08;ARDENNES;1
08322;;Neuville-lès-This;NEUVILLE-LES-THIS;08090;08;ARDENNES;1
08323;La;Neuville-lès-Wasigny;NEUVILLE-LES-WASIGNY;08270;08;ARDENNES;1
08324;;Neuvizy;NEUVIZY;08430;08;ARDENNES;1
08325;;Noirval;NOIRVAL;08400;08;ARDENNES;1
08326;;Nouart;NOUART;08240;08;ARDENNES;1
08327;;Nouvion-sur-Meuse;NOUVION-SUR-MEUSE;08160;08;ARDENNES;1
08328;;Nouzonville;NOUZONVILLE;08700;08;ARDENNES;1
08329;;Novion-Porcien;NOVION-PORCIEN;08270;08;ARDENNES;1
08330;;Novy-Chevrières;NOVY-CHEVRIERES;08300;08;ARDENNES;1
08331;;Noyers-Pont-Maugis;NOYERS-PONT-MAUGIS;08350;08;ARDENNES;1
08332;;Oches;OCHES;08240;08;ARDENNES;1
08333;;Olizy-Primat;OLIZY-PRIMAT;08250;08;ARDENNES;1
08334;;Omicourt;OMICOURT;08450;08;ARDENNES;1
08335;;Omont;OMONT;08430;08;ARDENNES;1
08336;;Osnes;OSNES;08110;08;ARDENNES;1
08338;;Pauvres;PAUVRES;08310;08;ARDENNES;1
08339;;Perthes;PERTHES;08300;08;ARDENNES;1
08340;;Poilcourt-Sydney;POILCOURT-SYDNEY;08190;08;ARDENNES;1
08341;;Poix-Terron;POIX-TERRON;08430;08;ARDENNES;1
08342;;Pouru-aux-Bois;POURU-AUX-BOIS;08140;08;ARDENNES;1
08343;;Pouru-Saint-Remy;POURU-SAINT-REMY;08140;08;ARDENNES;1
08344;;Prez;PREZ;08290;08;ARDENNES;1
08346;;Prix-lès-Mézières;PRIX-LES-MEZIERES;08000;08;ARDENNES;1
08347;;Puilly-et-Charbeaux;PUILLY-ET-CHARBEAUX;08370;08;ARDENNES;1
08348;;Puiseux;PUISEUX;08270;08;ARDENNES;1
08349;;Pure;PURE;08110;08;ARDENNES;1
08350;;Quatre-Champs;QUATRE-CHAMPS;08400;08;ARDENNES;1
08351;;Quilly;QUILLY;08400;08;ARDENNES;1
08352;;Raillicourt;RAILLICOURT;08430;08;ARDENNES;1
08353;;Rancennes;RANCENNES;08600;08;ARDENNES;1
08354;;Raucourt-et-Flaba;RAUCOURT-ET-FLABA;08450;08;ARDENNES;1
08355;;Regniowez;REGNIOWEZ;08230;08;ARDENNES;1
08356;;Remaucourt;REMAUCOURT;08220;08;ARDENNES;1
08357;;Remilly-Aillicourt;REMILLY-AILLICOURT;08450;08;ARDENNES;1
08358;;Remilly-les-Pothées;REMILLY-LES-POTHEES;08150;08;ARDENNES;1
08360;;Renneville;RENNEVILLE;08220;08;ARDENNES;1
08361;;Renwez;RENWEZ;08150;08;ARDENNES;1
08362;;Rethel;RETHEL;08300;08;ARDENNES;1
08363;;Revin;REVIN;08500;08;ARDENNES;1
08364;;Rilly-sur-Aisne;RILLY-SUR-AISNE;08130;08;ARDENNES;1
08365;;Rimogne;RIMOGNE;08150;08;ARDENNES;1
08366;;Rocquigny;ROCQUIGNY;08220;08;ARDENNES;1
08367;;Rocroi;ROCROI;08230;08;ARDENNES;1
08368;;Roizy;ROIZY;08190;08;ARDENNES;1
08369;La;Romagne;ROMAGNE;08220;08;ARDENNES;1
08370;;Rouvroy-sur-Audry;ROUVROY-SUR-AUDRY;08150;08;ARDENNES;1
08371;;Rubécourt-et-Lamécourt;RUBECOURT-ET-LAMECOURT;08140;08;ARDENNES;1
08372;;Rubigny;RUBIGNY;08220;08;ARDENNES;1
08373;;Rumigny;RUMIGNY;08290;08;ARDENNES;1
08374;La;Sabotterie;SABOTTERIE;08130;08;ARDENNES;1
08375;;Sachy;SACHY;08110;08;ARDENNES;1
08376;;Sailly;SAILLY;08110;08;ARDENNES;1
08377;;Saint-Aignan;SAINT-AIGNAN;08350;08;ARDENNES;1
08378;;Saint-Clément-à-Arnes;SAINT-CLEMENT-A-ARNES;08310;08;ARDENNES;1
08379;;Saint-Étienne-à-Arnes;SAINT-ETIENNE-A-ARNES;08310;08;ARDENNES;1
08380;;Saint-Fergeux;SAINT-FERGEUX;08360;08;ARDENNES;1
08381;;Saint-Germainmont;SAINT-GERMAINMONT;08190;08;ARDENNES;1
08382;;Saint-Jean-aux-Bois;SAINT-JEAN-AUX-BOIS;08220;08;ARDENNES;1
08383;;Saint-Juvin;SAINT-JUVIN;08250;08;ARDENNES;1
08384;;Saint-Lambert-et-Mont-de-Jeux;SAINT-LAMBERT-ET-MONT-DE-JEUX;08130;08;ARDENNES;1
08385;;Saint-Laurent;SAINT-LAURENT;08090;08;ARDENNES;1
08386;;Saint-Loup-en-Champagne;SAINT-LOUP-EN-CHAMPAGNE;08300;08;ARDENNES;1
08387;;Saint-Loup-Terrier;SAINT-LOUP-TERRIER;08130;08;ARDENNES;1
08388;;Saint-Marceau;SAINT-MARCEAU;08160;08;ARDENNES;1
08389;;Saint-Marcel;SAINT-MARCEL;08560;08;ARDENNES;1
08390;;Sainte-Marie;SAINTE-MARIE;08400;08;ARDENNES;1
08391;;Saint-Menges;SAINT-MENGES;08200;08;ARDENNES;1
08392;;Saint-Morel;SAINT-MOREL;08400;08;ARDENNES;1
08393;;Saint-Pierre-à-Arnes;SAINT-PIERRE-A-ARNES;08310;08;ARDENNES;1
08394;;Saint-Pierremont;SAINT-PIERREMONT;08240;08;ARDENNES;1
08395;;Saint-Pierre-sur-Vence;SAINT-PIERRE-SUR-VENCE;08430;08;ARDENNES;1
08396;;Saint-Quentin-le-Petit;SAINT-QUENTIN-LE-PETIT;08220;08;ARDENNES;1
08397;;Saint-Remy-le-Petit;SAINT-REMY-LE-PETIT;08300;08;ARDENNES;1
08398;;Sainte-Vaubourg;SAINTE-VAUBOURG;08130;08;ARDENNES;1
08399;;Sapogne-sur-Marche;SAPOGNE-SUR-MARCHE;08370;08;ARDENNES;1
08400;;Sapogne-et-Feuchères;SAPOGNE-ET-FEUCHERES;08160;08;ARDENNES;1
08401;;Saulces-Champenoises;SAULCES-CHAMPENOISES;08130;08;ARDENNES;1
08402;;Saulces-Monclin;SAULCES-MONCLIN;08270;08;ARDENNES;1
08403;;Sault-lès-Rethel;SAULT-LES-RETHEL;08300;08;ARDENNES;1
08404;;Sault-Saint-Remy;SAULT-SAINT-REMY;08190;08;ARDENNES;1
08405;;Sauville;SAUVILLE;08390;08;ARDENNES;1
08406;;Savigny-sur-Aisne;SAVIGNY-SUR-AISNE;08400;08;ARDENNES;1
08407;;Séchault;SECHAULT;08250;08;ARDENNES;1
08408;;Sécheval;SECHEVAL;08150;08;ARDENNES;1
08409;;Sedan;SEDAN;08200;08;ARDENNES;1
08410;;Semide;SEMIDE;08400;08;ARDENNES;1
08411;;Semuy;SEMUY;08130;08;ARDENNES;1
08412;;Senuc;SENUC;08250;08;ARDENNES;1
08413;;Seraincourt;SERAINCOURT;08220;08;ARDENNES;1
08415;;Sery;SERY;08270;08;ARDENNES;1
08416;;Seuil;SEUIL;08300;08;ARDENNES;1
08417;;Sévigny-la-Forêt;SEVIGNY-LA-FORET;08230;08;ARDENNES;1
08418;;Sévigny-Waleppe;SEVIGNY-WALEPPE;08220;08;ARDENNES;1
08419;;Signy-l'Abbaye;SIGNY-L'ABBAYE;08460;08;ARDENNES;1
08420;;Signy-le-Petit;SIGNY-LE-PETIT;08380;08;ARDENNES;1
08421;;Signy-Montlibert;SIGNY-MONTLIBERT;08370;08;ARDENNES;1
08422;;Singly;SINGLY;08430;08;ARDENNES;1
08424;;Sommauthe;SOMMAUTHE;08240;08;ARDENNES;1
08425;;Sommerance;SOMMERANCE;08250;08;ARDENNES;1
08426;;Son;SON;08300;08;ARDENNES;1
08427;;Sorbon;SORBON;08300;08;ARDENNES;1
08428;;Sorcy-Bauthémont;SORCY-BAUTHEMONT;08270;08;ARDENNES;1
08429;;Sormonne;SORMONNE;08150;08;ARDENNES;1
08430;;Stonne;STONNE;08390;08;ARDENNES;1
08431;;Sugny;SUGNY;08400;08;ARDENNES;1
08432;;Sury;SURY;08090;08;ARDENNES;1
08433;;Suzanne;SUZANNE;08130;08;ARDENNES;1
08434;;Sy;SY;08390;08;ARDENNES;1
08435;;Tagnon;TAGNON;08300;08;ARDENNES;1
08436;;Taillette;TAILLETTE;08230;08;ARDENNES;1
08437;;Tailly;TAILLY;08240;08;ARDENNES;1
08438;;Taizy;TAIZY;08360;08;ARDENNES;1
08439;;Tannay;TANNAY;08390;08;ARDENNES;1
08440;;Tarzy;TARZY;08380;08;ARDENNES;1
08441;;Termes;TERMES;08250;08;ARDENNES;1
08443;;Terron-sur-Aisne;TERRON-SUR-AISNE;08400;08;ARDENNES;1
08444;;Tétaigne;TETAIGNE;08110;08;ARDENNES;1
08445;;Thelonne;THELONNE;08350;08;ARDENNES;1
08446;;Thénorgues;THENORGUES;08240;08;ARDENNES;1
08448;;Thilay;THILAY;08800;08;ARDENNES;1
08449;;Thin-le-Moutier;THIN-LE-MOUTIER;08460;08;ARDENNES;1
08450;;This;THIS;08090;08;ARDENNES;1
08451;Le;Thour;THOUR;08190;08;ARDENNES;1
08452;;Thugny-Trugny;THUGNY-TRUGNY;08300;08;ARDENNES;1
08453;;Toges;TOGES;08400;08;ARDENNES;1
08454;;Touligny;TOULIGNY;08430;08;ARDENNES;1
08455;;Tourcelles-Chaumont;TOURCELLES-CHAUMONT;08400;08;ARDENNES;1
08456;;Tournavaux;TOURNAVAUX;08800;08;ARDENNES;1
08457;;Tournes;TOURNES;08090;08;ARDENNES;1
08458;;Tourteron;TOURTERON;08130;08;ARDENNES;1
08459;;Tremblois-lès-Carignan;TREMBLOIS-LES-CARIGNAN;08110;08;ARDENNES;1
08460;;Tremblois-lès-Rocroi;TREMBLOIS-LES-ROCROI;08150;08;ARDENNES;1
08461;;Vandy;VANDY;08400;08;ARDENNES;1
08462;;Vaux-Champagne;VAUX-CHAMPAGNE;08130;08;ARDENNES;1
08463;;Vaux-en-Dieulet;VAUX-EN-DIEULET;08240;08;ARDENNES;1
08464;;Vaux-lès-Mouron;VAUX-LES-MOURON;08250;08;ARDENNES;1
08465;;Vaux-lès-Rubigny;VAUX-LES-RUBIGNY;08220;08;ARDENNES;1
08466;;Vaux-lès-Mouzon;VAUX-LES-MOUZON;08210;08;ARDENNES;1
08467;;Vaux-Montreuil;VAUX-MONTREUIL;08270;08;ARDENNES;1
08468;;Vaux-Villaine;VAUX-VILLAINE;08150;08;ARDENNES;1
08469;;Vendresse;VENDRESSE;08160;08;ARDENNES;1
08470;;Verpel;VERPEL;08240;08;ARDENNES;1
08471;;Verrières;VERRIERES;08390;08;ARDENNES;1
08472;;Viel-Saint-Remy;VIEL-SAINT-REMY;08270;08;ARDENNES;1
08473;;Vieux-lès-Asfeld;VIEUX-LES-ASFELD;08190;08;ARDENNES;1
08475;;Villers-Cernay;VILLERS-CERNAY;08140;08;ARDENNES;1
08476;;Villers-devant-le-Thour;VILLERS-DEVANT-LE-THOUR;08190;08;ARDENNES;1
08477;;Villers-devant-Mouzon;VILLERS-DEVANT-MOUZON;08210;08;ARDENNES;1
08478;;Villers-le-Tilleul;VILLERS-LE-TILLEUL;08430;08;ARDENNES;1
08479;;Villers-le-Tourneur;VILLERS-LE-TOURNEUR;08430;08;ARDENNES;1
08480;;Villers-Semeuse;VILLERS-SEMEUSE;08000;08;ARDENNES;1
08481;;Villers-sur-Bar;VILLERS-SUR-BAR;08350;08;ARDENNES;1
08482;;Villers-sur-le-Mont;VILLERS-SUR-LE-MONT;08430;08;ARDENNES;1
08483;;Ville-sur-Lumes;VILLE-SUR-LUMES;08440;08;ARDENNES;1
08484;;Ville-sur-Retourne;VILLE-SUR-RETOURNE;08310;08;ARDENNES;1
08485;;Villy;VILLY;08370;08;ARDENNES;1
08486;;Vireux-Molhain;VIREUX-MOLHAIN;08320;08;ARDENNES;1
08487;;Vireux-Wallerand;VIREUX-WALLERAND;08320;08;ARDENNES;1
08488;;Vivier-au-Court;VIVIER-AU-COURT;08440;08;ARDENNES;1
08489;;Voncq;VONCQ;08400;08;ARDENNES;1
08490;;Vouziers;VOUZIERS;08400;08;ARDENNES;1
08491;;Vrigne-aux-Bois;VRIGNE-AUX-BOIS;08330;08;ARDENNES;1
08492;;Vrigne-Meuse;VRIGNE-MEUSE;08350;08;ARDENNES;1
08493;;Vrizy;VRIZY;08400;08;ARDENNES;1
08494;;Wadelincourt;WADELINCOURT;08200;08;ARDENNES;1
08496;;Wagnon;WAGNON;08270;08;ARDENNES;1
08497;;Warcq;WARCQ;08000;08;ARDENNES;1
08498;;Warnécourt;WARNECOURT;08090;08;ARDENNES;1
08499;;Wasigny;WASIGNY;08270;08;ARDENNES;1
08500;;Wignicourt;WIGNICOURT;08270;08;ARDENNES;1
08501;;Williers;WILLIERS;08110;08;ARDENNES;1
08502;;Yoncq;YONCQ;08210;08;ARDENNES;1
08503;;Yvernaumont;YVERNAUMONT;08430;08;ARDENNES;1
09001;;Aigues-Juntes;AIGUES-JUNTES;09240;09;ARIEGE;1
09002;;Aigues-Vives;AIGUES-VIVES;09600;09;ARIEGE;1
09003;L';Aiguillon;AIGUILLON;09300;09;ARIEGE;1
09004;;Albiès;ALBIES;09310;09;ARIEGE;1
09005;;Aleu;ALEU;09320;09;ARIEGE;1
09006;;Alliat;ALLIAT;09400;09;ARIEGE;1
09007;;Allières;ALLIERES;09240;09;ARIEGE;1
09008;;Alos;ALOS;09200;09;ARIEGE;1
09009;;Alzen;ALZEN;09240;09;ARIEGE;1
09011;;Antras;ANTRAS;09800;09;ARIEGE;1
09012;;Appy;APPY;09250;09;ARIEGE;1
09013;;Arabaux;ARABAUX;09000;09;ARIEGE;1
09014;;Argein;ARGEIN;09800;09;ARIEGE;1
09015;;Arignac;ARIGNAC;09400;09;ARIEGE;1
09016;;Arnave;ARNAVE;09400;09;ARIEGE;1
09017;;Arrien-en-Bethmale;ARRIEN-EN-BETHMALE;09800;09;ARIEGE;1
09018;;Arrout;ARROUT;09800;09;ARIEGE;1
09019;;Artigat;ARTIGAT;09130;09;ARIEGE;1
09020;;Artigues;ARTIGUES;09460;09;ARIEGE;1
09021;;Artix;ARTIX;09120;09;ARIEGE;1
09022;;Arvigna;ARVIGNA;09100;09;ARIEGE;1
09023;;Ascou;ASCOU;09110;09;ARIEGE;1
09024;;Aston;ASTON;09310;09;ARIEGE;1
09025;;Aucazein;AUCAZEIN;09800;09;ARIEGE;1
09026;;Audressein;AUDRESSEIN;09800;09;ARIEGE;1
09027;;Augirein;AUGIREIN;09800;09;ARIEGE;1
09028;;Aulos;AULOS;09310;09;ARIEGE;1
09029;;Aulus-les-Bains;AULUS-LES-BAINS;09140;09;ARIEGE;1
09030;;Auzat;AUZAT;09220;09;ARIEGE;1
09031;;Axiat;AXIAT;09250;09;ARIEGE;1
09032;;Ax-les-Thermes;AX-LES-THERMES;09110;09;ARIEGE;1
09033;;Bagert;BAGERT;09160;09;ARIEGE;1
09034;;Balacet;BALACET;09800;09;ARIEGE;1
09035;;Balaguères;BALAGUERES;09800;09;ARIEGE;1
09037;;Barjac;BARJAC;09190;09;ARIEGE;1
09038;La;Bastide-de-Besplas;BASTIDE-DE-BESPLAS;09350;09;ARIEGE;1
09039;La;Bastide-de-Bousignac;BASTIDE-DE-BOUSIGNAC;09500;09;ARIEGE;1
09040;La;Bastide-de-Lordat;BASTIDE-DE-LORDAT;09700;09;ARIEGE;1
09041;La;Bastide-du-Salat;BASTIDE-DU-SALAT;09160;09;ARIEGE;1
09042;La;Bastide-de-Sérou;BASTIDE-DE-SEROU;09240;09;ARIEGE;1
09043;La;Bastide-sur-l'Hers;BASTIDE-SUR-L'HERS;09600;09;ARIEGE;1
09044;;Baulou;BAULOU;09000;09;ARIEGE;1
09045;;Bédeilhac-et-Aynat;BEDEILHAC-ET-AYNAT;09400;09;ARIEGE;1
09046;;Bédeille;BEDEILLE;09230;09;ARIEGE;1
09047;;Bélesta;BELESTA;09300;09;ARIEGE;1
09048;;Belloc;BELLOC;09600;09;ARIEGE;1
09049;;Bénac;BENAC;09000;09;ARIEGE;1
09050;;Benagues;BENAGUES;09100;09;ARIEGE;1
09051;;Bénaix;BENAIX;09300;09;ARIEGE;1
09052;;Besset;BESSET;09500;09;ARIEGE;1
09053;;Bestiac;BESTIAC;09250;09;ARIEGE;1
09054;;Betchat;BETCHAT;09160;09;ARIEGE;1
09055;;Bethmale;BETHMALE;09800;09;ARIEGE;1
09056;;Bézac;BEZAC;09100;09;ARIEGE;1
09057;;Biert;BIERT;09320;09;ARIEGE;1
09058;;Bompas;BOMPAS;09400;09;ARIEGE;1
09059;;Bonac-Irazein;BONAC-IRAZEIN;09800;09;ARIEGE;1
09060;;Bonnac;BONNAC;09100;09;ARIEGE;1
09061;Les;Bordes-sur-Arize;BORDES-SUR-ARIZE;09350;09;ARIEGE;1
09062;Les;Bordes-sur-Lez;BORDES-SUR-LEZ;09800;09;ARIEGE;1
09063;Le;Bosc;BOSC;09000;09;ARIEGE;1
09064;;Bouan;BOUAN;09310;09;ARIEGE;1
09065;;Boussenac;BOUSSENAC;09320;09;ARIEGE;1
09066;;Brassac;BRASSAC;09000;09;ARIEGE;1
09067;;Brie;BRIE;09700;09;ARIEGE;1
09068;;Burret;BURRET;09000;09;ARIEGE;1
09069;;Buzan;BUZAN;09800;09;ARIEGE;1
09070;Les;Cabannes;CABANNES;09310;09;ARIEGE;1
09071;;Cadarcet;CADARCET;09240;09;ARIEGE;1
09072;;Calzan;CALZAN;09120;09;ARIEGE;1
09073;;Camarade;CAMARADE;09290;09;ARIEGE;1
09074;;Camon;CAMON;09500;09;ARIEGE;1
09075;;Campagne-sur-Arize;CAMPAGNE-SUR-ARIZE;09350;09;ARIEGE;1
09076;;Canté;CANTE;09700;09;ARIEGE;1
09077;;Capoulet-et-Junac;CAPOULET-ET-JUNAC;09400;09;ARIEGE;1
09078;;Carcanières;CARCANIERES;09460;09;ARIEGE;1
09079;;Carla-Bayle;CARLA-BAYLE;09130;09;ARIEGE;1
09080;;Carla-de-Roquefort;CARLA-DE-ROQUEFORT;09300;09;ARIEGE;1
09081;Le;Carlaret;CARLARET;09100;09;ARIEGE;1
09082;;Castelnau-Durban;CASTELNAU-DURBAN;09420;09;ARIEGE;1
09083;;Castéras;CASTERAS;09130;09;ARIEGE;1
09084;;Castex;CASTEX;09350;09;ARIEGE;1
09085;;Castillon-en-Couserans;CASTILLON-EN-COUSERANS;09800;09;ARIEGE;1
09086;;Caumont;CAUMONT;09160;09;ARIEGE;1
09087;;Caussou;CAUSSOU;09250;09;ARIEGE;1
09088;;Caychax;CAYCHAX;09250;09;ARIEGE;1
09089;;Cazals-des-Baylès;CAZALS-DES-BAYLES;09500;09;ARIEGE;1
09090;;Cazaux;CAZAUX;09120;09;ARIEGE;1
09091;;Cazavet;CAZAVET;09160;09;ARIEGE;1
09092;;Cazenave-Serres-et-Allens;CAZENAVE-SERRES-ET-ALLENS;09400;09;ARIEGE;1
09093;;Celles;CELLES;09000;09;ARIEGE;1
09094;;Cérizols;CERIZOLS;09230;09;ARIEGE;1
09095;;Cescau;CESCAU;09800;09;ARIEGE;1
09096;;Château-Verdun;CHATEAU-VERDUN;09310;09;ARIEGE;1
09097;;Clermont;CLERMONT;09420;09;ARIEGE;1
09098;;Contrazy;CONTRAZY;09230;09;ARIEGE;1
09099;;Cos;COS;09000;09;ARIEGE;1
09100;;Couflens;COUFLENS;09140;09;ARIEGE;1
09101;;Coussa;COUSSA;09120;09;ARIEGE;1
09102;;Coutens;COUTENS;09500;09;ARIEGE;1
09103;;Crampagna;CRAMPAGNA;09120;09;ARIEGE;1
09104;;Dalou;DALOU;09120;09;ARIEGE;1
09105;;Daumazan-sur-Arize;DAUMAZAN-SUR-ARIZE;09350;09;ARIEGE;1
09106;;Dreuilhe;DREUILHE;09300;09;ARIEGE;1
09107;;Dun;DUN;09600;09;ARIEGE;1
09108;;Durban-sur-Arize;DURBAN-SUR-ARIZE;09240;09;ARIEGE;1
09109;;Durfort;DURFORT;09130;09;ARIEGE;1
09110;;Encourtiech;ENCOURTIECH;09200;09;ARIEGE;1
09111;;Engomer;ENGOMER;09800;09;ARIEGE;1
09113;;Ercé;ERCE;09140;09;ARIEGE;1
09114;;Erp;ERP;09200;09;ARIEGE;1
09115;;Esclagne;ESCLAGNE;09600;09;ARIEGE;1
09116;;Escosse;ESCOSSE;09100;09;ARIEGE;1
09117;;Esplas;ESPLAS;09700;09;ARIEGE;1
09118;;Esplas-de-Sérou;ESPLAS-DE-SEROU;09420;09;ARIEGE;1
09119;;Eycheil;EYCHEIL;09200;09;ARIEGE;1
09120;;Fabas;FABAS;09230;09;ARIEGE;1
09121;;Ferrières-sur-Ariège;FERRIERES-SUR-ARIEGE;09000;09;ARIEGE;1
09122;;Foix;FOIX;09000;09;ARIEGE;1
09123;;Fornex;FORNEX;09350;09;ARIEGE;1
09124;Le;Fossat;FOSSAT;09130;09;ARIEGE;1
09125;;Fougax-et-Barrineuf;FOUGAX-ET-BARRINEUF;09300;09;ARIEGE;1
09126;;Freychenet;FREYCHENET;09300;09;ARIEGE;1
09127;;Gabre;GABRE;09290;09;ARIEGE;1
09128;;Gajan;GAJAN;09190;09;ARIEGE;1
09129;;Galey;GALEY;09800;09;ARIEGE;1
09130;;Ganac;GANAC;09000;09;ARIEGE;1
09131;;Garanou;GARANOU;09250;09;ARIEGE;1
09132;;Gaudiès;GAUDIES;09700;09;ARIEGE;1
09133;;Génat;GENAT;09400;09;ARIEGE;1
09134;;Gestiès;GESTIES;09220;09;ARIEGE;1
09135;;Goulier;GOULIER;09220;09;ARIEGE;1
09136;;Gourbit;GOURBIT;09400;09;ARIEGE;1
09137;;Gudas;GUDAS;09120;09;ARIEGE;1
09138;L';Herm;HERM;09000;09;ARIEGE;1
09139;L';Hospitalet-près-l'Andorre;HOSPITALET-PRES-L'ANDORRE;09390;09;ARIEGE;1
09140;;Ignaux;IGNAUX;09110;09;ARIEGE;1
09141;;Illartein;ILLARTEIN;09800;09;ARIEGE;1
09142;;Ilhat;ILHAT;09300;09;ARIEGE;1
09143;;Illier-et-Laramade;ILLIER-ET-LARAMADE;09220;09;ARIEGE;1
09145;Les;Issards;ISSARDS;09100;09;ARIEGE;1
09146;;Justiniac;JUSTINIAC;09700;09;ARIEGE;1
09147;;Labatut;LABATUT;09700;09;ARIEGE;1
09148;;Lacave;LACAVE;09160;09;ARIEGE;1
09149;;Lacourt;LACOURT;09200;09;ARIEGE;1
09150;;Lagarde;LAGARDE;09500;09;ARIEGE;1
09151;;Lanoux;LANOUX;09130;09;ARIEGE;1
09152;;Lapège;LAPEGE;09400;09;ARIEGE;1
09153;;Lapenne;LAPENNE;09500;09;ARIEGE;1
09154;;Larbont;LARBONT;09240;09;ARIEGE;1
09155;;Larcat;LARCAT;09310;09;ARIEGE;1
09156;;Larnat;LARNAT;09310;09;ARIEGE;1
09157;;Laroque-d'Olmes;LAROQUE-D'OLMES;09600;09;ARIEGE;1
09158;;Lasserre;LASSERRE;09230;09;ARIEGE;1
09159;;Lassur;LASSUR;09310;09;ARIEGE;1
09160;;Lavelanet;LAVELANET;09300;09;ARIEGE;1
09161;;Léran;LERAN;09600;09;ARIEGE;1
09162;;Lercoul;LERCOUL;09220;09;ARIEGE;1
09163;;Lescousse;LESCOUSSE;09100;09;ARIEGE;1
09164;;Lescure;LESCURE;09420;09;ARIEGE;1
09165;;Lesparrou;LESPARROU;09300;09;ARIEGE;1
09166;;Leychert;LEYCHERT;09300;09;ARIEGE;1
09167;;Lézat-sur-Lèze;LEZAT-SUR-LEZE;09210;09;ARIEGE;1
09168;;Lieurac;LIEURAC;09300;09;ARIEGE;1
09169;;Limbrassac;LIMBRASSAC;09600;09;ARIEGE;1
09170;;Lissac;LISSAC;09700;09;ARIEGE;1
09171;;Lordat;LORDAT;09250;09;ARIEGE;1
09172;;Loubaut;LOUBAUT;09350;09;ARIEGE;1
09173;;Loubens;LOUBENS;09120;09;ARIEGE;1
09174;;Loubières;LOUBIERES;09000;09;ARIEGE;1
09175;;Ludiès;LUDIES;09100;09;ARIEGE;1
09176;;Luzenac;LUZENAC;09250;09;ARIEGE;1
09177;;Madière;MADIERE;09100;09;ARIEGE;1
09178;;Malegoude;MALEGOUDE;09500;09;ARIEGE;1
09179;;Malléon;MALLEON;09120;09;ARIEGE;1
09180;;Manses;MANSES;09500;09;ARIEGE;1
09181;Le;Mas-d'Azil;MAS-D'AZIL;09290;09;ARIEGE;1
09182;;Massat;MASSAT;09320;09;ARIEGE;1
09183;;Mauvezin-de-Prat;MAUVEZIN-DE-PRAT;09160;09;ARIEGE;1
09184;;Mauvezin-de-Sainte-Croix;MAUVEZIN-DE-SAINTE-CROIX;09230;09;ARIEGE;1
09185;;Mazères;MAZERES;09270;09;ARIEGE;1
09186;;Méras;MERAS;09350;09;ARIEGE;1
09187;;Mercenac;MERCENAC;09160;09;ARIEGE;1
09188;;Mercus-Garrabet;MERCUS-GARRABET;09400;09;ARIEGE;1
09189;;Mérens-les-Vals;MERENS-LES-VALS;09110;09;ARIEGE;1
09190;;Mérigon;MERIGON;09230;09;ARIEGE;1
09192;;Miglos;MIGLOS;09400;09;ARIEGE;1
09193;;Mijanès;MIJANES;09460;09;ARIEGE;1
09194;;Mirepoix;MIREPOIX;09500;09;ARIEGE;1
09195;;Monesple;MONESPLE;09130;09;ARIEGE;1
09196;;Montagagne;MONTAGAGNE;09240;09;ARIEGE;1
09197;;Montaillou;MONTAILLOU;09110;09;ARIEGE;1
09198;;Montardit;MONTARDIT;09230;09;ARIEGE;1
09199;;Montaut;MONTAUT;09700;09;ARIEGE;1
09200;;Montbel;MONTBEL;09600;09;ARIEGE;1
09201;;Montégut-en-Couserans;MONTEGUT-EN-COUSERANS;09200;09;ARIEGE;1
09202;;Montégut-Plantaurel;MONTEGUT-PLANTAUREL;09120;09;ARIEGE;1
09203;;Montels;MONTELS;09240;09;ARIEGE;1
09204;;Montesquieu-Avantès;MONTESQUIEU-AVANTES;09200;09;ARIEGE;1
09205;;Montfa;MONTFA;09350;09;ARIEGE;1
09206;;Montferrier;MONTFERRIER;09300;09;ARIEGE;1
09207;;Montgaillard;MONTGAILLARD;09330;09;ARIEGE;1
09208;;Montgauch;MONTGAUCH;09160;09;ARIEGE;1
09209;;Montjoie-en-Couserans;MONTJOIE-EN-COUSERANS;09200;09;ARIEGE;1
09210;;Montoulieu;MONTOULIEU;09000;09;ARIEGE;1
09211;;Montségur;MONTSEGUR;09300;09;ARIEGE;1
09212;;Montseron;MONTSERON;09240;09;ARIEGE;1
09213;;Moulin-Neuf;MOULIN-NEUF;09500;09;ARIEGE;1
09214;;Moulis;MOULIS;09200;09;ARIEGE;1
09215;;Nalzen;NALZEN;09300;09;ARIEGE;1
09216;;Nescus;NESCUS;09240;09;ARIEGE;1
09217;;Niaux;NIAUX;09400;09;ARIEGE;1
09218;;Orgeix;ORGEIX;09110;09;ARIEGE;1
09219;;Orgibet;ORGIBET;09800;09;ARIEGE;1
09220;;Orlu;ORLU;09110;09;ARIEGE;1
09221;;Ornolac-Ussat-les-Bains;ORNOLAC-USSAT-LES-BAINS;09400;09;ARIEGE;1
09222;;Orus;ORUS;09220;09;ARIEGE;1
09223;;Oust;OUST;09140;09;ARIEGE;1
09224;;Pailhès;PAILHES;09130;09;ARIEGE;1
09225;;Pamiers;PAMIERS;09100;09;ARIEGE;1
09226;;Pech;PECH;09310;09;ARIEGE;1
09227;;Péreille;PEREILLE;09300;09;ARIEGE;1
09228;;Perles-et-Castelet;PERLES-ET-CASTELET;09110;09;ARIEGE;1
09229;Le;Peyrat;PEYRAT;09600;09;ARIEGE;1
09230;Le;Pla;PLA;09460;09;ARIEGE;1
09231;Le;Port;PORT;09320;09;ARIEGE;1
09232;;Prades;PRADES;09110;09;ARIEGE;1
09233;;Pradettes;PRADETTES;09600;09;ARIEGE;1
09234;;Pradières;PRADIERES;09000;09;ARIEGE;1
09235;;Prat-Bonrepaux;PRAT-BONREPAUX;09160;09;ARIEGE;1
09236;;Prayols;PRAYOLS;09000;09;ARIEGE;1
09237;Le;Puch;PUCH;09460;09;ARIEGE;1
09238;Les;Pujols;PUJOLS;09100;09;ARIEGE;1
09239;;Quérigut;QUERIGUT;09460;09;ARIEGE;1
09240;;Quié;QUIE;09400;09;ARIEGE;1
09241;;Rabat-les-Trois-Seigneurs;RABAT-LES-TROIS-SEIGNEURS;09400;09;ARIEGE;1
09242;;Raissac;RAISSAC;09300;09;ARIEGE;1
09243;;Régat;REGAT;09600;09;ARIEGE;1
09244;;Rieucros;RIEUCROS;09500;09;ARIEGE;1
09245;;Rieux-de-Pelleport;RIEUX-DE-PELLEPORT;09120;09;ARIEGE;1
09246;;Rimont;RIMONT;09420;09;ARIEGE;1
09247;;Rivèrenert;RIVERENERT;09200;09;ARIEGE;1
09249;;Roquefixade;ROQUEFIXADE;09300;09;ARIEGE;1
09250;;Roquefort-les-Cascades;ROQUEFORT-LES-CASCADES;09300;09;ARIEGE;1
09251;;Roumengoux;ROUMENGOUX;09500;09;ARIEGE;1
09252;;Rouze;ROUZE;09460;09;ARIEGE;1
09253;;Sabarat;SABARAT;09350;09;ARIEGE;1
09254;;Saint-Amadou;SAINT-AMADOU;09100;09;ARIEGE;1
09255;;Saint-Amans;SAINT-AMANS;09100;09;ARIEGE;1
09256;;Saint-Bauzeil;SAINT-BAUZEIL;09120;09;ARIEGE;1
09257;;Sainte-Croix-Volvestre;SAINTE-CROIX-VOLVESTRE;09230;09;ARIEGE;1
09258;;Saint-Félix-de-Rieutord;SAINT-FELIX-DE-RIEUTORD;09120;09;ARIEGE;1
09259;;Saint-Félix-de-Tournegat;SAINT-FELIX-DE-TOURNEGAT;09500;09;ARIEGE;1
09260;;Sainte-Foi;SAINTE-FOI;09500;09;ARIEGE;1
09261;;Saint-Girons;SAINT-GIRONS;09200;09;ARIEGE;1
09262;;Saint-Jean-d'Aigues-Vives;SAINT-JEAN-D'AIGUES-VIVES;09300;09;ARIEGE;1
09263;;Saint-Jean-du-Castillonnais;SAINT-JEAN-DU-CASTILLONNAIS;09800;09;ARIEGE;1
09264;;Saint-Jean-de-Verges;SAINT-JEAN-DE-VERGES;09000;09;ARIEGE;1
09265;;Saint-Jean-du-Falga;SAINT-JEAN-DU-FALGA;09100;09;ARIEGE;1
09266;;Saint-Julien-de-Gras-Capou;SAINT-JULIEN-DE-GRAS-CAPOU;09500;09;ARIEGE;1
09267;;Saint-Lary;SAINT-LARY;09800;09;ARIEGE;1
09268;;Saint-Lizier;SAINT-LIZIER;09190;09;ARIEGE;1
09269;;Saint-Martin-de-Caralp;SAINT-MARTIN-DE-CARALP;09000;09;ARIEGE;1
09270;;Saint-Martin-d'Oydes;SAINT-MARTIN-D'OYDES;09100;09;ARIEGE;1
09271;;Saint-Michel;SAINT-MICHEL;09100;09;ARIEGE;1
09272;;Saint-Paul-de-Jarrat;SAINT-PAUL-DE-JARRAT;09000;09;ARIEGE;1
09273;;Saint-Pierre-de-Rivière;SAINT-PIERRE-DE-RIVIERE;09000;09;ARIEGE;1
09274;;Saint-Quentin-la-Tour;SAINT-QUENTIN-LA-TOUR;09500;09;ARIEGE;1
09275;;Saint-Quirc;SAINT-QUIRC;09700;09;ARIEGE;1
09276;;Saint-Victor-Rouzaud;SAINT-VICTOR-ROUZAUD;09100;09;ARIEGE;1
09277;;Saint-Ybars;SAINT-YBARS;09210;09;ARIEGE;1
09279;;Salsein;SALSEIN;09800;09;ARIEGE;1
09280;;Saurat;SAURAT;09400;09;ARIEGE;1
09281;;Sautel;SAUTEL;09300;09;ARIEGE;1
09282;;Saverdun;SAVERDUN;09700;09;ARIEGE;1
09283;;Savignac-les-Ormeaux;SAVIGNAC-LES-ORMEAUX;09110;09;ARIEGE;1
09284;;Ségura;SEGURA;09120;09;ARIEGE;1
09285;;Seix;SEIX;09140;09;ARIEGE;1
09286;;Sem;SEM;09220;09;ARIEGE;1
09287;;Senconac;SENCONAC;09250;09;ARIEGE;1
09289;;Lorp-Sentaraille;LORP-SENTARAILLE;09190;09;ARIEGE;1
09290;;Sentein;SENTEIN;09800;09;ARIEGE;1
09291;;Sentenac-d'Oust;SENTENAC-D'OUST;09140;09;ARIEGE;1
09292;;Sentenac-de-Sérou;SENTENAC-DE-SEROU;09240;09;ARIEGE;1
09293;;Serres-sur-Arget;SERRES-SUR-ARGET;09000;09;ARIEGE;1
09294;;Sieuras;SIEURAS;09130;09;ARIEGE;1
09295;;Siguer;SIGUER;09220;09;ARIEGE;1
09296;;Sinsat;SINSAT;09310;09;ARIEGE;1
09297;;Sor;SOR;09800;09;ARIEGE;1
09298;;Sorgeat;SORGEAT;09110;09;ARIEGE;1
09299;;Soueix-Rogalle;SOUEIX-ROGALLE;09140;09;ARIEGE;1
09300;;Soula;SOULA;09000;09;ARIEGE;1
09301;;Soulan;SOULAN;09320;09;ARIEGE;1
09302;;Suc-et-Sentenac;SUC-ET-SENTENAC;09220;09;ARIEGE;1
09303;;Surba;SURBA;09400;09;ARIEGE;1
09304;;Suzan;SUZAN;09240;09;ARIEGE;1
09305;;Tabre;TABRE;09600;09;ARIEGE;1
09306;;Tarascon-sur-Ariège;TARASCON-SUR-ARIEGE;09400;09;ARIEGE;1
09307;;Taurignan-Castet;TAURIGNAN-CASTET;09160;09;ARIEGE;1
09308;;Taurignan-Vieux;TAURIGNAN-VIEUX;09190;09;ARIEGE;1
09309;;Teilhet;TEILHET;09500;09;ARIEGE;1
09310;;Thouars-sur-Arize;THOUARS-SUR-ARIZE;09350;09;ARIEGE;1
09311;;Tignac;TIGNAC;09110;09;ARIEGE;1
09312;La;Tour-du-Crieu;TOUR-DU-CRIEU;09100;09;ARIEGE;1
09313;;Tourtouse;TOURTOUSE;09230;09;ARIEGE;1
09314;;Tourtrol;TOURTROL;09500;09;ARIEGE;1
09315;;Trémoulet;TREMOULET;09700;09;ARIEGE;1
09316;;Troye-d'Ariège;TROYE-D'ARIEGE;09500;09;ARIEGE;1
09317;;Uchentein;UCHENTEIN;09800;09;ARIEGE;1
09318;;Unac;UNAC;09250;09;ARIEGE;1
09319;;Unzent;UNZENT;09100;09;ARIEGE;1
09320;;Urs;URS;09310;09;ARIEGE;1
09321;;Ussat;USSAT;09400;09;ARIEGE;1
09322;;Ustou;USTOU;09140;09;ARIEGE;1
09323;;Vals;VALS;09500;09;ARIEGE;1
09324;;Varilhes;VARILHES;09120;09;ARIEGE;1
09325;;Vaychis;VAYCHIS;09110;09;ARIEGE;1
09326;;Vèbre;VEBRE;09310;09;ARIEGE;1
09327;;Ventenac;VENTENAC;09120;09;ARIEGE;1
09328;;Verdun;VERDUN;09310;09;ARIEGE;1
09329;;Vernajoul;VERNAJOUL;09000;09;ARIEGE;1
09330;;Vernaux;VERNAUX;09250;09;ARIEGE;1
09331;Le;Vernet;VERNET;09700;09;ARIEGE;1
09332;;Verniolle;VERNIOLLE;09340;09;ARIEGE;1
09334;;Vicdessos;VICDESSOS;09220;09;ARIEGE;1
09335;;Villeneuve;VILLENEUVE;09800;09;ARIEGE;1
09336;;Villeneuve-d'Olmes;VILLENEUVE-D'OLMES;09300;09;ARIEGE;1
09338;;Villeneuve-du-Latou;VILLENEUVE-DU-LATOU;09130;09;ARIEGE;1
09339;;Villeneuve-du-Paréage;VILLENEUVE-DU-PAREAGE;09100;09;ARIEGE;1
09340;;Vira;VIRA;09120;09;ARIEGE;1
09341;;Viviès;VIVIES;09500;09;ARIEGE;1
09342;;Sainte-Suzanne;SAINTE-SUZANNE;09130;09;ARIEGE;1
10002;;Ailleville;AILLEVILLE;10200;10;AUBE;1
10003;;Aix-en-Othe;AIX-EN-OTHE;10160;10;AUBE;1
10004;;Allibaudières;ALLIBAUDIERES;10700;10;AUBE;1
10005;;Amance;AMANCE;10140;10;AUBE;1
10006;;Arcis-sur-Aube;ARCIS-SUR-AUBE;10700;10;AUBE;1
10007;;Arconville;ARCONVILLE;10200;10;AUBE;1
10008;;Argançon;ARGANCON;10140;10;AUBE;1
10009;;Arrelles;ARRELLES;10340;10;AUBE;1
10010;;Arrembécourt;ARREMBECOURT;10330;10;AUBE;1
10011;;Arrentières;ARRENTIERES;10200;10;AUBE;1
10012;;Arsonval;ARSONVAL;10200;10;AUBE;1
10013;;Assenay;ASSENAY;10320;10;AUBE;1
10014;;Assencières;ASSENCIERES;10220;10;AUBE;1
10015;;Aubeterre;AUBETERRE;10150;10;AUBE;1
10017;;Aulnay;AULNAY;10240;10;AUBE;1
10018;;Auxon;AUXON;10130;10;AUBE;1
10019;;Val-d'Auzon;VAL-D'AUZON;10220;10;AUBE;1
10020;;Avant-lès-Marcilly;AVANT-LES-MARCILLY;10400;10;AUBE;1
10021;;Avant-lès-Ramerupt;AVANT-LES-RAMERUPT;10240;10;AUBE;1
10022;;Avirey-Lingey;AVIREY-LINGEY;10340;10;AUBE;1
10023;;Avon-la-Pèze;AVON-LA-PEZE;10290;10;AUBE;1
10024;;Avreuil;AVREUIL;10130;10;AUBE;1
10025;;Bagneux-la-Fosse;BAGNEUX-LA-FOSSE;10340;10;AUBE;1
10026;;Bailly-le-Franc;BAILLY-LE-FRANC;10330;10;AUBE;1
10027;;Balignicourt;BALIGNICOURT;10330;10;AUBE;1
10028;;Balnot-la-Grange;BALNOT-LA-GRANGE;10210;10;AUBE;1
10029;;Balnot-sur-Laignes;BALNOT-SUR-LAIGNES;10110;10;AUBE;1
10030;;Barberey-Saint-Sulpice;BARBEREY-SAINT-SULPICE;10600;10;AUBE;1
10031;;Barbuise;BARBUISE;10400;10;AUBE;1
10032;;Baroville;BAROVILLE;10200;10;AUBE;1
10033;;Bar-sur-Aube;BAR-SUR-AUBE;10200;10;AUBE;1
10034;;Bar-sur-Seine;BAR-SUR-SEINE;10110;10;AUBE;1
10035;;Bayel;BAYEL;10310;10;AUBE;1
10037;;Bercenay-en-Othe;BERCENAY-EN-OTHE;10190;10;AUBE;1
10038;;Bercenay-le-Hayer;BERCENAY-LE-HAYER;10290;10;AUBE;1
10039;;Bergères;BERGERES;10200;10;AUBE;1
10040;;Bernon;BERNON;10130;10;AUBE;1
10041;;Bertignolles;BERTIGNOLLES;10110;10;AUBE;1
10042;;Bérulle;BERULLE;10160;10;AUBE;1
10043;;Bessy;BESSY;10170;10;AUBE;1
10044;;Bétignicourt;BETIGNICOURT;10500;10;AUBE;1
10045;;Beurey;BEUREY;10140;10;AUBE;1
10046;;Blaincourt-sur-Aube;BLAINCOURT-SUR-AUBE;10500;10;AUBE;1
10047;;Blignicourt;BLIGNICOURT;10500;10;AUBE;1
10048;;Bligny;BLIGNY;10200;10;AUBE;1
10049;Les;Bordes-Aumont;BORDES-AUMONT;10800;10;AUBE;1
10050;;Bossancourt;BOSSANCOURT;10140;10;AUBE;1
10051;;Bouilly;BOUILLY;10320;10;AUBE;1
10052;;Boulages;BOULAGES;10380;10;AUBE;1
10053;;Bouranton;BOURANTON;10270;10;AUBE;1
10054;;Bourdenay;BOURDENAY;10290;10;AUBE;1
10055;;Bourguignons;BOURGUIGNONS;10110;10;AUBE;1
10056;;Bouy-Luxembourg;BOUY-LUXEMBOURG;10220;10;AUBE;1
10057;;Bouy-sur-Orvin;BOUY-SUR-ORVIN;10400;10;AUBE;1
10058;;Bragelogne-Beauvoir;BRAGELOGNE-BEAUVOIR;10340;10;AUBE;1
10059;;Braux;BRAUX;10500;10;AUBE;1
10060;;Bréviandes;BREVIANDES;10800;10;AUBE;1
10061;;Brévonnes;BREVONNES;10220;10;AUBE;1
10062;;Briel-sur-Barse;BRIEL-SUR-BARSE;10140;10;AUBE;1
10063;;Brienne-la-Vieille;BRIENNE-LA-VIEILLE;10500;10;AUBE;1
10064;;Brienne-le-Château;BRIENNE-LE-CHATEAU;10500;10;AUBE;1
10065;;Brillecourt;BRILLECOURT;10240;10;AUBE;1
10066;;Bucey-en-Othe;BUCEY-EN-OTHE;10190;10;AUBE;1
10067;;Buchères;BUCHERES;10800;10;AUBE;1
10068;;Buxeuil;BUXEUIL;10110;10;AUBE;1
10069;;Buxières-sur-Arce;BUXIERES-SUR-ARCE;10110;10;AUBE;1
10070;;Celles-sur-Ource;CELLES-SUR-OURCE;10110;10;AUBE;1
10071;;Chacenay;CHACENAY;10110;10;AUBE;1
10072;La;Chaise;CHAISE;10500;10;AUBE;1
10073;;Chalette-sur-Voire;CHALETTE-SUR-VOIRE;10500;10;AUBE;1
10074;;Chamoy;CHAMOY;10130;10;AUBE;1
10075;;Champfleury;CHAMPFLEURY;10700;10;AUBE;1
10076;;Champignol-lez-Mondeville;CHAMPIGNOL-LEZ-MONDEVILLE;10200;10;AUBE;1
10077;;Champigny-sur-Aube;CHAMPIGNY-SUR-AUBE;10700;10;AUBE;1
10078;;Champ-sur-Barse;CHAMP-SUR-BARSE;10140;10;AUBE;1
10079;;Channes;CHANNES;10340;10;AUBE;1
10080;;Chaource;CHAOURCE;10210;10;AUBE;1
10081;La;Chapelle-Saint-Luc;CHAPELLE-SAINT-LUC;10600;10;AUBE;1
10082;;Chapelle-Vallon;CHAPELLE-VALLON;10700;10;AUBE;1
10083;;Chappes;CHAPPES;10260;10;AUBE;1
10084;;Charmont-sous-Barbuise;CHARMONT-SOUS-BARBUISE;10150;10;AUBE;1
10085;;Charmoy;CHARMOY;10290;10;AUBE;1
10086;;Charny-le-Bachot;CHARNY-LE-BACHOT;10380;10;AUBE;1
10087;;Chaserey;CHASEREY;10210;10;AUBE;1
10089;;Châtres;CHATRES;10510;10;AUBE;1
10090;;Chauchigny;CHAUCHIGNY;10170;10;AUBE;1
10091;;Chaudrey;CHAUDREY;10240;10;AUBE;1
10092;;Chauffour-lès-Bailly;CHAUFFOUR-LES-BAILLY;10110;10;AUBE;1
10093;;Chaumesnil;CHAUMESNIL;10500;10;AUBE;1
10094;;Chavanges;CHAVANGES;10330;10;AUBE;1
10095;Le;Chêne;CHENE;10700;10;AUBE;1
10096;;Chennegy;CHENNEGY;10190;10;AUBE;1
10097;;Chervey;CHERVEY;10110;10;AUBE;1
10098;;Chesley;CHESLEY;10210;10;AUBE;1
10099;;Chessy-les-Prés;CHESSY-LES-PRES;10130;10;AUBE;1
10100;;Clérey;CLEREY;10390;10;AUBE;1
10101;;Coclois;COCLOIS;10240;10;AUBE;1
10102;;Colombé-la-Fosse;COLOMBE-LA-FOSSE;10200;10;AUBE;1
10103;;Colombé-le-Sec;COLOMBE-LE-SEC;10200;10;AUBE;1
10104;;Cormost;CORMOST;10800;10;AUBE;1
10105;;Courcelles-sur-Voire;COURCELLES-SUR-VOIRE;10500;10;AUBE;1
10106;;Courceroy;COURCEROY;10400;10;AUBE;1
10107;;Coursan-en-Othe;COURSAN-EN-OTHE;10130;10;AUBE;1
10108;;Courtaoult;COURTAOULT;10130;10;AUBE;1
10109;;Courtenot;COURTENOT;10260;10;AUBE;1
10110;;Courteranges;COURTERANGES;10270;10;AUBE;1
10111;;Courteron;COURTERON;10250;10;AUBE;1
10112;;Coussegrey;COUSSEGREY;10210;10;AUBE;1
10113;;Couvignon;COUVIGNON;10200;10;AUBE;1
10114;;Crancey;CRANCEY;10100;10;AUBE;1
10115;;Creney-près-Troyes;CRENEY-PRES-TROYES;10150;10;AUBE;1
10116;;Crésantignes;CRESANTIGNES;10320;10;AUBE;1
10117;;Crespy-le-Neuf;CRESPY-LE-NEUF;10500;10;AUBE;1
10118;Les;Croûtes;CROUTES;10130;10;AUBE;1
10119;;Cunfin;CUNFIN;10360;10;AUBE;1
10120;;Cussangy;CUSSANGY;10210;10;AUBE;1
10121;;Dampierre;DAMPIERRE;10240;10;AUBE;1
10122;;Davrey;DAVREY;10130;10;AUBE;1
10123;;Dienville;DIENVILLE;10500;10;AUBE;1
10124;;Dierrey-Saint-Julien;DIERREY-SAINT-JULIEN;10190;10;AUBE;1
10125;;Dierrey-Saint-Pierre;DIERREY-SAINT-PIERRE;10190;10;AUBE;1
10126;;Dolancourt;DOLANCOURT;10200;10;AUBE;1
10127;;Dommartin-le-Coq;DOMMARTIN-LE-COQ;10240;10;AUBE;1
10128;;Donnement;DONNEMENT;10330;10;AUBE;1
10129;;Dosches;DOSCHES;10220;10;AUBE;1
10130;;Dosnon;DOSNON;10700;10;AUBE;1
10131;;Droupt-Saint-Basle;DROUPT-SAINT-BASLE;10170;10;AUBE;1
10132;;Droupt-Sainte-Marie;DROUPT-SAINTE-MARIE;10170;10;AUBE;1
10133;;Eaux-Puiseaux;EAUX-PUISEAUX;10130;10;AUBE;1
10134;;Échemines;ECHEMINES;10350;10;AUBE;1
10135;;Éclance;ECLANCE;10200;10;AUBE;1
10136;;Éguilly-sous-Bois;EGUILLY-SOUS-BOIS;10110;10;AUBE;1
10137;;Engente;ENGENTE;10200;10;AUBE;1
10138;;Épagne;EPAGNE;10500;10;AUBE;1
10139;;Épothémont;EPOTHEMONT;10500;10;AUBE;1
10140;;Ervy-le-Châtel;ERVY-LE-CHATEL;10130;10;AUBE;1
10141;;Essoyes;ESSOYES;10360;10;AUBE;1
10142;;Estissac;ESTISSAC;10190;10;AUBE;1
10143;;Étourvy;ETOURVY;10210;10;AUBE;1
10144;;Étrelles-sur-Aube;ETRELLES-SUR-AUBE;10170;10;AUBE;1
10145;;Faux-Villecerf;FAUX-VILLECERF;10290;10;AUBE;1
10146;;Fay-lès-Marcilly;FAY-LES-MARCILLY;10290;10;AUBE;1
10147;;Fays-la-Chapelle;FAYS-LA-CHAPELLE;10320;10;AUBE;1
10148;;Ferreux-Quincey;FERREUX-QUINCEY;10400;10;AUBE;1
10149;;Feuges;FEUGES;10150;10;AUBE;1
10150;;Fontaine;FONTAINE;10200;10;AUBE;1
10151;;Fontaine-les-Grès;FONTAINE-LES-GRES;10280;10;AUBE;1
10153;;Fontaine-Mâcon;FONTAINE-MACON;10400;10;AUBE;1
10154;;Fontenay-de-Bossery;FONTENAY-DE-BOSSERY;10400;10;AUBE;1
10155;;Fontette;FONTETTE;10360;10;AUBE;1
10156;;Fontvannes;FONTVANNES;10190;10;AUBE;1
10157;La;Fosse-Corduan;FOSSE-CORDUAN;10100;10;AUBE;1
10158;;Fouchères;FOUCHERES;10260;10;AUBE;1
10159;;Fralignes;FRALIGNES;10110;10;AUBE;1
10160;;Fravaux;FRAVAUX;10200;10;AUBE;1
10161;;Fresnay;FRESNAY;10200;10;AUBE;1
10162;;Fresnoy-le-Château;FRESNOY-LE-CHATEAU;10270;10;AUBE;1
10163;;Fuligny;FULIGNY;10200;10;AUBE;1
10164;;Gélannes;GELANNES;10100;10;AUBE;1
10165;;Géraudot;GERAUDOT;10220;10;AUBE;1
10166;Les;Grandes-Chapelles;GRANDES-CHAPELLES;10170;10;AUBE;1
10167;;Grandville;GRANDVILLE;10700;10;AUBE;1
10168;Les;Granges;GRANGES;10210;10;AUBE;1
10169;;Gumery;GUMERY;10400;10;AUBE;1
10170;;Gyé-sur-Seine;GYE-SUR-SEINE;10250;10;AUBE;1
10171;;Hampigny;HAMPIGNY;10500;10;AUBE;1
10172;;Herbisse;HERBISSE;10700;10;AUBE;1
10173;;Isle-Aumont;ISLE-AUMONT;10800;10;AUBE;1
10174;;Isle-Aubigny;ISLE-AUBIGNY;10240;10;AUBE;1
10175;;Jasseines;JASSEINES;10330;10;AUBE;1
10176;;Jaucourt;JAUCOURT;10200;10;AUBE;1
10177;;Javernant;JAVERNANT;10320;10;AUBE;1
10178;;Jessains;JESSAINS;10140;10;AUBE;1
10179;;Jeugny;JEUGNY;10320;10;AUBE;1
10180;;Joncreuil;JONCREUIL;10330;10;AUBE;1
10181;;Jully-sur-Sarce;JULLY-SUR-SARCE;10260;10;AUBE;1
10182;;Juvancourt;JUVANCOURT;10310;10;AUBE;1
10183;;Juvanzé;JUVANZE;10140;10;AUBE;1
10184;;Juzanvigny;JUZANVIGNY;10500;10;AUBE;1
10185;;Lagesse;LAGESSE;10210;10;AUBE;1
10186;;Laines-aux-Bois;LAINES-AUX-BOIS;10120;10;AUBE;1
10187;;Landreville;LANDREVILLE;10110;10;AUBE;1
10188;;Lantages;LANTAGES;10210;10;AUBE;1
10189;;Lassicourt;LASSICOURT;10500;10;AUBE;1
10190;;Laubressel;LAUBRESSEL;10270;10;AUBE;1
10191;;Lavau;LAVAU;10150;10;AUBE;1
10192;;Lentilles;LENTILLES;10330;10;AUBE;1
10193;;Lesmont;LESMONT;10500;10;AUBE;1
10194;;Lévigny;LEVIGNY;10200;10;AUBE;1
10195;;Lhuître;LHUITRE;10700;10;AUBE;1
10196;;Lignières;LIGNIERES;10130;10;AUBE;1
10197;;Lignol-le-Château;LIGNOL-LE-CHATEAU;10200;10;AUBE;1
10198;;Lirey;LIREY;10320;10;AUBE;1
10199;;Loches-sur-Ource;LOCHES-SUR-OURCE;10110;10;AUBE;1
10200;La;Loge-aux-Chèvres;LOGE-AUX-CHEVRES;10140;10;AUBE;1
10201;La;Loge-Pomblin;LOGE-POMBLIN;10210;10;AUBE;1
10202;Les;Loges-Margueron;LOGES-MARGUERON;10210;10;AUBE;1
10203;;Longchamp-sur-Aujon;LONGCHAMP-SUR-AUJON;10310;10;AUBE;1
10204;;Longeville-sur-Mogne;LONGEVILLE-SUR-MOGNE;10320;10;AUBE;1
10205;;Longpré-le-Sec;LONGPRE-LE-SEC;10140;10;AUBE;1
10206;;Longsols;LONGSOLS;10240;10;AUBE;1
10207;;Longueville-sur-Aube;LONGUEVILLE-SUR-AUBE;10170;10;AUBE;1
10208;La;Louptière-Thénard;LOUPTIERE-THENARD;10400;10;AUBE;1
10209;;Lusigny-sur-Barse;LUSIGNY-SUR-BARSE;10270;10;AUBE;1
10210;;Luyères;LUYERES;10150;10;AUBE;1
10211;;Macey;MACEY;10300;10;AUBE;1
10212;;Machy;MACHY;10320;10;AUBE;1
10213;;Magnant;MAGNANT;10110;10;AUBE;1
10214;;Magnicourt;MAGNICOURT;10240;10;AUBE;1
10215;;Magny-Fouchard;MAGNY-FOUCHARD;10140;10;AUBE;1
10216;;Mailly-le-Camp;MAILLY-LE-CAMP;10230;10;AUBE;1
10217;;Maison-des-Champs;MAISON-DES-CHAMPS;10140;10;AUBE;1
10218;;Maisons-lès-Chaource;MAISONS-LES-CHAOURCE;10210;10;AUBE;1
10219;;Maisons-lès-Soulaines;MAISONS-LES-SOULAINES;10200;10;AUBE;1
10220;;Maizières-la-Grande-Paroisse;MAIZIERES-LA-GRANDE-PAROISSE;10510;10;AUBE;1
10221;;Maizières-lès-Brienne;MAIZIERES-LES-BRIENNE;10500;10;AUBE;1
10222;;Maraye-en-Othe;MARAYE-EN-OTHE;10160;10;AUBE;1
10223;;Marcilly-le-Hayer;MARCILLY-LE-HAYER;10290;10;AUBE;1
10224;;Marigny-le-Châtel;MARIGNY-LE-CHATEL;10350;10;AUBE;1
10225;;Marnay-sur-Seine;MARNAY-SUR-SEINE;10400;10;AUBE;1
10226;;Marolles-lès-Bailly;MAROLLES-LES-BAILLY;10110;10;AUBE;1
10227;;Marolles-sous-Lignières;MAROLLES-SOUS-LIGNIERES;10130;10;AUBE;1
10228;;Mathaux;MATHAUX;10500;10;AUBE;1
10229;;Maupas;MAUPAS;10320;10;AUBE;1
10230;;Mergey;MERGEY;10600;10;AUBE;1
10231;Le;Mériot;MERIOT;10400;10;AUBE;1
10232;;Merrey-sur-Arce;MERREY-SUR-ARCE;10110;10;AUBE;1
10233;;Méry-sur-Seine;MERY-SUR-SEINE;10170;10;AUBE;1
10234;;Mesgrigny;MESGRIGNY;10170;10;AUBE;1
10235;;Mesnil-la-Comtesse;MESNIL-LA-COMTESSE;10700;10;AUBE;1
10236;;Mesnil-Lettre;MESNIL-LETTRE;10240;10;AUBE;1
10237;;Mesnil-Saint-Loup;MESNIL-SAINT-LOUP;10190;10;AUBE;1
10238;;Mesnil-Saint-Père;MESNIL-SAINT-PERE;10140;10;AUBE;1
10239;;Mesnil-Sellières;MESNIL-SELLIERES;10220;10;AUBE;1
10240;;Messon;MESSON;10190;10;AUBE;1
10241;;Metz-Robert;METZ-ROBERT;10210;10;AUBE;1
10242;;Meurville;MEURVILLE;10200;10;AUBE;1
10243;;Molins-sur-Aube;MOLINS-SUR-AUBE;10500;10;AUBE;1
10245;;Montaulin;MONTAULIN;10270;10;AUBE;1
10246;;Montceaux-lès-Vaudes;MONTCEAUX-LES-VAUDES;10260;10;AUBE;1
10247;;Montfey;MONTFEY;10130;10;AUBE;1
10248;;Montgueux;MONTGUEUX;10300;10;AUBE;1
10249;;Montiéramey;MONTIERAMEY;10270;10;AUBE;1
10250;;Montier-en-l'Isle;MONTIER-EN-L'ISLE;10200;10;AUBE;1
10251;;Montigny-les-Monts;MONTIGNY-LES-MONTS;10130;10;AUBE;1
10252;;Montmartin-le-Haut;MONTMARTIN-LE-HAUT;10140;10;AUBE;1
10253;;Montmorency-Beaufort;MONTMORENCY-BEAUFORT;10330;10;AUBE;1
10254;;Montpothier;MONTPOTHIER;10400;10;AUBE;1
10255;;Montreuil-sur-Barse;MONTREUIL-SUR-BARSE;10270;10;AUBE;1
10256;;Montsuzain;MONTSUZAIN;10150;10;AUBE;1
10257;;Morembert;MOREMBERT;10240;10;AUBE;1
10258;;Morvilliers;MORVILLIERS;10500;10;AUBE;1
10259;La;Motte-Tilly;MOTTE-TILLY;10400;10;AUBE;1
10260;;Moussey;MOUSSEY;10800;10;AUBE;1
10261;;Mussy-sur-Seine;MUSSY-SUR-SEINE;10250;10;AUBE;1
10262;;Neuville-sur-Seine;NEUVILLE-SUR-SEINE;10250;10;AUBE;1
10263;;Neuville-sur-Vanne;NEUVILLE-SUR-VANNE;10190;10;AUBE;1
10264;;Noé-les-Mallets;NOE-LES-MALLETS;10360;10;AUBE;1
10265;Les;Noës-près-Troyes;NOES-PRES-TROYES;10420;10;AUBE;1
10266;;Nogent-en-Othe;NOGENT-EN-OTHE;10160;10;AUBE;1
10267;;Nogent-sur-Aube;NOGENT-SUR-AUBE;10240;10;AUBE;1
10268;;Nogent-sur-Seine;NOGENT-SUR-SEINE;10400;10;AUBE;1
10269;;Nozay;NOZAY;10700;10;AUBE;1
10270;;Onjon;ONJON;10220;10;AUBE;1
10271;;Origny-le-Sec;ORIGNY-LE-SEC;10510;10;AUBE;1
10272;;Ormes;ORMES;10700;10;AUBE;1
10273;;Ortillon;ORTILLON;10700;10;AUBE;1
10274;;Orvilliers-Saint-Julien;ORVILLIERS-SAINT-JULIEN;10170;10;AUBE;1
10275;;Ossey-les-Trois-Maisons;OSSEY-LES-TROIS-MAISONS;10100;10;AUBE;1
10276;;Paisy-Cosdon;PAISY-COSDON;10160;10;AUBE;1
10277;;Palis;PALIS;10190;10;AUBE;1
10278;;Pargues;PARGUES;10210;10;AUBE;1
10279;;Pars-lès-Chavanges;PARS-LES-CHAVANGES;10330;10;AUBE;1
10280;;Pars-lès-Romilly;PARS-LES-ROMILLY;10100;10;AUBE;1
10281;Le;Pavillon-Sainte-Julie;PAVILLON-SAINTE-JULIE;10350;10;AUBE;1
10282;;Payns;PAYNS;10600;10;AUBE;1
10283;;Pel-et-Der;PEL-ET-DER;10500;10;AUBE;1
10284;;Périgny-la-Rose;PERIGNY-LA-ROSE;10400;10;AUBE;1
10285;;Perthes-lès-Brienne;PERTHES-LES-BRIENNE;10500;10;AUBE;1
10286;;Petit-Mesnil;PETIT-MESNIL;10500;10;AUBE;1
10287;;Piney;PINEY;10220;10;AUBE;1
10288;;Plaines-Saint-Lange;PLAINES-SAINT-LANGE;10250;10;AUBE;1
10289;;Plancy-l'Abbaye;PLANCY-L'ABBAYE;10380;10;AUBE;1
10290;;Planty;PLANTY;10160;10;AUBE;1
10291;;Plessis-Barbuise;PLESSIS-BARBUISE;10400;10;AUBE;1
10293;;Poivres;POIVRES;10700;10;AUBE;1
10294;;Poligny;POLIGNY;10110;10;AUBE;1
10295;;Polisot;POLISOT;10110;10;AUBE;1
10296;;Polisy;POLISY;10110;10;AUBE;1
10297;;Pont-Sainte-Marie;PONT-SAINTE-MARIE;10150;10;AUBE;1
10298;;Pont-sur-Seine;PONT-SUR-SEINE;10400;10;AUBE;1
10299;;Pouan-les-Vallées;POUAN-LES-VALLEES;10700;10;AUBE;1
10300;;Pougy;POUGY;10240;10;AUBE;1
10301;;Pouy-sur-Vannes;POUY-SUR-VANNES;10290;10;AUBE;1
10302;;Praslin;PRASLIN;10210;10;AUBE;1
10303;;Précy-Notre-Dame;PRECY-NOTRE-DAME;10500;10;AUBE;1
10304;;Précy-Saint-Martin;PRECY-SAINT-MARTIN;10500;10;AUBE;1
10305;;Prémierfait;PREMIERFAIT;10170;10;AUBE;1
10306;;Proverville;PROVERVILLE;10200;10;AUBE;1
10307;;Prugny;PRUGNY;10190;10;AUBE;1
10308;;Prunay-Belleville;PRUNAY-BELLEVILLE;10350;10;AUBE;1
10309;;Prusy;PRUSY;10210;10;AUBE;1
10310;;Puits-et-Nuisement;PUITS-ET-NUISEMENT;10140;10;AUBE;1
10312;;Racines;RACINES;10130;10;AUBE;1
10313;;Radonvilliers;RADONVILLIERS;10500;10;AUBE;1
10314;;Ramerupt;RAMERUPT;10240;10;AUBE;1
10315;;Rances;RANCES;10500;10;AUBE;1
10316;;Rhèges;RHEGES;10170;10;AUBE;1
10317;Les;Riceys;RICEYS;10340;10;AUBE;1
10318;;Rigny-la-Nonneuse;RIGNY-LA-NONNEUSE;10290;10;AUBE;1
10319;;Rigny-le-Ferron;RIGNY-LE-FERRON;10160;10;AUBE;1
10320;;Rilly-Sainte-Syre;RILLY-SAINTE-SYRE;10280;10;AUBE;1
10321;La;Rivière-de-Corps;RIVIERE-DE-CORPS;10440;10;AUBE;1
10323;;Romilly-sur-Seine;ROMILLY-SUR-SEINE;10100;10;AUBE;1
10324;;Roncenay;RONCENAY;10320;10;AUBE;1
10325;;Rosières-près-Troyes;ROSIERES-PRES-TROYES;10430;10;AUBE;1
10326;;Rosnay-l'Hôpital;ROSNAY-L'HOPITAL;10500;10;AUBE;1
10327;La;Rothière;ROTHIERE;10500;10;AUBE;1
10328;;Rouilly-Sacey;ROUILLY-SACEY;10220;10;AUBE;1
10329;;Rouilly-Saint-Loup;ROUILLY-SAINT-LOUP;10800;10;AUBE;1
10330;;Rouvres-les-Vignes;ROUVRES-LES-VIGNES;10200;10;AUBE;1
10331;;Rumilly-lès-Vaudes;RUMILLY-LES-VAUDES;10260;10;AUBE;1
10332;;Ruvigny;RUVIGNY;10410;10;AUBE;1
10333;;Saint-André-les-Vergers;SAINT-ANDRE-LES-VERGERS;10120;10;AUBE;1
10334;;Saint-Aubin;SAINT-AUBIN;10400;10;AUBE;1
10335;;Saint-Benoist-sur-Vanne;SAINT-BENOIST-SUR-VANNE;10160;10;AUBE;1
10336;;Saint-Benoît-sur-Seine;SAINT-BENOIT-SUR-SEINE;10600;10;AUBE;1
10337;;Saint-Christophe-Dodinicourt;SAINT-CHRISTOPHE-DODINICOURT;10500;10;AUBE;1
10338;;Saint-Étienne-sous-Barbuise;SAINT-ETIENNE-SOUS-BARBUISE;10700;10;AUBE;1
10339;;Saint-Flavy;SAINT-FLAVY;10350;10;AUBE;1
10340;;Saint-Germain;SAINT-GERMAIN;10120;10;AUBE;1
10341;;Saint-Hilaire-sous-Romilly;SAINT-HILAIRE-SOUS-ROMILLY;10100;10;AUBE;1
10342;;Saint-Jean-de-Bonneval;SAINT-JEAN-DE-BONNEVAL;10320;10;AUBE;1
10343;;Saint-Julien-les-Villas;SAINT-JULIEN-LES-VILLAS;10800;10;AUBE;1
10344;;Saint-Léger-près-Troyes;SAINT-LEGER-PRES-TROYES;10800;10;AUBE;1
10345;;Saint-Léger-sous-Brienne;SAINT-LEGER-SOUS-BRIENNE;10500;10;AUBE;1
10346;;Saint-Léger-sous-Margerie;SAINT-LEGER-SOUS-MARGERIE;10330;10;AUBE;1
10347;;Saint-Loup-de-Buffigny;SAINT-LOUP-DE-BUFFIGNY;10100;10;AUBE;1
10348;;Saint-Lupien;SAINT-LUPIEN;10350;10;AUBE;1
10349;;Saint-Lyé;SAINT-LYE;10600;10;AUBE;1
10350;;Saint-Mards-en-Othe;SAINT-MARDS-EN-OTHE;10160;10;AUBE;1
10351;;Saint-Martin-de-Bossenay;SAINT-MARTIN-DE-BOSSENAY;10100;10;AUBE;1
10352;;Sainte-Maure;SAINTE-MAURE;10150;10;AUBE;1
10353;;Saint-Mesmin;SAINT-MESMIN;10280;10;AUBE;1
10354;;Saint-Nabord-sur-Aube;SAINT-NABORD-SUR-AUBE;10700;10;AUBE;1
10355;;Saint-Nicolas-la-Chapelle;SAINT-NICOLAS-LA-CHAPELLE;10400;10;AUBE;1
10356;;Saint-Oulph;SAINT-OULPH;10170;10;AUBE;1
10357;;Saint-Parres-aux-Tertres;SAINT-PARRES-AUX-TERTRES;10410;10;AUBE;1
10358;;Saint-Parres-lès-Vaudes;SAINT-PARRES-LES-VAUDES;10260;10;AUBE;1
10359;;Saint-Phal;SAINT-PHAL;10130;10;AUBE;1
10360;;Saint-Pouange;SAINT-POUANGE;10120;10;AUBE;1
10361;;Saint-Remy-sous-Barbuise;SAINT-REMY-SOUS-BARBUISE;10700;10;AUBE;1
10362;;Sainte-Savine;SAINTE-SAVINE;10300;10;AUBE;1
10363;;Saint-Thibault;SAINT-THIBAULT;10800;10;AUBE;1
10364;;Saint-Usage;SAINT-USAGE;10360;10;AUBE;1
10365;;Salon;SALON;10700;10;AUBE;1
10366;;Saulcy;SAULCY;10200;10;AUBE;1
10367;La;Saulsotte;SAULSOTTE;10400;10;AUBE;1
10368;;Savières;SAVIERES;10600;10;AUBE;1
10369;;Semoine;SEMOINE;10700;10;AUBE;1
10370;;Soligny-les-Étangs;SOLIGNY-LES-ETANGS;10400;10;AUBE;1
10371;;Sommeval;SOMMEVAL;10320;10;AUBE;1
10372;;Soulaines-Dhuys;SOULAINES-DHUYS;10200;10;AUBE;1
10373;;Souligny;SOULIGNY;10320;10;AUBE;1
10374;;Spoy;SPOY;10200;10;AUBE;1
10375;;Thennelières;THENNELIERES;10410;10;AUBE;1
10376;;Thieffrain;THIEFFRAIN;10140;10;AUBE;1
10377;;Thil;THIL;10200;10;AUBE;1
10378;;Thors;THORS;10200;10;AUBE;1
10379;;Torcy-le-Grand;TORCY-LE-GRAND;10700;10;AUBE;1
10380;;Torcy-le-Petit;TORCY-LE-PETIT;10700;10;AUBE;1
10381;;Torvilliers;TORVILLIERS;10440;10;AUBE;1
10382;;Traînel;TRAINEL;10400;10;AUBE;1
10383;;Trancault;TRANCAULT;10290;10;AUBE;1
10384;;Trannes;TRANNES;10140;10;AUBE;1
10386;;Trouans;TROUANS;10700;10;AUBE;1
10387;;Troyes;TROYES;10000;10;AUBE;1
10388;;Turgy;TURGY;10210;10;AUBE;1
10389;;Unienville;UNIENVILLE;10140;10;AUBE;1
10390;;Urville;URVILLE;10200;10;AUBE;1
10391;;Vailly;VAILLY;10150;10;AUBE;1
10392;;Vallant-Saint-Georges;VALLANT-SAINT-GEORGES;10170;10;AUBE;1
10393;;Vallentigny;VALLENTIGNY;10500;10;AUBE;1
10394;;Vallières;VALLIERES;10210;10;AUBE;1
10395;;Vanlay;VANLAY;10210;10;AUBE;1
10396;;Vauchassis;VAUCHASSIS;10190;10;AUBE;1
10397;;Vauchonvilliers;VAUCHONVILLIERS;10140;10;AUBE;1
10398;;Vaucogne;VAUCOGNE;10240;10;AUBE;1
10399;;Vaudes;VAUDES;10260;10;AUBE;1
10400;;Vaupoisson;VAUPOISSON;10700;10;AUBE;1
10401;;Vendeuvre-sur-Barse;VENDEUVRE-SUR-BARSE;10140;10;AUBE;1
10402;La;Vendue-Mignot;VENDUE-MIGNOT;10800;10;AUBE;1
10403;;Vernonvilliers;VERNONVILLIERS;10200;10;AUBE;1
10404;;Verpillières-sur-Ource;VERPILLIERES-SUR-OURCE;10360;10;AUBE;1
10405;;Verricourt;VERRICOURT;10240;10;AUBE;1
10406;;Verrières;VERRIERES;10390;10;AUBE;1
10408;;Viâpres-le-Petit;VIAPRES-LE-PETIT;10380;10;AUBE;1
10409;;Villacerf;VILLACERF;10600;10;AUBE;1
10410;;Villadin;VILLADIN;10290;10;AUBE;1
10411;La;Ville-aux-Bois;VILLE-AUX-BOIS;10500;10;AUBE;1
10412;;Villechétif;VILLECHETIF;10410;10;AUBE;1
10414;;Villeloup;VILLELOUP;10350;10;AUBE;1
10415;;Villemaur-sur-Vanne;VILLEMAUR-SUR-VANNE;10190;10;AUBE;1
10416;;Villemereuil;VILLEMEREUIL;10800;10;AUBE;1
10417;;Villemoiron-en-Othe;VILLEMOIRON-EN-OTHE;10160;10;AUBE;1
10418;;Villemorien;VILLEMORIEN;10110;10;AUBE;1
10419;;Villemoyenne;VILLEMOYENNE;10260;10;AUBE;1
10420;;Villenauxe-la-Grande;VILLENAUXE-LA-GRANDE;10370;10;AUBE;1
10421;La;Villeneuve-au-Châtelot;VILLENEUVE-AU-CHATELOT;10400;10;AUBE;1
10422;;Villeneuve-au-Chemin;VILLENEUVE-AU-CHEMIN;10130;10;AUBE;1
10423;La;Villeneuve-au-Chêne;VILLENEUVE-AU-CHENE;10140;10;AUBE;1
10424;;Villeret;VILLERET;10330;10;AUBE;1
10425;;Villery;VILLERY;10320;10;AUBE;1
10426;;Ville-sous-la-Ferté;VILLE-SOUS-LA-FERTE;10310;10;AUBE;1
10427;;Ville-sur-Arce;VILLE-SUR-ARCE;10110;10;AUBE;1
10428;;Ville-sur-Terre;VILLE-SUR-TERRE;10200;10;AUBE;1
10429;;Villette-sur-Aube;VILLETTE-SUR-AUBE;10700;10;AUBE;1
10430;;Villiers-Herbisse;VILLIERS-HERBISSE;10700;10;AUBE;1
10431;;Villiers-le-Bois;VILLIERS-LE-BOIS;10210;10;AUBE;1
10432;;Villiers-sous-Praslin;VILLIERS-SOUS-PRASLIN;10210;10;AUBE;1
10433;;Villy-en-Trodes;VILLY-EN-TRODES;10140;10;AUBE;1
10434;;Villy-le-Bois;VILLY-LE-BOIS;10800;10;AUBE;1
10435;;Villy-le-Maréchal;VILLY-LE-MARECHAL;10800;10;AUBE;1
10436;;Vinets;VINETS;10700;10;AUBE;1
10437;;Virey-sous-Bar;VIREY-SOUS-BAR;10260;10;AUBE;1
10438;;Vitry-le-Croisé;VITRY-LE-CROISE;10110;10;AUBE;1
10439;;Viviers-sur-Artaut;VIVIERS-SUR-ARTAUT;10110;10;AUBE;1
10440;;Voigny;VOIGNY;10200;10;AUBE;1
10441;;Vosnon;VOSNON;10130;10;AUBE;1
10442;;Voué;VOUE;10150;10;AUBE;1
10443;;Vougrey;VOUGREY;10210;10;AUBE;1
10444;;Vulaines;VULAINES;10160;10;AUBE;1
10445;;Yèvres-le-Petit;YEVRES-LE-PETIT;10500;10;AUBE;1
11001;;Aigues-Vives;AIGUES-VIVES;11800;11;AUDE;1
11002;;Airoux;AIROUX;11320;11;AUDE;1
11003;;Ajac;AJAC;11300;11;AUDE;1
11004;;Alaigne;ALAIGNE;11240;11;AUDE;1
11005;;Alairac;ALAIRAC;11290;11;AUDE;1
11006;;Albas;ALBAS;11360;11;AUDE;1
11007;;Albières;ALBIERES;11330;11;AUDE;1
11008;;Alet-les-Bains;ALET-LES-BAINS;11580;11;AUDE;1
11009;;Alzonne;ALZONNE;11170;11;AUDE;1
11010;;Antugnac;ANTUGNAC;11190;11;AUDE;1
11011;;Aragon;ARAGON;11600;11;AUDE;1
11012;;Argeliers;ARGELIERS;11120;11;AUDE;1
11013;;Argens-Minervois;ARGENS-MINERVOIS;11200;11;AUDE;1
11014;;Armissan;ARMISSAN;11110;11;AUDE;1
11015;;Arques;ARQUES;11190;11;AUDE;1
11016;;Arquettes-en-Val;ARQUETTES-EN-VAL;11220;11;AUDE;1
11017;;Artigues;ARTIGUES;11140;11;AUDE;1
11018;;Arzens;ARZENS;11290;11;AUDE;1
11019;;Aunat;AUNAT;11140;11;AUDE;1
11020;;Auriac;AURIAC;11330;11;AUDE;1
11021;;Axat;AXAT;11140;11;AUDE;1
11022;;Azille;AZILLE;11700;11;AUDE;1
11023;;Badens;BADENS;11800;11;AUDE;1
11024;;Bages;BAGES;11100;11;AUDE;1
11025;;Bagnoles;BAGNOLES;11600;11;AUDE;1
11026;;Baraigne;BARAIGNE;11410;11;AUDE;1
11027;;Barbaira;BARBAIRA;11800;11;AUDE;1
11028;;Belcaire;BELCAIRE;11340;11;AUDE;1
11029;;Belcastel-et-Buc;BELCASTEL-ET-BUC;11580;11;AUDE;1
11030;;Belflou;BELFLOU;11410;11;AUDE;1
11031;;Belfort-sur-Rebenty;BELFORT-SUR-REBENTY;11140;11;AUDE;1
11032;;Bellegarde-du-Razès;BELLEGARDE-DU-RAZES;11240;11;AUDE;1
11033;;Belpech;BELPECH;11420;11;AUDE;1
11034;;Belvèze-du-Razès;BELVEZE-DU-RAZES;11240;11;AUDE;1
11035;;Belvianes-et-Cavirac;BELVIANES-ET-CAVIRAC;11500;11;AUDE;1
11036;;Belvis;BELVIS;11340;11;AUDE;1
11037;;Berriac;BERRIAC;11090;11;AUDE;1
11038;;Bessède-de-Sault;BESSEDE-DE-SAULT;11140;11;AUDE;1
11039;La;Bezole;BEZOLE;11300;11;AUDE;1
11040;;Bizanet;BIZANET;11200;11;AUDE;1
11041;;Bize-Minervois;BIZE-MINERVOIS;11120;11;AUDE;1
11042;;Blomac;BLOMAC;11700;11;AUDE;1
11043;;Bouilhonnac;BOUILHONNAC;11800;11;AUDE;1
11044;;Bouisse;BOUISSE;11190;11;AUDE;1
11045;;Bouriège;BOURIEGE;11300;11;AUDE;1
11046;;Bourigeole;BOURIGEOLE;11300;11;AUDE;1
11047;Le;Bousquet;BOUSQUET;11140;11;AUDE;1
11048;;Boutenac;BOUTENAC;11200;11;AUDE;1
11049;;Bram;BRAM;11150;11;AUDE;1
11050;;Brenac;BRENAC;11500;11;AUDE;1
11051;;Brézilhac;BREZILHAC;11270;11;AUDE;1
11052;;Brousses-et-Villaret;BROUSSES-ET-VILLARET;11390;11;AUDE;1
11053;;Brugairolles;BRUGAIROLLES;11300;11;AUDE;1
11054;Les;Brunels;BRUNELS;11400;11;AUDE;1
11055;;Bugarach;BUGARACH;11190;11;AUDE;1
11056;;Cabrespine;CABRESPINE;11160;11;AUDE;1
11057;;Cahuzac;CAHUZAC;11420;11;AUDE;1
11058;;Cailhau;CAILHAU;11240;11;AUDE;1
11059;;Cailhavel;CAILHAVEL;11240;11;AUDE;1
11060;;Cailla;CAILLA;11140;11;AUDE;1
11061;;Cambieure;CAMBIEURE;11240;11;AUDE;1
11062;;Campagna-de-Sault;CAMPAGNA-DE-SAULT;11140;11;AUDE;1
11063;;Campagne-sur-Aude;CAMPAGNE-SUR-AUDE;11260;11;AUDE;1
11064;;Camplong-d'Aude;CAMPLONG-D'AUDE;11200;11;AUDE;1
11065;;Camps-sur-l'Agly;CAMPS-SUR-L'AGLY;11190;11;AUDE;1
11066;;Camurac;CAMURAC;11340;11;AUDE;1
11067;;Canet;CANET;11200;11;AUDE;1
11068;;Capendu;CAPENDU;11700;11;AUDE;1
11069;;Carcassonne;CARCASSONNE;11000;11;AUDE;1
11070;;Carlipa;CARLIPA;11170;11;AUDE;1
11071;;Cascastel-des-Corbières;CASCASTEL-DES-CORBIERES;11360;11;AUDE;1
11072;La;Cassaigne;CASSAIGNE;11270;11;AUDE;1
11073;;Cassaignes;CASSAIGNES;11190;11;AUDE;1
11074;Les;Cassés;CASSES;11320;11;AUDE;1
11075;;Castans;CASTANS;11160;11;AUDE;1
11076;;Castelnaudary;CASTELNAUDARY;11400;11;AUDE;1
11077;;Castelnau-d'Aude;CASTELNAU-D'AUDE;11700;11;AUDE;1
11078;;Castelreng;CASTELRENG;11300;11;AUDE;1
11079;;Caudebronde;CAUDEBRONDE;11390;11;AUDE;1
11080;;Caudeval;CAUDEVAL;11230;11;AUDE;1
11081;;Caunes-Minervois;CAUNES-MINERVOIS;11160;11;AUDE;1
11082;;Caunette-sur-Lauquet;CAUNETTE-SUR-LAUQUET;11250;11;AUDE;1
11083;;Caunettes-en-Val;CAUNETTES-EN-VAL;11220;11;AUDE;1
11084;;Caux-et-Sauzens;CAUX-ET-SAUZENS;11170;11;AUDE;1
11085;;Cavanac;CAVANAC;11570;11;AUDE;1
11086;;Caves;CAVES;11510;11;AUDE;1
11087;;Cazalrenoux;CAZALRENOUX;11270;11;AUDE;1
11088;;Cazilhac;CAZILHAC;11570;11;AUDE;1
11089;;Cenne-Monestiés;CENNE-MONESTIES;11170;11;AUDE;1
11090;;Cépie;CEPIE;11300;11;AUDE;1
11091;;Chalabre;CHALABRE;11230;11;AUDE;1
11092;;Citou;CITOU;11160;11;AUDE;1
11093;Le;Clat;CLAT;11140;11;AUDE;1
11094;;Clermont-sur-Lauquet;CLERMONT-SUR-LAUQUET;11250;11;AUDE;1
11095;;Comigne;COMIGNE;11700;11;AUDE;1
11096;;Comus;COMUS;11340;11;AUDE;1
11097;;Conilhac-de-la-Montagne;CONILHAC-DE-LA-MONTAGNE;11190;11;AUDE;1
11098;;Conilhac-Corbières;CONILHAC-CORBIERES;11200;11;AUDE;1
11099;;Conques-sur-Orbiel;CONQUES-SUR-ORBIEL;11600;11;AUDE;1
11100;;Corbières;CORBIERES;11230;11;AUDE;1
11101;;Coudons;COUDONS;11500;11;AUDE;1
11102;;Couffoulens;COUFFOULENS;11250;11;AUDE;1
11103;;Couiza;COUIZA;11190;11;AUDE;1
11104;;Counozouls;COUNOZOULS;11140;11;AUDE;1
11105;;Cournanel;COURNANEL;11300;11;AUDE;1
11106;;Coursan;COURSAN;11110;11;AUDE;1
11107;;Courtauly;COURTAULY;11230;11;AUDE;1
11108;La;Courtète;COURTETE;11240;11;AUDE;1
11109;;Coustaussa;COUSTAUSSA;11190;11;AUDE;1
11110;;Coustouge;COUSTOUGE;11220;11;AUDE;1
11111;;Cruscades;CRUSCADES;11200;11;AUDE;1
11112;;Cubières-sur-Cinoble;CUBIERES-SUR-CINOBLE;11190;11;AUDE;1
11113;;Cucugnan;CUCUGNAN;11350;11;AUDE;1
11114;;Cumiès;CUMIES;11410;11;AUDE;1
11115;;Cuxac-Cabardès;CUXAC-CABARDES;11390;11;AUDE;1
11116;;Cuxac-d'Aude;CUXAC-D'AUDE;11590;11;AUDE;1
11117;;Davejean;DAVEJEAN;11330;11;AUDE;1
11118;;Dernacueillette;DERNACUEILLETTE;11330;11;AUDE;1
11119;La;Digne-d'Amont;DIGNE-D'AMONT;11300;11;AUDE;1
11120;La;Digne-d'Aval;DIGNE-D'AVAL;11300;11;AUDE;1
11121;;Donazac;DONAZAC;11240;11;AUDE;1
11122;;Douzens;DOUZENS;11700;11;AUDE;1
11123;;Duilhac-sous-Peyrepertuse;DUILHAC-SOUS-PEYREPERTUSE;11350;11;AUDE;1
11124;;Durban-Corbières;DURBAN-CORBIERES;11360;11;AUDE;1
11125;;Embres-et-Castelmaure;EMBRES-ET-CASTELMAURE;11360;11;AUDE;1
11126;;Escales;ESCALES;11200;11;AUDE;1
11127;;Escouloubre;ESCOULOUBRE;11140;11;AUDE;1
11128;;Escueillens-et-Saint-Just-de-Bélengard;ESCUEILLENS-ET-SAINT-JUST-DE-BELENGARD;11240;11;AUDE;1
11129;;Espéraza;ESPERAZA;11260;11;AUDE;1
11130;;Espezel;ESPEZEL;11340;11;AUDE;1
11131;;Fa;FA;11260;11;AUDE;1
11132;;Fabrezan;FABREZAN;11200;11;AUDE;1
11133;;Fajac-en-Val;FAJAC-EN-VAL;11220;11;AUDE;1
11134;;Fajac-la-Relenque;FAJAC-LA-RELENQUE;11410;11;AUDE;1
11135;La;Fajolle;FAJOLLE;11140;11;AUDE;1
11136;;Fanjeaux;FANJEAUX;11270;11;AUDE;1
11137;;Félines-Termenès;FELINES-TERMENES;11330;11;AUDE;1
11138;;Fendeille;FENDEILLE;11400;11;AUDE;1
11139;;Fenouillet-du-Razès;FENOUILLET-DU-RAZES;11240;11;AUDE;1
11140;;Ferrals-les-Corbières;FERRALS-LES-CORBIERES;11200;11;AUDE;1
11141;;Ferran;FERRAN;11240;11;AUDE;1
11142;;Festes-et-Saint-André;FESTES-ET-SAINT-ANDRE;11300;11;AUDE;1
11143;;Feuilla;FEUILLA;11510;11;AUDE;1
11144;;Fitou;FITOU;11510;11;AUDE;1
11145;;Fleury;FLEURY;11560;11;AUDE;1
11146;;Floure;FLOURE;11800;11;AUDE;1
11147;;Fontanès-de-Sault;FONTANES-DE-SAULT;11140;11;AUDE;1
11148;;Fontcouverte;FONTCOUVERTE;11700;11;AUDE;1
11149;;Fonters-du-Razès;FONTERS-DU-RAZES;11400;11;AUDE;1
11150;;Fontiers-Cabardès;FONTIERS-CABARDES;11310;11;AUDE;1
11151;;Fontiès-d'Aude;FONTIES-D'AUDE;11800;11;AUDE;1
11152;;Fontjoncouse;FONTJONCOUSE;11360;11;AUDE;1
11153;La;Force;FORCE;11270;11;AUDE;1
11154;;Fournes-Cabardès;FOURNES-CABARDES;11600;11;AUDE;1
11155;;Fourtou;FOURTOU;11190;11;AUDE;1
11156;;Fraisse-Cabardès;FRAISSE-CABARDES;11600;11;AUDE;1
11157;;Fraissé-des-Corbières;FRAISSE-DES-CORBIERES;11360;11;AUDE;1
11158;;Gaja-et-Villedieu;GAJA-ET-VILLEDIEU;11300;11;AUDE;1
11159;;Gaja-la-Selve;GAJA-LA-SELVE;11270;11;AUDE;1
11160;;Galinagues;GALINAGUES;11140;11;AUDE;1
11161;;Gardie;GARDIE;11250;11;AUDE;1
11162;;Generville;GENERVILLE;11270;11;AUDE;1
11163;;Gincla;GINCLA;11140;11;AUDE;1
11164;;Ginestas;GINESTAS;11120;11;AUDE;1
11165;;Ginoles;GINOLES;11500;11;AUDE;1
11166;;Gourvieille;GOURVIEILLE;11410;11;AUDE;1
11167;;Gramazie;GRAMAZIE;11240;11;AUDE;1
11168;;Granès;GRANES;11500;11;AUDE;1
11169;;Greffeil;GREFFEIL;11250;11;AUDE;1
11170;;Gruissan;GRUISSAN;11430;11;AUDE;1
11171;;Gueytes-et-Labastide;GUEYTES-ET-LABASTIDE;11230;11;AUDE;1
11172;;Homps;HOMPS;11200;11;AUDE;1
11173;;Hounoux;HOUNOUX;11240;11;AUDE;1
11174;Les;Ilhes;ILHES;11380;11;AUDE;1
11175;;Issel;ISSEL;11400;11;AUDE;1
11176;;Jonquières;JONQUIERES;11220;11;AUDE;1
11177;;Joucou;JOUCOU;11140;11;AUDE;1
11178;;Labastide-d'Anjou;LABASTIDE-D'ANJOU;11320;11;AUDE;1
11179;;Labastide-en-Val;LABASTIDE-EN-VAL;11220;11;AUDE;1
11180;;Labastide-Esparbairenque;LABASTIDE-ESPARBAIRENQUE;11380;11;AUDE;1
11181;;Labécède-Lauragais;LABECEDE-LAURAGAIS;11400;11;AUDE;1
11182;;Lacombe;LACOMBE;11310;11;AUDE;1
11183;;Ladern-sur-Lauquet;LADERN-SUR-LAUQUET;11250;11;AUDE;1
11184;;Lafage;LAFAGE;11420;11;AUDE;1
11185;;Lagrasse;LAGRASSE;11220;11;AUDE;1
11186;;Lairière;LAIRIERE;11330;11;AUDE;1
11187;;Lanet;LANET;11330;11;AUDE;1
11188;La;Palme;PALME;11480;11;AUDE;1
11189;;Laprade;LAPRADE;11390;11;AUDE;1
11190;La;Redorte;REDORTE;11700;11;AUDE;1
11191;;Laroque-de-Fa;LAROQUE-DE-FA;11330;11;AUDE;1
11192;;Lasbordes;LASBORDES;11400;11;AUDE;1
11193;;Lasserre-de-Prouille;LASSERRE-DE-PROUILLE;11270;11;AUDE;1
11194;;Lastours;LASTOURS;11600;11;AUDE;1
11195;;Laurabuc;LAURABUC;11400;11;AUDE;1
11196;;Laurac;LAURAC;11270;11;AUDE;1
11197;;Lauraguel;LAURAGUEL;11300;11;AUDE;1
11198;;Laure-Minervois;LAURE-MINERVOIS;11800;11;AUDE;1
11199;;Lavalette;LAVALETTE;11290;11;AUDE;1
11200;;Lespinassière;LESPINASSIERE;11160;11;AUDE;1
11201;;Leuc;LEUC;11250;11;AUDE;1
11202;;Leucate;LEUCATE;11370;11;AUDE;1
11203;;Lézignan-Corbières;LEZIGNAN-CORBIERES;11200;11;AUDE;1
11204;;Lignairolles;LIGNAIROLLES;11240;11;AUDE;1
11205;;Limousis;LIMOUSIS;11600;11;AUDE;1
11206;;Limoux;LIMOUX;11300;11;AUDE;1
11207;;Loupia;LOUPIA;11300;11;AUDE;1
11208;La;Louvière-Lauragais;LOUVIERE-LAURAGAIS;11410;11;AUDE;1
11209;;Luc-sur-Aude;LUC-SUR-AUDE;11190;11;AUDE;1
11210;;Luc-sur-Orbieu;LUC-SUR-ORBIEU;11200;11;AUDE;1
11211;;Magrie;MAGRIE;11300;11;AUDE;1
11212;;Mailhac;MAILHAC;11120;11;AUDE;1
11213;;Maisons;MAISONS;11330;11;AUDE;1
11214;;Malras;MALRAS;11300;11;AUDE;1
11215;;Malves-en-Minervois;MALVES-EN-MINERVOIS;11600;11;AUDE;1
11216;;Malviès;MALVIES;11300;11;AUDE;1
11217;;Marcorignan;MARCORIGNAN;11120;11;AUDE;1
11218;;Marquein;MARQUEIN;11410;11;AUDE;1
11219;;Marsa;MARSA;11140;11;AUDE;1
11220;;Marseillette;MARSEILLETTE;11800;11;AUDE;1
11221;Les;Martys;MARTYS;11390;11;AUDE;1
11222;;Mas-Cabardès;MAS-CABARDES;11380;11;AUDE;1
11223;;Mas-des-Cours;MAS-DES-COURS;11570;11;AUDE;1
11224;;Massac;MASSAC;11330;11;AUDE;1
11225;;Mas-Saintes-Puelles;MAS-SAINTES-PUELLES;11400;11;AUDE;1
11226;;Mayreville;MAYREVILLE;11420;11;AUDE;1
11227;;Mayronnes;MAYRONNES;11220;11;AUDE;1
11228;;Mazerolles-du-Razès;MAZEROLLES-DU-RAZES;11240;11;AUDE;1
11229;;Mazuby;MAZUBY;11140;11;AUDE;1
11230;;Mérial;MERIAL;11140;11;AUDE;1
11231;;Mézerville;MEZERVILLE;11410;11;AUDE;1
11232;;Miraval-Cabardes;MIRAVAL-CABARDES;11380;11;AUDE;1
11233;;Mirepeisset;MIREPEISSET;11120;11;AUDE;1
11234;;Mireval-Lauragais;MIREVAL-LAURAGAIS;11400;11;AUDE;1
11235;;Missègre;MISSEGRE;11580;11;AUDE;1
11236;;Molandier;MOLANDIER;11420;11;AUDE;1
11238;;Molleville;MOLLEVILLE;11410;11;AUDE;1
11239;;Montauriol;MONTAURIOL;11410;11;AUDE;1
11240;;Montazels;MONTAZELS;11190;11;AUDE;1
11241;;Montbrun-des-Corbières;MONTBRUN-DES-CORBIERES;11700;11;AUDE;1
11242;;Montclar;MONTCLAR;11250;11;AUDE;1
11243;;Montferrand;MONTFERRAND;11320;11;AUDE;1
11244;;Montfort-sur-Boulzane;MONTFORT-SUR-BOULZANE;11140;11;AUDE;1
11245;;Montgaillard;MONTGAILLARD;11330;11;AUDE;1
11246;;Montgradail;MONTGRADAIL;11240;11;AUDE;1
11247;;Monthaut;MONTHAUT;11240;11;AUDE;1
11248;;Montirat;MONTIRAT;11800;11;AUDE;1
11249;;Montjardin;MONTJARDIN;11230;11;AUDE;1
11250;;Montjoi;MONTJOI;11330;11;AUDE;1
11251;;Montlaur;MONTLAUR;11220;11;AUDE;1
11252;;Montmaur;MONTMAUR;11320;11;AUDE;1
11253;;Montolieu;MONTOLIEU;11170;11;AUDE;1
11254;;Montréal;MONTREAL;11290;11;AUDE;1
11255;;Montredon-des-Corbières;MONTREDON-DES-CORBIERES;11100;11;AUDE;1
11256;;Montséret;MONTSERET;11200;11;AUDE;1
11257;;Monze;MONZE;11800;11;AUDE;1
11258;;Moussan;MOUSSAN;11120;11;AUDE;1
11259;;Moussoulens;MOUSSOULENS;11170;11;AUDE;1
11260;;Mouthoumet;MOUTHOUMET;11330;11;AUDE;1
11261;;Moux;MOUX;11700;11;AUDE;1
11262;;Narbonne;NARBONNE;11100;11;AUDE;1
11263;;Nébias;NEBIAS;11500;11;AUDE;1
11264;;Névian;NEVIAN;11200;11;AUDE;1
11265;;Niort-de-Sault;NIORT-DE-SAULT;11140;11;AUDE;1
11266;;Port-la-Nouvelle;PORT-LA-NOUVELLE;11210;11;AUDE;1
11267;;Ornaisons;ORNAISONS;11200;11;AUDE;1
11268;;Orsans;ORSANS;11270;11;AUDE;1
11269;;Ouveillan;OUVEILLAN;11590;11;AUDE;1
11270;;Padern;PADERN;11350;11;AUDE;1
11271;;Palairac;PALAIRAC;11330;11;AUDE;1
11272;;Palaja;PALAJA;11570;11;AUDE;1
11273;;Paraza;PARAZA;11200;11;AUDE;1
11274;;Pauligne;PAULIGNE;11300;11;AUDE;1
11275;;Payra-sur-l'Hers;PAYRA-SUR-L'HERS;11410;11;AUDE;1
11276;;Paziols;PAZIOLS;11350;11;AUDE;1
11277;;Pécharic-et-le-Py;PECHARIC-ET-LE-PY;11420;11;AUDE;1
11278;;Pech-Luna;PECH-LUNA;11420;11;AUDE;1
11279;;Pennautier;PENNAUTIER;11610;11;AUDE;1
11280;;Pépieux;PEPIEUX;11700;11;AUDE;1
11281;;Pexiora;PEXIORA;11150;11;AUDE;1
11282;;Peyrefitte-du-Razès;PEYREFITTE-DU-RAZES;11230;11;AUDE;1
11283;;Peyrefitte-sur-l'Hers;PEYREFITTE-SUR-L'HERS;11410;11;AUDE;1
11284;;Peyrens;PEYRENS;11400;11;AUDE;1
11285;;Peyriac-de-Mer;PEYRIAC-DE-MER;11440;11;AUDE;1
11286;;Peyriac-Minervois;PEYRIAC-MINERVOIS;11160;11;AUDE;1
11287;;Peyrolles;PEYROLLES;11190;11;AUDE;1
11288;;Pezens;PEZENS;11170;11;AUDE;1
11289;;Pieusse;PIEUSSE;11300;11;AUDE;1
11290;;Plaigne;PLAIGNE;11420;11;AUDE;1
11291;;Plavilla;PLAVILLA;11270;11;AUDE;1
11292;La;Pomarède;POMAREDE;11400;11;AUDE;1
11293;;Pomas;POMAS;11250;11;AUDE;1
11294;;Pomy;POMY;11300;11;AUDE;1
11295;;Portel-des-Corbières;PORTEL-DES-CORBIERES;11490;11;AUDE;1
11296;;Pouzols-Minervois;POUZOLS-MINERVOIS;11120;11;AUDE;1
11297;;Pradelles-Cabardès;PRADELLES-CABARDES;11380;11;AUDE;1
11298;;Pradelles-en-Val;PRADELLES-EN-VAL;11220;11;AUDE;1
11299;;Preixan;PREIXAN;11250;11;AUDE;1
11300;;Puginier;PUGINIER;11400;11;AUDE;1
11301;;Puichéric;PUICHERIC;11700;11;AUDE;1
11302;;Puilaurens;PUILAURENS;11140;11;AUDE;1
11303;;Puivert;PUIVERT;11230;11;AUDE;1
11304;;Quillan;QUILLAN;11500;11;AUDE;1
11305;;Quintillan;QUINTILLAN;11360;11;AUDE;1
11306;;Quirbajou;QUIRBAJOU;11500;11;AUDE;1
11307;;Raissac-d'Aude;RAISSAC-D'AUDE;11200;11;AUDE;1
11308;;Raissac-sur-Lampy;RAISSAC-SUR-LAMPY;11170;11;AUDE;1
11309;;Rennes-le-Château;RENNES-LE-CHATEAU;11190;11;AUDE;1
11310;;Rennes-les-Bains;RENNES-LES-BAINS;11190;11;AUDE;1
11311;;Ribaute;RIBAUTE;11220;11;AUDE;1
11312;;Ribouisse;RIBOUISSE;11270;11;AUDE;1
11313;;Ricaud;RICAUD;11400;11;AUDE;1
11314;;Rieux-en-Val;RIEUX-EN-VAL;11220;11;AUDE;1
11315;;Rieux-Minervois;RIEUX-MINERVOIS;11160;11;AUDE;1
11316;;Rivel;RIVEL;11230;11;AUDE;1
11317;;Rodome;RODOME;11140;11;AUDE;1
11318;;Roquecourbe-Minervois;ROQUECOURBE-MINERVOIS;11700;11;AUDE;1
11319;;Roquefère;ROQUEFERE;11380;11;AUDE;1
11320;;Roquefeuil;ROQUEFEUIL;11340;11;AUDE;1
11321;;Roquefort-de-Sault;ROQUEFORT-DE-SAULT;11140;11;AUDE;1
11322;;Roquefort-des-Corbières;ROQUEFORT-DES-CORBIERES;11540;11;AUDE;1
11323;;Roquetaillade;ROQUETAILLADE;11300;11;AUDE;1
11324;;Roubia;ROUBIA;11200;11;AUDE;1
11325;;Rouffiac-d'Aude;ROUFFIAC-D'AUDE;11250;11;AUDE;1
11326;;Rouffiac-des-Corbières;ROUFFIAC-DES-CORBIERES;11350;11;AUDE;1
11327;;Roullens;ROULLENS;11290;11;AUDE;1
11328;;Routier;ROUTIER;11240;11;AUDE;1
11329;;Rouvenac;ROUVENAC;11260;11;AUDE;1
11330;;Rustiques;RUSTIQUES;11800;11;AUDE;1
11331;;Saint-Amans;SAINT-AMANS;11270;11;AUDE;1
11332;;Saint-André-de-Roquelongue;SAINT-ANDRE-DE-ROQUELONGUE;11200;11;AUDE;1
11333;;Saint-Benoît;SAINT-BENOIT;11230;11;AUDE;1
11334;;Sainte-Camelle;SAINTE-CAMELLE;11410;11;AUDE;1
11335;;Sainte-Colombe-sur-Guette;SAINTE-COLOMBE-SUR-GUETTE;11140;11;AUDE;1
11336;;Sainte-Colombe-sur-l'Hers;SAINTE-COLOMBE-SUR-L'HERS;11230;11;AUDE;1
11337;;Saint-Couat-d'Aude;SAINT-COUAT-D'AUDE;11700;11;AUDE;1
11338;;Saint-Couat-du-Razès;SAINT-COUAT-DU-RAZES;11300;11;AUDE;1
11339;;Saint-Denis;SAINT-DENIS;11310;11;AUDE;1
11340;;Sainte-Eulalie;SAINTE-EULALIE;11170;11;AUDE;1
11341;;Saint-Ferriol;SAINT-FERRIOL;11500;11;AUDE;1
11342;;Saint-Frichoux;SAINT-FRICHOUX;11800;11;AUDE;1
11343;;Saint-Gaudéric;SAINT-GAUDERIC;11270;11;AUDE;1
11344;;Saint-Hilaire;SAINT-HILAIRE;11250;11;AUDE;1
11345;;Saint-Jean-de-Barrou;SAINT-JEAN-DE-BARROU;11360;11;AUDE;1
11346;;Saint-Jean-de-Paracol;SAINT-JEAN-DE-PARACOL;11260;11;AUDE;1
11347;;Saint-Julia-de-Bec;SAINT-JULIA-DE-BEC;11500;11;AUDE;1
11348;;Saint-Julien-de-Briola;SAINT-JULIEN-DE-BRIOLA;11270;11;AUDE;1
11350;;Saint-Just-et-le-Bézu;SAINT-JUST-ET-LE-BEZU;11500;11;AUDE;1
11351;;Saint-Laurent-de-la-Cabrerisse;SAINT-LAURENT-DE-LA-CABRERISSE;11220;11;AUDE;1
11352;;Saint-Louis-et-Parahou;SAINT-LOUIS-ET-PARAHOU;11500;11;AUDE;1
11353;;Saint-Marcel-sur-Aude;SAINT-MARCEL-SUR-AUDE;11120;11;AUDE;1
11354;;Saint-Martin-des-Puits;SAINT-MARTIN-DES-PUITS;11220;11;AUDE;1
11355;;Saint-Martin-de-Villereglan;SAINT-MARTIN-DE-VILLEREGLAN;11300;11;AUDE;1
11356;;Saint-Martin-Lalande;SAINT-MARTIN-LALANDE;11400;11;AUDE;1
11357;;Saint-Martin-le-Vieil;SAINT-MARTIN-LE-VIEIL;11170;11;AUDE;1
11358;;Saint-Martin-Lys;SAINT-MARTIN-LYS;11500;11;AUDE;1
11359;;Saint-Michel-de-Lanès;SAINT-MICHEL-DE-LANES;11410;11;AUDE;1
11360;;Saint-Nazaire-d'Aude;SAINT-NAZAIRE-D'AUDE;11120;11;AUDE;1
11361;;Saint-Papoul;SAINT-PAPOUL;11400;11;AUDE;1
11362;;Saint-Paulet;SAINT-PAULET;11320;11;AUDE;1
11363;;Saint-Pierre-des-Champs;SAINT-PIERRE-DES-CHAMPS;11220;11;AUDE;1
11364;;Saint-Polycarpe;SAINT-POLYCARPE;11300;11;AUDE;1
11365;;Saint-Sernin;SAINT-SERNIN;11420;11;AUDE;1
11366;;Sainte-Valière;SAINTE-VALIERE;11120;11;AUDE;1
11367;;Saissac;SAISSAC;11310;11;AUDE;1
11368;;Sallèles-Cabardès;SALLELES-CABARDES;11600;11;AUDE;1
11369;;Sallèles-d'Aude;SALLELES-D'AUDE;11590;11;AUDE;1
11370;;Salles-d'Aude;SALLES-D'AUDE;11110;11;AUDE;1
11371;;Salles-sur-l'Hers;SALLES-SUR-L'HERS;11410;11;AUDE;1
11372;;Salsigne;SALSIGNE;11600;11;AUDE;1
11373;;Salvezines;SALVEZINES;11140;11;AUDE;1
11374;;Salza;SALZA;11330;11;AUDE;1
11375;;Seignalens;SEIGNALENS;11240;11;AUDE;1
11376;La;Serpent;SERPENT;11190;11;AUDE;1
11377;;Serres;SERRES;11190;11;AUDE;1
11378;;Serviès-en-Val;SERVIES-EN-VAL;11220;11;AUDE;1
11379;;Sigean;SIGEAN;11130;11;AUDE;1
11380;;Sonnac-sur-l'Hers;SONNAC-SUR-L'HERS;11230;11;AUDE;1
11381;;Sougraigne;SOUGRAIGNE;11190;11;AUDE;1
11382;;Souilhanels;SOUILHANELS;11400;11;AUDE;1
11383;;Souilhe;SOUILHE;11400;11;AUDE;1
11384;;Soulatgé;SOULATGE;11350;11;AUDE;1
11385;;Soupex;SOUPEX;11320;11;AUDE;1
11386;;Talairan;TALAIRAN;11220;11;AUDE;1
11387;;Taurize;TAURIZE;11220;11;AUDE;1
11388;;Termes;TERMES;11330;11;AUDE;1
11389;;Terroles;TERROLES;11580;11;AUDE;1
11390;;Thézan-des-Corbières;THEZAN-DES-CORBIERES;11200;11;AUDE;1
11391;La;Tourette-Cabardès;TOURETTE-CABARDES;11380;11;AUDE;1
11392;;Tournissan;TOURNISSAN;11220;11;AUDE;1
11393;;Tourouzelle;TOUROUZELLE;11200;11;AUDE;1
11394;;Tourreilles;TOURREILLES;11300;11;AUDE;1
11395;;Trassanel;TRASSANEL;11160;11;AUDE;1
11396;;Trausse;TRAUSSE;11160;11;AUDE;1
11397;;Trèbes;TREBES;11800;11;AUDE;1
11398;;Treilles;TREILLES;11510;11;AUDE;1
11399;;Tréville;TREVILLE;11400;11;AUDE;1
11400;;Tréziers;TREZIERS;11230;11;AUDE;1
11401;;Tuchan;TUCHAN;11350;11;AUDE;1
11402;;Valmigère;VALMIGERE;11580;11;AUDE;1
11404;;Ventenac-Cabardès;VENTENAC-CABARDES;11610;11;AUDE;1
11405;;Ventenac-en-Minervois;VENTENAC-EN-MINERVOIS;11120;11;AUDE;1
11406;;Véraza;VERAZA;11580;11;AUDE;1
11407;;Verdun-en-Lauragais;VERDUN-EN-LAURAGAIS;11400;11;AUDE;1
11408;;Verzeille;VERZEILLE;11250;11;AUDE;1
11409;;Vignevieille;VIGNEVIEILLE;11330;11;AUDE;1
11410;;Villalier;VILLALIER;11600;11;AUDE;1
11411;;Villanière;VILLANIERE;11600;11;AUDE;1
11412;;Villardebelle;VILLARDEBELLE;11580;11;AUDE;1
11413;;Villardonnel;VILLARDONNEL;11600;11;AUDE;1
11414;;Villar-en-Val;VILLAR-EN-VAL;11220;11;AUDE;1
11415;;Villar-Saint-Anselme;VILLAR-SAINT-ANSELME;11250;11;AUDE;1
11416;;Villarzel-Cabardès;VILLARZEL-CABARDES;11600;11;AUDE;1
11417;;Villarzel-du-Razès;VILLARZEL-DU-RAZES;11300;11;AUDE;1
11418;;Villasavary;VILLASAVARY;11150;11;AUDE;1
11419;;Villautou;VILLAUTOU;11420;11;AUDE;1
11420;;Villebazy;VILLEBAZY;11250;11;AUDE;1
11421;;Villedaigne;VILLEDAIGNE;11200;11;AUDE;1
11422;;Villedubert;VILLEDUBERT;11800;11;AUDE;1
11423;;Villefloure;VILLEFLOURE;11570;11;AUDE;1
11424;;Villefort;VILLEFORT;11230;11;AUDE;1
11425;;Villegailhenc;VILLEGAILHENC;11600;11;AUDE;1
11426;;Villegly;VILLEGLY;11600;11;AUDE;1
11427;;Villelongue-d'Aude;VILLELONGUE-D'AUDE;11300;11;AUDE;1
11428;;Villemagne;VILLEMAGNE;11310;11;AUDE;1
11429;;Villemoustaussou;VILLEMOUSTAUSSOU;11620;11;AUDE;1
11430;;Villeneuve-la-Comptal;VILLENEUVE-LA-COMPTAL;11400;11;AUDE;1
11431;;Villeneuve-les-Corbières;VILLENEUVE-LES-CORBIERES;11360;11;AUDE;1
11432;;Villeneuve-lès-Montréal;VILLENEUVE-LES-MONTREAL;11290;11;AUDE;1
11433;;Villeneuve-Minervois;VILLENEUVE-MINERVOIS;11160;11;AUDE;1
11434;;Villepinte;VILLEPINTE;11150;11;AUDE;1
11435;;Villerouge-Termenès;VILLEROUGE-TERMENES;11330;11;AUDE;1
11436;;Villesèque-des-Corbières;VILLESEQUE-DES-CORBIERES;11360;11;AUDE;1
11437;;Villesèquelande;VILLESEQUELANDE;11170;11;AUDE;1
11438;;Villesiscle;VILLESISCLE;11150;11;AUDE;1
11439;;Villespy;VILLESPY;11170;11;AUDE;1
11440;;Villetritouls;VILLETRITOULS;11220;11;AUDE;1
11441;;Vinassan;VINASSAN;11110;11;AUDE;1
12001;;Agen-d'Aveyron;AGEN-D'AVEYRON;12630;12;AVEYRON;1
12002;;Aguessac;AGUESSAC;12520;12;AVEYRON;1
12003;Les;Albres;ALBRES;12220;12;AVEYRON;1
12004;;Almont-les-Junies;ALMONT-LES-JUNIES;12300;12;AVEYRON;1
12005;;Alpuech;ALPUECH;12210;12;AVEYRON;1
12006;;Alrance;ALRANCE;12430;12;AVEYRON;1
12007;;Ambeyrac;AMBEYRAC;12260;12;AVEYRON;1
12008;;Anglars-Saint-Félix;ANGLARS-SAINT-FELIX;12390;12;AVEYRON;1
12009;;Arnac-sur-Dourdou;ARNAC-SUR-DOURDOU;12360;12;AVEYRON;1
12010;;Arques;ARQUES;12290;12;AVEYRON;1
12011;;Arvieu;ARVIEU;12120;12;AVEYRON;1
12012;;Asprières;ASPRIERES;12700;12;AVEYRON;1
12013;;Aubin;AUBIN;12110;12;AVEYRON;1
12014;;Aurelle-Verlac;AURELLE-VERLAC;12130;12;AVEYRON;1
12015;;Auriac-Lagast;AURIAC-LAGAST;12120;12;AVEYRON;1
12016;;Auzits;AUZITS;12390;12;AVEYRON;1
12017;;Ayssènes;AYSSENES;12430;12;AVEYRON;1
12018;;Balaguier-d'Olt;BALAGUIER-D'OLT;12260;12;AVEYRON;1
12019;;Balaguier-sur-Rance;BALAGUIER-SUR-RANCE;12380;12;AVEYRON;1
12020;;Balsac;BALSAC;12510;12;AVEYRON;1
12021;La;Bastide-l'Évêque;BASTIDE-L'EVEQUE;12200;12;AVEYRON;1
12022;La;Bastide-Pradines;BASTIDE-PRADINES;12490;12;AVEYRON;1
12023;La;Bastide-Solages;BASTIDE-SOLAGES;12550;12;AVEYRON;1
12024;;Belcastel;BELCASTEL;12390;12;AVEYRON;1
12025;;Belmont-sur-Rance;BELMONT-SUR-RANCE;12370;12;AVEYRON;1
12026;;Bertholène;BERTHOLENE;12310;12;AVEYRON;1
12027;;Bessuéjouls;BESSUEJOULS;12500;12;AVEYRON;1
12028;;Boisse-Penchot;BOISSE-PENCHOT;12300;12;AVEYRON;1
12029;;Bor-et-Bar;BOR-ET-BAR;12270;12;AVEYRON;1
12030;;Bouillac;BOUILLAC;12300;12;AVEYRON;1
12031;;Bournazel;BOURNAZEL;12390;12;AVEYRON;1
12032;;Boussac;BOUSSAC;12160;12;AVEYRON;1
12033;;Bozouls;BOZOULS;12340;12;AVEYRON;1
12034;;Brandonnet;BRANDONNET;12350;12;AVEYRON;1
12035;;Brasc;BRASC;12550;12;AVEYRON;1
12036;;Brommat;BROMMAT;12600;12;AVEYRON;1
12037;;Broquiès;BROQUIES;12480;12;AVEYRON;1
12038;;Brousse-le-Château;BROUSSE-LE-CHATEAU;12480;12;AVEYRON;1
12039;;Brusque;BRUSQUE;12360;12;AVEYRON;1
12040;;Buzeins;BUZEINS;12150;12;AVEYRON;1
12041;;Cabanès;CABANES;12800;12;AVEYRON;1
12042;;Calmels-et-le-Viala;CALMELS-ET-LE-VIALA;12400;12;AVEYRON;1
12043;;Calmont;CALMONT;12450;12;AVEYRON;1
12044;;Camarès;CAMARES;12360;12;AVEYRON;1
12045;;Camboulazet;CAMBOULAZET;12160;12;AVEYRON;1
12046;;Camjac;CAMJAC;12800;12;AVEYRON;1
12047;;Campagnac;CAMPAGNAC;12560;12;AVEYRON;1
12048;;Campouriez;CAMPOURIEZ;12140;12;AVEYRON;1
12049;;Campuac;CAMPUAC;12580;12;AVEYRON;1
12050;;Canet-de-Salars;CANET-DE-SALARS;12290;12;AVEYRON;1
12051;;Cantoin;CANTOIN;12420;12;AVEYRON;1
12052;;Capdenac-Gare;CAPDENAC-GARE;12700;12;AVEYRON;1
12053;La;Capelle-Balaguier;CAPELLE-BALAGUIER;12260;12;AVEYRON;1
12054;La;Capelle-Bleys;CAPELLE-BLEYS;12240;12;AVEYRON;1
12055;La;Capelle-Bonance;CAPELLE-BONANCE;12130;12;AVEYRON;1
12056;;Baraqueville;BARAQUEVILLE;12160;12;AVEYRON;1
12057;;Cassagnes-Bégonhès;CASSAGNES-BEGONHES;12120;12;AVEYRON;1
12058;;Cassuéjouls;CASSUEJOULS;12210;12;AVEYRON;1
12059;;Castanet;CASTANET;12240;12;AVEYRON;1
12060;;Castelmary;CASTELMARY;12800;12;AVEYRON;1
12061;;Castelnau-de-Mandailles;CASTELNAU-DE-MANDAILLES;12500;12;AVEYRON;1
12062;;Castelnau-Pégayrols;CASTELNAU-PEGAYROLS;12620;12;AVEYRON;1
12063;La;Cavalerie;CAVALERIE;12230;12;AVEYRON;1
12064;Le;Cayrol;CAYROL;12500;12;AVEYRON;1
12065;;Centrès;CENTRES;12120;12;AVEYRON;1
12066;;Clairvaux-d'Aveyron;CLAIRVAUX-D'AVEYRON;12330;12;AVEYRON;1
12067;Le;Clapier;CLAPIER;12540;12;AVEYRON;1
12068;;Colombiès;COLOMBIES;12240;12;AVEYRON;1
12069;;Combret;COMBRET;12370;12;AVEYRON;1
12070;;Compeyre;COMPEYRE;12520;12;AVEYRON;1
12071;;Compolibat;COMPOLIBAT;12350;12;AVEYRON;1
12072;;Comprégnac;COMPREGNAC;12100;12;AVEYRON;1
12073;;Comps-la-Grand-Ville;COMPS-LA-GRAND-VILLE;12120;12;AVEYRON;1
12074;;Condom-d'Aubrac;CONDOM-D'AUBRAC;12470;12;AVEYRON;1
12075;;Connac;CONNAC;12170;12;AVEYRON;1
12076;;Conques;CONQUES;12320;12;AVEYRON;1
12077;;Cornus;CORNUS;12540;12;AVEYRON;1
12078;Les;Costes-Gozon;COSTES-GOZON;12400;12;AVEYRON;1
12079;;Coubisou;COUBISOU;12190;12;AVEYRON;1
12080;;Coupiac;COUPIAC;12550;12;AVEYRON;1
12081;;Coussergues;COUSSERGUES;12310;12;AVEYRON;1
12082;La;Couvertoirade;COUVERTOIRADE;12230;12;AVEYRON;1
12083;;Cransac;CRANSAC;12110;12;AVEYRON;1
12084;;Creissels;CREISSELS;12100;12;AVEYRON;1
12085;;Crespin;CRESPIN;12800;12;AVEYRON;1
12086;La;Cresse;CRESSE;12640;12;AVEYRON;1
12087;;Cruéjouls;CRUEJOULS;12340;12;AVEYRON;1
12088;;Curières;CURIERES;12210;12;AVEYRON;1
12089;;Decazeville;DECAZEVILLE;12300;12;AVEYRON;1
12090;;Druelle;DRUELLE;12510;12;AVEYRON;1
12091;;Drulhe;DRULHE;12350;12;AVEYRON;1
12092;;Durenque;DURENQUE;12170;12;AVEYRON;1
12093;Le;Fel;FEL;12140;12;AVEYRON;1
12094;;Entraygues-sur-Truyère;ENTRAYGUES-SUR-TRUYERE;12140;12;AVEYRON;1
12095;;Escandolières;ESCANDOLIERES;12390;12;AVEYRON;1
12096;;Espalion;ESPALION;12500;12;AVEYRON;1
12097;;Espeyrac;ESPEYRAC;12140;12;AVEYRON;1
12098;;Estaing;ESTAING;12190;12;AVEYRON;1
12099;;Fayet;FAYET;12360;12;AVEYRON;1
12100;;Firmi;FIRMI;12300;12;AVEYRON;1
12101;;Flagnac;FLAGNAC;12300;12;AVEYRON;1
12102;;Flavin;FLAVIN;12450;12;AVEYRON;1
12103;;Florentin-la-Capelle;FLORENTIN-LA-CAPELLE;12140;12;AVEYRON;1
12104;;Foissac;FOISSAC;12260;12;AVEYRON;1
12105;La;Fouillade;FOUILLADE;12270;12;AVEYRON;1
12106;;Gabriac;GABRIAC;12340;12;AVEYRON;1
12107;;Gaillac-d'Aveyron;GAILLAC-D'AVEYRON;12310;12;AVEYRON;1
12108;;Galgan;GALGAN;12220;12;AVEYRON;1
12109;;Gissac;GISSAC;12360;12;AVEYRON;1
12110;;Golinhac;GOLINHAC;12140;12;AVEYRON;1
12111;;Goutrens;GOUTRENS;12390;12;AVEYRON;1
12112;;Graissac;GRAISSAC;12420;12;AVEYRON;1
12113;;Gramond;GRAMOND;12160;12;AVEYRON;1
12114;;Grand-Vabre;GRAND-VABRE;12320;12;AVEYRON;1
12115;L';Hospitalet-du-Larzac;HOSPITALET-DU-LARZAC;12230;12;AVEYRON;1
12116;;Huparlac;HUPARLAC;12460;12;AVEYRON;1
12117;;Lacalm;LACALM;12210;12;AVEYRON;1
12118;;Lacroix-Barrez;LACROIX-BARREZ;12600;12;AVEYRON;1
12119;;Laguiole;LAGUIOLE;12210;12;AVEYRON;1
12120;;Laissac;LAISSAC;12310;12;AVEYRON;1
12121;;Lanuéjouls;LANUEJOULS;12350;12;AVEYRON;1
12122;;Lapanouse-de-Cernon;LAPANOUSE-DE-CERNON;12230;12;AVEYRON;1
12123;;Lapanouse;LAPANOUSE;12150;12;AVEYRON;1
12124;;Lassouts;LASSOUTS;12500;12;AVEYRON;1
12125;;Laval-Roquecezière;LAVAL-ROQUECEZIERE;12380;12;AVEYRON;1
12126;;Lavernhe;LAVERNHE;12150;12;AVEYRON;1
12127;;Lédergues;LEDERGUES;12170;12;AVEYRON;1
12128;;Lescure-Jaoul;LESCURE-JAOUL;12440;12;AVEYRON;1
12129;;Lestrade-et-Thouels;LESTRADE-ET-THOUELS;12430;12;AVEYRON;1
12130;;Livinhac-le-Haut;LIVINHAC-LE-HAUT;12300;12;AVEYRON;1
12131;La;Loubière;LOUBIERE;12740;12;AVEYRON;1
12133;;Luc-la-Primaube;LUC-LA-PRIMAUBE;12450;12;AVEYRON;1
12134;;Lugan;LUGAN;12220;12;AVEYRON;1
12135;;Lunac;LUNAC;12270;12;AVEYRON;1
12136;;Maleville;MALEVILLE;12350;12;AVEYRON;1
12137;;Manhac;MANHAC;12160;12;AVEYRON;1
12138;;Marcillac-Vallon;MARCILLAC-VALLON;12330;12;AVEYRON;1
12139;;Marnhagues-et-Latour;MARNHAGUES-ET-LATOUR;12540;12;AVEYRON;1
12140;;Martiel;MARTIEL;12200;12;AVEYRON;1
12141;;Martrin;MARTRIN;12550;12;AVEYRON;1
12142;;Mayran;MAYRAN;12390;12;AVEYRON;1
12143;;Mélagues;MELAGUES;12360;12;AVEYRON;1
12144;;Meljac;MELJAC;12120;12;AVEYRON;1
12145;;Millau;MILLAU;12100;12;AVEYRON;1
12146;Le;Monastère;MONASTERE;12000;12;AVEYRON;1
12147;;Montagnol;MONTAGNOL;12360;12;AVEYRON;1
12148;;Montbazens;MONTBAZENS;12220;12;AVEYRON;1
12149;;Montclar;MONTCLAR;12550;12;AVEYRON;1
12150;;Monteils;MONTEILS;12200;12;AVEYRON;1
12151;;Montézic;MONTEZIC;12460;12;AVEYRON;1
12152;;Montfranc;MONTFRANC;12380;12;AVEYRON;1
12153;;Montjaux;MONTJAUX;12490;12;AVEYRON;1
12154;;Montlaur;MONTLAUR;12400;12;AVEYRON;1
12155;;Fondamente;FONDAMENTE;12540;12;AVEYRON;1
12156;;Montpeyroux;MONTPEYROUX;12210;12;AVEYRON;1
12157;;Montrozier;MONTROZIER;12630;12;AVEYRON;1
12158;;Montsalès;MONTSALES;12260;12;AVEYRON;1
12159;;Morlhon-le-Haut;MORLHON-LE-HAUT;12200;12;AVEYRON;1
12160;;Mostuéjouls;MOSTUEJOULS;12720;12;AVEYRON;1
12161;;Mouret;MOURET;12330;12;AVEYRON;1
12162;;Moyrazès;MOYRAZES;12160;12;AVEYRON;1
12163;;Murasson;MURASSON;12370;12;AVEYRON;1
12164;;Mur-de-Barrez;MUR-DE-BARREZ;12600;12;AVEYRON;1
12165;;Muret-le-Château;MURET-LE-CHATEAU;12330;12;AVEYRON;1
12166;;Murols;MUROLS;12600;12;AVEYRON;1
12167;;Najac;NAJAC;12270;12;AVEYRON;1
12168;;Nant;NANT;12230;12;AVEYRON;1
12169;;Naucelle;NAUCELLE;12800;12;AVEYRON;1
12170;;Naussac;NAUSSAC;12700;12;AVEYRON;1
12171;;Nauviale;NAUVIALE;12330;12;AVEYRON;1
12172;Le;Nayrac;NAYRAC;12190;12;AVEYRON;1
12173;;Noailhac;NOAILHAC;12320;12;AVEYRON;1
12174;;Olemps;OLEMPS;12510;12;AVEYRON;1
12175;;Ols-et-Rinhodes;OLS-ET-RINHODES;12260;12;AVEYRON;1
12176;;Onet-le-Château;ONET-LE-CHATEAU;12850;12;AVEYRON;1
12177;;Palmas;PALMAS;12310;12;AVEYRON;1
12178;;Paulhe;PAULHE;12520;12;AVEYRON;1
12179;;Peux-et-Couffouleux;PEUX-ET-COUFFOULEUX;12360;12;AVEYRON;1
12180;;Peyreleau;PEYRELEAU;12720;12;AVEYRON;1
12181;;Peyrusse-le-Roc;PEYRUSSE-LE-ROC;12220;12;AVEYRON;1
12182;;Pierrefiche;PIERREFICHE;12130;12;AVEYRON;1
12183;;Plaisance;PLAISANCE;12550;12;AVEYRON;1
12184;;Pomayrols;POMAYROLS;12130;12;AVEYRON;1
12185;;Pont-de-Salars;PONT-DE-SALARS;12290;12;AVEYRON;1
12186;;Pousthomy;POUSTHOMY;12380;12;AVEYRON;1
12187;;Prades-d'Aubrac;PRADES-D'AUBRAC;12470;12;AVEYRON;1
12188;;Prades-Salars;PRADES-SALARS;12290;12;AVEYRON;1
12189;;Pradinas;PRADINAS;12240;12;AVEYRON;1
12190;;Prévinquières;PREVINQUIERES;12350;12;AVEYRON;1
12191;;Privezac;PRIVEZAC;12350;12;AVEYRON;1
12192;;Mounes-Prohencoux;MOUNES-PROHENCOUX;12370;12;AVEYRON;1
12193;;Pruines;PRUINES;12320;12;AVEYRON;1
12194;;Quins;QUINS;12800;12;AVEYRON;1
12195;;Rebourguil;REBOURGUIL;12400;12;AVEYRON;1
12196;;Recoules-Prévinquières;RECOULES-PREVINQUIERES;12150;12;AVEYRON;1
12197;;Réquista;REQUISTA;12170;12;AVEYRON;1
12198;;Rieupeyroux;RIEUPEYROUX;12240;12;AVEYRON;1
12199;;Rignac;RIGNAC;12390;12;AVEYRON;1
12200;;Rivière-sur-Tarn;RIVIERE-SUR-TARN;12640;12;AVEYRON;1
12201;;Rodelle;RODELLE;12340;12;AVEYRON;1
12202;;Rodez;RODEZ;12000;12;AVEYRON;1
12203;;Roquefort-sur-Soulzon;ROQUEFORT-SUR-SOULZON;12250;12;AVEYRON;1
12204;La;Roque-Sainte-Marguerite;ROQUE-SAINTE-MARGUERITE;12100;12;AVEYRON;1
12205;La;Rouquette;ROUQUETTE;12200;12;AVEYRON;1
12206;;Roussennac;ROUSSENNAC;12220;12;AVEYRON;1
12207;;Rullac-Saint-Cirq;RULLAC-SAINT-CIRQ;12120;12;AVEYRON;1
12208;;Saint-Affrique;SAINT-AFFRIQUE;12400;12;AVEYRON;1
12209;;Saint-Amans-des-Cots;SAINT-AMANS-DES-COTS;12460;12;AVEYRON;1
12210;;Saint-André-de-Najac;SAINT-ANDRE-DE-NAJAC;12270;12;AVEYRON;1
12211;;Saint-André-de-Vézines;SAINT-ANDRE-DE-VEZINES;12720;12;AVEYRON;1
12212;;Saint-Beaulize;SAINT-BEAULIZE;12540;12;AVEYRON;1
12213;;Saint-Beauzély;SAINT-BEAUZELY;12620;12;AVEYRON;1
12214;;Saint-Chély-d'Aubrac;SAINT-CHELY-D'AUBRAC;12470;12;AVEYRON;1
12215;;Saint-Christophe-Vallon;SAINT-CHRISTOPHE-VALLON;12330;12;AVEYRON;1
12216;;Saint-Côme-d'Olt;SAINT-COME-D'OLT;12500;12;AVEYRON;1
12217;;Sainte-Croix;SAINTE-CROIX;12260;12;AVEYRON;1
12218;;Saint-Cyprien-sur-Dourdou;SAINT-CYPRIEN-SUR-DOURDOU;12320;12;AVEYRON;1
12219;;Sainte-Eulalie-d'Olt;SAINTE-EULALIE-D'OLT;12130;12;AVEYRON;1
12220;;Sainte-Eulalie-de-Cernon;SAINTE-EULALIE-DE-CERNON;12230;12;AVEYRON;1
12221;;Saint-Félix-de-Lunel;SAINT-FELIX-DE-LUNEL;12320;12;AVEYRON;1
12222;;Saint-Félix-de-Sorgues;SAINT-FELIX-DE-SORGUES;12400;12;AVEYRON;1
12223;;Sainte-Geneviève-sur-Argence;SAINTE-GENEVIEVE-SUR-ARGENCE;12420;12;AVEYRON;1
12224;;Saint-Geniez-d'Olt;SAINT-GENIEZ-D'OLT;12130;12;AVEYRON;1
12225;;Saint-Georges-de-Luzençon;SAINT-GEORGES-DE-LUZENCON;12100;12;AVEYRON;1
12226;;Saint-Hippolyte;SAINT-HIPPOLYTE;12140;12;AVEYRON;1
12227;;Saint-Igest;SAINT-IGEST;12260;12;AVEYRON;1
12228;;Saint-Izaire;SAINT-IZAIRE;12480;12;AVEYRON;1
12229;;Saint-Jean-d'Alcapiès;SAINT-JEAN-D'ALCAPIES;12250;12;AVEYRON;1
12230;;Saint-Jean-Delnous;SAINT-JEAN-DELNOUS;12170;12;AVEYRON;1
12231;;Saint-Jean-du-Bruel;SAINT-JEAN-DU-BRUEL;12230;12;AVEYRON;1
12232;;Saint-Jean-et-Saint-Paul;SAINT-JEAN-ET-SAINT-PAUL;12250;12;AVEYRON;1
12233;;Saint-Juéry;SAINT-JUERY;12550;12;AVEYRON;1
12234;;Sainte-Juliette-sur-Viaur;SAINTE-JULIETTE-SUR-VIAUR;12120;12;AVEYRON;1
12235;;Saint-Just-sur-Viaur;SAINT-JUST-SUR-VIAUR;12170;12;AVEYRON;1
12236;;Saint-Laurent-de-Lévézou;SAINT-LAURENT-DE-LEVEZOU;12620;12;AVEYRON;1
12237;;Saint-Laurent-d'Olt;SAINT-LAURENT-D'OLT;12560;12;AVEYRON;1
12238;;Saint-Léons;SAINT-LEONS;12780;12;AVEYRON;1
12239;;Saint-Martin-de-Lenne;SAINT-MARTIN-DE-LENNE;12130;12;AVEYRON;1
12240;;Saint-Parthem;SAINT-PARTHEM;12300;12;AVEYRON;1
12241;;Sainte-Radegonde;SAINTE-RADEGONDE;12850;12;AVEYRON;1
12242;;Saint-Rémy;SAINT-REMY;12200;12;AVEYRON;1
12243;;Saint-Rome-de-Cernon;SAINT-ROME-DE-CERNON;12490;12;AVEYRON;1
12244;;Saint-Rome-de-Tarn;SAINT-ROME-DE-TARN;12490;12;AVEYRON;1
12245;;Saint-Salvadou;SAINT-SALVADOU;12200;12;AVEYRON;1
12246;;Saint-Santin;SAINT-SANTIN;12300;12;AVEYRON;1
12247;;Saint-Saturnin-de-Lenne;SAINT-SATURNIN-DE-LENNE;12560;12;AVEYRON;1
12248;;Saint-Sernin-sur-Rance;SAINT-SERNIN-SUR-RANCE;12380;12;AVEYRON;1
12249;;Saint-Sever-du-Moustier;SAINT-SEVER-DU-MOUSTIER;12370;12;AVEYRON;1
12250;;Saint-Symphorien-de-Thénières;SAINT-SYMPHORIEN-DE-THENIERES;12460;12;AVEYRON;1
12251;;Saint-Victor-et-Melvieu;SAINT-VICTOR-ET-MELVIEU;12400;12;AVEYRON;1
12252;;Salles-Courbatiès;SALLES-COURBATIES;12260;12;AVEYRON;1
12253;;Salles-Curan;SALLES-CURAN;12410;12;AVEYRON;1
12254;;Salles-la-Source;SALLES-LA-SOURCE;12330;12;AVEYRON;1
12255;;Salmiech;SALMIECH;12120;12;AVEYRON;1
12256;;Salvagnac-Cajarc;SALVAGNAC-CAJARC;12260;12;AVEYRON;1
12257;;Causse-et-Diège;CAUSSE-ET-DIEGE;12700;12;AVEYRON;1
12258;La;Salvetat-Peyralès;SALVETAT-PEYRALES;12440;12;AVEYRON;1
12259;;Sanvensa;SANVENSA;12200;12;AVEYRON;1
12260;;Sauclières;SAUCLIERES;12230;12;AVEYRON;1
12261;;Saujac;SAUJAC;12260;12;AVEYRON;1
12262;;Sauveterre-de-Rouergue;SAUVETERRE-DE-ROUERGUE;12800;12;AVEYRON;1
12263;;Savignac;SAVIGNAC;12200;12;AVEYRON;1
12264;;Sébazac-Concourès;SEBAZAC-CONCOURES;12740;12;AVEYRON;1
12265;;Sébrazac;SEBRAZAC;12190;12;AVEYRON;1
12266;;Ségur;SEGUR;12290;12;AVEYRON;1
12267;La;Selve;SELVE;12170;12;AVEYRON;1
12268;;Sénergues;SENERGUES;12320;12;AVEYRON;1
12269;La;Serre;SERRE;12380;12;AVEYRON;1
12270;;Sévérac-le-Château;SEVERAC-LE-CHATEAU;12150;12;AVEYRON;1
12271;;Sévérac-l'Église;SEVERAC-L'EGLISE;12310;12;AVEYRON;1
12272;;Sonnac;SONNAC;12700;12;AVEYRON;1
12273;;Soulages-Bonneval;SOULAGES-BONNEVAL;12210;12;AVEYRON;1
12274;;Sylvanès;SYLVANES;12360;12;AVEYRON;1
12275;;Tauriac-de-Camarès;TAURIAC-DE-CAMARES;12360;12;AVEYRON;1
12276;;Tauriac-de-Naucelle;TAURIAC-DE-NAUCELLE;12800;12;AVEYRON;1
12277;;Taussac;TAUSSAC;12600;12;AVEYRON;1
12278;;Tayrac;TAYRAC;12440;12;AVEYRON;1
12279;La;Terrisse;TERRISSE;12210;12;AVEYRON;1
12280;;Thérondels;THERONDELS;12600;12;AVEYRON;1
12281;;Toulonjac;TOULONJAC;12200;12;AVEYRON;1
12282;;Tournemire;TOURNEMIRE;12250;12;AVEYRON;1
12283;;Trémouilles;TREMOUILLES;12290;12;AVEYRON;1
12284;Le;Truel;TRUEL;12430;12;AVEYRON;1
12285;;Vabre-Tizac;VABRE-TIZAC;12240;12;AVEYRON;1
12286;;Vabres-l'Abbaye;VABRES-L'ABBAYE;12400;12;AVEYRON;1
12287;;Vailhourles;VAILHOURLES;12200;12;AVEYRON;1
12288;;Valady;VALADY;12330;12;AVEYRON;1
12289;;Valzergues;VALZERGUES;12220;12;AVEYRON;1
12290;;Vaureilles;VAUREILLES;12220;12;AVEYRON;1
12291;;Verrières;VERRIERES;12520;12;AVEYRON;1
12292;;Versols-et-Lapeyre;VERSOLS-ET-LAPEYRE;12400;12;AVEYRON;1
12293;;Veyreau;VEYREAU;12720;12;AVEYRON;1
12294;;Vézins-de-Lévézou;VEZINS-DE-LEVEZOU;12780;12;AVEYRON;1
12295;;Viala-du-Pas-de-Jaux;VIALA-DU-PAS-DE-JAUX;12250;12;AVEYRON;1
12296;;Viala-du-Tarn;VIALA-DU-TARN;12490;12;AVEYRON;1
12297;Le;Vibal;VIBAL;12290;12;AVEYRON;1
12298;;Villecomtal;VILLECOMTAL;12580;12;AVEYRON;1
12299;;Villefranche-de-Panat;VILLEFRANCHE-DE-PANAT;12430;12;AVEYRON;1
12300;;Villefranche-de-Rouergue;VILLEFRANCHE-DE-ROUERGUE;12200;12;AVEYRON;1
12301;;Villeneuve;VILLENEUVE;12260;12;AVEYRON;1
12303;;Vimenet;VIMENET;12310;12;AVEYRON;1
12304;;Vitrac-en-Viadène;VITRAC-EN-VIADENE;12420;12;AVEYRON;1
12305;;Viviez;VIVIEZ;12110;12;AVEYRON;1
12307;;Curan;CURAN;12410;12;AVEYRON;1
13001;;Aix-en-Provence;AIX-EN-PROVENCE;13090;13;BOUCHES DU RHONE;1
13002;;Allauch;ALLAUCH;13190;13;BOUCHES DU RHONE;1
13003;;Alleins;ALLEINS;13980;13;BOUCHES DU RHONE;1
13004;;Arles;ARLES;13200;13;BOUCHES DU RHONE;1
13005;;Aubagne;AUBAGNE;13400;13;BOUCHES DU RHONE;1
13006;;Aureille;AUREILLE;13930;13;BOUCHES DU RHONE;1
13007;;Auriol;AURIOL;13390;13;BOUCHES DU RHONE;1
13008;;Aurons;AURONS;13121;13;BOUCHES DU RHONE;1
13009;La;Barben;BARBEN;13330;13;BOUCHES DU RHONE;1
13010;;Barbentane;BARBENTANE;13570;13;BOUCHES DU RHONE;1
13011;Les;Baux-de-Provence;BAUX-DE-PROVENCE;13520;13;BOUCHES DU RHONE;1
13012;;Beaurecueil;BEAURECUEIL;13100;13;BOUCHES DU RHONE;1
13013;;Belcodène;BELCODENE;13720;13;BOUCHES DU RHONE;1
13014;;Berre-l'Étang;BERRE-L'ETANG;13130;13;BOUCHES DU RHONE;1
13015;;Bouc-Bel-Air;BOUC-BEL-AIR;13320;13;BOUCHES DU RHONE;1
13016;La;Bouilladisse;BOUILLADISSE;13720;13;BOUCHES DU RHONE;1
13017;;Boulbon;BOULBON;13150;13;BOUCHES DU RHONE;1
13018;;Cabannes;CABANNES;13440;13;BOUCHES DU RHONE;1
13019;;Cabriès;CABRIES;13480;13;BOUCHES DU RHONE;1
13020;;Cadolive;CADOLIVE;13950;13;BOUCHES DU RHONE;1
13021;;Carry-le-Rouet;CARRY-LE-ROUET;13620;13;BOUCHES DU RHONE;1
13022;;Cassis;CASSIS;13260;13;BOUCHES DU RHONE;1
13023;;Ceyreste;CEYRESTE;13600;13;BOUCHES DU RHONE;1
13024;;Charleval;CHARLEVAL;13350;13;BOUCHES DU RHONE;1
13025;;Châteauneuf-le-Rouge;CHATEAUNEUF-LE-ROUGE;13790;13;BOUCHES DU RHONE;1
13026;;Châteauneuf-les-Martigues;CHATEAUNEUF-LES-MARTIGUES;13220;13;BOUCHES DU RHONE;1
13027;;Châteaurenard;CHATEAURENARD;13160;13;BOUCHES DU RHONE;1
13028;La;Ciotat;CIOTAT;13600;13;BOUCHES DU RHONE;1
13029;;Cornillon-Confoux;CORNILLON-CONFOUX;13250;13;BOUCHES DU RHONE;1
13030;;Cuges-les-Pins;CUGES-LES-PINS;13780;13;BOUCHES DU RHONE;1
13031;La;Destrousse;DESTROUSSE;13112;13;BOUCHES DU RHONE;1
13032;;Éguilles;EGUILLES;13510;13;BOUCHES DU RHONE;1
13033;;Ensuès-la-Redonne;ENSUES-LA-REDONNE;13820;13;BOUCHES DU RHONE;1
13034;;Eygalières;EYGALIERES;13810;13;BOUCHES DU RHONE;1
13035;;Eyguières;EYGUIERES;13430;13;BOUCHES DU RHONE;1
13036;;Eyragues;EYRAGUES;13630;13;BOUCHES DU RHONE;1
13037;La;Fare-les-Oliviers;FARE-LES-OLIVIERS;13580;13;BOUCHES DU RHONE;1
13038;;Fontvieille;FONTVIEILLE;13990;13;BOUCHES DU RHONE;1
13039;;Fos-sur-Mer;FOS-SUR-MER;13270;13;BOUCHES DU RHONE;1
13040;;Fuveau;FUVEAU;13710;13;BOUCHES DU RHONE;1
13041;;Gardanne;GARDANNE;13120;13;BOUCHES DU RHONE;1
13042;;Gémenos;GEMENOS;13420;13;BOUCHES DU RHONE;1
13043;;Gignac-la-Nerthe;GIGNAC-LA-NERTHE;13180;13;BOUCHES DU RHONE;1
13044;;Grans;GRANS;13450;13;BOUCHES DU RHONE;1
13045;;Graveson;GRAVESON;13690;13;BOUCHES DU RHONE;1
13046;;Gréasque;GREASQUE;13850;13;BOUCHES DU RHONE;1
13047;;Istres;ISTRES;13800;13;BOUCHES DU RHONE;1
13048;;Jouques;JOUQUES;13490;13;BOUCHES DU RHONE;1
13049;;Lamanon;LAMANON;13113;13;BOUCHES DU RHONE;1
13050;;Lambesc;LAMBESC;13410;13;BOUCHES DU RHONE;1
13051;;Lançon-Provence;LANCON-PROVENCE;13680;13;BOUCHES DU RHONE;1
13052;;Maillane;MAILLANE;13910;13;BOUCHES DU RHONE;1
13053;;Mallemort;MALLEMORT;13370;13;BOUCHES DU RHONE;1
13054;;Marignane;MARIGNANE;13700;13;BOUCHES DU RHONE;1
13055;;Marseille;MARSEILLE;;13;;
13056;;Martigues;MARTIGUES;13500;13;BOUCHES DU RHONE;1
13057;;Mas-Blanc-des-Alpilles;MAS-BLANC-DES-ALPILLES;13103;13;BOUCHES DU RHONE;1
13058;;Maussane-les-Alpilles;MAUSSANE-LES-ALPILLES;13520;13;BOUCHES DU RHONE;1
13059;;Meyrargues;MEYRARGUES;13650;13;BOUCHES DU RHONE;1
13060;;Meyreuil;MEYREUIL;13590;13;BOUCHES DU RHONE;1
13061;;Saint-Pierre-de-Mézoargues;SAINT-PIERRE-DE-MEZOARGUES;13150;13;BOUCHES DU RHONE;1
13062;;Mimet;MIMET;13105;13;BOUCHES DU RHONE;1
13063;;Miramas;MIRAMAS;13140;13;BOUCHES DU RHONE;1
13064;;Mollégès;MOLLEGES;13940;13;BOUCHES DU RHONE;1
13065;;Mouriès;MOURIES;13890;13;BOUCHES DU RHONE;1
13066;;Noves;NOVES;13550;13;BOUCHES DU RHONE;1
13067;;Orgon;ORGON;13660;13;BOUCHES DU RHONE;1
13068;;Paradou;PARADOU;13520;13;BOUCHES DU RHONE;1
13069;;Pélissanne;PELISSANNE;13330;13;BOUCHES DU RHONE;1
13070;La;Penne-sur-Huveaune;PENNE-SUR-HUVEAUNE;13821;13;BOUCHES DU RHONE;1
13071;Les;Pennes-Mirabeau;PENNES-MIRABEAU;13170;13;BOUCHES DU RHONE;1
13072;;Peynier;PEYNIER;13790;13;BOUCHES DU RHONE;1
13073;;Peypin;PEYPIN;13124;13;BOUCHES DU RHONE;1
13074;;Peyrolles-en-Provence;PEYROLLES-EN-PROVENCE;13860;13;BOUCHES DU RHONE;1
13075;;Plan-de-Cuques;PLAN-DE-CUQUES;13380;13;BOUCHES DU RHONE;1
13076;;Plan-d'Orgon;PLAN-D'ORGON;13750;13;BOUCHES DU RHONE;1
13077;;Port-de-Bouc;PORT-DE-BOUC;13110;13;BOUCHES DU RHONE;1
13078;;Port-Saint-Louis-du-Rhône;PORT-SAINT-LOUIS-DU-RHONE;13230;13;BOUCHES DU RHONE;1
13079;;Puyloubier;PUYLOUBIER;13114;13;BOUCHES DU RHONE;1
13080;Le;Puy-Sainte-Réparade;PUY-SAINTE-REPARADE;13610;13;BOUCHES DU RHONE;1
13081;;Rognac;ROGNAC;13340;13;BOUCHES DU RHONE;1
13082;;Rognes;ROGNES;13840;13;BOUCHES DU RHONE;1
13083;;Rognonas;ROGNONAS;13870;13;BOUCHES DU RHONE;1
13084;La;Roque-d'Anthéron;ROQUE-D'ANTHERON;13640;13;BOUCHES DU RHONE;1
13085;;Roquefort-la-Bédoule;ROQUEFORT-LA-BEDOULE;13830;13;BOUCHES DU RHONE;1
13086;;Roquevaire;ROQUEVAIRE;13360;13;BOUCHES DU RHONE;1
13087;;Rousset;ROUSSET;13790;13;BOUCHES DU RHONE;1
13088;Le;Rove;ROVE;13740;13;BOUCHES DU RHONE;1
13089;;Saint-Andiol;SAINT-ANDIOL;13670;13;BOUCHES DU RHONE;1
13090;;Saint-Antonin-sur-Bayon;SAINT-ANTONIN-SUR-BAYON;13100;13;BOUCHES DU RHONE;1
13091;;Saint-Cannat;SAINT-CANNAT;13760;13;BOUCHES DU RHONE;1
13092;;Saint-Chamas;SAINT-CHAMAS;13250;13;BOUCHES DU RHONE;1
13093;;Saint-Estève-Janson;SAINT-ESTEVE-JANSON;13610;13;BOUCHES DU RHONE;1
13094;;Saint-Étienne-du-Grès;SAINT-ETIENNE-DU-GRES;13103;13;BOUCHES DU RHONE;1
13095;;Saint-Marc-Jaumegarde;SAINT-MARC-JAUMEGARDE;13100;13;BOUCHES DU RHONE;1
13096;;Saintes-Maries-de-la-Mer;SAINTES-MARIES-DE-LA-MER;13460;13;BOUCHES DU RHONE;1
13097;;Saint-Martin-de-Crau;SAINT-MARTIN-DE-CRAU;13310;13;BOUCHES DU RHONE;1
13098;;Saint-Mitre-les-Remparts;SAINT-MITRE-LES-REMPARTS;13920;13;BOUCHES DU RHONE;1
13099;;Saint-Paul-lès-Durance;SAINT-PAUL-LES-DURANCE;13115;13;BOUCHES DU RHONE;1
13100;;Saint-Rémy-de-Provence;SAINT-REMY-DE-PROVENCE;13210;13;BOUCHES DU RHONE;1
13101;;Saint-Savournin;SAINT-SAVOURNIN;13119;13;BOUCHES DU RHONE;1
13102;;Saint-Victoret;SAINT-VICTORET;13730;13;BOUCHES DU RHONE;1
13103;;Salon-de-Provence;SALON-DE-PROVENCE;13300;13;BOUCHES DU RHONE;1
13104;;Sausset-les-Pins;SAUSSET-LES-PINS;13960;13;BOUCHES DU RHONE;1
13105;;Sénas;SENAS;13560;13;BOUCHES DU RHONE;1
13106;;Septèmes-les-Vallons;SEPTEMES-LES-VALLONS;13240;13;BOUCHES DU RHONE;1
13107;;Simiane-Collongue;SIMIANE-COLLONGUE;13109;13;BOUCHES DU RHONE;1
13108;;Tarascon;TARASCON;13150;13;BOUCHES DU RHONE;1
13109;Le;Tholonet;THOLONET;13100;13;BOUCHES DU RHONE;1
13110;;Trets;TRETS;13530;13;BOUCHES DU RHONE;1
13111;;Vauvenargues;VAUVENARGUES;13126;13;BOUCHES DU RHONE;1
13112;;Velaux;VELAUX;13880;13;BOUCHES DU RHONE;1
13113;;Venelles;VENELLES;13770;13;BOUCHES DU RHONE;1
13114;;Ventabren;VENTABREN;13122;13;BOUCHES DU RHONE;1
13115;;Vernègues;VERNEGUES;13116;13;BOUCHES DU RHONE;1
13116;;Verquières;VERQUIERES;13670;13;BOUCHES DU RHONE;1
13117;;Vitrolles;VITROLLES;13127;13;BOUCHES DU RHONE;1
13118;;Coudoux;COUDOUX;13111;13;BOUCHES DU RHONE;1
13119;;Carnoux-en-Provence;CARNOUX-EN-PROVENCE;13470;13;BOUCHES DU RHONE;1
14001;;Ablon;ABLON;14600;14;CALVADOS;1
14002;;Acqueville;ACQUEVILLE;14220;14;CALVADOS;1
14003;;Agy;AGY;14400;14;CALVADOS;1
14004;;Aignerville;AIGNERVILLE;14710;14;CALVADOS;1
14005;;Airan;AIRAN;14370;14;CALVADOS;1
14006;;Amayé-sur-Orne;AMAYE-SUR-ORNE;14210;14;CALVADOS;1
14007;;Amayé-sur-Seulles;AMAYE-SUR-SEULLES;14310;14;CALVADOS;1
14008;;Amblie;AMBLIE;14480;14;CALVADOS;1
14009;;Amfreville;AMFREVILLE;14860;14;CALVADOS;1
14011;;Anctoville;ANCTOVILLE;14240;14;CALVADOS;1
14012;;Angerville;ANGERVILLE;14430;14;CALVADOS;1
14013;;Angoville;ANGOVILLE;14220;14;CALVADOS;1
14014;;Anguerny;ANGUERNY;14610;14;CALVADOS;1
14015;;Anisy;ANISY;14610;14;CALVADOS;1
14016;;Annebault;ANNEBAULT;14430;14;CALVADOS;1
14019;;Arganchy;ARGANCHY;14400;14;CALVADOS;1
14020;;Argences;ARGENCES;14370;14;CALVADOS;1
14021;;Arromanches-les-Bains;ARROMANCHES-LES-BAINS;14117;14;CALVADOS;1
14022;;Asnelles;ASNELLES;14960;14;CALVADOS;1
14023;;Asnières-en-Bessin;ASNIERES-EN-BESSIN;14710;14;CALVADOS;1
14024;;Auberville;AUBERVILLE;14640;14;CALVADOS;1
14025;;Aubigny;AUBIGNY;14700;14;CALVADOS;1
14026;;Audrieu;AUDRIEU;14250;14;CALVADOS;1
14027;;Aunay-sur-Odon;AUNAY-SUR-ODON;14260;14;CALVADOS;1
14028;;Auquainville;AUQUAINVILLE;14140;14;CALVADOS;1
14029;Les;Autels-Saint-Bazile;AUTELS-SAINT-BAZILE;14140;14;CALVADOS;1
14030;;Authie;AUTHIE;14280;14;CALVADOS;1
14031;Les;Authieux-Papion;AUTHIEUX-PAPION;14140;14;CALVADOS;1
14032;Les;Authieux-sur-Calonne;AUTHIEUX-SUR-CALONNE;14130;14;CALVADOS;1
14033;;Auvillars;AUVILLARS;14340;14;CALVADOS;1
14034;;Avenay;AVENAY;14210;14;CALVADOS;1
14035;;Balleroy;BALLEROY;14490;14;CALVADOS;1
14036;;Banneville-la-Campagne;BANNEVILLE-LA-CAMPAGNE;14940;14;CALVADOS;1
14037;;Banneville-sur-Ajon;BANNEVILLE-SUR-AJON;14260;14;CALVADOS;1
14038;;Banville;BANVILLE;14480;14;CALVADOS;1
14039;;Barbery;BARBERY;14220;14;CALVADOS;1
14040;;Barbeville;BARBEVILLE;14400;14;CALVADOS;1
14041;;Barneville-la-Bertran;BARNEVILLE-LA-BERTRAN;14600;14;CALVADOS;1
14042;;Baron-sur-Odon;BARON-SUR-ODON;14210;14;CALVADOS;1
14043;;Barou-en-Auge;BAROU-EN-AUGE;14620;14;CALVADOS;1
14044;;Basly;BASLY;14610;14;CALVADOS;1
14045;;Basseneville;BASSENEVILLE;14670;14;CALVADOS;1
14046;;Bavent;BAVENT;14860;14;CALVADOS;1
14047;;Bayeux;BAYEUX;14400;14;CALVADOS;1
14049;;Bazenville;BAZENVILLE;14480;14;CALVADOS;1
14050;La;Bazoque;BAZOQUE;14490;14;CALVADOS;1
14052;;Beaulieu;BEAULIEU;14350;14;CALVADOS;1
14053;;Beaumais;BEAUMAIS;14620;14;CALVADOS;1
14054;;Beaumesnil;BEAUMESNIL;14380;14;CALVADOS;1
14055;;Beaumont-en-Auge;BEAUMONT-EN-AUGE;14950;14;CALVADOS;1
14056;;Bauquay;BAUQUAY;14260;14;CALVADOS;1
14057;;Bellengreville;BELLENGREVILLE;14370;14;CALVADOS;1
14058;;Bellou;BELLOU;14140;14;CALVADOS;1
14059;;Benerville-sur-Mer;BENERVILLE-SUR-MER;14910;14;CALVADOS;1
14060;;Bénouville;BENOUVILLE;14970;14;CALVADOS;1
14061;Le;Bény-Bocage;BENY-BOCAGE;14350;14;CALVADOS;1
14062;;Bény-sur-Mer;BENY-SUR-MER;14440;14;CALVADOS;1
14063;;Bernesq;BERNESQ;14710;14;CALVADOS;1
14064;;Bernières-d'Ailly;BERNIERES-D'AILLY;14170;14;CALVADOS;1
14065;;Bernières-le-Patry;BERNIERES-LE-PATRY;14410;14;CALVADOS;1
14066;;Bernières-sur-Mer;BERNIERES-SUR-MER;14990;14;CALVADOS;1
14068;;Biéville-Beuville;BIEVILLE-BEUVILLE;14112;14;CALVADOS;1
14069;;Beuvillers;BEUVILLERS;14100;14;CALVADOS;1
14070;;Beuvron-en-Auge;BEUVRON-EN-AUGE;14430;14;CALVADOS;1
14073;La;Bigne;BIGNE;14260;14;CALVADOS;1
14074;;Billy;BILLY;14370;14;CALVADOS;1
14075;;Bissières;BISSIERES;14370;14;CALVADOS;1
14076;;Blainville-sur-Orne;BLAINVILLE-SUR-ORNE;14550;14;CALVADOS;1
14077;;Blangy-le-Château;BLANGY-LE-CHATEAU;14130;14;CALVADOS;1
14078;;Blay;BLAY;14400;14;CALVADOS;1
14079;;Blonville-sur-Mer;BLONVILLE-SUR-MER;14910;14;CALVADOS;1
14080;Le;Bô;BO;14690;14;CALVADOS;1
14081;;Boissey;BOISSEY;14170;14;CALVADOS;1
14082;La;Boissière;BOISSIERE;14340;14;CALVADOS;1
14083;;Bonnebosq;BONNEBOSQ;14340;14;CALVADOS;1
14084;;Bonnemaison;BONNEMAISON;14260;14;CALVADOS;1
14085;;Bonneville-la-Louvet;BONNEVILLE-LA-LOUVET;14130;14;CALVADOS;1
14086;;Bonneville-sur-Touques;BONNEVILLE-SUR-TOUQUES;14800;14;CALVADOS;1
14087;;Bonnœil;BONNOEIL;14700;14;CALVADOS;1
14088;;Bons-Tassilly;BONS-TASSILLY;14420;14;CALVADOS;1
14089;;Bougy;BOUGY;14210;14;CALVADOS;1
14090;;Boulon;BOULON;14220;14;CALVADOS;1
14091;;Bourgeauville;BOURGEAUVILLE;14430;14;CALVADOS;1
14092;;Bourguébus;BOURGUEBUS;14540;14;CALVADOS;1
14093;;Branville;BRANVILLE;14430;14;CALVADOS;1
14096;;Brémoy;BREMOY;14260;14;CALVADOS;1
14097;;Bretteville-le-Rabet;BRETTEVILLE-LE-RABET;14190;14;CALVADOS;1
14098;;Bretteville-l'Orgueilleuse;BRETTEVILLE-L'ORGUEILLEUSE;14740;14;CALVADOS;1
14099;;Bretteville-sur-Dives;BRETTEVILLE-SUR-DIVES;14170;14;CALVADOS;1
14100;;Bretteville-sur-Laize;BRETTEVILLE-SUR-LAIZE;14680;14;CALVADOS;1
14101;;Bretteville-sur-Odon;BRETTEVILLE-SUR-ODON;14760;14;CALVADOS;1
14102;Le;Breuil-en-Auge;BREUIL-EN-AUGE;14130;14;CALVADOS;1
14103;Le;Breuil-en-Bessin;BREUIL-EN-BESSIN;14330;14;CALVADOS;1
14104;Le;Brévedent;BREVEDENT;14130;14;CALVADOS;1
14105;La;Brévière;BREVIERE;14140;14;CALVADOS;1
14106;;Bréville-les-Monts;BREVILLE-LES-MONTS;14860;14;CALVADOS;1
14107;;Bricqueville;BRICQUEVILLE;14710;14;CALVADOS;1
14109;;Brouay;BROUAY;14250;14;CALVADOS;1
14110;;Brucourt;BRUCOURT;14160;14;CALVADOS;1
14111;;Bucéels;BUCEELS;14250;14;CALVADOS;1
14113;;Burcy;BURCY;14410;14;CALVADOS;1
14115;;Bures-les-Monts;BURES-LES-MONTS;14350;14;CALVADOS;1
14116;Le;Bû-sur-Rouvres;BU-SUR-ROUVRES;14190;14;CALVADOS;1
14117;;Cabourg;CABOURG;14390;14;CALVADOS;1
14118;;Caen;CAEN;14000;14;CALVADOS;1
14119;;Cagny;CAGNY;14630;14;CALVADOS;1
14120;;Cahagnes;CAHAGNES;14240;14;CALVADOS;1
14121;;Cahagnolles;CAHAGNOLLES;14490;14;CALVADOS;1
14122;La;Caine;CAINE;14210;14;CALVADOS;1
14123;;Cairon;CAIRON;14610;14;CALVADOS;1
14124;La;Cambe;CAMBE;14230;14;CALVADOS;1
14125;;Cambes-en-Plaine;CAMBES-EN-PLAINE;14610;14;CALVADOS;1
14126;;Cambremer;CAMBREMER;14340;14;CALVADOS;1
14127;;Campagnolles;CAMPAGNOLLES;14500;14;CALVADOS;1
14128;;Campandré-Valcongrain;CAMPANDRE-VALCONGRAIN;14260;14;CALVADOS;1
14129;;Campeaux;CAMPEAUX;14350;14;CALVADOS;1
14130;;Campigny;CAMPIGNY;14490;14;CALVADOS;1
14131;;Canapville;CANAPVILLE;14800;14;CALVADOS;1
14132;;Canchy;CANCHY;14230;14;CALVADOS;1
14134;;Canteloup;CANTELOUP;14370;14;CALVADOS;1
14135;;Carcagny;CARCAGNY;14740;14;CALVADOS;1
14136;;Cardonville;CARDONVILLE;14230;14;CALVADOS;1
14137;;Carpiquet;CARPIQUET;14650;14;CALVADOS;1
14138;;Cartigny-l'Épinay;CARTIGNY-L'EPINAY;14330;14;CALVADOS;1
14139;;Carville;CARVILLE;14350;14;CALVADOS;1
14140;;Castillon;CASTILLON;14490;14;CALVADOS;1
14141;;Castillon-en-Auge;CASTILLON-EN-AUGE;14140;14;CALVADOS;1
14142;;Castilly;CASTILLY;14330;14;CALVADOS;1
14143;;Caumont-l'Éventé;CAUMONT-L'EVENTE;14240;14;CALVADOS;1
14144;;Caumont-sur-Orne;CAUMONT-SUR-ORNE;14220;14;CALVADOS;1
14145;;Cauvicourt;CAUVICOURT;14190;14;CALVADOS;1
14146;;Cauville;CAUVILLE;14770;14;CALVADOS;1
14147;;Cernay;CERNAY;14290;14;CALVADOS;1
14148;;Cerqueux;CERQUEUX;14290;14;CALVADOS;1
14149;;Cesny-aux-Vignes;CESNY-AUX-VIGNES;14270;14;CALVADOS;1
14150;;Cesny-Bois-Halbout;CESNY-BOIS-HALBOUT;14220;14;CALVADOS;1
14151;;Champ-du-Boult;CHAMP-DU-BOULT;14380;14;CALVADOS;1
14152;La;Chapelle-Engerbold;CHAPELLE-ENGERBOLD;14770;14;CALVADOS;1
14153;La;Chapelle-Haute-Grue;CHAPELLE-HAUTE-GRUE;14140;14;CALVADOS;1
14154;La;Chapelle-Yvon;CHAPELLE-YVON;14290;14;CALVADOS;1
14155;;Cheffreville-Tonnencourt;CHEFFREVILLE-TONNENCOURT;14140;14;CALVADOS;1
14156;;Chênedollé;CHENEDOLLE;14410;14;CALVADOS;1
14157;;Cheux;CHEUX;14210;14;CALVADOS;1
14158;;Chicheboville;CHICHEBOVILLE;14370;14;CALVADOS;1
14159;;Chouain;CHOUAIN;14250;14;CALVADOS;1
14160;;Cintheaux;CINTHEAUX;14680;14;CALVADOS;1
14161;;Clarbec;CLARBEC;14130;14;CALVADOS;1
14162;;Clécy;CLECY;14570;14;CALVADOS;1
14163;;Cléville;CLEVILLE;14370;14;CALVADOS;1
14164;;Clinchamps-sur-Orne;CLINCHAMPS-SUR-ORNE;14320;14;CALVADOS;1
14165;;Colleville-sur-Mer;COLLEVILLE-SUR-MER;14710;14;CALVADOS;1
14166;;Colleville-Montgomery;COLLEVILLE-MONTGOMERY;14880;14;CALVADOS;1
14167;;Colombelles;COLOMBELLES;14460;14;CALVADOS;1
14168;;Colombières;COLOMBIERES;14710;14;CALVADOS;1
14169;;Colombiers-sur-Seulles;COLOMBIERS-SUR-SEULLES;14480;14;CALVADOS;1
14170;;Colomby-sur-Thaon;COLOMBY-SUR-THAON;14610;14;CALVADOS;1
14171;;Combray;COMBRAY;14220;14;CALVADOS;1
14172;;Commes;COMMES;14520;14;CALVADOS;1
14173;;Condé-sur-Ifs;CONDE-SUR-IFS;14270;14;CALVADOS;1
14174;;Condé-sur-Noireau;CONDE-SUR-NOIREAU;14110;14;CALVADOS;1
14175;;Condé-sur-Seulles;CONDE-SUR-SEULLES;14400;14;CALVADOS;1
14176;;Conteville;CONTEVILLE;14540;14;CALVADOS;1
14177;;Coquainvilliers;COQUAINVILLIERS;14130;14;CALVADOS;1
14178;;Corbon;CORBON;14340;14;CALVADOS;1
14179;;Cordebugle;CORDEBUGLE;14100;14;CALVADOS;1
14180;;Cordey;CORDEY;14700;14;CALVADOS;1
14181;;Cormelles-le-Royal;CORMELLES-LE-ROYAL;14123;14;CALVADOS;1
14182;;Cormolain;CORMOLAIN;14240;14;CALVADOS;1
14183;;Cossesseville;COSSESSEVILLE;14690;14;CALVADOS;1
14184;;Cottun;COTTUN;14400;14;CALVADOS;1
14185;;Coudray-Rabut;COUDRAY-RABUT;14130;14;CALVADOS;1
14186;;Coulombs;COULOMBS;14480;14;CALVADOS;1
14187;;Coulonces;COULONCES;14500;14;CALVADOS;1
14188;;Coulvain;COULVAIN;14310;14;CALVADOS;1
14189;;Coupesarte;COUPESARTE;14140;14;CALVADOS;1
14190;;Courcy;COURCY;14170;14;CALVADOS;1
14191;;Courseulles-sur-Mer;COURSEULLES-SUR-MER;14470;14;CALVADOS;1
14192;;Courson;COURSON;14380;14;CALVADOS;1
14193;;Courtonne-la-Meurdrac;COURTONNE-LA-MEURDRAC;14100;14;CALVADOS;1
14194;;Courtonne-les-Deux-Églises;COURTONNE-LES-DEUX-EGLISES;14290;14;CALVADOS;1
14195;;Courvaudon;COURVAUDON;14260;14;CALVADOS;1
14196;;Crépon;CREPON;14480;14;CALVADOS;1
14197;;Cresserons;CRESSERONS;14440;14;CALVADOS;1
14198;;Cresseveuille;CRESSEVEUILLE;14430;14;CALVADOS;1
14200;;Creully;CREULLY;14480;14;CALVADOS;1
14201;;Crèvecœur-en-Auge;CREVECOEUR-EN-AUGE;14340;14;CALVADOS;1
14202;;Cricquebœuf;CRICQUEBOEUF;14113;14;CALVADOS;1
14203;;Cricqueville-en-Auge;CRICQUEVILLE-EN-AUGE;14430;14;CALVADOS;1
14204;;Cricqueville-en-Bessin;CRICQUEVILLE-EN-BESSIN;14450;14;CALVADOS;1
14205;;Cristot;CRISTOT;14250;14;CALVADOS;1
14206;;Crocy;CROCY;14620;14;CALVADOS;1
14207;;Croisilles;CROISILLES;14220;14;CALVADOS;1
14208;;Croissanville;CROISSANVILLE;14370;14;CALVADOS;1
14209;;Crouay;CROUAY;14400;14;CALVADOS;1
14210;La;Croupte;CROUPTE;14140;14;CALVADOS;1
14211;;Culey-le-Patry;CULEY-LE-PATRY;14220;14;CALVADOS;1
14212;;Cully;CULLY;14480;14;CALVADOS;1
14213;;Curcy-sur-Orne;CURCY-SUR-ORNE;14220;14;CALVADOS;1
14214;;Cussy;CUSSY;14400;14;CALVADOS;1
14215;;Cuverville;CUVERVILLE;14840;14;CALVADOS;1
14216;;Damblainville;DAMBLAINVILLE;14620;14;CALVADOS;1
14217;;Dampierre;DAMPIERRE;14350;14;CALVADOS;1
14218;;Danestal;DANESTAL;14430;14;CALVADOS;1
14219;;Danvou-la-Ferrière;DANVOU-LA-FERRIERE;14770;14;CALVADOS;1
14220;;Deauville;DEAUVILLE;14800;14;CALVADOS;1
14221;;Démouville;DEMOUVILLE;14840;14;CALVADOS;1
14222;Le;Désert;DESERT;14350;14;CALVADOS;1
14223;Le;Détroit;DETROIT;14690;14;CALVADOS;1
14224;;Deux-Jumeaux;DEUX-JUMEAUX;14230;14;CALVADOS;1
14225;;Dives-sur-Mer;DIVES-SUR-MER;14160;14;CALVADOS;1
14226;;Donnay;DONNAY;14220;14;CALVADOS;1
14227;;Douville-en-Auge;DOUVILLE-EN-AUGE;14430;14;CALVADOS;1
14228;;Douvres-la-Délivrande;DOUVRES-LA-DELIVRANDE;14440;14;CALVADOS;1
14229;;Dozulé;DOZULE;14430;14;CALVADOS;1
14230;;Drubec;DRUBEC;14130;14;CALVADOS;1
14231;;Beaufour-Druval;BEAUFOUR-DRUVAL;14340;14;CALVADOS;1
14232;;Ducy-Sainte-Marguerite;DUCY-SAINTE-MARGUERITE;14250;14;CALVADOS;1
14235;;Écrammeville;ECRAMMEVILLE;14710;14;CALVADOS;1
14236;;Ellon;ELLON;14250;14;CALVADOS;1
14237;;Émiéville;EMIEVILLE;14630;14;CALVADOS;1
14238;;Englesqueville-en-Auge;ENGLESQUEVILLE-EN-AUGE;14800;14;CALVADOS;1
14239;;Englesqueville-la-Percée;ENGLESQUEVILLE-LA-PERCEE;14710;14;CALVADOS;1
14240;;Épaney;EPANEY;14170;14;CALVADOS;1
14241;;Épinay-sur-Odon;EPINAY-SUR-ODON;14310;14;CALVADOS;1
14242;;Épron;EPRON;14610;14;CALVADOS;1
14243;;Équemauville;EQUEMAUVILLE;14600;14;CALVADOS;1
14244;;Eraines;ERAINES;14700;14;CALVADOS;1
14245;;Ernes;ERNES;14270;14;CALVADOS;1
14246;;Escoville;ESCOVILLE;14850;14;CALVADOS;1
14248;;Espins;ESPINS;14220;14;CALVADOS;1
14249;;Esquay-Notre-Dame;ESQUAY-NOTRE-DAME;14210;14;CALVADOS;1
14250;;Esquay-sur-Seulles;ESQUAY-SUR-SEULLES;14400;14;CALVADOS;1
14251;;Esson;ESSON;14220;14;CALVADOS;1
14252;;Estrées-la-Campagne;ESTREES-LA-CAMPAGNE;14190;14;CALVADOS;1
14253;;Estry;ESTRY;14410;14;CALVADOS;1
14254;;Éterville;ETERVILLE;14930;14;CALVADOS;1
14255;;Étouvy;ETOUVY;14350;14;CALVADOS;1
14256;;Étréham;ETREHAM;14400;14;CALVADOS;1
14257;;Évrecy;EVRECY;14210;14;CALVADOS;1
14258;;Falaise;FALAISE;14700;14;CALVADOS;1
14259;;Familly;FAMILLY;14290;14;CALVADOS;1
14260;;Fauguernon;FAUGUERNON;14100;14;CALVADOS;1
14261;Le;Faulq;FAULQ;14130;14;CALVADOS;1
14264;La;Ferrière-Harang;FERRIERE-HARANG;14350;14;CALVADOS;1
14265;;Fervaques;FERVAQUES;14140;14;CALVADOS;1
14266;;Feuguerolles-Bully;FEUGUEROLLES-BULLY;14320;14;CALVADOS;1
14268;;Fierville-Bray;FIERVILLE-BRAY;14190;14;CALVADOS;1
14269;;Fierville-les-Parcs;FIERVILLE-LES-PARCS;14130;14;CALVADOS;1
14270;;Firfol;FIRFOL;14100;14;CALVADOS;1
14271;;Fleury-sur-Orne;FLEURY-SUR-ORNE;14123;14;CALVADOS;1
14272;La;Folie;FOLIE;14710;14;CALVADOS;1
14273;La;Folletière-Abenon;FOLLETIERE-ABENON;14290;14;CALVADOS;1
14274;;Fontaine-Étoupefour;FONTAINE-ETOUPEFOUR;14790;14;CALVADOS;1
14275;;Fontaine-Henry;FONTAINE-HENRY;14610;14;CALVADOS;1
14276;;Fontaine-le-Pin;FONTAINE-LE-PIN;14190;14;CALVADOS;1
14277;;Fontenay-le-Marmion;FONTENAY-LE-MARMION;14320;14;CALVADOS;1
14278;;Fontenay-le-Pesnel;FONTENAY-LE-PESNEL;14250;14;CALVADOS;1
14279;;Fontenermont;FONTENERMONT;14380;14;CALVADOS;1
14280;;Formentin;FORMENTIN;14340;14;CALVADOS;1
14281;;Formigny;FORMIGNY;14710;14;CALVADOS;1
14282;;Foulognes;FOULOGNES;14240;14;CALVADOS;1
14283;;Fourches;FOURCHES;14620;14;CALVADOS;1
14284;;Fourneaux-le-Val;FOURNEAUX-LE-VAL;14700;14;CALVADOS;1
14285;Le;Fournet;FOURNET;14340;14;CALVADOS;1
14286;;Fourneville;FOURNEVILLE;14600;14;CALVADOS;1
14287;;Frénouville;FRENOUVILLE;14630;14;CALVADOS;1
14288;Le;Fresne-Camilly;FRESNE-CAMILLY;14480;14;CALVADOS;1
14289;;Fresné-la-Mère;FRESNE-LA-MERE;14700;14;CALVADOS;1
14290;;Fresney-le-Puceux;FRESNEY-LE-PUCEUX;14680;14;CALVADOS;1
14291;;Fresney-le-Vieux;FRESNEY-LE-VIEUX;14220;14;CALVADOS;1
14292;;Friardel;FRIARDEL;14290;14;CALVADOS;1
14293;;Fumichon;FUMICHON;14590;14;CALVADOS;1
14294;;Garcelles-Secqueville;GARCELLES-SECQUEVILLE;14540;14;CALVADOS;1
14296;Le;Gast;GAST;14380;14;CALVADOS;1
14297;;Gavrus;GAVRUS;14210;14;CALVADOS;1
14298;;Géfosse-Fontenay;GEFOSSE-FONTENAY;14230;14;CALVADOS;1
14299;;Genneville;GENNEVILLE;14600;14;CALVADOS;1
14300;;Gerrots;GERROTS;14430;14;CALVADOS;1
14301;;Giberville;GIBERVILLE;14730;14;CALVADOS;1
14302;;Glanville;GLANVILLE;14950;14;CALVADOS;1
14303;;Glos;GLOS;14100;14;CALVADOS;1
14304;;Gonneville-sur-Honfleur;GONNEVILLE-SUR-HONFLEUR;14600;14;CALVADOS;1
14305;;Gonneville-sur-Mer;GONNEVILLE-SUR-MER;14510;14;CALVADOS;1
14306;;Gonneville-en-Auge;GONNEVILLE-EN-AUGE;14810;14;CALVADOS;1
14307;;Goupillières;GOUPILLIERES;14210;14;CALVADOS;1
14308;;Goustranville;GOUSTRANVILLE;14430;14;CALVADOS;1
14309;;Gouvix;GOUVIX;14680;14;CALVADOS;1
14310;;Grainville-Langannerie;GRAINVILLE-LANGANNERIE;14190;14;CALVADOS;1
14311;;Grainville-sur-Odon;GRAINVILLE-SUR-ODON;14210;14;CALVADOS;1
14312;;Grandcamp-Maisy;GRANDCAMP-MAISY;14450;14;CALVADOS;1
14313;;Grandchamp-le-Château;GRANDCHAMP-LE-CHATEAU;14140;14;CALVADOS;1
14316;;Grangues;GRANGUES;14160;14;CALVADOS;1
14317;La;Graverie;GRAVERIE;14350;14;CALVADOS;1
14318;;Graye-sur-Mer;GRAYE-SUR-MER;14470;14;CALVADOS;1
14319;;Grentheville;GRENTHEVILLE;14540;14;CALVADOS;1
14320;;Grimbosq;GRIMBOSQ;14220;14;CALVADOS;1
14322;;Guéron;GUERON;14400;14;CALVADOS;1
14324;;Hamars;HAMARS;14220;14;CALVADOS;1
14325;;Hermanville-sur-Mer;HERMANVILLE-SUR-MER;14880;14;CALVADOS;1
14326;;Hermival-les-Vaux;HERMIVAL-LES-VAUX;14100;14;CALVADOS;1
14327;;Hérouville-Saint-Clair;HEROUVILLE-SAINT-CLAIR;14200;14;CALVADOS;1
14328;;Hérouvillette;HEROUVILLETTE;14850;14;CALVADOS;1
14329;;Heuland;HEULAND;14430;14;CALVADOS;1
14330;;Heurtevent;HEURTEVENT;14140;14;CALVADOS;1
14331;;Hiéville;HIEVILLE;14170;14;CALVADOS;1
14332;La;Hoguette;HOGUETTE;14700;14;CALVADOS;1
14333;;Honfleur;HONFLEUR;14600;14;CALVADOS;1
14334;L';Hôtellerie;HOTELLERIE;14100;14;CALVADOS;1
14335;;Hotot-en-Auge;HOTOT-EN-AUGE;14430;14;CALVADOS;1
14336;;Hottot-les-Bagues;HOTTOT-LES-BAGUES;14250;14;CALVADOS;1
14337;La;Houblonnière;HOUBLONNIERE;14340;14;CALVADOS;1
14338;;Houlgate;HOULGATE;14510;14;CALVADOS;1
14339;;Hubert-Folie;HUBERT-FOLIE;14540;14;CALVADOS;1
14341;;Ifs;IFS;14123;14;CALVADOS;1
14342;;Isigny-sur-Mer;ISIGNY-SUR-MER;14230;14;CALVADOS;1
14343;Les;Isles-Bardel;ISLES-BARDEL;14690;14;CALVADOS;1
14344;;Janville;JANVILLE;14670;14;CALVADOS;1
14345;;Jort;JORT;14170;14;CALVADOS;1
14346;;Juaye-Mondaye;JUAYE-MONDAYE;14250;14;CALVADOS;1
14347;;Jurques;JURQUES;14260;14;CALVADOS;1
14348;;Juvigny-sur-Seulles;JUVIGNY-SUR-SEULLES;14250;14;CALVADOS;1
14349;;Laize-la-Ville;LAIZE-LA-VILLE;14320;14;CALVADOS;1
14350;La;Lande-sur-Drôme;LANDE-SUR-DROME;14240;14;CALVADOS;1
14352;;Landelles-et-Coupigny;LANDELLES-ET-COUPIGNY;14380;14;CALVADOS;1
14353;;Landes-sur-Ajon;LANDES-SUR-AJON;14310;14;CALVADOS;1
14354;;Langrune-sur-Mer;LANGRUNE-SUR-MER;14830;14;CALVADOS;1
14355;;Lantheuil;LANTHEUIL;14480;14;CALVADOS;1
14356;;Lasson;LASSON;14740;14;CALVADOS;1
14357;;Lassy;LASSY;14770;14;CALVADOS;1
14358;;Léaupartie;LEAUPARTIE;14340;14;CALVADOS;1
14359;;Lécaude;LECAUDE;14140;14;CALVADOS;1
14360;;Leffard;LEFFARD;14700;14;CALVADOS;1
14361;;Lénault;LENAULT;14770;14;CALVADOS;1
14362;;Lessard-et-le-Chêne;LESSARD-ET-LE-CHENE;14140;14;CALVADOS;1
14364;;Lingèvres;LINGEVRES;14250;14;CALVADOS;1
14365;;Lion-sur-Mer;LION-SUR-MER;14780;14;CALVADOS;1
14366;;Lisieux;LISIEUX;14100;14;CALVADOS;1
14367;;Lison;LISON;14330;14;CALVADOS;1
14368;;Lisores;LISORES;14140;14;CALVADOS;1
14369;;Litteau;LITTEAU;14490;14;CALVADOS;1
14370;Le;Molay-Littry;MOLAY-LITTRY;14330;14;CALVADOS;1
14371;;Livarot;LIVAROT;14140;14;CALVADOS;1
14372;;Livry;LIVRY;14240;14;CALVADOS;1
14373;Le;Locheur;LOCHEUR;14210;14;CALVADOS;1
14374;Les;Loges;LOGES;14240;14;CALVADOS;1
14375;Les;Loges-Saulces;LOGES-SAULCES;14700;14;CALVADOS;1
14376;;Longraye;LONGRAYE;14250;14;CALVADOS;1
14377;;Longues-sur-Mer;LONGUES-SUR-MER;14400;14;CALVADOS;1
14378;;Longueville;LONGUEVILLE;14230;14;CALVADOS;1
14379;;Longvillers;LONGVILLERS;14310;14;CALVADOS;1
14380;;Loucelles;LOUCELLES;14250;14;CALVADOS;1
14381;;Louvagny;LOUVAGNY;14170;14;CALVADOS;1
14382;;Louvières;LOUVIERES;14710;14;CALVADOS;1
14383;;Louvigny;LOUVIGNY;14111;14;CALVADOS;1
14384;;Luc-sur-Mer;LUC-SUR-MER;14530;14;CALVADOS;1
14385;;Magny-en-Bessin;MAGNY-EN-BESSIN;14400;14;CALVADOS;1
14386;;Magny-la-Campagne;MAGNY-LA-CAMPAGNE;14270;14;CALVADOS;1
14387;;Magny-le-Freule;MAGNY-LE-FREULE;14270;14;CALVADOS;1
14388;;Maisoncelles-la-Jourdan;MAISONCELLES-LA-JOURDAN;14500;14;CALVADOS;1
14389;;Maisoncelles-Pelvey;MAISONCELLES-PELVEY;14310;14;CALVADOS;1
14390;;Maisoncelles-sur-Ajon;MAISONCELLES-SUR-AJON;14210;14;CALVADOS;1
14391;;Maisons;MAISONS;14400;14;CALVADOS;1
14393;;Maizet;MAIZET;14210;14;CALVADOS;1
14394;;Maizières;MAIZIERES;14190;14;CALVADOS;1
14395;;Malloué;MALLOUE;14350;14;CALVADOS;1
14396;;Maltot;MALTOT;14930;14;CALVADOS;1
14397;;Mandeville-en-Bessin;MANDEVILLE-EN-BESSIN;14710;14;CALVADOS;1
14398;;Manerbe;MANERBE;14340;14;CALVADOS;1
14399;;Manneville-la-Pipard;MANNEVILLE-LA-PIPARD;14130;14;CALVADOS;1
14400;Le;Manoir;MANOIR;14400;14;CALVADOS;1
14401;;Manvieux;MANVIEUX;14117;14;CALVADOS;1
14402;Le;Marais-la-Chapelle;MARAIS-LA-CHAPELLE;14620;14;CALVADOS;1
14403;;Marolles;MAROLLES;14100;14;CALVADOS;1
14404;;Martainville;MARTAINVILLE;14220;14;CALVADOS;1
14405;;Martigny-sur-l'Ante;MARTIGNY-SUR-L'ANTE;14700;14;CALVADOS;1
14406;;Martragny;MARTRAGNY;14740;14;CALVADOS;1
14407;;Mathieu;MATHIEU;14920;14;CALVADOS;1
14408;;May-sur-Orne;MAY-SUR-ORNE;14320;14;CALVADOS;1
14409;;Merville-Franceville-Plage;MERVILLE-FRANCEVILLE-PLAGE;14810;14;CALVADOS;1
14410;;Méry-Corbon;MERY-CORBON;14370;14;CALVADOS;1
14411;;Meslay;MESLAY;14220;14;CALVADOS;1
14412;Le;Mesnil-au-Grain;MESNIL-AU-GRAIN;14260;14;CALVADOS;1
14413;Le;Mesnil-Auzouf;MESNIL-AUZOUF;14260;14;CALVADOS;1
14414;Le;Mesnil-Bacley;MESNIL-BACLEY;14140;14;CALVADOS;1
14415;Le;Mesnil-Benoist;MESNIL-BENOIST;14380;14;CALVADOS;1
14416;Le;Mesnil-Caussois;MESNIL-CAUSSOIS;14380;14;CALVADOS;1
14417;;Mesnil-Clinchamps;MESNIL-CLINCHAMPS;14380;14;CALVADOS;1
14418;Le;Mesnil-Durand;MESNIL-DURAND;14140;14;CALVADOS;1
14419;Le;Mesnil-Eudes;MESNIL-EUDES;14100;14;CALVADOS;1
14420;Le;Mesnil-Germain;MESNIL-GERMAIN;14140;14;CALVADOS;1
14421;Le;Mesnil-Guillaume;MESNIL-GUILLAUME;14100;14;CALVADOS;1
14422;Le;Mesnil-Mauger;MESNIL-MAUGER;14270;14;CALVADOS;1
14423;Le;Mesnil-Patry;MESNIL-PATRY;14740;14;CALVADOS;1
14424;Le;Mesnil-Robert;MESNIL-ROBERT;14380;14;CALVADOS;1
14425;Le;Mesnil-Simon;MESNIL-SIMON;14140;14;CALVADOS;1
14426;Le;Mesnil-sur-Blangy;MESNIL-SUR-BLANGY;14130;14;CALVADOS;1
14427;Le;Mesnil-Villement;MESNIL-VILLEMENT;14690;14;CALVADOS;1
14429;;Meulles;MEULLES;14290;14;CALVADOS;1
14430;;Meuvaines;MEUVAINES;14960;14;CALVADOS;1
14431;;Mézidon-Canon;MEZIDON-CANON;14270;14;CALVADOS;1
14432;;Missy;MISSY;14210;14;CALVADOS;1
14433;;Mittois;MITTOIS;14170;14;CALVADOS;1
14435;Les;Monceaux;MONCEAUX;14100;14;CALVADOS;1
14436;;Monceaux-en-Bessin;MONCEAUX-EN-BESSIN;14400;14;CALVADOS;1
14437;;Mondeville;MONDEVILLE;14120;14;CALVADOS;1
14438;;Mondrainville;MONDRAINVILLE;14210;14;CALVADOS;1
14439;;Monfréville;MONFREVILLE;14230;14;CALVADOS;1
14440;;Montamy;MONTAMY;14260;14;CALVADOS;1
14441;;Mont-Bertrand;MONT-BERTRAND;14350;14;CALVADOS;1
14442;;Montchamp;MONTCHAMP;14350;14;CALVADOS;1
14443;;Montchauvet;MONTCHAUVET;14350;14;CALVADOS;1
14444;;Monteille;MONTEILLE;14270;14;CALVADOS;1
14445;;Montfiquet;MONTFIQUET;14490;14;CALVADOS;1
14446;;Montigny;MONTIGNY;14210;14;CALVADOS;1
14448;;Montreuil-en-Auge;MONTREUIL-EN-AUGE;14340;14;CALVADOS;1
14449;;Monts-en-Bessin;MONTS-EN-BESSIN;14310;14;CALVADOS;1
14450;;Montviette;MONTVIETTE;14140;14;CALVADOS;1
14452;;Morteaux-Coulibœuf;MORTEAUX-COULIBOEUF;14620;14;CALVADOS;1
14453;;Mosles;MOSLES;14400;14;CALVADOS;1
14454;;Mouen;MOUEN;14790;14;CALVADOS;1
14455;;Moulines;MOULINES;14220;14;CALVADOS;1
14456;;Moult;MOULT;14370;14;CALVADOS;1
14457;Les;Moutiers-en-Auge;MOUTIERS-EN-AUGE;14620;14;CALVADOS;1
14458;Les;Moutiers-en-Cinglais;MOUTIERS-EN-CINGLAIS;14220;14;CALVADOS;1
14459;Les;Moutiers-Hubert;MOUTIERS-HUBERT;14140;14;CALVADOS;1
14460;;Moyaux;MOYAUX;14590;14;CALVADOS;1
14461;;Mutrécy;MUTRECY;14220;14;CALVADOS;1
14462;;Neuilly-la-Forêt;NEUILLY-LA-FORET;14230;14;CALVADOS;1
14465;;Nonant;NONANT;14400;14;CALVADOS;1
14466;;Norolles;NOROLLES;14100;14;CALVADOS;1
14467;;Noron-l'Abbaye;NORON-L'ABBAYE;14700;14;CALVADOS;1
14468;;Noron-la-Poterie;NORON-LA-POTERIE;14490;14;CALVADOS;1
14469;;Norrey-en-Auge;NORREY-EN-AUGE;14620;14;CALVADOS;1
14471;;Notre-Dame-de-Courson;NOTRE-DAME-DE-COURSON;14140;14;CALVADOS;1
14473;;Notre-Dame-de-Livaye;NOTRE-DAME-DE-LIVAYE;14340;14;CALVADOS;1
14474;;Notre-Dame-d'Estrées;NOTRE-DAME-D'ESTREES;14340;14;CALVADOS;1
14475;;Noyers-Bocage;NOYERS-BOCAGE;14210;14;CALVADOS;1
14476;;Olendon;OLENDON;14170;14;CALVADOS;1
14477;;Ondefontaine;ONDEFONTAINE;14260;14;CALVADOS;1
14478;;Orbec;ORBEC;14290;14;CALVADOS;1
14480;;Osmanville;OSMANVILLE;14230;14;CALVADOS;1
14481;Les;Oubeaux;OUBEAUX;14230;14;CALVADOS;1
14482;;Ouézy;OUEZY;14270;14;CALVADOS;1
14483;;Ouffières;OUFFIERES;14220;14;CALVADOS;1
14484;;Ouilly-du-Houley;OUILLY-DU-HOULEY;14590;14;CALVADOS;1
14486;;Ouilly-le-Tesson;OUILLY-LE-TESSON;14190;14;CALVADOS;1
14487;;Ouilly-le-Vicomte;OUILLY-LE-VICOMTE;14100;14;CALVADOS;1
14488;;Ouistreham;OUISTREHAM;14150;14;CALVADOS;1
14489;;Ouville-la-Bien-Tournée;OUVILLE-LA-BIEN-TOURNEE;14170;14;CALVADOS;1
14491;;Parfouru-sur-Odon;PARFOURU-SUR-ODON;14310;14;CALVADOS;1
14492;;Pennedepie;PENNEDEPIE;14600;14;CALVADOS;1
14493;;Percy-en-Auge;PERCY-EN-AUGE;14270;14;CALVADOS;1
14494;;Périers-en-Auge;PERIERS-EN-AUGE;14160;14;CALVADOS;1
14495;;Périers-sur-le-Dan;PERIERS-SUR-LE-DAN;14112;14;CALVADOS;1
14496;;Périgny;PERIGNY;14770;14;CALVADOS;1
14497;;Perrières;PERRIERES;14170;14;CALVADOS;1
14498;;Pertheville-Ners;PERTHEVILLE-NERS;14700;14;CALVADOS;1
14499;;Petiville;PETIVILLE;14390;14;CALVADOS;1
14500;;Pierrefitte-en-Auge;PIERREFITTE-EN-AUGE;14130;14;CALVADOS;1
14501;;Pierrefitte-en-Cinglais;PIERREFITTE-EN-CINGLAIS;14690;14;CALVADOS;1
14502;;Pierrepont;PIERREPONT;14690;14;CALVADOS;1
14503;;Pierres;PIERRES;14410;14;CALVADOS;1
14504;Le;Pin;PIN;14590;14;CALVADOS;1
14505;;Placy;PLACY;14220;14;CALVADOS;1
14506;;Planquery;PLANQUERY;14490;14;CALVADOS;1
14508;Le;Plessis-Grimoult;PLESSIS-GRIMOULT;14770;14;CALVADOS;1
14509;;Plumetot;PLUMETOT;14440;14;CALVADOS;1
14510;La;Pommeraye;POMMERAYE;14690;14;CALVADOS;1
14511;;Pont-Bellanger;PONT-BELLANGER;14380;14;CALVADOS;1
14512;;Pontécoulant;PONTECOULANT;14110;14;CALVADOS;1
14513;;Pont-Farcy;PONT-FARCY;14380;14;CALVADOS;1
14514;;Pont-l'Évêque;PONT-L'EVEQUE;14130;14;CALVADOS;1
14515;;Port-en-Bessin-Huppain;PORT-EN-BESSIN-HUPPAIN;14520;14;CALVADOS;1
14516;;Potigny;POTIGNY;14420;14;CALVADOS;1
14517;;Poussy-la-Campagne;POUSSY-LA-CAMPAGNE;14540;14;CALVADOS;1
14518;;Préaux-Saint-Sébastien;PREAUX-SAINT-SEBASTIEN;14290;14;CALVADOS;1
14519;;Préaux-Bocage;PREAUX-BOCAGE;14210;14;CALVADOS;1
14520;Le;Pré-d'Auge;PRE-D'AUGE;14340;14;CALVADOS;1
14521;;Presles;PRESLES;14410;14;CALVADOS;1
14522;;Prêtreville;PRETREVILLE;14140;14;CALVADOS;1
14523;;Proussy;PROUSSY;14110;14;CALVADOS;1
14524;;Putot-en-Auge;PUTOT-EN-AUGE;14430;14;CALVADOS;1
14525;;Putot-en-Bessin;PUTOT-EN-BESSIN;14740;14;CALVADOS;1
14527;;Biéville-Quétiéville;BIEVILLE-QUETIEVILLE;14270;14;CALVADOS;1
14528;;Quetteville;QUETTEVILLE;14130;14;CALVADOS;1
14529;;Ranchy;RANCHY;14400;14;CALVADOS;1
14530;;Ranville;RANVILLE;14860;14;CALVADOS;1
14531;;Rapilly;RAPILLY;14690;14;CALVADOS;1
14532;Le;Reculey;RECULEY;14350;14;CALVADOS;1
14533;;Repentigny;REPENTIGNY;14340;14;CALVADOS;1
14534;;Reux;REUX;14130;14;CALVADOS;1
14535;;Reviers;REVIERS;14470;14;CALVADOS;1
14536;La;Rivière-Saint-Sauveur;RIVIERE-SAINT-SAUVEUR;14600;14;CALVADOS;1
14538;;Rocquancourt;ROCQUANCOURT;14540;14;CALVADOS;1
14539;La;Rocque;ROCQUE;14410;14;CALVADOS;1
14540;;Rocques;ROCQUES;14100;14;CALVADOS;1
14541;La;Roque-Baignard;ROQUE-BAIGNARD;14340;14;CALVADOS;1
14542;;Rosel;ROSEL;14740;14;CALVADOS;1
14543;;Rots;ROTS;14980;14;CALVADOS;1
14544;;Roucamps;ROUCAMPS;14260;14;CALVADOS;1
14545;;Roullours;ROULLOURS;14500;14;CALVADOS;1
14546;;Rouvres;ROUVRES;14190;14;CALVADOS;1
14547;;Rubercy;RUBERCY;14710;14;CALVADOS;1
14548;;Rucqueville;RUCQUEVILLE;14480;14;CALVADOS;1
14549;;Rully;RULLY;14410;14;CALVADOS;1
14550;;Rumesnil;RUMESNIL;14340;14;CALVADOS;1
14551;;Russy;RUSSY;14710;14;CALVADOS;1
14552;;Ryes;RYES;14400;14;CALVADOS;1
14553;;Saint-Agnan-le-Malherbe;SAINT-AGNAN-LE-MALHERBE;14260;14;CALVADOS;1
14554;;Saint-Aignan-de-Cramesnil;SAINT-AIGNAN-DE-CRAMESNIL;14540;14;CALVADOS;1
14555;;Saint-André-d'Hébertot;SAINT-ANDRE-D'HEBERTOT;14130;14;CALVADOS;1
14556;;Saint-André-sur-Orne;SAINT-ANDRE-SUR-ORNE;14320;14;CALVADOS;1
14557;;Saint-Arnoult;SAINT-ARNOULT;14800;14;CALVADOS;1
14558;;Saint-Aubin-d'Arquenay;SAINT-AUBIN-D'ARQUENAY;14970;14;CALVADOS;1
14559;;Saint-Aubin-des-Bois;SAINT-AUBIN-DES-BOIS;14380;14;CALVADOS;1
14562;;Saint-Aubin-sur-Mer;SAINT-AUBIN-SUR-MER;14750;14;CALVADOS;1
14563;;Saint-Benoît-d'Hébertot;SAINT-BENOIT-D'HEBERTOT;14130;14;CALVADOS;1
14564;;Saint-Charles-de-Percy;SAINT-CHARLES-DE-PERCY;14350;14;CALVADOS;1
14565;;Saint-Côme-de-Fresné;SAINT-COME-DE-FRESNE;14960;14;CALVADOS;1
14566;;Saint-Contest;SAINT-CONTEST;14280;14;CALVADOS;1
14568;;Sainte-Croix-Grand-Tonne;SAINTE-CROIX-GRAND-TONNE;14740;14;CALVADOS;1
14569;;Sainte-Croix-sur-Mer;SAINTE-CROIX-SUR-MER;14480;14;CALVADOS;1
14570;;Saint-Cyr-du-Ronceray;SAINT-CYR-DU-RONCERAY;14290;14;CALVADOS;1
14571;;Saint-Denis-de-Mailloc;SAINT-DENIS-DE-MAILLOC;14100;14;CALVADOS;1
14572;;Saint-Denis-de-Méré;SAINT-DENIS-DE-MERE;14110;14;CALVADOS;1
14573;;Saint-Denis-Maisoncelles;SAINT-DENIS-MAISONCELLES;14350;14;CALVADOS;1
14574;;Saint-Désir;SAINT-DESIR;14100;14;CALVADOS;1
14575;;Saint-Étienne-la-Thillaye;SAINT-ETIENNE-LA-THILLAYE;14950;14;CALVADOS;1
14576;;Sainte-Foy-de-Montgommery;SAINTE-FOY-DE-MONTGOMMERY;14140;14;CALVADOS;1
14577;;Saint-Gabriel-Brécy;SAINT-GABRIEL-BRECY;14480;14;CALVADOS;1
14578;;Saint-Gatien-des-Bois;SAINT-GATIEN-DES-BOIS;14130;14;CALVADOS;1
14579;;Saint-Georges-d'Aunay;SAINT-GEORGES-D'AUNAY;14260;14;CALVADOS;1
14580;;Saint-Georges-en-Auge;SAINT-GEORGES-EN-AUGE;14140;14;CALVADOS;1
14581;;Saint-Germain-d'Ectot;SAINT-GERMAIN-D'ECTOT;14240;14;CALVADOS;1
14582;;Saint-Germain-de-Livet;SAINT-GERMAIN-DE-LIVET;14100;14;CALVADOS;1
14583;;Saint-Germain-de-Montgommery;SAINT-GERMAIN-DE-MONTGOMMERY;14140;14;CALVADOS;1
14584;;Saint-Germain-de-Tallevende-la-Lande-Vaumont;SAINT-GERMAIN-DE-TALLEVENDE-LA-LANDE-VAUMONT;14500;14;CALVADOS;1
14585;;Saint-Germain-du-Crioult;SAINT-GERMAIN-DU-CRIOULT;14110;14;CALVADOS;1
14586;;Saint-Germain-du-Pert;SAINT-GERMAIN-DU-PERT;14230;14;CALVADOS;1
14587;;Saint-Germain-la-Blanche-Herbe;SAINT-GERMAIN-LA-BLANCHE-HERBE;14280;14;CALVADOS;1
14588;;Saint-Germain-Langot;SAINT-GERMAIN-LANGOT;14700;14;CALVADOS;1
14589;;Saint-Germain-le-Vasson;SAINT-GERMAIN-LE-VASSON;14190;14;CALVADOS;1
14590;;Sainte-Honorine-de-Ducy;SAINTE-HONORINE-DE-DUCY;14240;14;CALVADOS;1
14591;;Sainte-Honorine-des-Pertes;SAINTE-HONORINE-DES-PERTES;14520;14;CALVADOS;1
14592;;Sainte-Honorine-du-Fay;SAINTE-HONORINE-DU-FAY;14210;14;CALVADOS;1
14593;;Saint-Hymer;SAINT-HYMER;14130;14;CALVADOS;1
14595;;Saint-Jean-de-Livet;SAINT-JEAN-DE-LIVET;14100;14;CALVADOS;1
14596;;Saint-Jean-des-Essartiers;SAINT-JEAN-DES-ESSARTIERS;14350;14;CALVADOS;1
14597;;Saint-Jean-le-Blanc;SAINT-JEAN-LE-BLANC;14770;14;CALVADOS;1
14598;;Saint-Jouin;SAINT-JOUIN;14430;14;CALVADOS;1
14599;;Saint-Julien-de-Mailloc;SAINT-JULIEN-DE-MAILLOC;14290;14;CALVADOS;1
14600;;Saint-Julien-le-Faucon;SAINT-JULIEN-LE-FAUCON;14140;14;CALVADOS;1
14601;;Saint-Julien-sur-Calonne;SAINT-JULIEN-SUR-CALONNE;14130;14;CALVADOS;1
14602;;Saint-Lambert;SAINT-LAMBERT;14570;14;CALVADOS;1
14603;;Saint-Laurent-de-Condel;SAINT-LAURENT-DE-CONDEL;14220;14;CALVADOS;1
14604;;Saint-Laurent-du-Mont;SAINT-LAURENT-DU-MONT;14340;14;CALVADOS;1
14605;;Saint-Laurent-sur-Mer;SAINT-LAURENT-SUR-MER;14710;14;CALVADOS;1
14606;;Saint-Léger-Dubosq;SAINT-LEGER-DUBOSQ;14430;14;CALVADOS;1
14607;;Saint-Louet-sur-Seulles;SAINT-LOUET-SUR-SEULLES;14310;14;CALVADOS;1
14608;;Saint-Loup-de-Fribois;SAINT-LOUP-DE-FRIBOIS;14340;14;CALVADOS;1
14609;;Saint-Loup-Hors;SAINT-LOUP-HORS;14400;14;CALVADOS;1
14610;;Saint-Manvieu-Norrey;SAINT-MANVIEU-NORREY;14740;14;CALVADOS;1
14611;;Saint-Manvieu-Bocage;SAINT-MANVIEU-BOCAGE;14380;14;CALVADOS;1
14613;;Saint-Marcouf;SAINT-MARCOUF;14330;14;CALVADOS;1
14614;;Sainte-Marguerite-d'Elle;SAINTE-MARGUERITE-D'ELLE;14330;14;CALVADOS;1
14615;;Sainte-Marguerite-des-Loges;SAINTE-MARGUERITE-DES-LOGES;14140;14;CALVADOS;1
14616;;Sainte-Marguerite-de-Viette;SAINTE-MARGUERITE-DE-VIETTE;14140;14;CALVADOS;1
14618;;Sainte-Marie-Laumont;SAINTE-MARIE-LAUMONT;14350;14;CALVADOS;1
14619;;Sainte-Marie-Outre-l'Eau;SAINTE-MARIE-OUTRE-L'EAU;14380;14;CALVADOS;1
14620;;Saint-Martin-aux-Chartrains;SAINT-MARTIN-AUX-CHARTRAINS;14130;14;CALVADOS;1
14621;;Saint-Martin-de-Bienfaite-la-Cressonnière;SAINT-MARTIN-DE-BIENFAITE-LA-CRESSONNIERE;14290;14;CALVADOS;1
14622;;Saint-Martin-de-Blagny;SAINT-MARTIN-DE-BLAGNY;14710;14;CALVADOS;1
14623;;Saint-Martin-de-Fontenay;SAINT-MARTIN-DE-FONTENAY;14320;14;CALVADOS;1
14625;;Saint-Martin-de-la-Lieue;SAINT-MARTIN-DE-LA-LIEUE;14100;14;CALVADOS;1
14626;;Saint-Martin-de-Mailloc;SAINT-MARTIN-DE-MAILLOC;14100;14;CALVADOS;1
14627;;Saint-Martin-de-Mieux;SAINT-MARTIN-DE-MIEUX;14700;14;CALVADOS;1
14628;;Saint-Martin-de-Sallen;SAINT-MARTIN-DE-SALLEN;14220;14;CALVADOS;1
14629;;Saint-Martin-des-Besaces;SAINT-MARTIN-DES-BESACES;14350;14;CALVADOS;1
14630;;Saint-Martin-des-Entrées;SAINT-MARTIN-DES-ENTREES;14400;14;CALVADOS;1
14632;;Saint-Martin-Don;SAINT-MARTIN-DON;14350;14;CALVADOS;1
14633;;Saint-Martin-du-Mesnil-Oury;SAINT-MARTIN-DU-MESNIL-OURY;14140;14;CALVADOS;1
14634;;Saint-Michel-de-Livet;SAINT-MICHEL-DE-LIVET;14140;14;CALVADOS;1
14635;;Saint-Omer;SAINT-OMER;14220;14;CALVADOS;1
14636;;Saint-Ouen-des-Besaces;SAINT-OUEN-DES-BESACES;14350;14;CALVADOS;1
14637;;Saint-Ouen-du-Mesnil-Oger;SAINT-OUEN-DU-MESNIL-OGER;14670;14;CALVADOS;1
14638;;Saint-Ouen-le-Houx;SAINT-OUEN-LE-HOUX;14140;14;CALVADOS;1
14639;;Saint-Ouen-le-Pin;SAINT-OUEN-LE-PIN;14340;14;CALVADOS;1
14640;;Saint-Pair;SAINT-PAIR;14670;14;CALVADOS;1
14643;;Saint-Paul-du-Vernay;SAINT-PAUL-DU-VERNAY;14490;14;CALVADOS;1
14644;;Saint-Philbert-des-Champs;SAINT-PHILBERT-DES-CHAMPS;14130;14;CALVADOS;1
14645;;Saint-Pierre-Azif;SAINT-PIERRE-AZIF;14950;14;CALVADOS;1
14646;;Saint-Pierre-Canivet;SAINT-PIERRE-CANIVET;14700;14;CALVADOS;1
14647;;Saint-Pierre-de-Mailloc;SAINT-PIERRE-DE-MAILLOC;14290;14;CALVADOS;1
14648;;Saint-Pierre-des-Ifs;SAINT-PIERRE-DES-IFS;14100;14;CALVADOS;1
14649;;Saint-Pierre-du-Bû;SAINT-PIERRE-DU-BU;14700;14;CALVADOS;1
14650;;Saint-Pierre-du-Fresne;SAINT-PIERRE-DU-FRESNE;14260;14;CALVADOS;1
14651;;Saint-Pierre-du-Jonquet;SAINT-PIERRE-DU-JONQUET;14670;14;CALVADOS;1
14652;;Saint-Pierre-du-Mont;SAINT-PIERRE-DU-MONT;14450;14;CALVADOS;1
14653;;Saint-Pierre-la-Vieille;SAINT-PIERRE-LA-VIEILLE;14770;14;CALVADOS;1
14654;;Saint-Pierre-sur-Dives;SAINT-PIERRE-SUR-DIVES;14170;14;CALVADOS;1
14655;;Saint-Pierre-Tarentaine;SAINT-PIERRE-TARENTAINE;14350;14;CALVADOS;1
14656;;Saint-Rémy;SAINT-REMY;14570;14;CALVADOS;1
14657;;Saint-Samson;SAINT-SAMSON;14670;14;CALVADOS;1
14658;;Saint-Sever-Calvados;SAINT-SEVER-CALVADOS;14380;14;CALVADOS;1
14659;;Saint-Sylvain;SAINT-SYLVAIN;14190;14;CALVADOS;1
14660;;Saint-Vaast-en-Auge;SAINT-VAAST-EN-AUGE;14640;14;CALVADOS;1
14661;;Saint-Vaast-sur-Seulles;SAINT-VAAST-SUR-SEULLES;14250;14;CALVADOS;1
14662;;Saint-Vigor-des-Mézerets;SAINT-VIGOR-DES-MEZERETS;14770;14;CALVADOS;1
14663;;Saint-Vigor-le-Grand;SAINT-VIGOR-LE-GRAND;14400;14;CALVADOS;1
14664;;Sallen;SALLEN;14240;14;CALVADOS;1
14665;;Sallenelles;SALLENELLES;14121;14;CALVADOS;1
14666;;Sannerville;SANNERVILLE;14940;14;CALVADOS;1
14667;;Saon;SAON;14330;14;CALVADOS;1
14668;;Saonnet;SAONNET;14330;14;CALVADOS;1
14669;;Sassy;SASSY;14170;14;CALVADOS;1
14670;;Secqueville-en-Bessin;SECQUEVILLE-EN-BESSIN;14740;14;CALVADOS;1
14671;;Sept-Frères;SEPT-FRERES;14380;14;CALVADOS;1
14672;;Sept-Vents;SEPT-VENTS;14240;14;CALVADOS;1
14674;;Soignolles;SOIGNOLLES;14190;14;CALVADOS;1
14675;;Soliers;SOLIERS;14540;14;CALVADOS;1
14676;;Sommervieu;SOMMERVIEU;14400;14;CALVADOS;1
14677;;Soulangy;SOULANGY;14700;14;CALVADOS;1
14678;;Soumont-Saint-Quentin;SOUMONT-SAINT-QUENTIN;14420;14;CALVADOS;1
14679;;Subles;SUBLES;14400;14;CALVADOS;1
14680;;Sully;SULLY;14400;14;CALVADOS;1
14681;;Surrain;SURRAIN;14710;14;CALVADOS;1
14682;;Surville;SURVILLE;14130;14;CALVADOS;1
14684;;Tessel;TESSEL;14250;14;CALVADOS;1
14685;;Thaon;THAON;14610;14;CALVADOS;1
14686;Le;Theil-Bocage;THEIL-BOCAGE;14410;14;CALVADOS;1
14687;Le;Theil-en-Auge;THEIL-EN-AUGE;14130;14;CALVADOS;1
14688;;Thiéville;THIEVILLE;14170;14;CALVADOS;1
14689;;Thury-Harcourt;THURY-HARCOURT;14220;14;CALVADOS;1
14690;;Tierceville;TIERCEVILLE;14480;14;CALVADOS;1
14691;;Tilly-la-Campagne;TILLY-LA-CAMPAGNE;14540;14;CALVADOS;1
14692;;Tilly-sur-Seulles;TILLY-SUR-SEULLES;14250;14;CALVADOS;1
14693;;Tordouet;TORDOUET;14290;14;CALVADOS;1
14694;Le;Torquesne;TORQUESNE;14130;14;CALVADOS;1
14695;;Torteval-Quesnay;TORTEVAL-QUESNAY;14240;14;CALVADOS;1
14696;;Tortisambert;TORTISAMBERT;14140;14;CALVADOS;1
14697;L';Oudon;OUDON;14170;14;CALVADOS;1
14698;;Touffréville;TOUFFREVILLE;14940;14;CALVADOS;1
14699;;Touques;TOUQUES;14800;14;CALVADOS;1
14700;;Tour-en-Bessin;TOUR-EN-BESSIN;14400;14;CALVADOS;1
14701;;Tourgéville;TOURGEVILLE;14800;14;CALVADOS;1
14702;;Tournay-sur-Odon;TOURNAY-SUR-ODON;14310;14;CALVADOS;1
14703;;Tournebu;TOURNEBU;14220;14;CALVADOS;1
14704;Le;Tourneur;TOURNEUR;14350;14;CALVADOS;1
14705;;Tournières;TOURNIERES;14330;14;CALVADOS;1
14706;;Tourville-en-Auge;TOURVILLE-EN-AUGE;14130;14;CALVADOS;1
14707;;Tourville-sur-Odon;TOURVILLE-SUR-ODON;14210;14;CALVADOS;1
14708;;Tracy-Bocage;TRACY-BOCAGE;14310;14;CALVADOS;1
14709;;Tracy-sur-Mer;TRACY-SUR-MER;14117;14;CALVADOS;1
14710;;Tréprel;TREPREL;14690;14;CALVADOS;1
14711;;Trévières;TREVIERES;14710;14;CALVADOS;1
14712;;Troarn;TROARN;14670;14;CALVADOS;1
14713;;Trois-Monts;TROIS-MONTS;14210;14;CALVADOS;1
14714;Le;Tronquay;TRONQUAY;14490;14;CALVADOS;1
14715;;Trouville-sur-Mer;TROUVILLE-SUR-MER;14360;14;CALVADOS;1
14716;;Trungy;TRUNGY;14490;14;CALVADOS;1
14717;;Truttemer-le-Grand;TRUTTEMER-LE-GRAND;14500;14;CALVADOS;1
14718;;Truttemer-le-Petit;TRUTTEMER-LE-PETIT;14500;14;CALVADOS;1
14719;;Urville;URVILLE;14190;14;CALVADOS;1
14720;;Ussy;USSY;14420;14;CALVADOS;1
14721;;Vacognes-Neuilly;VACOGNES-NEUILLY;14210;14;CALVADOS;1
14722;La;Vacquerie;VACQUERIE;14240;14;CALVADOS;1
14723;;Valsemé;VALSEME;14340;14;CALVADOS;1
14724;;Varaville;VARAVILLE;14390;14;CALVADOS;1
14726;;Vassy;VASSY;14410;14;CALVADOS;1
14727;;Vaubadon;VAUBADON;14490;14;CALVADOS;1
14728;;Vaucelles;VAUCELLES;14400;14;CALVADOS;1
14729;;Vaudeloges;VAUDELOGES;14170;14;CALVADOS;1
14730;;Vaudry;VAUDRY;14500;14;CALVADOS;1
14731;;Vauville;VAUVILLE;14800;14;CALVADOS;1
14732;;Vaux-sur-Aure;VAUX-SUR-AURE;14400;14;CALVADOS;1
14733;;Vaux-sur-Seulles;VAUX-SUR-SEULLES;14400;14;CALVADOS;1
14734;;Vendes;VENDES;14250;14;CALVADOS;1
14735;;Vendeuvre;VENDEUVRE;14170;14;CALVADOS;1
14737;;Versainville;VERSAINVILLE;14700;14;CALVADOS;1
14738;;Verson;VERSON;14790;14;CALVADOS;1
14739;;Ver-sur-Mer;VER-SUR-MER;14114;14;CALVADOS;1
14740;La;Vespière;VESPIERE;14290;14;CALVADOS;1
14741;Le;Vey;VEY;14570;14;CALVADOS;1
14742;;Vicques;VICQUES;14170;14;CALVADOS;1
14743;;Victot-Pontfol;VICTOT-PONTFOL;14430;14;CALVADOS;1
14744;;Vienne-en-Bessin;VIENNE-EN-BESSIN;14400;14;CALVADOS;1
14745;;Vierville-sur-Mer;VIERVILLE-SUR-MER;14710;14;CALVADOS;1
14746;;Viessoix;VIESSOIX;14410;14;CALVADOS;1
14747;;Vieux;VIEUX;14930;14;CALVADOS;1
14748;;Vieux-Bourg;VIEUX-BOURG;14130;14;CALVADOS;1
14749;;Vieux-Fumé;VIEUX-FUME;14270;14;CALVADOS;1
14750;;Vieux-Pont-en-Auge;VIEUX-PONT-EN-AUGE;14140;14;CALVADOS;1
14751;;Vignats;VIGNATS;14700;14;CALVADOS;1
14752;;Villers-Bocage;VILLERS-BOCAGE;14310;14;CALVADOS;1
14753;;Villers-Canivet;VILLERS-CANIVET;14420;14;CALVADOS;1
14754;;Villers-sur-Mer;VILLERS-SUR-MER;14640;14;CALVADOS;1
14755;;Villerville;VILLERVILLE;14113;14;CALVADOS;1
14756;La;Villette;VILLETTE;14570;14;CALVADOS;1
14757;;Villiers-le-Sec;VILLIERS-LE-SEC;14480;14;CALVADOS;1
14758;;Villons-les-Buissons;VILLONS-LES-BUISSONS;14610;14;CALVADOS;1
14759;;Villy-lez-Falaise;VILLY-LEZ-FALAISE;14700;14;CALVADOS;1
14760;;Villy-Bocage;VILLY-BOCAGE;14310;14;CALVADOS;1
14761;;Vimont;VIMONT;14370;14;CALVADOS;1
14762;;Vire;VIRE;14500;14;CALVADOS;1
14763;;Vouilly;VOUILLY;14230;14;CALVADOS;1
14764;;Pont-d'Ouilly;PONT-D'OUILLY;14690;14;CALVADOS;1
15001;;Allanche;ALLANCHE;15160;15;CANTAL;1
15002;;Alleuze;ALLEUZE;15100;15;CANTAL;1
15003;;Ally;ALLY;15700;15;CANTAL;1
15004;;Andelat;ANDELAT;15100;15;CANTAL;1
15005;;Anglards-de-Saint-Flour;ANGLARDS-DE-SAINT-FLOUR;15100;15;CANTAL;1
15006;;Anglards-de-Salers;ANGLARDS-DE-SALERS;15380;15;CANTAL;1
15007;;Anterrieux;ANTERRIEUX;15110;15;CANTAL;1
15008;;Antignac;ANTIGNAC;15240;15;CANTAL;1
15009;;Apchon;APCHON;15400;15;CANTAL;1
15010;;Arches;ARCHES;15200;15;CANTAL;1
15011;;Arnac;ARNAC;15150;15;CANTAL;1
15012;;Arpajon-sur-Cère;ARPAJON-SUR-CERE;15130;15;CANTAL;1
15013;;Auriac-l'Église;AURIAC-L'EGLISE;15500;15;CANTAL;1
15014;;Aurillac;AURILLAC;15000;15;CANTAL;1
15015;;Auzers;AUZERS;15240;15;CANTAL;1
15016;;Ayrens;AYRENS;15250;15;CANTAL;1
15017;;Badailhac;BADAILHAC;15800;15;CANTAL;1
15018;;Barriac-les-Bosquets;BARRIAC-LES-BOSQUETS;15700;15;CANTAL;1
15019;;Bassignac;BASSIGNAC;15240;15;CANTAL;1
15020;;Beaulieu;BEAULIEU;15270;15;CANTAL;1
15021;;Boisset;BOISSET;15600;15;CANTAL;1
15022;;Bonnac;BONNAC;15500;15;CANTAL;1
15024;;Brageac;BRAGEAC;15700;15;CANTAL;1
15025;;Albepierre-Bredons;ALBEPIERRE-BREDONS;15300;15;CANTAL;1
15026;;Brezons;BREZONS;15230;15;CANTAL;1
15027;;Calvinet;CALVINET;15340;15;CANTAL;1
15028;;Carlat;CARLAT;15130;15;CANTAL;1
15029;;Cassaniouze;CASSANIOUZE;15340;15;CANTAL;1
15030;;Cayrols;CAYROLS;15290;15;CANTAL;1
15031;;Celles;CELLES;15170;15;CANTAL;1
15032;;Celoux;CELOUX;15500;15;CANTAL;1
15033;;Cézens;CEZENS;15230;15;CANTAL;1
15034;;Chaliers;CHALIERS;15320;15;CANTAL;1
15035;;Chalinargues;CHALINARGUES;15170;15;CANTAL;1
15036;;Chalvignac;CHALVIGNAC;15200;15;CANTAL;1
15037;;Champagnac;CHAMPAGNAC;15350;15;CANTAL;1
15038;;Champs-sur-Tarentaine-Marchal;CHAMPS-SUR-TARENTAINE-MARCHAL;15270;15;CANTAL;1
15040;;Chanterelle;CHANTERELLE;15190;15;CANTAL;1
15041;La;Chapelle-d'Alagnon;CHAPELLE-D'ALAGNON;15300;15;CANTAL;1
15042;La;Chapelle-Laurent;CHAPELLE-LAURENT;15500;15;CANTAL;1
15043;;Charmensac;CHARMENSAC;15500;15;CANTAL;1
15044;;Chastel-sur-Murat;CHASTEL-SUR-MURAT;15300;15;CANTAL;1
15045;;Chaudes-Aigues;CHAUDES-AIGUES;15110;15;CANTAL;1
15046;;Chaussenac;CHAUSSENAC;15700;15;CANTAL;1
15047;;Chavagnac;CHAVAGNAC;15300;15;CANTAL;1
15048;;Chazelles;CHAZELLES;15500;15;CANTAL;1
15049;;Cheylade;CHEYLADE;15400;15;CANTAL;1
15050;Le;Claux;CLAUX;15400;15;CANTAL;1
15051;;Clavières;CLAVIERES;15320;15;CANTAL;1
15052;;Collandres;COLLANDRES;15400;15;CANTAL;1
15053;;Coltines;COLTINES;15170;15;CANTAL;1
15054;;Condat;CONDAT;15190;15;CANTAL;1
15055;;Coren;COREN;15100;15;CANTAL;1
15056;;Crandelles;CRANDELLES;15250;15;CANTAL;1
15057;;Cros-de-Montvert;CROS-DE-MONTVERT;15150;15;CANTAL;1
15058;;Cros-de-Ronesque;CROS-DE-RONESQUE;15130;15;CANTAL;1
15059;;Cussac;CUSSAC;15430;15;CANTAL;1
15060;;Deux-Verges;DEUX-VERGES;15110;15;CANTAL;1
15061;;Dienne;DIENNE;15300;15;CANTAL;1
15063;;Drugeac;DRUGEAC;15140;15;CANTAL;1
15064;;Escorailles;ESCORAILLES;15700;15;CANTAL;1
15065;;Espinasse;ESPINASSE;15110;15;CANTAL;1
15066;Le;Falgoux;FALGOUX;15380;15;CANTAL;1
15067;Le;Fau;FAU;15140;15;CANTAL;1
15068;;Faverolles;FAVEROLLES;15390;15;CANTAL;1
15069;;Ferrières-Saint-Mary;FERRIERES-SAINT-MARY;15170;15;CANTAL;1
15070;;Fontanges;FONTANGES;15140;15;CANTAL;1
15071;;Fournoulès;FOURNOULES;15600;15;CANTAL;1
15072;;Freix-Anglards;FREIX-ANGLARDS;15310;15;CANTAL;1
15073;;Fridefont;FRIDEFONT;15110;15;CANTAL;1
15074;;Giou-de-Mamou;GIOU-DE-MAMOU;15130;15;CANTAL;1
15075;;Girgols;GIRGOLS;15310;15;CANTAL;1
15076;;Glénat;GLENAT;15150;15;CANTAL;1
15077;;Gourdièges;GOURDIEGES;15230;15;CANTAL;1
15078;;Jabrun;JABRUN;15110;15;CANTAL;1
15079;;Jaleyrac;JALEYRAC;15200;15;CANTAL;1
15080;;Joursac;JOURSAC;15170;15;CANTAL;1
15081;;Jou-sous-Monjou;JOU-SOUS-MONJOU;15800;15;CANTAL;1
15082;;Junhac;JUNHAC;15120;15;CANTAL;1
15083;;Jussac;JUSSAC;15250;15;CANTAL;1
15084;;Labesserette;LABESSERETTE;15120;15;CANTAL;1
15085;;Labrousse;LABROUSSE;15130;15;CANTAL;1
15086;;Lacapelle-Barrès;LACAPELLE-BARRES;15230;15;CANTAL;1
15087;;Lacapelle-del-Fraisse;LACAPELLE-DEL-FRAISSE;15120;15;CANTAL;1
15088;;Lacapelle-Viescamp;LACAPELLE-VIESCAMP;15150;15;CANTAL;1
15089;;Ladinhac;LADINHAC;15120;15;CANTAL;1
15090;;Lafeuillade-en-Vézie;LAFEUILLADE-EN-VEZIE;15130;15;CANTAL;1
15091;;Landeyrat;LANDEYRAT;15160;15;CANTAL;1
15092;;Lanobre;LANOBRE;15270;15;CANTAL;1
15093;;Lapeyrugue;LAPEYRUGUE;15120;15;CANTAL;1
15094;;Laroquebrou;LAROQUEBROU;15150;15;CANTAL;1
15095;;Laroquevieille;LAROQUEVIEILLE;15250;15;CANTAL;1
15096;;Lascelle;LASCELLE;15590;15;CANTAL;1
15097;;Lastic;LASTIC;15500;15;CANTAL;1
15098;;Laurie;LAURIE;15500;15;CANTAL;1
15099;;Lavastrie;LAVASTRIE;15260;15;CANTAL;1
15100;;Laveissenet;LAVEISSENET;15300;15;CANTAL;1
15101;;Laveissière;LAVEISSIERE;15300;15;CANTAL;1
15102;;Lavigerie;LAVIGERIE;15300;15;CANTAL;1
15103;;Leucamp;LEUCAMP;15120;15;CANTAL;1
15104;;Leynhac;LEYNHAC;15600;15;CANTAL;1
15105;;Leyvaux;LEYVAUX;43450;15;HAUTE LOIRE;1
15106;;Lieutadès;LIEUTADES;15110;15;CANTAL;1
15107;;Lorcières;LORCIERES;15320;15;CANTAL;1
15108;;Loubaresse;LOUBARESSE;15390;15;CANTAL;1
15110;;Lugarde;LUGARDE;15190;15;CANTAL;1
15111;;Madic;MADIC;15210;15;CANTAL;1
15112;;Malbo;MALBO;15230;15;CANTAL;1
15113;;Mandailles-Saint-Julien;MANDAILLES-SAINT-JULIEN;15590;15;CANTAL;1
15114;;Marcenat;MARCENAT;15190;15;CANTAL;1
15116;;Marchastel;MARCHASTEL;15400;15;CANTAL;1
15117;;Marcolès;MARCOLES;15220;15;CANTAL;1
15118;;Marmanhac;MARMANHAC;15250;15;CANTAL;1
15119;;Massiac;MASSIAC;15500;15;CANTAL;1
15120;;Mauriac;MAURIAC;15200;15;CANTAL;1
15121;;Maurines;MAURINES;15110;15;CANTAL;1
15122;;Maurs;MAURS;15600;15;CANTAL;1
15123;;Méallet;MEALLET;15200;15;CANTAL;1
15124;;Menet;MENET;15400;15;CANTAL;1
15125;;Mentières;MENTIERES;15100;15;CANTAL;1
15126;;Molèdes;MOLEDES;15500;15;CANTAL;1
15127;;Molompize;MOLOMPIZE;15500;15;CANTAL;1
15128;La;Monselie;MONSELIE;15240;15;CANTAL;1
15129;;Montboudif;MONTBOUDIF;15190;15;CANTAL;1
15130;;Montchamp;MONTCHAMP;15100;15;CANTAL;1
15131;Le;Monteil;MONTEIL;15240;15;CANTAL;1
15132;;Montgreleix;MONTGRELEIX;15190;15;CANTAL;1
15133;;Montmurat;MONTMURAT;15600;15;CANTAL;1
15134;;Montsalvy;MONTSALVY;15120;15;CANTAL;1
15135;;Montvert;MONTVERT;15150;15;CANTAL;1
15136;;Mourjou;MOURJOU;15340;15;CANTAL;1
15137;;Moussages;MOUSSAGES;15380;15;CANTAL;1
15138;;Murat;MURAT;15300;15;CANTAL;1
15139;;Narnhac;NARNHAC;15230;15;CANTAL;1
15140;;Naucelles;NAUCELLES;15000;15;CANTAL;1
15141;;Neussargues-Moissac;NEUSSARGUES-MOISSAC;15170;15;CANTAL;1
15142;;Neuvéglise;NEUVEGLISE;15260;15;CANTAL;1
15143;;Nieudan;NIEUDAN;15150;15;CANTAL;1
15144;;Omps;OMPS;15290;15;CANTAL;1
15145;;Oradour;ORADOUR;15260;15;CANTAL;1
15146;;Pailherols;PAILHEROLS;15800;15;CANTAL;1
15147;;Parlan;PARLAN;15290;15;CANTAL;1
15148;;Paulhac;PAULHAC;15430;15;CANTAL;1
15149;;Paulhenc;PAULHENC;15230;15;CANTAL;1
15150;;Pers;PERS;15290;15;CANTAL;1
15151;;Peyrusse;PEYRUSSE;15170;15;CANTAL;1
15152;;Pierrefort;PIERREFORT;15230;15;CANTAL;1
15153;;Pleaux;PLEAUX;15700;15;CANTAL;1
15154;;Polminhac;POLMINHAC;15800;15;CANTAL;1
15155;;Pradiers;PRADIERS;15160;15;CANTAL;1
15156;;Prunet;PRUNET;15130;15;CANTAL;1
15157;;Quézac;QUEZAC;15600;15;CANTAL;1
15158;;Rageade;RAGEADE;15500;15;CANTAL;1
15159;;Raulhac;RAULHAC;15800;15;CANTAL;1
15160;;Reilhac;REILHAC;15250;15;CANTAL;1
15161;;Rézentières;REZENTIERES;15170;15;CANTAL;1
15162;;Riom-ès-Montagnes;RIOM-ES-MONTAGNES;15400;15;CANTAL;1
15163;;Roannes-Saint-Mary;ROANNES-SAINT-MARY;15220;15;CANTAL;1
15164;;Roffiac;ROFFIAC;15100;15;CANTAL;1
15165;;Rouffiac;ROUFFIAC;15150;15;CANTAL;1
15166;;Roumégoux;ROUMEGOUX;15290;15;CANTAL;1
15167;;Rouziers;ROUZIERS;15600;15;CANTAL;1
15168;;Ruynes-en-Margeride;RUYNES-EN-MARGERIDE;15320;15;CANTAL;1
15169;;Saignes;SAIGNES;15240;15;CANTAL;1
15170;;Saint-Amandin;SAINT-AMANDIN;15190;15;CANTAL;1
15171;;Sainte-Anastasie;SAINTE-ANASTASIE;15170;15;CANTAL;1
15172;;Saint-Antoine;SAINT-ANTOINE;15220;15;CANTAL;1
15173;;Saint-Bonnet-de-Condat;SAINT-BONNET-DE-CONDAT;15190;15;CANTAL;1
15174;;Saint-Bonnet-de-Salers;SAINT-BONNET-DE-SALERS;15140;15;CANTAL;1
15175;;Saint-Cernin;SAINT-CERNIN;15310;15;CANTAL;1
15176;;Saint-Chamant;SAINT-CHAMANT;15140;15;CANTAL;1
15178;;Saint-Cirgues-de-Jordanne;SAINT-CIRGUES-DE-JORDANNE;15590;15;CANTAL;1
15179;;Saint-Cirgues-de-Malbert;SAINT-CIRGUES-DE-MALBERT;15140;15;CANTAL;1
15180;;Saint-Clément;SAINT-CLEMENT;15800;15;CANTAL;1
15181;;Saint-Constant;SAINT-CONSTANT;15600;15;CANTAL;1
15182;;Saint-Étienne-Cantalès;SAINT-ETIENNE-CANTALES;15150;15;CANTAL;1
15183;;Saint-Étienne-de-Carlat;SAINT-ETIENNE-DE-CARLAT;15130;15;CANTAL;1
15184;;Saint-Étienne-de-Maurs;SAINT-ETIENNE-DE-MAURS;15600;15;CANTAL;1
15185;;Saint-Étienne-de-Chomeil;SAINT-ETIENNE-DE-CHOMEIL;15400;15;CANTAL;1
15186;;Sainte-Eulalie;SAINTE-EULALIE;15140;15;CANTAL;1
15187;;Saint-Flour;SAINT-FLOUR;15100;15;CANTAL;1
15188;;Saint-Georges;SAINT-GEORGES;15100;15;CANTAL;1
15189;;Saint-Gérons;SAINT-GERONS;15150;15;CANTAL;1
15190;;Saint-Hippolyte;SAINT-HIPPOLYTE;15400;15;CANTAL;1
15191;;Saint-Illide;SAINT-ILLIDE;15310;15;CANTAL;1
15192;;Saint-Jacques-des-Blats;SAINT-JACQUES-DES-BLATS;15580;15;CANTAL;1
15194;;Saint-Julien-de-Toursac;SAINT-JULIEN-DE-TOURSAC;15600;15;CANTAL;1
15195;;Saint-Just;SAINT-JUST;15390;15;CANTAL;1
15196;;Saint-Mamet-la-Salvetat;SAINT-MAMET-LA-SALVETAT;15220;15;CANTAL;1
15197;;Saint-Marc;SAINT-MARC;15390;15;CANTAL;1
15198;;Sainte-Marie;SAINTE-MARIE;15230;15;CANTAL;1
15199;;Saint-Martial;SAINT-MARTIAL;15110;15;CANTAL;1
15200;;Saint-Martin-Cantalès;SAINT-MARTIN-CANTALES;15140;15;CANTAL;1
15201;;Saint-Martin-sous-Vigouroux;SAINT-MARTIN-SOUS-VIGOUROUX;15230;15;CANTAL;1
15202;;Saint-Martin-Valmeroux;SAINT-MARTIN-VALMEROUX;15140;15;CANTAL;1
15203;;Saint-Mary-le-Plain;SAINT-MARY-LE-PLAIN;15500;15;CANTAL;1
15204;;Saint-Paul-des-Landes;SAINT-PAUL-DES-LANDES;15250;15;CANTAL;1
15205;;Saint-Paul-de-Salers;SAINT-PAUL-DE-SALERS;15140;15;CANTAL;1
15206;;Saint-Pierre;SAINT-PIERRE;15350;15;CANTAL;1
15207;;Saint-Poncy;SAINT-PONCY;15500;15;CANTAL;1
15208;;Saint-Projet-de-Salers;SAINT-PROJET-DE-SALERS;15140;15;CANTAL;1
15209;;Saint-Rémy-de-Chaudes-Aigues;SAINT-REMY-DE-CHAUDES-AIGUES;15110;15;CANTAL;1
15211;;Saint-Santin-Cantalès;SAINT-SANTIN-CANTALES;15150;15;CANTAL;1
15212;;Saint-Santin-de-Maurs;SAINT-SANTIN-DE-MAURS;15600;15;CANTAL;1
15213;;Saint-Saturnin;SAINT-SATURNIN;15190;15;CANTAL;1
15214;;Saint-Saury;SAINT-SAURY;15290;15;CANTAL;1
15215;;Saint-Simon;SAINT-SIMON;15130;15;CANTAL;1
15216;;Saint-Urcize;SAINT-URCIZE;15110;15;CANTAL;1
15217;;Saint-Victor;SAINT-VICTOR;15150;15;CANTAL;1
15218;;Saint-Vincent-de-Salers;SAINT-VINCENT-DE-SALERS;15380;15;CANTAL;1
15219;;Salers;SALERS;15140;15;CANTAL;1
15220;;Salins;SALINS;15200;15;CANTAL;1
15221;;Sansac-de-Marmiesse;SANSAC-DE-MARMIESSE;15130;15;CANTAL;1
15222;;Sansac-Veinazès;SANSAC-VEINAZES;15120;15;CANTAL;1
15223;;Sauvat;SAUVAT;15240;15;CANTAL;1
15224;La;Ségalassière;SEGALASSIERE;15290;15;CANTAL;1
15225;;Ségur-les-Villas;SEGUR-LES-VILLAS;15300;15;CANTAL;1
15226;;Sénezergues;SENEZERGUES;15340;15;CANTAL;1
15227;;Sériers;SERIERS;15100;15;CANTAL;1
15228;;Siran;SIRAN;15150;15;CANTAL;1
15229;;Soulages;SOULAGES;15100;15;CANTAL;1
15230;;Sourniac;SOURNIAC;15200;15;CANTAL;1
15231;;Talizat;TALIZAT;15170;15;CANTAL;1
15232;;Tanavelle;TANAVELLE;15100;15;CANTAL;1
15233;;Teissières-de-Cornet;TEISSIERES-DE-CORNET;15250;15;CANTAL;1
15234;;Teissières-lès-Bouliès;TEISSIERES-LES-BOULIES;15130;15;CANTAL;1
15235;Les;Ternes;TERNES;15100;15;CANTAL;1
15236;;Thiézac;THIEZAC;15450;15;CANTAL;1
15237;;Tiviers;TIVIERS;15100;15;CANTAL;1
15238;;Tournemire;TOURNEMIRE;15310;15;CANTAL;1
15240;;Trémouille;TREMOUILLE;15270;15;CANTAL;1
15241;La;Trinitat;TRINITAT;15110;15;CANTAL;1
15242;Le;Trioulou;TRIOULOU;15600;15;CANTAL;1
15243;;Trizac;TRIZAC;15400;15;CANTAL;1
15244;;Ussel;USSEL;15300;15;CANTAL;1
15245;;Vabres;VABRES;15100;15;CANTAL;1
15246;;Valette;VALETTE;15400;15;CANTAL;1
15247;;Valjouze;VALJOUZE;15170;15;CANTAL;1
15248;;Valuéjols;VALUEJOLS;15300;15;CANTAL;1
15249;Le;Vaulmier;VAULMIER;15380;15;CANTAL;1
15250;;Vebret;VEBRET;15240;15;CANTAL;1
15251;;Védrines-Saint-Loup;VEDRINES-SAINT-LOUP;15100;15;CANTAL;1
15252;;Velzic;VELZIC;15590;15;CANTAL;1
15253;;Vernols;VERNOLS;15160;15;CANTAL;1
15254;;Veyrières;VEYRIERES;15350;15;CANTAL;1
15255;;Vézac;VEZAC;15130;15;CANTAL;1
15256;;Vèze;VEZE;15160;15;CANTAL;1
15257;;Vezels-Roussy;VEZELS-ROUSSY;15130;15;CANTAL;1
15258;;Vic-sur-Cère;VIC-SUR-CERE;15800;15;CANTAL;1
15259;;Vieillespesse;VIEILLESPESSE;15500;15;CANTAL;1
15260;;Vieillevie;VIEILLEVIE;15120;15;CANTAL;1
15261;Le;Vigean;VIGEAN;15200;15;CANTAL;1
15262;;Villedieu;VILLEDIEU;15100;15;CANTAL;1
15263;;Virargues;VIRARGUES;15300;15;CANTAL;1
15264;;Vitrac;VITRAC;15220;15;CANTAL;1
15265;;Ydes;YDES;15210;15;CANTAL;1
15266;;Yolet;YOLET;15130;15;CANTAL;1
15267;;Ytrac;YTRAC;15000;15;CANTAL;1
15268;Le;Rouget;ROUGET;15290;15;CANTAL;1
15269;;Besse;BESSE;15140;15;CANTAL;1
16001;;Abzac;ABZAC;16500;16;CHARENTE;1
16002;Les;Adjots;ADJOTS;16700;16;CHARENTE;1
16003;;Agris;AGRIS;16110;16;CHARENTE;1
16004;;Aignes-et-Puypéroux;AIGNES-ET-PUYPEROUX;16190;16;CHARENTE;1
16005;;Aigre;AIGRE;16140;16;CHARENTE;1
16007;;Alloue;ALLOUE;16490;16;CHARENTE;1
16008;;Ambérac;AMBERAC;16140;16;CHARENTE;1
16009;;Ambernac;AMBERNAC;16490;16;CHARENTE;1
16010;;Ambleville;AMBLEVILLE;16300;16;CHARENTE;1
16011;;Anais;ANAIS;16560;16;CHARENTE;1
16012;;Angeac-Champagne;ANGEAC-CHAMPAGNE;16130;16;CHARENTE;1
16013;;Angeac-Charente;ANGEAC-CHARENTE;16120;16;CHARENTE;1
16014;;Angeduc;ANGEDUC;16300;16;CHARENTE;1
16015;;Angoulême;ANGOULEME;16000;16;CHARENTE;1
16016;;Ansac-sur-Vienne;ANSAC-SUR-VIENNE;16500;16;CHARENTE;1
16017;;Anville;ANVILLE;16170;16;CHARENTE;1
16018;;Ars;ARS;16130;16;CHARENTE;1
16019;;Asnières-sur-Nouère;ASNIERES-SUR-NOUERE;16290;16;CHARENTE;1
16020;;Aubeterre-sur-Dronne;AUBETERRE-SUR-DRONNE;16390;16;CHARENTE;1
16021;;Aubeville;AUBEVILLE;16250;16;CHARENTE;1
16023;;Aunac;AUNAC;16460;16;CHARENTE;1
16024;;Aussac-Vadalle;AUSSAC-VADALLE;16560;16;CHARENTE;1
16025;;Baignes-Sainte-Radegonde;BAIGNES-SAINTE-RADEGONDE;16360;16;CHARENTE;1
16026;;Balzac;BALZAC;16430;16;CHARENTE;1
16027;;Barbezières;BARBEZIERES;16140;16;CHARENTE;1
16028;;Barbezieux-Saint-Hilaire;BARBEZIEUX-SAINT-HILAIRE;16300;16;CHARENTE;1
16029;;Bardenac;BARDENAC;16210;16;CHARENTE;1
16030;;Barret;BARRET;16300;16;CHARENTE;1
16031;;Barro;BARRO;16700;16;CHARENTE;1
16032;;Bassac;BASSAC;16120;16;CHARENTE;1
16033;;Bayers;BAYERS;16460;16;CHARENTE;1
16034;;Bazac;BAZAC;16210;16;CHARENTE;1
16035;;Beaulieu-sur-Sonnette;BEAULIEU-SUR-SONNETTE;16450;16;CHARENTE;1
16036;;Bécheresse;BECHERESSE;16250;16;CHARENTE;1
16037;;Bellon;BELLON;16210;16;CHARENTE;1
16038;;Benest;BENEST;16350;16;CHARENTE;1
16039;;Bernac;BERNAC;16700;16;CHARENTE;1
16040;;Berneuil;BERNEUIL;16480;16;CHARENTE;1
16041;;Bessac;BESSAC;16250;16;CHARENTE;1
16042;;Bessé;BESSE;16140;16;CHARENTE;1
16043;;Bignac;BIGNAC;16170;16;CHARENTE;1
16044;;Bioussac;BIOUSSAC;16700;16;CHARENTE;1
16045;;Birac;BIRAC;16120;16;CHARENTE;1
16046;;Blanzac-Porcheresse;BLANZAC-PORCHERESSE;16250;16;CHARENTE;1
16047;;Blanzaguet-Saint-Cybard;BLANZAGUET-SAINT-CYBARD;16320;16;CHARENTE;1
16048;;Boisbreteau;BOISBRETEAU;16480;16;CHARENTE;1
16049;;Bonnes;BONNES;16390;16;CHARENTE;1
16050;;Bonneuil;BONNEUIL;16120;16;CHARENTE;1
16051;;Bonneville;BONNEVILLE;16170;16;CHARENTE;1
16052;;(CANTON;BORS;16190;16;CHARENTE;1
16053;;(CANTON;BORS;16360;16;CHARENTE;1
16054;Le;Bouchage;BOUCHAGE;16350;16;CHARENTE;1
16055;;Bouëx;BOUEX;16410;16;CHARENTE;1
16056;;Bourg-Charente;BOURG-CHARENTE;16200;16;CHARENTE;1
16057;;Bouteville;BOUTEVILLE;16120;16;CHARENTE;1
16058;;Boutiers-Saint-Trojan;BOUTIERS-SAINT-TROJAN;16100;16;CHARENTE;1
16059;;Brettes;BRETTES;16240;16;CHARENTE;1
16060;;Bréville;BREVILLE;16370;16;CHARENTE;1
16061;;Brie;BRIE;16590;16;CHARENTE;1
16062;;Brie-sous-Barbezieux;BRIE-SOUS-BARBEZIEUX;16300;16;CHARENTE;1
16063;;Brie-sous-Chalais;BRIE-SOUS-CHALAIS;16210;16;CHARENTE;1
16064;;Brigueuil;BRIGUEUIL;16420;16;CHARENTE;1
16065;;Brillac;BRILLAC;16500;16;CHARENTE;1
16066;;Brossac;BROSSAC;16480;16;CHARENTE;1
16067;;Bunzac;BUNZAC;16110;16;CHARENTE;1
16068;;Cellefrouin;CELLEFROUIN;16260;16;CHARENTE;1
16069;;Cellettes;CELLETTES;16230;16;CHARENTE;1
16070;;Chabanais;CHABANAIS;16150;16;CHARENTE;1
16071;;Chabrac;CHABRAC;16150;16;CHARENTE;1
16072;;Chadurie;CHADURIE;16250;16;CHARENTE;1
16073;;Chalais;CHALAIS;16210;16;CHARENTE;1
16074;;Challignac;CHALLIGNAC;16300;16;CHARENTE;1
16075;;Champagne-Vigny;CHAMPAGNE-VIGNY;16250;16;CHARENTE;1
16076;;Champagne-Mouton;CHAMPAGNE-MOUTON;16350;16;CHARENTE;1
16077;;Champmillon;CHAMPMILLON;16290;16;CHARENTE;1
16078;;Champniers;CHAMPNIERS;16430;16;CHARENTE;1
16079;;Chantillac;CHANTILLAC;16360;16;CHARENTE;1
16081;La;Chapelle;CHAPELLE;16140;16;CHARENTE;1
16082;;Charmant;CHARMANT;16320;16;CHARENTE;1
16083;;Charmé;CHARME;16140;16;CHARENTE;1
16084;;Charras;CHARRAS;16380;16;CHARENTE;1
16085;;Chasseneuil-sur-Bonnieure;CHASSENEUIL-SUR-BONNIEURE;16260;16;CHARENTE;1
16086;;Chassenon;CHASSENON;16150;16;CHARENTE;1
16087;;Chassiecq;CHASSIECQ;16350;16;CHARENTE;1
16088;;Chassors;CHASSORS;16200;16;CHARENTE;1
16089;;Châteaubernard;CHATEAUBERNARD;16100;16;CHARENTE;1
16090;;Châteauneuf-sur-Charente;CHATEAUNEUF-SUR-CHARENTE;16120;16;CHARENTE;1
16091;;Châtignac;CHATIGNAC;16480;16;CHARENTE;1
16092;;Chavenat;CHAVENAT;16320;16;CHARENTE;1
16093;;Chazelles;CHAZELLES;16380;16;CHARENTE;1
16094;;Chenommet;CHENOMMET;16460;16;CHARENTE;1
16095;;Chenon;CHENON;16460;16;CHARENTE;1
16096;;Cherves-Châtelars;CHERVES-CHATELARS;16310;16;CHARENTE;1
16097;;Cherves-Richemont;CHERVES-RICHEMONT;16370;16;CHARENTE;1
16098;La;Chèvrerie;CHEVRERIE;16240;16;CHARENTE;1
16099;;Chillac;CHILLAC;16480;16;CHARENTE;1
16100;;Chirac;CHIRAC;16150;16;CHARENTE;1
16101;;Claix;CLAIX;16440;16;CHARENTE;1
16102;;Cognac;COGNAC;16100;16;CHARENTE;1
16103;;Combiers;COMBIERS;16320;16;CHARENTE;1
16104;;Condac;CONDAC;16700;16;CHARENTE;1
16105;;Condéon;CONDEON;16360;16;CHARENTE;1
16106;;Confolens;CONFOLENS;16500;16;CHARENTE;1
16107;;Coulgens;COULGENS;16560;16;CHARENTE;1
16108;;Coulonges;COULONGES;16330;16;CHARENTE;1
16109;;Courbillac;COURBILLAC;16200;16;CHARENTE;1
16110;;Courcôme;COURCOME;16240;16;CHARENTE;1
16111;;Courgeac;COURGEAC;16190;16;CHARENTE;1
16112;;Courlac;COURLAC;16210;16;CHARENTE;1
16113;La;Couronne;COURONNE;16400;16;CHARENTE;1
16114;;Couture;COUTURE;16460;16;CHARENTE;1
16115;;Cressac-Saint-Genis;CRESSAC-SAINT-GENIS;16250;16;CHARENTE;1
16116;;Criteuil-la-Magdeleine;CRITEUIL-LA-MAGDELEINE;16300;16;CHARENTE;1
16117;;Curac;CURAC;16210;16;CHARENTE;1
16118;;Deviat;DEVIAT;16190;16;CHARENTE;1
16119;;Dignac;DIGNAC;16410;16;CHARENTE;1
16120;;Dirac;DIRAC;16410;16;CHARENTE;1
16121;;Douzat;DOUZAT;16290;16;CHARENTE;1
16122;;Ébréon;EBREON;16140;16;CHARENTE;1
16123;;Échallat;ECHALLAT;16170;16;CHARENTE;1
16124;;Écuras;ECURAS;16220;16;CHARENTE;1
16125;;Édon;EDON;16320;16;CHARENTE;1
16127;;Empuré;EMPURE;16240;16;CHARENTE;1
16128;;Épenède;EPENEDE;16490;16;CHARENTE;1
16129;;Éraville;ERAVILLE;16120;16;CHARENTE;1
16130;Les;Essards;ESSARDS;16210;16;CHARENTE;1
16131;;Esse;ESSE;16500;16;CHARENTE;1
16132;;Étagnac;ETAGNAC;16150;16;CHARENTE;1
16133;;Étriac;ETRIAC;16250;16;CHARENTE;1
16134;;Exideuil;EXIDEUIL;16150;16;CHARENTE;1
16135;;Eymouthiers;EYMOUTHIERS;16220;16;CHARENTE;1
16136;La;Faye;FAYE;16700;16;CHARENTE;1
16137;;Feuillade;FEUILLADE;16380;16;CHARENTE;1
16138;;Fléac;FLEAC;16730;16;CHARENTE;1
16139;;Fleurac;FLEURAC;16200;16;CHARENTE;1
16140;;Fontclaireau;FONTCLAIREAU;16230;16;CHARENTE;1
16141;;Fontenille;FONTENILLE;16230;16;CHARENTE;1
16142;La;Forêt-de-Tessé;FORET-DE-TESSE;16240;16;CHARENTE;1
16143;;Fouquebrune;FOUQUEBRUNE;16410;16;CHARENTE;1
16144;;Fouqueure;FOUQUEURE;16140;16;CHARENTE;1
16145;;Foussignac;FOUSSIGNAC;16200;16;CHARENTE;1
16146;;Garat;GARAT;16410;16;CHARENTE;1
16147;;Gardes-le-Pontaroux;GARDES-LE-PONTAROUX;16320;16;CHARENTE;1
16148;;Genac;GENAC;16170;16;CHARENTE;1
16149;;Genouillac;GENOUILLAC;16270;16;CHARENTE;1
16150;;Gensac-la-Pallue;GENSAC-LA-PALLUE;16130;16;CHARENTE;1
16151;;Genté;GENTE;16130;16;CHARENTE;1
16152;;Gimeux;GIMEUX;16130;16;CHARENTE;1
16153;;Gondeville;GONDEVILLE;16200;16;CHARENTE;1
16154;;Gond-Pontouvre;GOND-PONTOUVRE;16160;16;CHARENTE;1
16155;Les;Gours;GOURS;16140;16;CHARENTE;1
16156;;Gourville;GOURVILLE;16170;16;CHARENTE;1
16157;Le;Grand-Madieu;GRAND-MADIEU;16450;16;CHARENTE;1
16158;;Grassac;GRASSAC;16380;16;CHARENTE;1
16160;;Guimps;GUIMPS;16300;16;CHARENTE;1
16161;;Guizengeard;GUIZENGEARD;16480;16;CHARENTE;1
16162;;Gurat;GURAT;16320;16;CHARENTE;1
16163;;Hiersac;HIERSAC;16290;16;CHARENTE;1
16164;;Hiesse;HIESSE;16490;16;CHARENTE;1
16165;;Houlette;HOULETTE;16200;16;CHARENTE;1
16166;L';Isle-d'Espagnac;ISLE-D'ESPAGNAC;16340;16;CHARENTE;1
16167;;Jarnac;JARNAC;16200;16;CHARENTE;1
16168;;Jauldes;JAULDES;16560;16;CHARENTE;1
16169;;Javrezac;JAVREZAC;16100;16;CHARENTE;1
16170;;Juignac;JUIGNAC;16190;16;CHARENTE;1
16171;;Juillac-le-Coq;JUILLAC-LE-COQ;16130;16;CHARENTE;1
16172;;Juillaguet;JUILLAGUET;16320;16;CHARENTE;1
16173;;Juillé;JUILLE;16230;16;CHARENTE;1
16174;;Julienne;JULIENNE;16200;16;CHARENTE;1
16175;;Jurignac;JURIGNAC;16250;16;CHARENTE;1
16176;;Lachaise;LACHAISE;16300;16;CHARENTE;1
16177;;Ladiville;LADIVILLE;16120;16;CHARENTE;1
16178;;Lagarde-sur-le-Né;LAGARDE-SUR-LE-NE;16300;16;CHARENTE;1
16179;;Lamérac;LAMERAC;16300;16;CHARENTE;1
16180;;Laprade;LAPRADE;16390;16;CHARENTE;1
16181;;Lessac;LESSAC;16500;16;CHARENTE;1
16182;;Lesterps;LESTERPS;16420;16;CHARENTE;1
16183;;Lésignac-Durand;LESIGNAC-DURAND;16310;16;CHARENTE;1
16184;;Lichères;LICHERES;16460;16;CHARENTE;1
16185;;Ligné;LIGNE;16140;16;CHARENTE;1
16186;;Lignières-Sonneville;LIGNIERES-SONNEVILLE;16130;16;CHARENTE;1
16187;;Linars;LINARS;16730;16;CHARENTE;1
16188;Le;Lindois;LINDOIS;16310;16;CHARENTE;1
16189;;Londigny;LONDIGNY;16700;16;CHARENTE;1
16190;;Longré;LONGRE;16240;16;CHARENTE;1
16191;;Lonnes;LONNES;16230;16;CHARENTE;1
16192;;Roumazières-Loubert;ROUMAZIERES-LOUBERT;16270;16;CHARENTE;1
16193;;Louzac-Saint-André;LOUZAC-SAINT-ANDRE;16100;16;CHARENTE;1
16194;;Lupsault;LUPSAULT;16140;16;CHARENTE;1
16195;;Lussac;LUSSAC;16450;16;CHARENTE;1
16196;;Luxé;LUXE;16230;16;CHARENTE;1
16197;La;Magdeleine;MAGDELEINE;16240;16;CHARENTE;1
16198;;Magnac-Lavalette-Villars;MAGNAC-LAVALETTE-VILLARS;16320;16;CHARENTE;1
16199;;Magnac-sur-Touvre;MAGNAC-SUR-TOUVRE;16600;16;CHARENTE;1
16200;;Maine-de-Boixe;MAINE-DE-BOIXE;16230;16;CHARENTE;1
16201;;Mainfonds;MAINFONDS;16250;16;CHARENTE;1
16202;;Mainxe;MAINXE;16200;16;CHARENTE;1
16203;;Mainzac;MAINZAC;16380;16;CHARENTE;1
16204;;Malaville;MALAVILLE;16120;16;CHARENTE;1
16205;;Manot;MANOT;16500;16;CHARENTE;1
16206;;Mansle;MANSLE;16230;16;CHARENTE;1
16207;;Marcillac-Lanville;MARCILLAC-LANVILLE;16140;16;CHARENTE;1
16208;;Mareuil;MAREUIL;16170;16;CHARENTE;1
16209;;Marillac-le-Franc;MARILLAC-LE-FRANC;16110;16;CHARENTE;1
16210;;Marsac;MARSAC;16570;16;CHARENTE;1
16211;;Marthon;MARTHON;16380;16;CHARENTE;1
16212;;Massignac;MASSIGNAC;16310;16;CHARENTE;1
16213;;Mazerolles;MAZEROLLES;16310;16;CHARENTE;1
16214;;Mazières;MAZIERES;16270;16;CHARENTE;1
16215;;Médillac;MEDILLAC;16210;16;CHARENTE;1
16216;;Mérignac;MERIGNAC;16200;16;CHARENTE;1
16217;;Merpins;MERPINS;16100;16;CHARENTE;1
16218;;Mesnac;MESNAC;16370;16;CHARENTE;1
16220;Les;Métairies;METAIRIES;16200;16;CHARENTE;1
16221;;Mons;MONS;16140;16;CHARENTE;1
16222;;Montboyer;MONTBOYER;16620;16;CHARENTE;1
16223;;Montbron;MONTBRON;16220;16;CHARENTE;1
16224;;Montchaude;MONTCHAUDE;16300;16;CHARENTE;1
16225;;Montembœuf;MONTEMBOEUF;16310;16;CHARENTE;1
16226;;Montignac-Charente;MONTIGNAC-CHARENTE;16330;16;CHARENTE;1
16227;;Montignac-le-Coq;MONTIGNAC-LE-COQ;16390;16;CHARENTE;1
16228;;Montigné;MONTIGNE;16170;16;CHARENTE;1
16229;;Montjean;MONTJEAN;16240;16;CHARENTE;1
16230;;Montmoreau-Saint-Cybard;MONTMOREAU-SAINT-CYBARD;16190;16;CHARENTE;1
16231;;Montrollet;MONTROLLET;16420;16;CHARENTE;1
16232;;Mornac;MORNAC;16600;16;CHARENTE;1
16233;;Mosnac;MOSNAC;16120;16;CHARENTE;1
16234;;Moulidars;MOULIDARS;16290;16;CHARENTE;1
16236;;Mouthiers-sur-Boëme;MOUTHIERS-SUR-BOEME;16440;16;CHARENTE;1
16237;;Mouton;MOUTON;16460;16;CHARENTE;1
16238;;Moutonneau;MOUTONNEAU;16460;16;CHARENTE;1
16239;;Mouzon;MOUZON;16310;16;CHARENTE;1
16240;;Nabinaud;NABINAUD;16390;16;CHARENTE;1
16241;;Nanclars;NANCLARS;16230;16;CHARENTE;1
16242;;Nanteuil-en-Vallée;NANTEUIL-EN-VALLEE;16700;16;CHARENTE;1
16243;;Nercillac;NERCILLAC;16200;16;CHARENTE;1
16244;;Nersac;NERSAC;16440;16;CHARENTE;1
16245;;Nieuil;NIEUIL;16270;16;CHARENTE;1
16246;;Nonac;NONAC;16190;16;CHARENTE;1
16247;;Nonaville;NONAVILLE;16120;16;CHARENTE;1
16248;;Oradour;ORADOUR;16140;16;CHARENTE;1
16249;;Oradour-Fanais;ORADOUR-FANAIS;16500;16;CHARENTE;1
16250;;Orgedeuil;ORGEDEUIL;16220;16;CHARENTE;1
16251;;Oriolles;ORIOLLES;16480;16;CHARENTE;1
16252;;Orival;ORIVAL;16210;16;CHARENTE;1
16253;;Paizay-Naudouin-Embourie;PAIZAY-NAUDOUIN-EMBOURIE;16240;16;CHARENTE;1
16254;;Palluaud;PALLUAUD;16390;16;CHARENTE;1
16255;;Parzac;PARZAC;16450;16;CHARENTE;1
16256;;Passirac;PASSIRAC;16480;16;CHARENTE;1
16257;;Péreuil;PEREUIL;16250;16;CHARENTE;1
16258;;Pérignac;PERIGNAC;16250;16;CHARENTE;1
16259;La;Péruse;PERUSE;16270;16;CHARENTE;1
16260;;Pillac;PILLAC;16390;16;CHARENTE;1
16261;Les;Pins;PINS;16260;16;CHARENTE;1
16262;;Plaizac;PLAIZAC;16170;16;CHARENTE;1
16263;;Plassac-Rouffiac;PLASSAC-ROUFFIAC;16250;16;CHARENTE;1
16264;;Pleuville;PLEUVILLE;16490;16;CHARENTE;1
16267;;Poullignac;POULLIGNAC;16190;16;CHARENTE;1
16268;;Poursac;POURSAC;16700;16;CHARENTE;1
16269;;Pranzac;PRANZAC;16110;16;CHARENTE;1
16270;;Pressignac;PRESSIGNAC;16150;16;CHARENTE;1
16271;;Puymoyen;PUYMOYEN;16400;16;CHARENTE;1
16272;;Puyréaux;PUYREAUX;16230;16;CHARENTE;1
16273;;Raix;RAIX;16240;16;CHARENTE;1
16274;;Rancogne;RANCOGNE;16110;16;CHARENTE;1
16275;;Ranville-Breuillaud;RANVILLE-BREUILLAUD;16140;16;CHARENTE;1
16276;;Reignac;REIGNAC;16360;16;CHARENTE;1
16277;;Réparsac;REPARSAC;16200;16;CHARENTE;1
16279;;Rioux-Martin;RIOUX-MARTIN;16210;16;CHARENTE;1
16280;;Rivières;RIVIERES;16110;16;CHARENTE;1
16281;La;Rochefoucauld;ROCHEFOUCAULD;16110;16;CHARENTE;1
16282;La;Rochette;ROCHETTE;16110;16;CHARENTE;1
16283;;Ronsenac;RONSENAC;16320;16;CHARENTE;1
16284;;Rouffiac;ROUFFIAC;16210;16;CHARENTE;1
16285;;Rougnac;ROUGNAC;16320;16;CHARENTE;1
16286;;Rouillac;ROUILLAC;16170;16;CHARENTE;1
16287;;Roullet-Saint-Estèphe;ROULLET-SAINT-ESTEPHE;16440;16;CHARENTE;1
16289;;Roussines;ROUSSINES;16310;16;CHARENTE;1
16290;;Rouzède;ROUZEDE;16220;16;CHARENTE;1
16291;;Ruelle-sur-Touvre;RUELLE-SUR-TOUVRE;16600;16;CHARENTE;1
16292;;Ruffec;RUFFEC;16700;16;CHARENTE;1
16293;;Saint-Adjutory;SAINT-ADJUTORY;16310;16;CHARENTE;1
16294;;Saint-Amant;SAINT-AMANT;16190;16;CHARENTE;1
16295;;Saint-Amant-de-Boixe;SAINT-AMANT-DE-BOIXE;16330;16;CHARENTE;1
16296;;Saint-Amant-de-Bonnieure;SAINT-AMANT-DE-BONNIEURE;16230;16;CHARENTE;1
16297;;Graves-Saint-Amant;GRAVES-SAINT-AMANT;16120;16;CHARENTE;1
16298;;Saint-Amant-de-Nouère;SAINT-AMANT-DE-NOUERE;16170;16;CHARENTE;1
16300;;Saint-Angeau;SAINT-ANGEAU;16230;16;CHARENTE;1
16301;;Saint-Aulais-la-Chapelle;SAINT-AULAIS-LA-CHAPELLE;16300;16;CHARENTE;1
16302;;Saint-Avit;SAINT-AVIT;16210;16;CHARENTE;1
16303;;Saint-Bonnet;SAINT-BONNET;16300;16;CHARENTE;1
16304;;Saint-Brice;SAINT-BRICE;16100;16;CHARENTE;1
16306;;Saint-Christophe;SAINT-CHRISTOPHE;16420;16;CHARENTE;1
16307;;Saint-Ciers-sur-Bonnieure;SAINT-CIERS-SUR-BONNIEURE;16230;16;CHARENTE;1
16308;;Saint-Claud;SAINT-CLAUD;16450;16;CHARENTE;1
16309;;Sainte-Colombe;SAINTE-COLOMBE;16230;16;CHARENTE;1
16310;;Saint-Coutant;SAINT-COUTANT;16350;16;CHARENTE;1
16312;;Saint-Cybardeaux;SAINT-CYBARDEAUX;16170;16;CHARENTE;1
16314;;Saint-Eutrope;SAINT-EUTROPE;16190;16;CHARENTE;1
16315;;Saint-Félix;SAINT-FELIX;16480;16;CHARENTE;1
16316;;Saint-Fort-sur-le-Né;SAINT-FORT-SUR-LE-NE;16130;16;CHARENTE;1
16317;;Saint-Fraigne;SAINT-FRAIGNE;16140;16;CHARENTE;1
16318;;Saint-Front;SAINT-FRONT;16460;16;CHARENTE;1
16320;;Saint-Genis-d'Hiersac;SAINT-GENIS-D'HIERSAC;16570;16;CHARENTE;1
16321;;Saint-Georges;SAINT-GEORGES;16700;16;CHARENTE;1
16322;;Saint-Germain-de-Confolens;SAINT-GERMAIN-DE-CONFOLENS;16500;16;CHARENTE;1
16323;;Saint-Germain-de-Montbron;SAINT-GERMAIN-DE-MONTBRON;16380;16;CHARENTE;1
16325;;Saint-Gourson;SAINT-GOURSON;16700;16;CHARENTE;1
16326;;Saint-Groux;SAINT-GROUX;16230;16;CHARENTE;1
16328;;Saint-Laurent-de-Belzagot;SAINT-LAURENT-DE-BELZAGOT;16190;16;CHARENTE;1
16329;;Saint-Laurent-de-Céris;SAINT-LAURENT-DE-CERIS;16450;16;CHARENTE;1
16330;;Saint-Laurent-de-Cognac;SAINT-LAURENT-DE-COGNAC;16100;16;CHARENTE;1
16331;;Saint-Laurent-des-Combes;SAINT-LAURENT-DES-COMBES;16480;16;CHARENTE;1
16332;;Saint-Léger;SAINT-LEGER;16250;16;CHARENTE;1
16334;;Saint-Martial;SAINT-MARTIAL;16190;16;CHARENTE;1
16335;;Saint-Martin-du-Clocher;SAINT-MARTIN-DU-CLOCHER;16700;16;CHARENTE;1
16336;;Saint-Mary;SAINT-MARY;16260;16;CHARENTE;1
16337;;Saint-Maurice-des-Lions;SAINT-MAURICE-DES-LIONS;16500;16;CHARENTE;1
16338;;Saint-Médard;SAINT-MEDARD;16300;16;CHARENTE;1
16339;;Auge-Saint-Médard;AUGE-SAINT-MEDARD;16170;16;CHARENTE;1
16340;;Saint-Même-les-Carrières;SAINT-MEME-LES-CARRIERES;16720;16;CHARENTE;1
16341;;Saint-Michel;SAINT-MICHEL;16470;16;CHARENTE;1
16342;;Saint-Palais-du-Né;SAINT-PALAIS-DU-NE;16300;16;CHARENTE;1
16343;;Saint-Preuil;SAINT-PREUIL;16130;16;CHARENTE;1
16344;;Saint-Projet-Saint-Constant;SAINT-PROJET-SAINT-CONSTANT;16110;16;CHARENTE;1
16345;;Saint-Quentin-sur-Charente;SAINT-QUENTIN-SUR-CHARENTE;16150;16;CHARENTE;1
16346;;Saint-Quentin-de-Chalais;SAINT-QUENTIN-DE-CHALAIS;16210;16;CHARENTE;1
16347;;Saint-Romain;SAINT-ROMAIN;16210;16;CHARENTE;1
16348;;Saint-Saturnin;SAINT-SATURNIN;16290;16;CHARENTE;1
16349;;Sainte-Sévère;SAINTE-SEVERE;16200;16;CHARENTE;1
16350;;Saint-Séverin;SAINT-SEVERIN;16390;16;CHARENTE;1
16351;;Saint-Simeux;SAINT-SIMEUX;16120;16;CHARENTE;1
16352;;Saint-Simon;SAINT-SIMON;16120;16;CHARENTE;1
16353;;Saint-Sornin;SAINT-SORNIN;16220;16;CHARENTE;1
16354;;Sainte-Souline;SAINTE-SOULINE;16480;16;CHARENTE;1
16355;;Saint-Sulpice-de-Cognac;SAINT-SULPICE-DE-COGNAC;16370;16;CHARENTE;1
16356;;Saint-Sulpice-de-Ruffec;SAINT-SULPICE-DE-RUFFEC;16460;16;CHARENTE;1
16357;;Saint-Vallier;SAINT-VALLIER;16480;16;CHARENTE;1
16358;;Saint-Yrieix-sur-Charente;SAINT-YRIEIX-SUR-CHARENTE;16710;16;CHARENTE;1
16359;;Salles-d'Angles;SALLES-D'ANGLES;16130;16;CHARENTE;1
16360;;Salles-de-Barbezieux;SALLES-DE-BARBEZIEUX;16300;16;CHARENTE;1
16361;;Salles-de-Villefagnan;SALLES-DE-VILLEFAGNAN;16700;16;CHARENTE;1
16362;;Salles-Lavalette;SALLES-LAVALETTE;16190;16;CHARENTE;1
16363;;Saulgond;SAULGOND;16420;16;CHARENTE;1
16364;;Sauvagnac;SAUVAGNAC;16310;16;CHARENTE;1
16365;;Sauvignac;SAUVIGNAC;16480;16;CHARENTE;1
16366;;Segonzac;SEGONZAC;16130;16;CHARENTE;1
16368;;Sers;SERS;16410;16;CHARENTE;1
16369;;Sigogne;SIGOGNE;16200;16;CHARENTE;1
16370;;Sireuil;SIREUIL;16440;16;CHARENTE;1
16371;;Sonneville;SONNEVILLE;16170;16;CHARENTE;1
16372;;Souffrignac;SOUFFRIGNAC;16380;16;CHARENTE;1
16373;;Souvigné;SOUVIGNE;16240;16;CHARENTE;1
16374;;Soyaux;SOYAUX;16800;16;CHARENTE;1
16375;;Suaux;SUAUX;16260;16;CHARENTE;1
16376;;Suris;SURIS;16270;16;CHARENTE;1
16377;La;Tâche;TACHE;16260;16;CHARENTE;1
16378;;Taizé-Aizie;TAIZE-AIZIE;16700;16;CHARENTE;1
16379;;Taponnat-Fleurignac;TAPONNAT-FLEURIGNAC;16110;16;CHARENTE;1
16380;Le;Tâtre;TATRE;16360;16;CHARENTE;1
16381;;Theil-Rabier;THEIL-RABIER;16240;16;CHARENTE;1
16382;;Torsac;TORSAC;16410;16;CHARENTE;1
16383;;Tourriers;TOURRIERS;16560;16;CHARENTE;1
16384;;Touvérac;TOUVERAC;16360;16;CHARENTE;1
16385;;Touvre;TOUVRE;16600;16;CHARENTE;1
16386;;Touzac;TOUZAC;16120;16;CHARENTE;1
16387;;Triac-Lautrait;TRIAC-LAUTRAIT;16200;16;CHARENTE;1
16388;;Trois-Palis;TROIS-PALIS;16730;16;CHARENTE;1
16389;;Turgon;TURGON;16350;16;CHARENTE;1
16390;;Tusson;TUSSON;16140;16;CHARENTE;1
16391;;Tuzie;TUZIE;16700;16;CHARENTE;1
16392;;Valence;VALENCE;16460;16;CHARENTE;1
16393;;Vars;VARS;16330;16;CHARENTE;1
16394;;Vaux-Lavalette;VAUX-LAVALETTE;16320;16;CHARENTE;1
16395;;Vaux-Rouillac;VAUX-ROUILLAC;16170;16;CHARENTE;1
16396;;Ventouse;VENTOUSE;16460;16;CHARENTE;1
16397;;Verdille;VERDILLE;16140;16;CHARENTE;1
16398;;Verneuil;VERNEUIL;16310;16;CHARENTE;1
16399;;Verrières;VERRIERES;16130;16;CHARENTE;1
16400;;Verteuil-sur-Charente;VERTEUIL-SUR-CHARENTE;16510;16;CHARENTE;1
16401;;Vervant;VERVANT;16330;16;CHARENTE;1
16402;;Vibrac;VIBRAC;16120;16;CHARENTE;1
16403;Le;Vieux-Cérier;VIEUX-CERIER;16350;16;CHARENTE;1
16404;;Vieux-Ruffec;VIEUX-RUFFEC;16350;16;CHARENTE;1
16405;;Vignolles;VIGNOLLES;16300;16;CHARENTE;1
16406;;Vilhonneur;VILHONNEUR;16220;16;CHARENTE;1
16408;;Villebois-Lavalette;VILLEBOIS-LAVALETTE;16320;16;CHARENTE;1
16409;;Villefagnan;VILLEFAGNAN;16240;16;CHARENTE;1
16410;;Villegats;VILLEGATS;16700;16;CHARENTE;1
16411;;Villejésus;VILLEJESUS;16140;16;CHARENTE;1
16412;;Villejoubert;VILLEJOUBERT;16560;16;CHARENTE;1
16413;;Villiers-le-Roux;VILLIERS-LE-ROUX;16240;16;CHARENTE;1
16414;;Villognon;VILLOGNON;16230;16;CHARENTE;1
16415;;Vindelle;VINDELLE;16430;16;CHARENTE;1
16416;;Vitrac-Saint-Vincent;VITRAC-SAINT-VINCENT;16310;16;CHARENTE;1
16417;;Viville;VIVILLE;16120;16;CHARENTE;1
16418;;Vœuil-et-Giget;VOEUIL-ET-GIGET;16400;16;CHARENTE;1
16419;;Vouharte;VOUHARTE;16330;16;CHARENTE;1
16420;;Voulgézac;VOULGEZAC;16250;16;CHARENTE;1
16421;;Vouthon;VOUTHON;16220;16;CHARENTE;1
16422;;Vouzan;VOUZAN;16410;16;CHARENTE;1
16423;;Xambes;XAMBES;16330;16;CHARENTE;1
16424;;Yviers;YVIERS;16210;16;CHARENTE;1
16425;;Yvrac-et-Malleyrand;YVRAC-ET-MALLEYRAND;16110;16;CHARENTE;1
17002;;Agudelle;AGUDELLE;17500;17;CHARENTE MARITIME;1
17003;;Aigrefeuille-d'Aunis;AIGREFEUILLE-D'AUNIS;17290;17;CHARENTE MARITIME;1
17004;;Île-d'Aix;ILE-D'AIX;17123;17;CHARENTE MARITIME;1
17005;;Allas-Bocage;ALLAS-BOCAGE;17150;17;CHARENTE MARITIME;1
17006;;Allas-Champagne;ALLAS-CHAMPAGNE;17500;17;CHARENTE MARITIME;1
17007;;Anais;ANAIS;17540;17;CHARENTE MARITIME;1
17008;;Andilly;ANDILLY;17230;17;CHARENTE MARITIME;1
17009;;Angliers;ANGLIERS;17540;17;CHARENTE MARITIME;1
17010;;Angoulins;ANGOULINS;17690;17;CHARENTE MARITIME;1
17011;;Annepont;ANNEPONT;17350;17;CHARENTE MARITIME;1
17012;;Annezay;ANNEZAY;17380;17;CHARENTE MARITIME;1
17013;;Antezant-la-Chapelle;ANTEZANT-LA-CHAPELLE;17400;17;CHARENTE MARITIME;1
17015;;Arces;ARCES;17120;17;CHARENTE MARITIME;1
17016;;Archiac;ARCHIAC;17520;17;CHARENTE MARITIME;1
17017;;Archingeay;ARCHINGEAY;17380;17;CHARENTE MARITIME;1
17018;;Ardillières;ARDILLIERES;17290;17;CHARENTE MARITIME;1
17019;;Ars-en-Ré;ARS-EN-RE;17590;17;CHARENTE MARITIME;1
17020;;Arthenac;ARTHENAC;17520;17;CHARENTE MARITIME;1
17021;;Arvert;ARVERT;17530;17;CHARENTE MARITIME;1
17022;;Asnières-la-Giraud;ASNIERES-LA-GIRAUD;17400;17;CHARENTE MARITIME;1
17023;;Aujac;AUJAC;17770;17;CHARENTE MARITIME;1
17024;;Aulnay;AULNAY;17470;17;CHARENTE MARITIME;1
17025;;Aumagne;AUMAGNE;17770;17;CHARENTE MARITIME;1
17026;;Authon-Ébéon;AUTHON-EBEON;17770;17;CHARENTE MARITIME;1
17027;;Avy;AVY;17800;17;CHARENTE MARITIME;1
17028;;Aytré;AYTRE;17440;17;CHARENTE MARITIME;1
17029;;Bagnizeau;BAGNIZEAU;17160;17;CHARENTE MARITIME;1
17030;;Balanzac;BALANZAC;17600;17;CHARENTE MARITIME;1
17031;;Ballans;BALLANS;17160;17;CHARENTE MARITIME;1
17032;;Ballon;BALLON;17290;17;CHARENTE MARITIME;1
17033;La;Barde;BARDE;17360;17;CHARENTE MARITIME;1
17034;;Barzan;BARZAN;17120;17;CHARENTE MARITIME;1
17035;;Bazauges;BAZAUGES;17490;17;CHARENTE MARITIME;1
17036;;Beaugeay;BEAUGEAY;17620;17;CHARENTE MARITIME;1
17037;;Beauvais-sur-Matha;BEAUVAIS-SUR-MATHA;17490;17;CHARENTE MARITIME;1
17038;;Bedenac;BEDENAC;17210;17;CHARENTE MARITIME;1
17039;;Belluire;BELLUIRE;17800;17;CHARENTE MARITIME;1
17040;La;Benâte;BENATE;17400;17;CHARENTE MARITIME;1
17041;;Benon;BENON;17170;17;CHARENTE MARITIME;1
17042;;Bercloux;BERCLOUX;17770;17;CHARENTE MARITIME;1
17043;;Bernay-Saint-Martin;BERNAY-SAINT-MARTIN;17330;17;CHARENTE MARITIME;1
17044;;Berneuil;BERNEUIL;17460;17;CHARENTE MARITIME;1
17045;;Beurlay;BEURLAY;17250;17;CHARENTE MARITIME;1
17046;;Bignay;BIGNAY;17400;17;CHARENTE MARITIME;1
17047;;Biron;BIRON;17800;17;CHARENTE MARITIME;1
17048;;Blanzac-lès-Matha;BLANZAC-LES-MATHA;17160;17;CHARENTE MARITIME;1
17049;;Blanzay-sur-Boutonne;BLANZAY-SUR-BOUTONNE;17470;17;CHARENTE MARITIME;1
17050;;Bois;BOIS;17240;17;CHARENTE MARITIME;1
17051;Le;Bois-Plage-en-Ré;BOIS-PLAGE-EN-RE;17580;17;CHARENTE MARITIME;1
17052;;Boisredon;BOISREDON;17150;17;CHARENTE MARITIME;1
17053;;Bords;BORDS;17430;17;CHARENTE MARITIME;1
17054;;Boresse-et-Martron;BORESSE-ET-MARTRON;17270;17;CHARENTE MARITIME;1
17055;;Boscamnant;BOSCAMNANT;17360;17;CHARENTE MARITIME;1
17056;;Bougneau;BOUGNEAU;17800;17;CHARENTE MARITIME;1
17057;;Bouhet;BOUHET;17540;17;CHARENTE MARITIME;1
17058;;Bourcefranc-le-Chapus;BOURCEFRANC-LE-CHAPUS;17560;17;CHARENTE MARITIME;1
17059;;Bourgneuf;BOURGNEUF;17220;17;CHARENTE MARITIME;1
17060;;Boutenac-Touvent;BOUTENAC-TOUVENT;17120;17;CHARENTE MARITIME;1
17061;;Bran;BRAN;17210;17;CHARENTE MARITIME;1
17062;;Bresdon;BRESDON;17490;17;CHARENTE MARITIME;1
17063;;Breuil-la-Réorte;BREUIL-LA-REORTE;17700;17;CHARENTE MARITIME;1
17064;;Breuillet;BREUILLET;17920;17;CHARENTE MARITIME;1
17065;;Breuil-Magné;BREUIL-MAGNE;17870;17;CHARENTE MARITIME;1
17066;;Brie-sous-Archiac;BRIE-SOUS-ARCHIAC;17520;17;CHARENTE MARITIME;1
17067;;Brie-sous-Matha;BRIE-SOUS-MATHA;17160;17;CHARENTE MARITIME;1
17068;;Brie-sous-Mortagne;BRIE-SOUS-MORTAGNE;17120;17;CHARENTE MARITIME;1
17069;;Brives-sur-Charente;BRIVES-SUR-CHARENTE;17800;17;CHARENTE MARITIME;1
17070;;Brizambourg;BRIZAMBOURG;17770;17;CHARENTE MARITIME;1
17071;La;Brousse;BROUSSE;17160;17;CHARENTE MARITIME;1
17072;;Burie;BURIE;17770;17;CHARENTE MARITIME;1
17073;;Bussac-sur-Charente;BUSSAC-SUR-CHARENTE;17100;17;CHARENTE MARITIME;1
17074;;Bussac-Forêt;BUSSAC-FORET;17210;17;CHARENTE MARITIME;1
17075;;Cabariot;CABARIOT;17430;17;CHARENTE MARITIME;1
17076;;Celles;CELLES;17520;17;CHARENTE MARITIME;1
17077;;Cercoux;CERCOUX;17270;17;CHARENTE MARITIME;1
17078;;Chadenac;CHADENAC;17800;17;CHARENTE MARITIME;1
17079;;Chaillevette;CHAILLEVETTE;17890;17;CHARENTE MARITIME;1
17080;;Chambon;CHAMBON;17290;17;CHARENTE MARITIME;1
17081;;Chamouillac;CHAMOUILLAC;17130;17;CHARENTE MARITIME;1
17082;;Champagnac;CHAMPAGNAC;17500;17;CHARENTE MARITIME;1
17083;;Champagne;CHAMPAGNE;17620;17;CHARENTE MARITIME;1
17084;;Champagnolles;CHAMPAGNOLLES;17240;17;CHARENTE MARITIME;1
17085;;Champdolent;CHAMPDOLENT;17430;17;CHARENTE MARITIME;1
17086;;Chaniers;CHANIERS;17610;17;CHARENTE MARITIME;1
17087;;Chantemerle-sur-la-Soie;CHANTEMERLE-SUR-LA-SOIE;17380;17;CHARENTE MARITIME;1
17089;La;Chapelle-des-Pots;CHAPELLE-DES-POTS;17100;17;CHARENTE MARITIME;1
17091;;Charron;CHARRON;17230;17;CHARENTE MARITIME;1
17092;;Chartuzac;CHARTUZAC;17130;17;CHARENTE MARITIME;1
17093;Le;Château-d'Oléron;CHATEAU-D'OLERON;17480;17;CHARENTE MARITIME;1
17094;;Châtelaillon-Plage;CHATELAILLON-PLAGE;17340;17;CHARENTE MARITIME;1
17095;;Chatenet;CHATENET;17210;17;CHARENTE MARITIME;1
17096;;Chaunac;CHAUNAC;17130;17;CHARENTE MARITIME;1
17097;Le;Chay;CHAY;17600;17;CHARENTE MARITIME;1
17098;;Chenac-Saint-Seurin-d'Uzet;CHENAC-SAINT-SEURIN-D'UZET;17120;17;CHARENTE MARITIME;1
17099;;Chepniers;CHEPNIERS;17210;17;CHARENTE MARITIME;1
17100;;Chérac;CHERAC;17610;17;CHARENTE MARITIME;1
17101;;Cherbonnières;CHERBONNIERES;17470;17;CHARENTE MARITIME;1
17102;;Chermignac;CHERMIGNAC;17460;17;CHARENTE MARITIME;1
17103;;Chervettes;CHERVETTES;17380;17;CHARENTE MARITIME;1
17104;;Chevanceaux;CHEVANCEAUX;17210;17;CHARENTE MARITIME;1
17105;;Chives;CHIVES;17510;17;CHARENTE MARITIME;1
17106;;Cierzac;CIERZAC;17520;17;CHARENTE MARITIME;1
17107;;Ciré-d'Aunis;CIRE-D'AUNIS;17290;17;CHARENTE MARITIME;1
17108;;Clam;CLAM;17500;17;CHARENTE MARITIME;1
17109;;Clavette;CLAVETTE;17220;17;CHARENTE MARITIME;1
17110;;Clérac;CLERAC;17270;17;CHARENTE MARITIME;1
17111;;Clion;CLION;17240;17;CHARENTE MARITIME;1
17112;La;Clisse;CLISSE;17600;17;CHARENTE MARITIME;1
17113;La;Clotte;CLOTTE;17360;17;CHARENTE MARITIME;1
17114;;Coivert;COIVERT;17330;17;CHARENTE MARITIME;1
17115;;Colombiers;COLOMBIERS;17460;17;CHARENTE MARITIME;1
17116;;Consac;CONSAC;17150;17;CHARENTE MARITIME;1
17117;;Contré;CONTRE;17470;17;CHARENTE MARITIME;1
17118;;Corignac;CORIGNAC;17130;17;CHARENTE MARITIME;1
17119;;Corme-Écluse;CORME-ECLUSE;17600;17;CHARENTE MARITIME;1
17120;;Corme-Royal;CORME-ROYAL;17600;17;CHARENTE MARITIME;1
17121;La;Couarde-sur-Mer;COUARDE-SUR-MER;17670;17;CHARENTE MARITIME;1
17122;;Coulonges;COULONGES;17800;17;CHARENTE MARITIME;1
17124;;Courant;COURANT;17330;17;CHARENTE MARITIME;1
17125;;Courcelles;COURCELLES;17400;17;CHARENTE MARITIME;1
17126;;Courcerac;COURCERAC;17160;17;CHARENTE MARITIME;1
17127;;Courçon;COURCON;17170;17;CHARENTE MARITIME;1
17128;;Courcoury;COURCOURY;17100;17;CHARENTE MARITIME;1
17129;;Courpignac;COURPIGNAC;17130;17;CHARENTE MARITIME;1
17130;;Coux;COUX;17130;17;CHARENTE MARITIME;1
17131;;Cozes;COZES;17120;17;CHARENTE MARITIME;1
17132;;Cramchaban;CRAMCHABAN;17170;17;CHARENTE MARITIME;1
17133;;Cravans;CRAVANS;17260;17;CHARENTE MARITIME;1
17134;;Crazannes;CRAZANNES;17350;17;CHARENTE MARITIME;1
17135;;Cressé;CRESSE;17160;17;CHARENTE MARITIME;1
17136;;Croix-Chapeau;CROIX-CHAPEAU;17220;17;CHARENTE MARITIME;1
17137;La;Croix-Comtesse;CROIX-COMTESSE;17330;17;CHARENTE MARITIME;1
17138;;Dampierre-sur-Boutonne;DAMPIERRE-SUR-BOUTONNE;17470;17;CHARENTE MARITIME;1
17139;;Dœuil-sur-le-Mignon;DOEUIL-SUR-LE-MIGNON;17330;17;CHARENTE MARITIME;1
17140;;Dolus-d'Oléron;DOLUS-D'OLERON;17550;17;CHARENTE MARITIME;1
17141;;Dompierre-sur-Charente;DOMPIERRE-SUR-CHARENTE;17610;17;CHARENTE MARITIME;1
17142;;Dompierre-sur-Mer;DOMPIERRE-SUR-MER;17139;17;CHARENTE MARITIME;1
17143;Le;Douhet;DOUHET;17100;17;CHARENTE MARITIME;1
17145;;Échebrune;ECHEBRUNE;17800;17;CHARENTE MARITIME;1
17146;;Échillais;ECHILLAIS;17620;17;CHARENTE MARITIME;1
17147;;Écoyeux;ECOYEUX;17770;17;CHARENTE MARITIME;1
17148;;Écurat;ECURAT;17810;17;CHARENTE MARITIME;1
17149;Les;Éduts;EDUTS;17510;17;CHARENTE MARITIME;1
17150;Les;Églises-d'Argenteuil;EGLISES-D'ARGENTEUIL;17400;17;CHARENTE MARITIME;1
17151;L';Éguille;EGUILLE;17600;17;CHARENTE MARITIME;1
17152;;Épargnes;EPARGNES;17120;17;CHARENTE MARITIME;1
17153;;Esnandes;ESNANDES;17137;17;CHARENTE MARITIME;1
17154;Les;Essards;ESSARDS;17250;17;CHARENTE MARITIME;1
17155;;Étaules;ETAULES;17750;17;CHARENTE MARITIME;1
17156;;Expiremont;EXPIREMONT;17130;17;CHARENTE MARITIME;1
17157;;Fenioux;FENIOUX;17350;17;CHARENTE MARITIME;1
17158;;Ferrières;FERRIERES;17170;17;CHARENTE MARITIME;1
17159;;Fléac-sur-Seugne;FLEAC-SUR-SEUGNE;17800;17;CHARENTE MARITIME;1
17160;;Floirac;FLOIRAC;17120;17;CHARENTE MARITIME;1
17161;La;Flotte;FLOTTE;17630;17;CHARENTE MARITIME;1
17162;;Fontaine-Chalendray;FONTAINE-CHALENDRAY;17510;17;CHARENTE MARITIME;1
17163;;Fontaines-d'Ozillac;FONTAINES-D'OZILLAC;17500;17;CHARENTE MARITIME;1
17164;;Fontcouverte;FONTCOUVERTE;17100;17;CHARENTE MARITIME;1
17165;;Fontenet;FONTENET;17400;17;CHARENTE MARITIME;1
17166;;Forges;FORGES;17290;17;CHARENTE MARITIME;1
17167;Le;Fouilloux;FOUILLOUX;17270;17;CHARENTE MARITIME;1
17168;;Fouras;FOURAS;17450;17;CHARENTE MARITIME;1
17169;La;Frédière;FREDIERE;17770;17;CHARENTE MARITIME;1
17171;;Geay;GEAY;17250;17;CHARENTE MARITIME;1
17172;;Gémozac;GEMOZAC;17260;17;CHARENTE MARITIME;1
17173;La;Genétouze;GENETOUZE;17360;17;CHARENTE MARITIME;1
17174;;Genouillé;GENOUILLE;17430;17;CHARENTE MARITIME;1
17175;;Germignac;GERMIGNAC;17520;17;CHARENTE MARITIME;1
17176;;Gibourne;GIBOURNE;17160;17;CHARENTE MARITIME;1
17177;Le;Gicq;GICQ;17160;17;CHARENTE MARITIME;1
17178;;Givrezac;GIVREZAC;17260;17;CHARENTE MARITIME;1
17179;Les;Gonds;GONDS;17100;17;CHARENTE MARITIME;1
17180;;Gourvillette;GOURVILLETTE;17490;17;CHARENTE MARITIME;1
17181;;Grandjean;GRANDJEAN;17350;17;CHARENTE MARITIME;1
17182;La;Grève-sur-Mignon;GREVE-SUR-MIGNON;17170;17;CHARENTE MARITIME;1
17183;;Grézac;GREZAC;17120;17;CHARENTE MARITIME;1
17184;La;Gripperie-Saint-Symphorien;GRIPPERIE-SAINT-SYMPHORIEN;17620;17;CHARENTE MARITIME;1
17185;Le;Gua;GUA;17600;17;CHARENTE MARITIME;1
17186;Le;Gué-d'Alleré;GUE-D'ALLERE;17540;17;CHARENTE MARITIME;1
17187;;Guitinières;GUITINIERES;17500;17;CHARENTE MARITIME;1
17188;;Haimps;HAIMPS;17160;17;CHARENTE MARITIME;1
17189;;Hiers-Brouage;HIERS-BROUAGE;17320;17;CHARENTE MARITIME;1
17190;L';Houmeau;HOUMEAU;17137;17;CHARENTE MARITIME;1
17191;La;Jard;JARD;17460;17;CHARENTE MARITIME;1
17192;;Jarnac-Champagne;JARNAC-CHAMPAGNE;17520;17;CHARENTE MARITIME;1
17193;La;Jarne;JARNE;17220;17;CHARENTE MARITIME;1
17194;La;Jarrie;JARRIE;17220;17;CHARENTE MARITIME;1
17195;La;Jarrie-Audouin;JARRIE-AUDOUIN;17330;17;CHARENTE MARITIME;1
17196;;Jazennes;JAZENNES;17260;17;CHARENTE MARITIME;1
17197;;Jonzac;JONZAC;17500;17;CHARENTE MARITIME;1
17198;;Juicq;JUICQ;17770;17;CHARENTE MARITIME;1
17199;;Jussas;JUSSAS;17130;17;CHARENTE MARITIME;1
17200;;Lagord;LAGORD;17140;17;CHARENTE MARITIME;1
17201;La;Laigne;LAIGNE;17170;17;CHARENTE MARITIME;1
17202;;Landes;LANDES;17380;17;CHARENTE MARITIME;1
17203;;Landrais;LANDRAIS;17290;17;CHARENTE MARITIME;1
17204;;Léoville;LEOVILLE;17500;17;CHARENTE MARITIME;1
17205;;Loire-les-Marais;LOIRE-LES-MARAIS;17870;17;CHARENTE MARITIME;1
17206;;Loiré-sur-Nie;LOIRE-SUR-NIE;17470;17;CHARENTE MARITIME;1
17207;;Loix;LOIX;17111;17;CHARENTE MARITIME;1
17208;;Longèves;LONGEVES;17230;17;CHARENTE MARITIME;1
17209;;Lonzac;LONZAC;17520;17;CHARENTE MARITIME;1
17210;;Lorignac;LORIGNAC;17240;17;CHARENTE MARITIME;1
17211;;Loulay;LOULAY;17330;17;CHARENTE MARITIME;1
17212;;Louzignac;LOUZIGNAC;17160;17;CHARENTE MARITIME;1
17213;;Lozay;LOZAY;17330;17;CHARENTE MARITIME;1
17214;;Luchat;LUCHAT;17600;17;CHARENTE MARITIME;1
17215;;Lussac;LUSSAC;17500;17;CHARENTE MARITIME;1
17216;;Lussant;LUSSANT;17430;17;CHARENTE MARITIME;1
17217;;Macqueville;MACQUEVILLE;17490;17;CHARENTE MARITIME;1
17218;;Marans;MARANS;17230;17;CHARENTE MARITIME;1
17219;;Marennes;MARENNES;17320;17;CHARENTE MARITIME;1
17220;;Marignac;MARIGNAC;17800;17;CHARENTE MARITIME;1
17221;;Marsais;MARSAIS;17700;17;CHARENTE MARITIME;1
17222;;Marsilly;MARSILLY;17137;17;CHARENTE MARITIME;1
17223;;Massac;MASSAC;17490;17;CHARENTE MARITIME;1
17224;;Matha;MATHA;17160;17;CHARENTE MARITIME;1
17225;Les;Mathes;MATHES;17570;17;CHARENTE MARITIME;1
17226;;Mazeray;MAZERAY;17400;17;CHARENTE MARITIME;1
17227;;Mazerolles;MAZEROLLES;17800;17;CHARENTE MARITIME;1
17228;;Médis;MEDIS;17600;17;CHARENTE MARITIME;1
17229;;Mérignac;MERIGNAC;17210;17;CHARENTE MARITIME;1
17230;;Meschers-sur-Gironde;MESCHERS-SUR-GIRONDE;17132;17;CHARENTE MARITIME;1
17231;;Messac;MESSAC;17130;17;CHARENTE MARITIME;1
17232;;Meursac;MEURSAC;17120;17;CHARENTE MARITIME;1
17233;;Meux;MEUX;17500;17;CHARENTE MARITIME;1
17234;;Migré;MIGRE;17330;17;CHARENTE MARITIME;1
17235;;Migron;MIGRON;17770;17;CHARENTE MARITIME;1
17236;;Mirambeau;MIRAMBEAU;17150;17;CHARENTE MARITIME;1
17237;;Moëze;MOEZE;17780;17;CHARENTE MARITIME;1
17238;;Moings;MOINGS;17500;17;CHARENTE MARITIME;1
17239;;Mons;MONS;17160;17;CHARENTE MARITIME;1
17240;;Montendre;MONTENDRE;17130;17;CHARENTE MARITIME;1
17241;;Montguyon;MONTGUYON;17270;17;CHARENTE MARITIME;1
17242;;Montils;MONTILS;17800;17;CHARENTE MARITIME;1
17243;;Montlieu-la-Garde;MONTLIEU-LA-GARDE;17210;17;CHARENTE MARITIME;1
17244;;Montpellier-de-Médillan;MONTPELLIER-DE-MEDILLAN;17260;17;CHARENTE MARITIME;1
17245;;Montroy;MONTROY;17220;17;CHARENTE MARITIME;1
17246;;Moragne;MORAGNE;17430;17;CHARENTE MARITIME;1
17247;;Mornac-sur-Seudre;MORNAC-SUR-SEUDRE;17113;17;CHARENTE MARITIME;1
17248;;Mortagne-sur-Gironde;MORTAGNE-SUR-GIRONDE;17120;17;CHARENTE MARITIME;1
17249;;Mortiers;MORTIERS;17500;17;CHARENTE MARITIME;1
17250;;Mosnac;MOSNAC;17240;17;CHARENTE MARITIME;1
17252;Le;Mung;MUNG;17350;17;CHARENTE MARITIME;1
17253;;Muron;MURON;17430;17;CHARENTE MARITIME;1
17254;;Nachamps;NACHAMPS;17380;17;CHARENTE MARITIME;1
17255;;Nancras;NANCRAS;17600;17;CHARENTE MARITIME;1
17256;;Nantillé;NANTILLE;17770;17;CHARENTE MARITIME;1
17257;;Néré;NERE;17510;17;CHARENTE MARITIME;1
17258;;Neuillac;NEUILLAC;17520;17;CHARENTE MARITIME;1
17259;;Neulles;NEULLES;17500;17;CHARENTE MARITIME;1
17260;;Neuvicq;NEUVICQ;17270;17;CHARENTE MARITIME;1
17261;;Neuvicq-le-Château;NEUVICQ-LE-CHATEAU;17490;17;CHARENTE MARITIME;1
17262;;Nieul-lès-Saintes;NIEUL-LES-SAINTES;17810;17;CHARENTE MARITIME;1
17263;;Nieul-le-Virouil;NIEUL-LE-VIROUIL;17150;17;CHARENTE MARITIME;1
17264;;Nieul-sur-Mer;NIEUL-SUR-MER;17137;17;CHARENTE MARITIME;1
17265;;Nieulle-sur-Seudre;NIEULLE-SUR-SEUDRE;17600;17;CHARENTE MARITIME;1
17266;Les;Nouillers;NOUILLERS;17380;17;CHARENTE MARITIME;1
17267;;Nuaillé-d'Aunis;NUAILLE-D'AUNIS;17540;17;CHARENTE MARITIME;1
17268;;Nuaillé-sur-Boutonne;NUAILLE-SUR-BOUTONNE;17470;17;CHARENTE MARITIME;1
17269;;Orignolles;ORIGNOLLES;17210;17;CHARENTE MARITIME;1
17270;;Ozillac;OZILLAC;17500;17;CHARENTE MARITIME;1
17271;;Paillé;PAILLE;17470;17;CHARENTE MARITIME;1
17272;;Péré;PERE;17700;17;CHARENTE MARITIME;1
17273;;Pérignac;PERIGNAC;17800;17;CHARENTE MARITIME;1
17274;;Périgny;PERIGNY;17180;17;CHARENTE MARITIME;1
17275;;Pessines;PESSINES;17810;17;CHARENTE MARITIME;1
17276;Le;Pin;PIN;17210;17;CHARENTE MARITIME;1
17277;;Saint-Denis-du-Pin;SAINT-DENIS-DU-PIN;17400;17;CHARENTE MARITIME;1
17278;;Pisany;PISANY;17600;17;CHARENTE MARITIME;1
17279;;Plassac;PLASSAC;17240;17;CHARENTE MARITIME;1
17280;;Plassay;PLASSAY;17250;17;CHARENTE MARITIME;1
17281;;Polignac;POLIGNAC;17210;17;CHARENTE MARITIME;1
17282;;Pommiers-Moulons;POMMIERS-MOULONS;17130;17;CHARENTE MARITIME;1
17283;;Pons;PONS;17800;17;CHARENTE MARITIME;1
17284;;Pont-l'Abbé-d'Arnoult;PONT-L'ABBE-D'ARNOULT;17250;17;CHARENTE MARITIME;1
17285;;Port-d'Envaux;PORT-D'ENVAUX;17350;17;CHARENTE MARITIME;1
17286;Les;Portes-en-Ré;PORTES-EN-RE;17880;17;CHARENTE MARITIME;1
17287;;Pouillac;POUILLAC;17210;17;CHARENTE MARITIME;1
17288;;Poursay-Garnaud;POURSAY-GARNAUD;17400;17;CHARENTE MARITIME;1
17289;;Préguillac;PREGUILLAC;17460;17;CHARENTE MARITIME;1
17290;;Prignac;PRIGNAC;17160;17;CHARENTE MARITIME;1
17291;;Puilboreau;PUILBOREAU;17138;17;CHARENTE MARITIME;1
17292;;Puy-du-Lac;PUY-DU-LAC;17380;17;CHARENTE MARITIME;1
17293;;Puyravault;PUYRAVAULT;17700;17;CHARENTE MARITIME;1
17294;;Puyrolland;PUYROLLAND;17380;17;CHARENTE MARITIME;1
17295;;Réaux;REAUX;17500;17;CHARENTE MARITIME;1
17296;;Rétaud;RETAUD;17460;17;CHARENTE MARITIME;1
17297;;Rivedoux-Plage;RIVEDOUX-PLAGE;17940;17;CHARENTE MARITIME;1
17298;;Rioux;RIOUX;17460;17;CHARENTE MARITIME;1
17299;;Rochefort;ROCHEFORT;17300;17;CHARENTE MARITIME;1
17300;La;Rochelle;ROCHELLE;17000;17;CHARENTE MARITIME;1
17301;;Romazières;ROMAZIERES;17510;17;CHARENTE MARITIME;1
17302;;Romegoux;ROMEGOUX;17250;17;CHARENTE MARITIME;1
17303;La;Ronde;RONDE;17170;17;CHARENTE MARITIME;1
17304;;Rouffiac;ROUFFIAC;17800;17;CHARENTE MARITIME;1
17305;;Rouffignac;ROUFFIGNAC;17130;17;CHARENTE MARITIME;1
17306;;Royan;ROYAN;17200;17;CHARENTE MARITIME;1
17307;;Sablonceaux;SABLONCEAUX;17600;17;CHARENTE MARITIME;1
17308;;Saint-Agnant;SAINT-AGNANT;17620;17;CHARENTE MARITIME;1
17309;;Saint-Aigulin;SAINT-AIGULIN;17360;17;CHARENTE MARITIME;1
17310;;Saint-André-de-Lidon;SAINT-ANDRE-DE-LIDON;17260;17;CHARENTE MARITIME;1
17311;;Saint-Augustin;SAINT-AUGUSTIN;17570;17;CHARENTE MARITIME;1
17312;;Saint-Bonnet-sur-Gironde;SAINT-BONNET-SUR-GIRONDE;17150;17;CHARENTE MARITIME;1
17313;;Saint-Bris-des-Bois;SAINT-BRIS-DES-BOIS;17770;17;CHARENTE MARITIME;1
17314;;Saint-Césaire;SAINT-CESAIRE;17770;17;CHARENTE MARITIME;1
17315;;Saint-Christophe;SAINT-CHRISTOPHE;17220;17;CHARENTE MARITIME;1
17316;;Saint-Ciers-Champagne;SAINT-CIERS-CHAMPAGNE;17520;17;CHARENTE MARITIME;1
17317;;Saint-Ciers-du-Taillon;SAINT-CIERS-DU-TAILLON;17240;17;CHARENTE MARITIME;1
17318;;Saint-Clément-des-Baleines;SAINT-CLEMENT-DES-BALEINES;17590;17;CHARENTE MARITIME;1
17319;;Sainte-Colombe;SAINTE-COLOMBE;17210;17;CHARENTE MARITIME;1
17320;;Saint-Coutant-le-Grand;SAINT-COUTANT-LE-GRAND;17430;17;CHARENTE MARITIME;1
17321;;Saint-Crépin;SAINT-CREPIN;17380;17;CHARENTE MARITIME;1
17322;;Saint-Cyr-du-Doret;SAINT-CYR-DU-DORET;17170;17;CHARENTE MARITIME;1
17323;;Saint-Denis-d'Oléron;SAINT-DENIS-D'OLERON;17650;17;CHARENTE MARITIME;1
17324;;Saint-Dizant-du-Bois;SAINT-DIZANT-DU-BOIS;17150;17;CHARENTE MARITIME;1
17325;;Saint-Dizant-du-Gua;SAINT-DIZANT-DU-GUA;17240;17;CHARENTE MARITIME;1
17326;;Saint-Eugène;SAINT-EUGENE;17520;17;CHARENTE MARITIME;1
17327;;Saint-Félix;SAINT-FELIX;17330;17;CHARENTE MARITIME;1
17328;;Saint-Fort-sur-Gironde;SAINT-FORT-SUR-GIRONDE;17240;17;CHARENTE MARITIME;1
17329;;Saint-Froult;SAINT-FROULT;17780;17;CHARENTE MARITIME;1
17330;;Sainte-Gemme;SAINTE-GEMME;17250;17;CHARENTE MARITIME;1
17331;;Saint-Genis-de-Saintonge;SAINT-GENIS-DE-SAINTONGE;17240;17;CHARENTE MARITIME;1
17332;;Saint-Georges-Antignac;SAINT-GEORGES-ANTIGNAC;17240;17;CHARENTE MARITIME;1
17333;;Saint-Georges-de-Didonne;SAINT-GEORGES-DE-DIDONNE;17110;17;CHARENTE MARITIME;1
17334;;Saint-Georges-de-Longuepierre;SAINT-GEORGES-DE-LONGUEPIERRE;17470;17;CHARENTE MARITIME;1
17335;;Saint-Georges-des-Agoûts;SAINT-GEORGES-DES-AGOUTS;17150;17;CHARENTE MARITIME;1
17336;;Saint-Georges-des-Coteaux;SAINT-GEORGES-DES-COTEAUX;17810;17;CHARENTE MARITIME;1
17337;;Saint-Georges-d'Oléron;SAINT-GEORGES-D'OLERON;17190;17;CHARENTE MARITIME;1
17338;;Saint-Georges-du-Bois;SAINT-GEORGES-DU-BOIS;17700;17;CHARENTE MARITIME;1
17339;;Saint-Germain-de-Lusignan;SAINT-GERMAIN-DE-LUSIGNAN;17500;17;CHARENTE MARITIME;1
17340;;Saint-Germain-de-Marencennes;SAINT-GERMAIN-DE-MARENCENNES;17700;17;CHARENTE MARITIME;1
17341;;Saint-Germain-de-Vibrac;SAINT-GERMAIN-DE-VIBRAC;17500;17;CHARENTE MARITIME;1
17342;;Saint-Germain-du-Seudre;SAINT-GERMAIN-DU-SEUDRE;17240;17;CHARENTE MARITIME;1
17343;;Saint-Grégoire-d'Ardennes;SAINT-GREGOIRE-D'ARDENNES;17240;17;CHARENTE MARITIME;1
17344;;Saint-Hilaire-de-Villefranche;SAINT-HILAIRE-DE-VILLEFRANCHE;17770;17;CHARENTE MARITIME;1
17345;;Saint-Hilaire-du-Bois;SAINT-HILAIRE-DU-BOIS;17500;17;CHARENTE MARITIME;1
17346;;Saint-Hippolyte;SAINT-HIPPOLYTE;17430;17;CHARENTE MARITIME;1
17347;;Saint-Jean-d'Angély;SAINT-JEAN-D'ANGELY;17400;17;CHARENTE MARITIME;1
17348;;Saint-Jean-d'Angle;SAINT-JEAN-D'ANGLE;17620;17;CHARENTE MARITIME;1
17349;;Saint-Jean-de-Liversay;SAINT-JEAN-DE-LIVERSAY;17170;17;CHARENTE MARITIME;1
17350;;Saint-Julien-de-l'Escap;SAINT-JULIEN-DE-L'ESCAP;17400;17;CHARENTE MARITIME;1
17351;;Saint-Just-Luzac;SAINT-JUST-LUZAC;17320;17;CHARENTE MARITIME;1
17352;;Saint-Laurent-de-la-Barrière;SAINT-LAURENT-DE-LA-BARRIERE;17380;17;CHARENTE MARITIME;1
17353;;Saint-Laurent-de-la-Prée;SAINT-LAURENT-DE-LA-PREE;17450;17;CHARENTE MARITIME;1
17354;;Saint-Léger;SAINT-LEGER;17800;17;CHARENTE MARITIME;1
17355;;Sainte-Lheurine;SAINTE-LHEURINE;17520;17;CHARENTE MARITIME;1
17356;;Saint-Loup;SAINT-LOUP;17380;17;CHARENTE MARITIME;1
17357;;Saint-Maigrin;SAINT-MAIGRIN;17520;17;CHARENTE MARITIME;1
17358;;Saint-Mandé-sur-Brédoire;SAINT-MANDE-SUR-BREDOIRE;17470;17;CHARENTE MARITIME;1
17359;;Saint-Mard;SAINT-MARD;17700;17;CHARENTE MARITIME;1
17360;;Sainte-Marie-de-Ré;SAINTE-MARIE-DE-RE;17740;17;CHARENTE MARITIME;1
17361;;Saint-Martial;SAINT-MARTIAL;17330;17;CHARENTE MARITIME;1
17362;;Saint-Martial-de-Mirambeau;SAINT-MARTIAL-DE-MIRAMBEAU;17150;17;CHARENTE MARITIME;1
17363;;Saint-Martial-de-Vitaterne;SAINT-MARTIAL-DE-VITATERNE;17500;17;CHARENTE MARITIME;1
17364;;Saint-Martial-sur-Né;SAINT-MARTIAL-SUR-NE;17520;17;CHARENTE MARITIME;1
17365;;Saint-Martin-d'Ary;SAINT-MARTIN-D'ARY;17270;17;CHARENTE MARITIME;1
17366;;Saint-Martin-de-Coux;SAINT-MARTIN-DE-COUX;17360;17;CHARENTE MARITIME;1
17367;;Saint-Martin-de-Juillers;SAINT-MARTIN-DE-JUILLERS;17400;17;CHARENTE MARITIME;1
17369;;Saint-Martin-de-Ré;SAINT-MARTIN-DE-RE;17410;17;CHARENTE MARITIME;1
17371;;Saint-Maurice-de-Tavernole;SAINT-MAURICE-DE-TAVERNOLE;17500;17;CHARENTE MARITIME;1
17372;;Saint-Médard;SAINT-MEDARD;17500;17;CHARENTE MARITIME;1
17373;;Saint-Médard-d'Aunis;SAINT-MEDARD-D'AUNIS;17220;17;CHARENTE MARITIME;1
17374;;Sainte-Même;SAINTE-MEME;17770;17;CHARENTE MARITIME;1
17375;;Saint-Nazaire-sur-Charente;SAINT-NAZAIRE-SUR-CHARENTE;17780;17;CHARENTE MARITIME;1
17376;;Saint-Ouen-d'Aunis;SAINT-OUEN-D'AUNIS;17230;17;CHARENTE MARITIME;1
17377;;Saint-Ouen;SAINT-OUEN;17490;17;CHARENTE MARITIME;1
17378;;Saint-Palais-de-Négrignac;SAINT-PALAIS-DE-NEGRIGNAC;17210;17;CHARENTE MARITIME;1
17379;;Saint-Palais-de-Phiolin;SAINT-PALAIS-DE-PHIOLIN;17800;17;CHARENTE MARITIME;1
17380;;Saint-Palais-sur-Mer;SAINT-PALAIS-SUR-MER;17420;17;CHARENTE MARITIME;1
17381;;Saint-Pardoult;SAINT-PARDOULT;17400;17;CHARENTE MARITIME;1
17382;;Saint-Pierre-d'Amilly;SAINT-PIERRE-D'AMILLY;17700;17;CHARENTE MARITIME;1
17383;;Saint-Pierre-de-Juillers;SAINT-PIERRE-DE-JUILLERS;17400;17;CHARENTE MARITIME;1
17384;;Saint-Pierre-de-l'Isle;SAINT-PIERRE-DE-L'ISLE;17330;17;CHARENTE MARITIME;1
17385;;Saint-Pierre-d'Oléron;SAINT-PIERRE-D'OLERON;17310;17;CHARENTE MARITIME;1
17386;;Saint-Pierre-du-Palais;SAINT-PIERRE-DU-PALAIS;17270;17;CHARENTE MARITIME;1
17387;;Saint-Porchaire;SAINT-PORCHAIRE;17250;17;CHARENTE MARITIME;1
17388;;Saint-Quantin-de-Rançanne;SAINT-QUANTIN-DE-RANCANNE;17800;17;CHARENTE MARITIME;1
17389;;Sainte-Radegonde;SAINTE-RADEGONDE;17250;17;CHARENTE MARITIME;1
17390;;Sainte-Ramée;SAINTE-RAMEE;17240;17;CHARENTE MARITIME;1
17391;;Saint-Rogatien;SAINT-ROGATIEN;17220;17;CHARENTE MARITIME;1
17392;;Saint-Romain-sur-Gironde;SAINT-ROMAIN-SUR-GIRONDE;17240;17;CHARENTE MARITIME;1
17393;;Saint-Romain-de-Benet;SAINT-ROMAIN-DE-BENET;17600;17;CHARENTE MARITIME;1
17394;;Saint-Saturnin-du-Bois;SAINT-SATURNIN-DU-BOIS;17700;17;CHARENTE MARITIME;1
17395;;Saint-Sauvant;SAINT-SAUVANT;17610;17;CHARENTE MARITIME;1
17396;;Saint-Sauveur-d'Aunis;SAINT-SAUVEUR-D'AUNIS;17540;17;CHARENTE MARITIME;1
17397;;Saint-Savinien;SAINT-SAVINIEN;17350;17;CHARENTE MARITIME;1
17398;;Saint-Seurin-de-Palenne;SAINT-SEURIN-DE-PALENNE;17800;17;CHARENTE MARITIME;1
17400;;Saint-Sever-de-Saintonge;SAINT-SEVER-DE-SAINTONGE;17800;17;CHARENTE MARITIME;1
17401;;Saint-Séverin-sur-Boutonne;SAINT-SEVERIN-SUR-BOUTONNE;17330;17;CHARENTE MARITIME;1
17402;;Saint-Sigismond-de-Clermont;SAINT-SIGISMOND-DE-CLERMONT;17240;17;CHARENTE MARITIME;1
17403;;Saint-Simon-de-Bordes;SAINT-SIMON-DE-BORDES;17500;17;CHARENTE MARITIME;1
17404;;Saint-Simon-de-Pellouaille;SAINT-SIMON-DE-PELLOUAILLE;17260;17;CHARENTE MARITIME;1
17405;;Saint-Sorlin-de-Conac;SAINT-SORLIN-DE-CONAC;17150;17;CHARENTE MARITIME;1
17406;;Saint-Sornin;SAINT-SORNIN;17600;17;CHARENTE MARITIME;1
17407;;Sainte-Soulle;SAINTE-SOULLE;17220;17;CHARENTE MARITIME;1
17408;;Saint-Sulpice-d'Arnoult;SAINT-SULPICE-D'ARNOULT;17250;17;CHARENTE MARITIME;1
17409;;Saint-Sulpice-de-Royan;SAINT-SULPICE-DE-ROYAN;17200;17;CHARENTE MARITIME;1
17410;;Saint-Thomas-de-Conac;SAINT-THOMAS-DE-CONAC;17150;17;CHARENTE MARITIME;1
17411;;Saint-Trojan-les-Bains;SAINT-TROJAN-LES-BAINS;17370;17;CHARENTE MARITIME;1
17412;;Saint-Vaize;SAINT-VAIZE;17100;17;CHARENTE MARITIME;1
17413;;Saint-Vivien;SAINT-VIVIEN;17220;17;CHARENTE MARITIME;1
17414;;Saint-Xandre;SAINT-XANDRE;17138;17;CHARENTE MARITIME;1
17415;;Saintes;SAINTES;17100;17;CHARENTE MARITIME;1
17416;;Saleignes;SALEIGNES;17510;17;CHARENTE MARITIME;1
17417;;Salignac-de-Mirambeau;SALIGNAC-DE-MIRAMBEAU;17130;17;CHARENTE MARITIME;1
17418;;Salignac-sur-Charente;SALIGNAC-SUR-CHARENTE;17800;17;CHARENTE MARITIME;1
17420;;Salles-sur-Mer;SALLES-SUR-MER;17220;17;CHARENTE MARITIME;1
17421;;Saujon;SAUJON;17600;17;CHARENTE MARITIME;1
17422;;Seigné;SEIGNE;17510;17;CHARENTE MARITIME;1
17423;;Semillac;SEMILLAC;17150;17;CHARENTE MARITIME;1
17424;;Semoussac;SEMOUSSAC;17150;17;CHARENTE MARITIME;1
17425;;Semussac;SEMUSSAC;17120;17;CHARENTE MARITIME;1
17426;Le;Seure;SEURE;17770;17;CHARENTE MARITIME;1
17427;;Siecq;SIECQ;17490;17;CHARENTE MARITIME;1
17428;;Sonnac;SONNAC;17160;17;CHARENTE MARITIME;1
17429;;Soubise;SOUBISE;17780;17;CHARENTE MARITIME;1
17430;;Soubran;SOUBRAN;17150;17;CHARENTE MARITIME;1
17431;;Soulignonne;SOULIGNONNE;17250;17;CHARENTE MARITIME;1
17432;;Souméras;SOUMERAS;17130;17;CHARENTE MARITIME;1
17433;;Sousmoulins;SOUSMOULINS;17130;17;CHARENTE MARITIME;1
17434;;Surgères;SURGERES;17700;17;CHARENTE MARITIME;1
17435;;Taillant;TAILLANT;17350;17;CHARENTE MARITIME;1
17436;;Taillebourg;TAILLEBOURG;17350;17;CHARENTE MARITIME;1
17437;;Talmont-sur-Gironde;TALMONT-SUR-GIRONDE;17120;17;CHARENTE MARITIME;1
17438;;Tanzac;TANZAC;17260;17;CHARENTE MARITIME;1
17439;;Taugon;TAUGON;17170;17;CHARENTE MARITIME;1
17440;;Ternant;TERNANT;17400;17;CHARENTE MARITIME;1
17441;;Tesson;TESSON;17460;17;CHARENTE MARITIME;1
17442;;Thaims;THAIMS;17120;17;CHARENTE MARITIME;1
17443;;Thairé;THAIRE;17290;17;CHARENTE MARITIME;1
17444;;Thénac;THENAC;17460;17;CHARENTE MARITIME;1
17445;;Thézac;THEZAC;17600;17;CHARENTE MARITIME;1
17446;;Thors;THORS;17160;17;CHARENTE MARITIME;1
17447;Le;Thou;THOU;17290;17;CHARENTE MARITIME;1
17448;;Tonnay-Boutonne;TONNAY-BOUTONNE;17380;17;CHARENTE MARITIME;1
17449;;Tonnay-Charente;TONNAY-CHARENTE;17430;17;CHARENTE MARITIME;1
17450;;Torxé;TORXE;17380;17;CHARENTE MARITIME;1
17451;Les;Touches-de-Périgny;TOUCHES-DE-PERIGNY;17160;17;CHARENTE MARITIME;1
17452;La;Tremblade;TREMBLADE;17390;17;CHARENTE MARITIME;1
17453;;Trizay;TRIZAY;17250;17;CHARENTE MARITIME;1
17454;;Tugéras-Saint-Maurice;TUGERAS-SAINT-MAURICE;17130;17;CHARENTE MARITIME;1
17455;La;Vallée;VALLEE;17250;17;CHARENTE MARITIME;1
17457;;Vandré;VANDRE;17700;17;CHARENTE MARITIME;1
17458;;Vanzac;VANZAC;17500;17;CHARENTE MARITIME;1
17459;;Varaize;VARAIZE;17400;17;CHARENTE MARITIME;1
17460;;Varzay;VARZAY;17460;17;CHARENTE MARITIME;1
17461;;Vaux-sur-Mer;VAUX-SUR-MER;17640;17;CHARENTE MARITIME;1
17462;;Vénérand;VENERAND;17100;17;CHARENTE MARITIME;1
17463;;Vergeroux;VERGEROUX;17300;17;CHARENTE MARITIME;1
17464;;Vergné;VERGNE;17330;17;CHARENTE MARITIME;1
17465;La;Vergne;VERGNE;17400;17;CHARENTE MARITIME;1
17466;;Vérines;VERINES;17540;17;CHARENTE MARITIME;1
17467;;Vervant;VERVANT;17400;17;CHARENTE MARITIME;1
17468;;Vibrac;VIBRAC;17130;17;CHARENTE MARITIME;1
17469;;Villars-en-Pons;VILLARS-EN-PONS;17260;17;CHARENTE MARITIME;1
17470;;Villars-les-Bois;VILLARS-LES-BOIS;17770;17;CHARENTE MARITIME;1
17471;La;Villedieu;VILLEDIEU;17470;17;CHARENTE MARITIME;1
17472;;Villedoux;VILLEDOUX;17230;17;CHARENTE MARITIME;1
17473;;Villemorin;VILLEMORIN;17470;17;CHARENTE MARITIME;1
17474;;Villeneuve-la-Comtesse;VILLENEUVE-LA-COMTESSE;17330;17;CHARENTE MARITIME;1
17476;;Villexavier;VILLEXAVIER;17500;17;CHARENTE MARITIME;1
17477;;Villiers-Couture;VILLIERS-COUTURE;17510;17;CHARENTE MARITIME;1
17478;;Vinax;VINAX;17510;17;CHARENTE MARITIME;1
17479;;Virollet;VIROLLET;17260;17;CHARENTE MARITIME;1
17480;;Virson;VIRSON;17290;17;CHARENTE MARITIME;1
17481;;Voissay;VOISSAY;17400;17;CHARENTE MARITIME;1
17482;;Vouhé;VOUHE;17700;17;CHARENTE MARITIME;1
17483;;Yves;YVES;17340;17;CHARENTE MARITIME;1
17484;;Port-des-Barques;PORT-DES-BARQUES;17730;17;CHARENTE MARITIME;1
17485;Le;Grand-Village-Plage;GRAND-VILLAGE-PLAGE;17370;17;CHARENTE MARITIME;1
17486;La;Brée-les-Bains;BREE-LES-BAINS;17840;17;CHARENTE MARITIME;1
18001;;Achères;ACHERES;18250;18;CHER;1
18002;;Ainay-le-Vieil;AINAY-LE-VIEIL;18200;18;CHER;1
18003;Les;Aix-d'Angillon;AIX-D'ANGILLON;18220;18;CHER;1
18004;;Allogny;ALLOGNY;18110;18;CHER;1
18005;;Allouis;ALLOUIS;18500;18;CHER;1
18006;;Annoix;ANNOIX;18340;18;CHER;1
18007;;Apremont-sur-Allier;APREMONT-SUR-ALLIER;18150;18;CHER;1
18008;;Arçay;ARCAY;18340;18;CHER;1
18009;;Arcomps;ARCOMPS;18200;18;CHER;1
18010;;Ardenais;ARDENAIS;18170;18;CHER;1
18011;;Argent-sur-Sauldre;ARGENT-SUR-SAULDRE;18410;18;CHER;1
18012;;Argenvières;ARGENVIERES;18140;18;CHER;1
18013;;Arpheuilles;ARPHEUILLES;18200;18;CHER;1
18014;;Assigny;ASSIGNY;18260;18;CHER;1
18015;;Aubigny-sur-Nère;AUBIGNY-SUR-NERE;18700;18;CHER;1
18016;;Aubinges;AUBINGES;18220;18;CHER;1
18017;;Augy-sur-Aubois;AUGY-SUR-AUBOIS;18600;18;CHER;1
18018;;Avord;AVORD;18520;18;CHER;1
18019;;Azy;AZY;18220;18;CHER;1
18020;;Bannay;BANNAY;18300;18;CHER;1
18021;;Bannegon;BANNEGON;18210;18;CHER;1
18022;;Barlieu;BARLIEU;18260;18;CHER;1
18023;;Baugy;BAUGY;18800;18;CHER;1
18024;;Beddes;BEDDES;18370;18;CHER;1
18025;;Beffes;BEFFES;18320;18;CHER;1
18026;;Belleville-sur-Loire;BELLEVILLE-SUR-LOIRE;18240;18;CHER;1
18027;;Bengy-sur-Craon;BENGY-SUR-CRAON;18520;18;CHER;1
18028;;Berry-Bouy;BERRY-BOUY;18500;18;CHER;1
18029;;Bessais-le-Fromental;BESSAIS-LE-FROMENTAL;18210;18;CHER;1
18030;;Blancafort;BLANCAFORT;18410;18;CHER;1
18031;;Blet;BLET;18350;18;CHER;1
18032;;Boulleret;BOULLERET;18240;18;CHER;1
18033;;Bourges;BOURGES;18000;18;CHER;1
18034;;Bouzais;BOUZAIS;18200;18;CHER;1
18035;;Brécy;BRECY;18220;18;CHER;1
18036;;Brinay;BRINAY;18120;18;CHER;1
18037;;Brinon-sur-Sauldre;BRINON-SUR-SAULDRE;18410;18;CHER;1
18038;;Bruère-Allichamps;BRUERE-ALLICHAMPS;18200;18;CHER;1
18039;;Bué;BUE;18300;18;CHER;1
18040;;Bussy;BUSSY;18130;18;CHER;1
18041;La;Celette;CELETTE;18360;18;CHER;1
18042;La;Celle;CELLE;18200;18;CHER;1
18043;La;Celle-Condé;CELLE-CONDE;18160;18;CHER;1
18044;;Cerbois;CERBOIS;18120;18;CHER;1
18045;;Chalivoy-Milon;CHALIVOY-MILON;18130;18;CHER;1
18046;;Chambon;CHAMBON;18190;18;CHER;1
18047;La;Chapelle-d'Angillon;CHAPELLE-D'ANGILLON;18380;18;CHER;1
18048;La;Chapelle-Hugon;CHAPELLE-HUGON;18150;18;CHER;1
18049;La;Chapelle-Montlinard;CHAPELLE-MONTLINARD;18140;18;CHER;1
18050;La;Chapelle-Saint-Ursin;CHAPELLE-SAINT-URSIN;18570;18;CHER;1
18051;La;Chapelotte;CHAPELOTTE;18250;18;CHER;1
18052;;Charenton-du-Cher;CHARENTON-DU-CHER;18210;18;CHER;1
18053;;Charentonnay;CHARENTONNAY;18140;18;CHER;1
18054;;Charly;CHARLY;18350;18;CHER;1
18055;;Chârost;CHAROST;18290;18;CHER;1
18056;;Chassy;CHASSY;18800;18;CHER;1
18057;;Châteaumeillant;CHATEAUMEILLANT;18370;18;CHER;1
18058;;Châteauneuf-sur-Cher;CHATEAUNEUF-SUR-CHER;18190;18;CHER;1
18059;Le;Châtelet;CHATELET;18170;18;CHER;1
18060;;Chaumont;CHAUMONT;18350;18;CHER;1
18061;;Chaumoux-Marcilly;CHAUMOUX-MARCILLY;18140;18;CHER;1
18062;Le;Chautay;CHAUTAY;18150;18;CHER;1
18063;;Chavannes;CHAVANNES;18190;18;CHER;1
18064;;Chéry;CHERY;18120;18;CHER;1
18065;;Chezal-Benoît;CHEZAL-BENOIT;18160;18;CHER;1
18066;;Civray;CIVRAY;18290;18;CHER;1
18067;;Clémont;CLEMONT;18410;18;CHER;1
18068;;Cogny;COGNY;18130;18;CHER;1
18069;;Colombiers;COLOMBIERS;18200;18;CHER;1
18070;;Concressault;CONCRESSAULT;18260;18;CHER;1
18071;;Contres;CONTRES;18130;18;CHER;1
18072;;Cornusse;CORNUSSE;18350;18;CHER;1
18073;;Corquoy;CORQUOY;18190;18;CHER;1
18074;;Couargues;COUARGUES;18300;18;CHER;1
18075;;Cours-les-Barres;COURS-LES-BARRES;18320;18;CHER;1
18076;;Coust;COUST;18210;18;CHER;1
18077;;Couy;COUY;18140;18;CHER;1
18078;;Crézançay-sur-Cher;CREZANCAY-SUR-CHER;18190;18;CHER;1
18079;;Crézancy-en-Sancerre;CREZANCY-EN-SANCERRE;18300;18;CHER;1
18080;;Croisy;CROISY;18350;18;CHER;1
18081;;Crosses;CROSSES;18340;18;CHER;1
18082;;Cuffy;CUFFY;18150;18;CHER;1
18083;;Culan;CULAN;18270;18;CHER;1
18084;;Dampierre-en-Crot;DAMPIERRE-EN-CROT;18260;18;CHER;1
18085;;Dampierre-en-Graçay;DAMPIERRE-EN-GRACAY;18310;18;CHER;1
18086;;Drevant;DREVANT;18200;18;CHER;1
18087;;Dun-sur-Auron;DUN-SUR-AURON;18130;18;CHER;1
18088;;Ennordres;ENNORDRES;18380;18;CHER;1
18089;;Épineuil-le-Fleuriel;EPINEUIL-LE-FLEURIEL;18360;18;CHER;1
18090;;Étréchy;ETRECHY;18800;18;CHER;1
18091;;Farges-Allichamps;FARGES-ALLICHAMPS;18200;18;CHER;1
18092;;Farges-en-Septaine;FARGES-EN-SEPTAINE;18800;18;CHER;1
18093;;Faverdines;FAVERDINES;18360;18;CHER;1
18094;;Feux;FEUX;18300;18;CHER;1
18095;;Flavigny;FLAVIGNY;18350;18;CHER;1
18096;;Foëcy;FOECY;18500;18;CHER;1
18097;;Fussy;FUSSY;18110;18;CHER;1
18098;;Gardefort;GARDEFORT;18300;18;CHER;1
18099;;Garigny;GARIGNY;18140;18;CHER;1
18100;;Genouilly;GENOUILLY;18310;18;CHER;1
18101;;Germigny-l'Exempt;GERMIGNY-L'EXEMPT;18150;18;CHER;1
18102;;Givardon;GIVARDON;18600;18;CHER;1
18103;;Graçay;GRACAY;18310;18;CHER;1
18104;;Groises;GROISES;18140;18;CHER;1
18105;;Gron;GRON;18800;18;CHER;1
18106;;Grossouvre;GROSSOUVRE;18600;18;CHER;1
18107;La;Groutte;GROUTTE;18200;18;CHER;1
18108;La;Guerche-sur-l'Aubois;GUERCHE-SUR-L'AUBOIS;18150;18;CHER;1
18109;;Henrichemont;HENRICHEMONT;18250;18;CHER;1
18110;;Herry;HERRY;18140;18;CHER;1
18111;;Humbligny;HUMBLIGNY;18250;18;CHER;1
18112;;Ids-Saint-Roch;IDS-SAINT-ROCH;18170;18;CHER;1
18113;;Ignol;IGNOL;18350;18;CHER;1
18114;;Ineuil;INEUIL;18160;18;CHER;1
18115;;Ivoy-le-Pré;IVOY-LE-PRE;18380;18;CHER;1
18116;;Jalognes;JALOGNES;18300;18;CHER;1
18117;;Jars;JARS;18260;18;CHER;1
18118;;Jouet-sur-l'Aubois;JOUET-SUR-L'AUBOIS;18320;18;CHER;1
18119;;Jussy-Champagne;JUSSY-CHAMPAGNE;18130;18;CHER;1
18120;;Jussy-le-Chaudrier;JUSSY-LE-CHAUDRIER;18140;18;CHER;1
18121;;Lantan;LANTAN;18130;18;CHER;1
18122;;Lapan;LAPAN;18340;18;CHER;1
18123;;Laverdines;LAVERDINES;18800;18;CHER;1
18124;;Lazenay;LAZENAY;18120;18;CHER;1
18125;;Léré;LERE;18240;18;CHER;1
18126;;Levet;LEVET;18340;18;CHER;1
18127;;Lignières;LIGNIERES;18160;18;CHER;1
18128;;Limeux;LIMEUX;18120;18;CHER;1
18129;;Lissay-Lochy;LISSAY-LOCHY;18340;18;CHER;1
18130;;Loye-sur-Arnon;LOYE-SUR-ARNON;18170;18;CHER;1
18131;;Lugny-Bourbonnais;LUGNY-BOURBONNAIS;18350;18;CHER;1
18132;;Lugny-Champagne;LUGNY-CHAMPAGNE;18140;18;CHER;1
18133;;Lunery;LUNERY;18400;18;CHER;1
18134;;Lury-sur-Arnon;LURY-SUR-ARNON;18120;18;CHER;1
18135;;Maisonnais;MAISONNAIS;18170;18;CHER;1
18136;;Marçais;MARCAIS;18170;18;CHER;1
18137;;Mareuil-sur-Arnon;MAREUIL-SUR-ARNON;18290;18;CHER;1
18138;;Marmagne;MARMAGNE;18500;18;CHER;1
18139;;Marseilles-lès-Aubigny;MARSEILLES-LES-AUBIGNY;18320;18;CHER;1
18140;;Massay;MASSAY;18120;18;CHER;1
18141;;Mehun-sur-Yèvre;MEHUN-SUR-YEVRE;18500;18;CHER;1
18142;;Meillant;MEILLANT;18200;18;CHER;1
18143;;Menetou-Couture;MENETOU-COUTURE;18320;18;CHER;1
18144;;Menetou-Râtel;MENETOU-RATEL;18300;18;CHER;1
18145;;Menetou-Salon;MENETOU-SALON;18510;18;CHER;1
18146;;Ménétréol-sous-Sancerre;MENETREOL-SOUS-SANCERRE;18300;18;CHER;1
18147;;Ménétréol-sur-Sauldre;MENETREOL-SUR-SAULDRE;18700;18;CHER;1
18148;;Méreau;MEREAU;18120;18;CHER;1
18149;;Méry-ès-Bois;MERY-ES-BOIS;18380;18;CHER;1
18150;;Méry-sur-Cher;MERY-SUR-CHER;18100;18;CHER;1
18151;;Montigny;MONTIGNY;18250;18;CHER;1
18152;;Montlouis;MONTLOUIS;18160;18;CHER;1
18153;;Morlac;MORLAC;18170;18;CHER;1
18154;;Mornay-Berry;MORNAY-BERRY;18350;18;CHER;1
18155;;Mornay-sur-Allier;MORNAY-SUR-ALLIER;18600;18;CHER;1
18156;;Morogues;MOROGUES;18220;18;CHER;1
18157;;Morthomiers;MORTHOMIERS;18570;18;CHER;1
18158;;Moulins-sur-Yèvre;MOULINS-SUR-YEVRE;18390;18;CHER;1
18159;;Nançay;NANCAY;18330;18;CHER;1
18160;;Nérondes;NERONDES;18350;18;CHER;1
18161;;Neuilly-en-Dun;NEUILLY-EN-DUN;18600;18;CHER;1
18162;;Neuilly-en-Sancerre;NEUILLY-EN-SANCERRE;18250;18;CHER;1
18163;;Neuvy-Deux-Clochers;NEUVY-DEUX-CLOCHERS;18250;18;CHER;1
18164;;Neuvy-le-Barrois;NEUVY-LE-BARROIS;18600;18;CHER;1
18165;;Neuvy-sur-Barangeon;NEUVY-SUR-BARANGEON;18330;18;CHER;1
18166;;Nohant-en-Goût;NOHANT-EN-GOUT;18390;18;CHER;1
18167;;Nohant-en-Graçay;NOHANT-EN-GRACAY;18310;18;CHER;1
18168;Le;Noyer;NOYER;18260;18;CHER;1
18169;;Nozières;NOZIERES;18200;18;CHER;1
18170;;Oizon;OIZON;18700;18;CHER;1
18171;;Orcenais;ORCENAIS;18200;18;CHER;1
18172;;Orval;ORVAL;18200;18;CHER;1
18173;;Osmery;OSMERY;18130;18;CHER;1
18174;;Osmoy;OSMOY;18390;18;CHER;1
18175;;Ourouer-les-Bourdelins;OUROUER-LES-BOURDELINS;18350;18;CHER;1
18176;;Parassy;PARASSY;18220;18;CHER;1
18177;;Parnay;PARNAY;18130;18;CHER;1
18178;La;Perche;PERCHE;18200;18;CHER;1
18179;;Pigny;PIGNY;18110;18;CHER;1
18180;;Plaimpied-Givaudins;PLAIMPIED-GIVAUDINS;18340;18;CHER;1
18181;;Plou;PLOU;18290;18;CHER;1
18182;;Poisieux;POISIEUX;18290;18;CHER;1
18183;Le;Pondy;PONDY;18210;18;CHER;1
18184;;Précy;PRECY;18140;18;CHER;1
18185;;Presly;PRESLY;18380;18;CHER;1
18186;;Preuilly;PREUILLY;18120;18;CHER;1
18187;;Préveranges;PREVERANGES;18370;18;CHER;1
18188;;Primelles;PRIMELLES;18400;18;CHER;1
18189;;Quantilly;QUANTILLY;18110;18;CHER;1
18190;;Quincy;QUINCY;18120;18;CHER;1
18191;;Raymond;RAYMOND;18130;18;CHER;1
18192;;Reigny;REIGNY;18270;18;CHER;1
18193;;Rezay;REZAY;18170;18;CHER;1
18194;;Rians;RIANS;18220;18;CHER;1
18195;;Sagonne;SAGONNE;18600;18;CHER;1
18196;;Saint-Aignan-des-Noyers;SAINT-AIGNAN-DES-NOYERS;18600;18;CHER;1
18197;;Saint-Amand-Montrond;SAINT-AMAND-MONTROND;18200;18;CHER;1
18198;;Saint-Ambroix;SAINT-AMBROIX;18290;18;CHER;1
18199;;Saint-Baudel;SAINT-BAUDEL;18160;18;CHER;1
18200;;Saint-Bouize;SAINT-BOUIZE;18300;18;CHER;1
18201;;Saint-Caprais;SAINT-CAPRAIS;18400;18;CHER;1
18202;;Saint-Céols;SAINT-CEOLS;18220;18;CHER;1
18203;;Saint-Christophe-le-Chaudry;SAINT-CHRISTOPHE-LE-CHAUDRY;18270;18;CHER;1
18204;;Saint-Denis-de-Palin;SAINT-DENIS-DE-PALIN;18130;18;CHER;1
18205;;Saint-Doulchard;SAINT-DOULCHARD;18230;18;CHER;1
18206;;Saint-Éloy-de-Gy;SAINT-ELOY-DE-GY;18110;18;CHER;1
18207;;Saint-Florent-sur-Cher;SAINT-FLORENT-SUR-CHER;18400;18;CHER;1
18208;;Sainte-Gemme-en-Sancerrois;SAINTE-GEMME-EN-SANCERROIS;18240;18;CHER;1
18209;;Saint-Georges-de-Poisieux;SAINT-GEORGES-DE-POISIEUX;18200;18;CHER;1
18210;;Saint-Georges-sur-la-Prée;SAINT-GEORGES-SUR-LA-PREE;18100;18;CHER;1
18211;;Saint-Georges-sur-Moulon;SAINT-GEORGES-SUR-MOULON;18110;18;CHER;1
18212;;Saint-Germain-des-Bois;SAINT-GERMAIN-DES-BOIS;18340;18;CHER;1
18213;;Saint-Germain-du-Puy;SAINT-GERMAIN-DU-PUY;18390;18;CHER;1
18214;;Saint-Hilaire-de-Court;SAINT-HILAIRE-DE-COURT;18100;18;CHER;1
18215;;Saint-Hilaire-de-Gondilly;SAINT-HILAIRE-DE-GONDILLY;18320;18;CHER;1
18216;;Saint-Hilaire-en-Lignières;SAINT-HILAIRE-EN-LIGNIERES;18160;18;CHER;1
18217;;Saint-Jeanvrin;SAINT-JEANVRIN;18370;18;CHER;1
18218;;Saint-Just;SAINT-JUST;18340;18;CHER;1
18219;;Saint-Laurent;SAINT-LAURENT;18330;18;CHER;1
18220;;Saint-Léger-le-Petit;SAINT-LEGER-LE-PETIT;18140;18;CHER;1
18221;;Saint-Loup-des-Chaumes;SAINT-LOUP-DES-CHAUMES;18190;18;CHER;1
18222;;Sainte-Lunaise;SAINTE-LUNAISE;18340;18;CHER;1
18223;;Saint-Martin-d'Auxigny;SAINT-MARTIN-D'AUXIGNY;18110;18;CHER;1
18224;;Saint-Martin-des-Champs;SAINT-MARTIN-DES-CHAMPS;18140;18;CHER;1
18225;;Saint-Maur;SAINT-MAUR;18270;18;CHER;1
18226;;Saint-Michel-de-Volangis;SAINT-MICHEL-DE-VOLANGIS;18390;18;CHER;1
18227;;Sainte-Montaine;SAINTE-MONTAINE;18700;18;CHER;1
18228;;Saint-Outrille;SAINT-OUTRILLE;18310;18;CHER;1
18229;;Saint-Palais;SAINT-PALAIS;18110;18;CHER;1
18230;;Saint-Pierre-les-Bois;SAINT-PIERRE-LES-BOIS;18170;18;CHER;1
18231;;Saint-Pierre-les-Étieux;SAINT-PIERRE-LES-ETIEUX;18210;18;CHER;1
18232;;Saint-Priest-la-Marche;SAINT-PRIEST-LA-MARCHE;18370;18;CHER;1
18233;;Saint-Satur;SAINT-SATUR;18300;18;CHER;1
18234;;Saint-Saturnin;SAINT-SATURNIN;18370;18;CHER;1
18235;;Sainte-Solange;SAINTE-SOLANGE;18220;18;CHER;1
18236;;Saint-Symphorien;SAINT-SYMPHORIEN;18190;18;CHER;1
18237;;Sainte-Thorette;SAINTE-THORETTE;18500;18;CHER;1
18238;;Saint-Vitte;SAINT-VITTE;18360;18;CHER;1
18239;;Saligny-le-Vif;SALIGNY-LE-VIF;18800;18;CHER;1
18240;;Sancergues;SANCERGUES;18140;18;CHER;1
18241;;Sancerre;SANCERRE;18300;18;CHER;1
18242;;Sancoins;SANCOINS;18600;18;CHER;1
18243;;Santranges;SANTRANGES;18240;18;CHER;1
18244;;Saugy;SAUGY;18290;18;CHER;1
18245;;Saulzais-le-Potier;SAULZAIS-LE-POTIER;18360;18;CHER;1
18246;;Savigny-en-Sancerre;SAVIGNY-EN-SANCERRE;18240;18;CHER;1
18247;;Savigny-en-Septaine;SAVIGNY-EN-SEPTAINE;18390;18;CHER;1
18248;;Senneçay;SENNECAY;18340;18;CHER;1
18249;;Sens-Beaujeu;SENS-BEAUJEU;18300;18;CHER;1
18250;;Serruelles;SERRUELLES;18190;18;CHER;1
18251;;Sévry;SEVRY;18140;18;CHER;1
18252;;Sidiailles;SIDIAILLES;18270;18;CHER;1
18253;;Soulangis;SOULANGIS;18220;18;CHER;1
18254;;Soye-en-Septaine;SOYE-EN-SEPTAINE;18340;18;CHER;1
18255;Le;Subdray;SUBDRAY;18570;18;CHER;1
18256;;Subligny;SUBLIGNY;18260;18;CHER;1
18257;;Sury-près-Léré;SURY-PRES-LERE;18240;18;CHER;1
18258;;Sury-en-Vaux;SURY-EN-VAUX;18300;18;CHER;1
18259;;Sury-ès-Bois;SURY-ES-BOIS;18260;18;CHER;1
18260;;Tendron;TENDRON;18350;18;CHER;1
18261;;Thaumiers;THAUMIERS;18210;18;CHER;1
18262;;Thauvenay;THAUVENAY;18300;18;CHER;1
18263;;Thénioux;THENIOUX;18100;18;CHER;1
18264;;Thou;THOU;18260;18;CHER;1
18265;;Torteron;TORTERON;18320;18;CHER;1
18266;;Touchay;TOUCHAY;18160;18;CHER;1
18267;;Trouy;TROUY;18570;18;CHER;1
18268;;Uzay-le-Venon;UZAY-LE-VENON;18190;18;CHER;1
18269;;Vailly-sur-Sauldre;VAILLY-SUR-SAULDRE;18260;18;CHER;1
18270;;Vallenay;VALLENAY;18190;18;CHER;1
18271;;Vasselay;VASSELAY;18110;18;CHER;1
18272;;Veaugues;VEAUGUES;18300;18;CHER;1
18273;;Venesmes;VENESMES;18190;18;CHER;1
18274;;Verdigny;VERDIGNY;18300;18;CHER;1
18275;;Vereaux;VEREAUX;18600;18;CHER;1
18276;;Vernais;VERNAIS;18210;18;CHER;1
18277;;Verneuil;VERNEUIL;18210;18;CHER;1
18278;;Vesdun;VESDUN;18360;18;CHER;1
18279;;Vierzon;VIERZON;18100;18;CHER;1
18280;;Vignoux-sous-les-Aix;VIGNOUX-SOUS-LES-AIX;18110;18;CHER;1
18281;;Vignoux-sur-Barangeon;VIGNOUX-SUR-BARANGEON;18500;18;CHER;1
18282;;Villabon;VILLABON;18800;18;CHER;1
18283;;Villecelin;VILLECELIN;18160;18;CHER;1
18284;;Villegenon;VILLEGENON;18260;18;CHER;1
18285;;Villeneuve-sur-Cher;VILLENEUVE-SUR-CHER;18400;18;CHER;1
18286;;Villequiers;VILLEQUIERS;18800;18;CHER;1
18287;;Vinon;VINON;18300;18;CHER;1
18288;;Vorly;VORLY;18340;18;CHER;1
18289;;Vornay;VORNAY;18130;18;CHER;1
18290;;Vouzeron;VOUZERON;18330;18;CHER;1
19001;;Affieux;AFFIEUX;19260;19;CORREZE;1
19002;;Aix;AIX;19200;19;CORREZE;1
19003;;Albignac;ALBIGNAC;19190;19;CORREZE;1
19004;;Albussac;ALBUSSAC;19380;19;CORREZE;1
19005;;Allassac;ALLASSAC;19240;19;CORREZE;1
19006;;Alleyrat;ALLEYRAT;19200;19;CORREZE;1
19007;;Altillac;ALTILLAC;19120;19;CORREZE;1
19008;;Ambrugeat;AMBRUGEAT;19250;19;CORREZE;1
19009;Les;Angles-sur-Corrèze;ANGLES-SUR-CORREZE;19000;19;CORREZE;1
19010;;Argentat;ARGENTAT;19400;19;CORREZE;1
19011;;Arnac-Pompadour;ARNAC-POMPADOUR;19230;19;CORREZE;1
19012;;Astaillac;ASTAILLAC;19120;19;CORREZE;1
19013;;Aubazines;AUBAZINES;19190;19;CORREZE;1
19014;;Auriac;AURIAC;19220;19;CORREZE;1
19015;;Ayen;AYEN;19310;19;CORREZE;1
19016;;Bar;BAR;19800;19;CORREZE;1
19017;;Bassignac-le-Bas;BASSIGNAC-LE-BAS;19430;19;CORREZE;1
19018;;Bassignac-le-Haut;BASSIGNAC-LE-HAUT;19220;19;CORREZE;1
19019;;Beaulieu-sur-Dordogne;BEAULIEU-SUR-DORDOGNE;19120;19;CORREZE;1
19020;;Beaumont;BEAUMONT;19390;19;CORREZE;1
19021;;Bellechassagne;BELLECHASSAGNE;19290;19;CORREZE;1
19022;;Benayes;BENAYES;19510;19;CORREZE;1
19023;;Beynat;BEYNAT;19190;19;CORREZE;1
19024;;Beyssac;BEYSSAC;19230;19;CORREZE;1
19025;;Beyssenac;BEYSSENAC;19230;19;CORREZE;1
19026;;Bilhac;BILHAC;19120;19;CORREZE;1
19027;;Bonnefond;BONNEFOND;19170;19;CORREZE;1
19028;;Bort-les-Orgues;BORT-LES-ORGUES;19110;19;CORREZE;1
19029;;Branceilles;BRANCEILLES;19500;19;CORREZE;1
19030;;Brignac-la-Plaine;BRIGNAC-LA-PLAINE;19310;19;CORREZE;1
19031;;Brive-la-Gaillarde;BRIVE-LA-GAILLARDE;19100;19;CORREZE;1
19032;;Brivezac;BRIVEZAC;19120;19;CORREZE;1
19033;;Bugeat;BUGEAT;19170;19;CORREZE;1
19034;;Camps-Saint-Mathurin-Léobazel;CAMPS-SAINT-MATHURIN-LEOBAZEL;19430;19;CORREZE;1
19035;;Chabrignac;CHABRIGNAC;19350;19;CORREZE;1
19036;;Chamberet;CHAMBERET;19370;19;CORREZE;1
19037;;Chamboulive;CHAMBOULIVE;19450;19;CORREZE;1
19038;;Chameyrat;CHAMEYRAT;19330;19;CORREZE;1
19039;;Champagnac-la-Noaille;CHAMPAGNAC-LA-NOAILLE;19320;19;CORREZE;1
19040;;Champagnac-la-Prune;CHAMPAGNAC-LA-PRUNE;19320;19;CORREZE;1
19041;;Chanac-les-Mines;CHANAC-LES-MINES;19150;19;CORREZE;1
19042;;Chanteix;CHANTEIX;19330;19;CORREZE;1
19043;La;Chapelle-aux-Brocs;CHAPELLE-AUX-BROCS;19360;19;CORREZE;1
19044;La;Chapelle-aux-Saints;CHAPELLE-AUX-SAINTS;19120;19;CORREZE;1
19045;La;Chapelle-Saint-Géraud;CHAPELLE-SAINT-GERAUD;19430;19;CORREZE;1
19046;;Chapelle-Spinasse;CHAPELLE-SPINASSE;19300;19;CORREZE;1
19047;;Chartrier-Ferrière;CHARTRIER-FERRIERE;19600;19;CORREZE;1
19048;Le;Chastang;CHASTANG;19190;19;CORREZE;1
19049;;Chasteaux;CHASTEAUX;19600;19;CORREZE;1
19050;;Chauffour-sur-Vell;CHAUFFOUR-SUR-VELL;19500;19;CORREZE;1
19051;;Chaumeil;CHAUMEIL;19390;19;CORREZE;1
19052;;Chavanac;CHAVANAC;19290;19;CORREZE;1
19053;;Chaveroche;CHAVEROCHE;19200;19;CORREZE;1
19054;;Chenailler-Mascheix;CHENAILLER-MASCHEIX;19120;19;CORREZE;1
19055;;Chirac-Bellevue;CHIRAC-BELLEVUE;19160;19;CORREZE;1
19056;;Clergoux;CLERGOUX;19320;19;CORREZE;1
19057;;Collonges-la-Rouge;COLLONGES-LA-ROUGE;19500;19;CORREZE;1
19058;;Combressol;COMBRESSOL;19250;19;CORREZE;1
19059;;Concèze;CONCEZE;19350;19;CORREZE;1
19060;;Condat-sur-Ganaveix;CONDAT-SUR-GANAVEIX;19140;19;CORREZE;1
19061;;Cornil;CORNIL;19150;19;CORREZE;1
19062;;Corrèze;CORREZE;19800;19;CORREZE;1
19063;;Cosnac;COSNAC;19360;19;CORREZE;1
19064;;Couffy-sur-Sarsonne;COUFFY-SUR-SARSONNE;19340;19;CORREZE;1
19065;;Courteix;COURTEIX;19340;19;CORREZE;1
19066;;Cublac;CUBLAC;19520;19;CORREZE;1
19067;;Curemonte;CUREMONTE;19500;19;CORREZE;1
19068;;Dampniat;DAMPNIAT;19360;19;CORREZE;1
19069;;Darazac;DARAZAC;19220;19;CORREZE;1
19070;;Darnets;DARNETS;19300;19;CORREZE;1
19071;;Davignac;DAVIGNAC;19250;19;CORREZE;1
19072;;Donzenac;DONZENAC;19270;19;CORREZE;1
19073;;Égletons;EGLETONS;19300;19;CORREZE;1
19074;L';Église-aux-Bois;EGLISE-AUX-BOIS;19170;19;CORREZE;1
19075;;Espagnac;ESPAGNAC;19150;19;CORREZE;1
19076;;Espartignac;ESPARTIGNAC;19140;19;CORREZE;1
19077;;Estivals;ESTIVALS;19600;19;CORREZE;1
19078;;Estivaux;ESTIVAUX;19410;19;CORREZE;1
19079;;Eyburie;EYBURIE;19140;19;CORREZE;1
19080;;Eygurande;EYGURANDE;19340;19;CORREZE;1
19081;;Eyrein;EYREIN;19800;19;CORREZE;1
19082;;Favars;FAVARS;19330;19;CORREZE;1
19083;;Feyt;FEYT;19340;19;CORREZE;1
19084;;Forgès;FORGES;19380;19;CORREZE;1
19085;;Gimel-les-Cascades;GIMEL-LES-CASCADES;19800;19;CORREZE;1
19086;;Goulles;GOULLES;19430;19;CORREZE;1
19087;;Gourdon-Murat;GOURDON-MURAT;19170;19;CORREZE;1
19088;;Grandsaigne;GRANDSAIGNE;19300;19;CORREZE;1
19089;;Gros-Chastang;GROS-CHASTANG;19320;19;CORREZE;1
19090;;Gumond;GUMOND;19320;19;CORREZE;1
19091;;Hautefage;HAUTEFAGE;19400;19;CORREZE;1
19092;Le;Jardin;JARDIN;19300;19;CORREZE;1
19093;;Jugeals-Nazareth;JUGEALS-NAZARETH;19500;19;CORREZE;1
19094;;Juillac;JUILLAC;19350;19;CORREZE;1
19095;;Lacelle;LACELLE;19170;19;CORREZE;1
19096;;Ladignac-sur-Rondelles;LADIGNAC-SUR-RONDELLES;19150;19;CORREZE;1
19097;;Lafage-sur-Sombre;LAFAGE-SUR-SOMBRE;19320;19;CORREZE;1
19098;;Lagarde-Enval;LAGARDE-ENVAL;19150;19;CORREZE;1
19099;;Lagleygeolle;LAGLEYGEOLLE;19500;19;CORREZE;1
19100;;Lagraulière;LAGRAULIERE;19700;19;CORREZE;1
19101;;Laguenne;LAGUENNE;19150;19;CORREZE;1
19102;;Lamazière-Basse;LAMAZIERE-BASSE;19160;19;CORREZE;1
19103;;Lamazière-Haute;LAMAZIERE-HAUTE;19340;19;CORREZE;1
19104;;Lamongerie;LAMONGERIE;19510;19;CORREZE;1
19105;;Lanteuil;LANTEUIL;19190;19;CORREZE;1
19106;;Lapleau;LAPLEAU;19550;19;CORREZE;1
19107;;Larche;LARCHE;19600;19;CORREZE;1
19108;;Laroche-près-Feyt;LAROCHE-PRES-FEYT;19340;19;CORREZE;1
19109;;Lascaux;LASCAUX;19130;19;CORREZE;1
19110;;Latronche;LATRONCHE;19160;19;CORREZE;1
19111;;Laval-sur-Luzège;LAVAL-SUR-LUZEGE;19550;19;CORREZE;1
19112;;Lestards;LESTARDS;19170;19;CORREZE;1
19113;;Liginiac;LIGINIAC;19160;19;CORREZE;1
19114;;Lignareix;LIGNAREIX;19200;19;CORREZE;1
19115;;Ligneyrac;LIGNEYRAC;19500;19;CORREZE;1
19116;;Liourdres;LIOURDRES;19120;19;CORREZE;1
19117;;Lissac-sur-Couze;LISSAC-SUR-COUZE;19600;19;CORREZE;1
19118;Le;Lonzac;LONZAC;19470;19;CORREZE;1
19119;;Lostanges;LOSTANGES;19500;19;CORREZE;1
19120;;Louignac;LOUIGNAC;19310;19;CORREZE;1
19121;;Lubersac;LUBERSAC;19210;19;CORREZE;1
19122;;Madranges;MADRANGES;19470;19;CORREZE;1
19123;;Malemort-sur-Corrèze;MALEMORT-SUR-CORREZE;19360;19;CORREZE;1
19124;;Mansac;MANSAC;19520;19;CORREZE;1
19125;;Marcillac-la-Croisille;MARCILLAC-LA-CROISILLE;19320;19;CORREZE;1
19126;;Marcillac-la-Croze;MARCILLAC-LA-CROZE;19500;19;CORREZE;1
19127;;Marc-la-Tour;MARC-LA-TOUR;19150;19;CORREZE;1
19128;;Margerides;MARGERIDES;19200;19;CORREZE;1
19129;;Masseret;MASSERET;19510;19;CORREZE;1
19130;;Maussac;MAUSSAC;19250;19;CORREZE;1
19131;;Meilhards;MEILHARDS;19510;19;CORREZE;1
19132;;Ménoire;MENOIRE;19190;19;CORREZE;1
19133;;Mercœur;MERCOEUR;19430;19;CORREZE;1
19134;;Merlines;MERLINES;19340;19;CORREZE;1
19135;;Mestes;MESTES;19200;19;CORREZE;1
19136;;Meymac;MEYMAC;19250;19;CORREZE;1
19137;;Meyrignac-l'Église;MEYRIGNAC-L'EGLISE;19800;19;CORREZE;1
19138;;Meyssac;MEYSSAC;19500;19;CORREZE;1
19139;;Millevaches;MILLEVACHES;19290;19;CORREZE;1
19140;;Monceaux-sur-Dordogne;MONCEAUX-SUR-DORDOGNE;19400;19;CORREZE;1
19141;;Monestier-Merlines;MONESTIER-MERLINES;19340;19;CORREZE;1
19142;;Monestier-Port-Dieu;MONESTIER-PORT-DIEU;19110;19;CORREZE;1
19143;;Montaignac-Saint-Hippolyte;MONTAIGNAC-SAINT-HIPPOLYTE;19300;19;CORREZE;1
19144;;Montgibaud;MONTGIBAUD;19210;19;CORREZE;1
19145;;Moustier-Ventadour;MOUSTIER-VENTADOUR;19300;19;CORREZE;1
19146;;Naves;NAVES;19460;19;CORREZE;1
19147;;Nespouls;NESPOULS;19600;19;CORREZE;1
19148;;Neuvic;NEUVIC;19160;19;CORREZE;1
19149;;Neuville;NEUVILLE;19380;19;CORREZE;1
19150;;Noailhac;NOAILHAC;19500;19;CORREZE;1
19151;;Noailles;NOAILLES;19600;19;CORREZE;1
19152;;Nonards;NONARDS;19120;19;CORREZE;1
19153;;Objat;OBJAT;19130;19;CORREZE;1
19154;;Orgnac-sur-Vézère;ORGNAC-SUR-VEZERE;19410;19;CORREZE;1
19155;;Orliac-de-Bar;ORLIAC-DE-BAR;19390;19;CORREZE;1
19156;;Palazinges;PALAZINGES;19190;19;CORREZE;1
19157;;Palisse;PALISSE;19160;19;CORREZE;1
19158;;Pandrignes;PANDRIGNES;19150;19;CORREZE;1
19159;;Péret-Bel-Air;PERET-BEL-AIR;19300;19;CORREZE;1
19160;;Pérols-sur-Vézère;PEROLS-SUR-VEZERE;19170;19;CORREZE;1
19161;;Perpezac-le-Blanc;PERPEZAC-LE-BLANC;19310;19;CORREZE;1
19162;;Perpezac-le-Noir;PERPEZAC-LE-NOIR;19410;19;CORREZE;1
19163;Le;Pescher;PESCHER;19190;19;CORREZE;1
19164;;Peyrelevade;PEYRELEVADE;19290;19;CORREZE;1
19165;;Peyrissac;PEYRISSAC;19260;19;CORREZE;1
19166;;Pierrefitte;PIERREFITTE;19450;19;CORREZE;1
19167;;Confolent-Port-Dieu;CONFOLENT-PORT-DIEU;19200;19;CORREZE;1
19168;;Pradines;PRADINES;19170;19;CORREZE;1
19169;;Puy-d'Arnac;PUY-D'ARNAC;19120;19;CORREZE;1
19170;;Queyssac-les-Vignes;QUEYSSAC-LES-VIGNES;19120;19;CORREZE;1
19171;;Reygade;REYGADE;19430;19;CORREZE;1
19172;;Rilhac-Treignac;RILHAC-TREIGNAC;19260;19;CORREZE;1
19173;;Rilhac-Xaintrie;RILHAC-XAINTRIE;19220;19;CORREZE;1
19174;La;Roche-Canillac;ROCHE-CANILLAC;19320;19;CORREZE;1
19175;;Roche-le-Peyroux;ROCHE-LE-PEYROUX;19160;19;CORREZE;1
19176;;Rosiers-d'Égletons;ROSIERS-D'EGLETONS;19300;19;CORREZE;1
19177;;Rosiers-de-Juillac;ROSIERS-DE-JUILLAC;19350;19;CORREZE;1
19178;;Sadroc;SADROC;19270;19;CORREZE;1
19179;;Saillac;SAILLAC;19500;19;CORREZE;1
19180;;Saint-Angel;SAINT-ANGEL;19200;19;CORREZE;1
19181;;Saint-Augustin;SAINT-AUGUSTIN;19390;19;CORREZE;1
19182;;Saint-Aulaire;SAINT-AULAIRE;19130;19;CORREZE;1
19183;;Saint-Bazile-de-la-Roche;SAINT-BAZILE-DE-LA-ROCHE;19320;19;CORREZE;1
19184;;Saint-Bazile-de-Meyssac;SAINT-BAZILE-DE-MEYSSAC;19500;19;CORREZE;1
19185;;Saint-Bonnet-Avalouze;SAINT-BONNET-AVALOUZE;19150;19;CORREZE;1
19186;;Saint-Bonnet-Elvert;SAINT-BONNET-ELVERT;19380;19;CORREZE;1
19187;;Saint-Bonnet-la-Rivière;SAINT-BONNET-LA-RIVIERE;19130;19;CORREZE;1
19188;;Saint-Bonnet-l'Enfantier;SAINT-BONNET-L'ENFANTIER;19410;19;CORREZE;1
19189;;Saint-Bonnet-les-Tours-de-Merle;SAINT-BONNET-LES-TOURS-DE-MERLE;19430;19;CORREZE;1
19190;;Saint-Bonnet-près-Bort;SAINT-BONNET-PRES-BORT;19200;19;CORREZE;1
19191;;Saint-Cernin-de-Larche;SAINT-CERNIN-DE-LARCHE;19600;19;CORREZE;1
19192;;Saint-Chamant;SAINT-CHAMANT;19380;19;CORREZE;1
19193;;Saint-Cirgues-la-Loutre;SAINT-CIRGUES-LA-LOUTRE;19220;19;CORREZE;1
19194;;Saint-Clément;SAINT-CLEMENT;19700;19;CORREZE;1
19195;;Saint-Cyprien;SAINT-CYPRIEN;19130;19;CORREZE;1
19196;;Saint-Cyr-la-Roche;SAINT-CYR-LA-ROCHE;19130;19;CORREZE;1
19198;;Saint-Éloy-les-Tuileries;SAINT-ELOY-LES-TUILERIES;19210;19;CORREZE;1
19199;;Saint-Étienne-aux-Clos;SAINT-ETIENNE-AUX-CLOS;19200;19;CORREZE;1
19200;;Saint-Étienne-la-Geneste;SAINT-ETIENNE-LA-GENESTE;19160;19;CORREZE;1
19201;;Saint-Exupéry-les-Roches;SAINT-EXUPERY-LES-ROCHES;19200;19;CORREZE;1
19202;;Sainte-Féréole;SAINTE-FEREOLE;19270;19;CORREZE;1
19203;;Sainte-Fortunade;SAINTE-FORTUNADE;19490;19;CORREZE;1
19204;;Saint-Fréjoux;SAINT-FREJOUX;19200;19;CORREZE;1
19205;;Saint-Geniez-ô-Merle;SAINT-GENIEZ-O-MERLE;19220;19;CORREZE;1
19206;;Saint-Germain-Lavolps;SAINT-GERMAIN-LAVOLPS;19290;19;CORREZE;1
19207;;Saint-Germain-les-Vergnes;SAINT-GERMAIN-LES-VERGNES;19330;19;CORREZE;1
19208;;Saint-Hilaire-Foissac;SAINT-HILAIRE-FOISSAC;19550;19;CORREZE;1
19209;;Saint-Hilaire-les-Courbes;SAINT-HILAIRE-LES-COURBES;19170;19;CORREZE;1
19210;;Saint-Hilaire-Luc;SAINT-HILAIRE-LUC;19160;19;CORREZE;1
19211;;Saint-Hilaire-Peyroux;SAINT-HILAIRE-PEYROUX;19560;19;CORREZE;1
19212;;Saint-Hilaire-Taurieux;SAINT-HILAIRE-TAURIEUX;19400;19;CORREZE;1
19213;;Saint-Jal;SAINT-JAL;19700;19;CORREZE;1
19214;;Saint-Julien-aux-Bois;SAINT-JULIEN-AUX-BOIS;19220;19;CORREZE;1
19215;;Saint-Julien-le-Pèlerin;SAINT-JULIEN-LE-PELERIN;19430;19;CORREZE;1
19216;;Saint-Julien-le-Vendômois;SAINT-JULIEN-LE-VENDOMOIS;19210;19;CORREZE;1
19217;;Saint-Julien-Maumont;SAINT-JULIEN-MAUMONT;19500;19;CORREZE;1
19218;;Saint-Julien-près-Bort;SAINT-JULIEN-PRES-BORT;19110;19;CORREZE;1
19219;;Sainte-Marie-Lapanouze;SAINTE-MARIE-LAPANOUZE;19160;19;CORREZE;1
19220;;Saint-Martial-de-Gimel;SAINT-MARTIAL-DE-GIMEL;19150;19;CORREZE;1
19221;;Saint-Martial-Entraygues;SAINT-MARTIAL-ENTRAYGUES;19400;19;CORREZE;1
19222;;Saint-Martin-la-Méanne;SAINT-MARTIN-LA-MEANNE;19320;19;CORREZE;1
19223;;Saint-Martin-Sepert;SAINT-MARTIN-SEPERT;19210;19;CORREZE;1
19225;;Saint-Merd-de-Lapleau;SAINT-MERD-DE-LAPLEAU;19320;19;CORREZE;1
19226;;Saint-Merd-les-Oussines;SAINT-MERD-LES-OUSSINES;19170;19;CORREZE;1
19227;;Saint-Mexant;SAINT-MEXANT;19330;19;CORREZE;1
19228;;Saint-Pantaléon-de-Lapleau;SAINT-PANTALEON-DE-LAPLEAU;19160;19;CORREZE;1
19229;;Saint-Pantaléon-de-Larche;SAINT-PANTALEON-DE-LARCHE;19600;19;CORREZE;1
19230;;Saint-Pardoux-Corbier;SAINT-PARDOUX-CORBIER;19210;19;CORREZE;1
19231;;Saint-Pardoux-la-Croisille;SAINT-PARDOUX-LA-CROISILLE;19320;19;CORREZE;1
19232;;Saint-Pardoux-le-Neuf;SAINT-PARDOUX-LE-NEUF;19200;19;CORREZE;1
19233;;Saint-Pardoux-le-Vieux;SAINT-PARDOUX-LE-VIEUX;19200;19;CORREZE;1
19234;;Saint-Pardoux-l'Ortigier;SAINT-PARDOUX-L'ORTIGIER;19270;19;CORREZE;1
19235;;Saint-Paul;SAINT-PAUL;19150;19;CORREZE;1
19236;;Saint-Priest-de-Gimel;SAINT-PRIEST-DE-GIMEL;19800;19;CORREZE;1
19237;;Saint-Privat;SAINT-PRIVAT;19220;19;CORREZE;1
19238;;Saint-Rémy;SAINT-REMY;19290;19;CORREZE;1
19239;;Saint-Robert;SAINT-ROBERT;19310;19;CORREZE;1
19240;;Saint-Salvadour;SAINT-SALVADOUR;19700;19;CORREZE;1
19241;;Saint-Setiers;SAINT-SETIERS;19290;19;CORREZE;1
19242;;Saint-Solve;SAINT-SOLVE;19130;19;CORREZE;1
19243;;Saint-Sornin-Lavolps;SAINT-SORNIN-LAVOLPS;19230;19;CORREZE;1
19244;;Saint-Sulpice-les-Bois;SAINT-SULPICE-LES-BOIS;19250;19;CORREZE;1
19245;;Saint-Sylvain;SAINT-SYLVAIN;19380;19;CORREZE;1
19246;;Saint-Viance;SAINT-VIANCE;19240;19;CORREZE;1
19247;;Saint-Victour;SAINT-VICTOUR;19200;19;CORREZE;1
19248;;Saint-Ybard;SAINT-YBARD;19140;19;CORREZE;1
19249;;Saint-Yrieix-le-Déjalat;SAINT-YRIEIX-LE-DEJALAT;19300;19;CORREZE;1
19250;;Salon-la-Tour;SALON-LA-TOUR;19510;19;CORREZE;1
19251;;Sarran;SARRAN;19800;19;CORREZE;1
19252;;Sarroux;SARROUX;19110;19;CORREZE;1
19253;;Segonzac;SEGONZAC;19310;19;CORREZE;1
19254;;Ségur-le-Château;SEGUR-LE-CHATEAU;19230;19;CORREZE;1
19255;;Seilhac;SEILHAC;19700;19;CORREZE;1
19256;;Sérandon;SERANDON;19160;19;CORREZE;1
19257;;Sérilhac;SERILHAC;19190;19;CORREZE;1
19258;;Servières-le-Château;SERVIERES-LE-CHATEAU;19220;19;CORREZE;1
19259;;Sexcles;SEXCLES;19430;19;CORREZE;1
19260;;Sioniac;SIONIAC;19120;19;CORREZE;1
19261;;Sornac;SORNAC;19290;19;CORREZE;1
19262;;Soudaine-Lavinadière;SOUDAINE-LAVINADIERE;19370;19;CORREZE;1
19263;;Soudeilles;SOUDEILLES;19300;19;CORREZE;1
19264;;Soursac;SOURSAC;19550;19;CORREZE;1
19265;;Tarnac;TARNAC;19170;19;CORREZE;1
19266;;Thalamy;THALAMY;19200;19;CORREZE;1
19268;;Toy-Viam;TOY-VIAM;19170;19;CORREZE;1
19269;;Treignac;TREIGNAC;19260;19;CORREZE;1
19270;;Troche;TROCHE;19230;19;CORREZE;1
19271;;Tudeils;TUDEILS;19120;19;CORREZE;1
19272;;Tulle;TULLE;19000;19;CORREZE;1
19273;;Turenne;TURENNE;19500;19;CORREZE;1
19274;;Ussac;USSAC;19270;19;CORREZE;1
19275;;Ussel;USSEL;19200;19;CORREZE;1
19276;;Uzerche;UZERCHE;19140;19;CORREZE;1
19277;;Valiergues;VALIERGUES;19200;19;CORREZE;1
19278;;Varetz;VARETZ;19240;19;CORREZE;1
19279;;Vars-sur-Roseix;VARS-SUR-ROSEIX;19130;19;CORREZE;1
19280;;Végennes;VEGENNES;19120;19;CORREZE;1
19281;;Veix;VEIX;19260;19;CORREZE;1
19282;;Venarsal;VENARSAL;19360;19;CORREZE;1
19283;;Veyrières;VEYRIERES;19200;19;CORREZE;1
19284;;Viam;VIAM;19170;19;CORREZE;1
19285;;Vigeois;VIGEOIS;19410;19;CORREZE;1
19286;;Vignols;VIGNOLS;19130;19;CORREZE;1
19287;;Vitrac-sur-Montane;VITRAC-SUR-MONTANE;19800;19;CORREZE;1
19288;;Voutezac;VOUTEZAC;19130;19;CORREZE;1
19289;;Yssandon;YSSANDON;19310;19;CORREZE;1
21001;;Agencourt;AGENCOURT;21700;21;COTE D'OR;1
21002;;Agey;AGEY;21410;21;COTE D'OR;1
21003;;Ahuy;AHUY;21121;21;COTE D'OR;1
21004;;Aignay-le-Duc;AIGNAY-LE-DUC;21510;21;COTE D'OR;1
21005;;Aiserey;AISEREY;21110;21;COTE D'OR;1
21006;;Aisey-sur-Seine;AISEY-SUR-SEINE;21400;21;COTE D'OR;1
21007;;Aisy-sous-Thil;AISY-SOUS-THIL;21390;21;COTE D'OR;1
21008;;Alise-Sainte-Reine;ALISE-SAINTE-REINE;21150;21;COTE D'OR;1
21009;;Allerey;ALLEREY;21230;21;COTE D'OR;1
21010;;Aloxe-Corton;ALOXE-CORTON;21420;21;COTE D'OR;1
21011;;Ampilly-les-Bordes;AMPILLY-LES-BORDES;21450;21;COTE D'OR;1
21012;;Ampilly-le-Sec;AMPILLY-LE-SEC;21400;21;COTE D'OR;1
21013;;Ancey;ANCEY;21410;21;COTE D'OR;1
21014;;Antheuil;ANTHEUIL;21360;21;COTE D'OR;1
21015;;Antigny-la-Ville;ANTIGNY-LA-VILLE;21230;21;COTE D'OR;1
21016;;Arceau;ARCEAU;21310;21;COTE D'OR;1
21017;;Arcenant;ARCENANT;21700;21;COTE D'OR;1
21018;;Arcey;ARCEY;21410;21;COTE D'OR;1
21020;;Arconcey;ARCONCEY;21320;21;COTE D'OR;1
21021;;Arc-sur-Tille;ARC-SUR-TILLE;21560;21;COTE D'OR;1
21022;;Argilly;ARGILLY;21700;21;COTE D'OR;1
21023;;Arnay-le-Duc;ARNAY-LE-DUC;21230;21;COTE D'OR;1
21024;;Arnay-sous-Vitteaux;ARNAY-SOUS-VITTEAUX;21350;21;COTE D'OR;1
21025;;Arrans;ARRANS;21500;21;COTE D'OR;1
21026;;Asnières-en-Montagne;ASNIERES-EN-MONTAGNE;21500;21;COTE D'OR;1
21027;;Asnières-lès-Dijon;ASNIERES-LES-DIJON;21380;21;COTE D'OR;1
21028;;Athée;ATHEE;21130;21;COTE D'OR;1
21029;;Athie;ATHIE;21500;21;COTE D'OR;1
21030;;Aubaine;AUBAINE;21360;21;COTE D'OR;1
21031;;Aubigny-en-Plaine;AUBIGNY-EN-PLAINE;21170;21;COTE D'OR;1
21032;;Aubigny-la-Ronce;AUBIGNY-LA-RONCE;21340;21;COTE D'OR;1
21033;;Aubigny-lès-Sombernon;AUBIGNY-LES-SOMBERNON;21540;21;COTE D'OR;1
21034;;Autricourt;AUTRICOURT;21570;21;COTE D'OR;1
21035;;Auvillars-sur-Saône;AUVILLARS-SUR-SAONE;21250;21;COTE D'OR;1
21036;;Auxant;AUXANT;21360;21;COTE D'OR;1
21037;;Auxey-Duresses;AUXEY-DURESSES;21190;21;COTE D'OR;1
21038;;Auxonne;AUXONNE;21130;21;COTE D'OR;1
21039;;Avelanges;AVELANGES;21120;21;COTE D'OR;1
21040;;Avosnes;AVOSNES;21350;21;COTE D'OR;1
21041;;Avot;AVOT;21580;21;COTE D'OR;1
21042;;Bagnot;BAGNOT;21700;21;COTE D'OR;1
21043;;Baigneux-les-Juifs;BAIGNEUX-LES-JUIFS;21450;21;COTE D'OR;1
21044;;Balot;BALOT;21330;21;COTE D'OR;1
21045;;Barbirey-sur-Ouche;BARBIREY-SUR-OUCHE;21410;21;COTE D'OR;1
21046;;Bard-le-Régulier;BARD-LE-REGULIER;21430;21;COTE D'OR;1
21047;;Bard-lès-Époisses;BARD-LES-EPOISSES;21460;21;COTE D'OR;1
21048;;Barges;BARGES;21910;21;COTE D'OR;1
21049;;Barjon;BARJON;21580;21;COTE D'OR;1
21050;;Baubigny;BAUBIGNY;21340;21;COTE D'OR;1
21051;;Baulme-la-Roche;BAULME-LA-ROCHE;21410;21;COTE D'OR;1
21052;;Beaulieu;BEAULIEU;21510;21;COTE D'OR;1
21053;;Beaumont-sur-Vingeanne;BEAUMONT-SUR-VINGEANNE;21310;21;COTE D'OR;1
21054;;Beaune;BEAUNE;21200;21;COTE D'OR;1
21055;;Beaunotte;BEAUNOTTE;21510;21;COTE D'OR;1
21056;;Beire-le-Châtel;BEIRE-LE-CHATEL;21310;21;COTE D'OR;1
21057;;Beire-le-Fort;BEIRE-LE-FORT;21110;21;COTE D'OR;1
21058;;Belan-sur-Ource;BELAN-SUR-OURCE;21570;21;COTE D'OR;1
21059;;Bellefond;BELLEFOND;21490;21;COTE D'OR;1
21060;;Belleneuve;BELLENEUVE;21310;21;COTE D'OR;1
21061;;Bellenod-sur-Seine;BELLENOD-SUR-SEINE;21510;21;COTE D'OR;1
21062;;Bellenot-sous-Pouilly;BELLENOT-SOUS-POUILLY;21320;21;COTE D'OR;1
21063;;Beneuvre;BENEUVRE;21290;21;COTE D'OR;1
21064;;Benoisey;BENOISEY;21500;21;COTE D'OR;1
21065;;Bessey-en-Chaume;BESSEY-EN-CHAUME;21360;21;COTE D'OR;1
21066;;Bessey-la-Cour;BESSEY-LA-COUR;21360;21;COTE D'OR;1
21067;;Bessey-lès-Cîteaux;BESSEY-LES-CITEAUX;21110;21;COTE D'OR;1
21068;;Beurey-Bauguay;BEUREY-BAUGUAY;21320;21;COTE D'OR;1
21069;;Beurizot;BEURIZOT;21350;21;COTE D'OR;1
21070;;Bévy;BEVY;21220;21;COTE D'OR;1
21071;;Bèze;BEZE;21310;21;COTE D'OR;1
21072;;Bézouotte;BEZOUOTTE;21310;21;COTE D'OR;1
21073;;Bierre-lès-Semur;BIERRE-LES-SEMUR;21390;21;COTE D'OR;1
21074;;Billey;BILLEY;21130;21;COTE D'OR;1
21075;;Billy-lès-Chanceaux;BILLY-LES-CHANCEAUX;21450;21;COTE D'OR;1
21076;;Binges;BINGES;21270;21;COTE D'OR;1
21077;;Bissey-la-Côte;BISSEY-LA-COTE;21520;21;COTE D'OR;1
21078;;Bissey-la-Pierre;BISSEY-LA-PIERRE;21330;21;COTE D'OR;1
21079;;Blagny-sur-Vingeanne;BLAGNY-SUR-VINGEANNE;21310;21;COTE D'OR;1
21080;;Blaisy-Bas;BLAISY-BAS;21540;21;COTE D'OR;1
21081;;Blaisy-Haut;BLAISY-HAUT;21540;21;COTE D'OR;1
21082;;Blancey;BLANCEY;21320;21;COTE D'OR;1
21083;;Blanot;BLANOT;21430;21;COTE D'OR;1
21084;;Source-Seine;SOURCE-SEINE;21690;21;COTE D'OR;1
21085;;Bligny-le-Sec;BLIGNY-LE-SEC;21440;21;COTE D'OR;1
21086;;Bligny-lès-Beaune;BLIGNY-LES-BEAUNE;21200;21;COTE D'OR;1
21087;;Bligny-sur-Ouche;BLIGNY-SUR-OUCHE;21360;21;COTE D'OR;1
21088;;Boncourt-le-Bois;BONCOURT-LE-BOIS;21700;21;COTE D'OR;1
21089;;Bonnencontre;BONNENCONTRE;21250;21;COTE D'OR;1
21090;;Boudreville;BOUDREVILLE;21520;21;COTE D'OR;1
21091;;Bouhey;BOUHEY;21360;21;COTE D'OR;1
21092;;Bouilland;BOUILLAND;21420;21;COTE D'OR;1
21093;;Bouix;BOUIX;21330;21;COTE D'OR;1
21094;;Bourberain;BOURBERAIN;21610;21;COTE D'OR;1
21095;;Bousselange;BOUSSELANGE;21250;21;COTE D'OR;1
21096;;Boussenois;BOUSSENOIS;21260;21;COTE D'OR;1
21097;;Boussey;BOUSSEY;21350;21;COTE D'OR;1
21098;;Boux-sous-Salmaise;BOUX-SOUS-SALMAISE;21690;21;COTE D'OR;1
21099;;Bouze-lès-Beaune;BOUZE-LES-BEAUNE;21200;21;COTE D'OR;1
21100;;Brain;BRAIN;21350;21;COTE D'OR;1
21101;;Braux;BRAUX;21390;21;COTE D'OR;1
21102;;Brazey-en-Morvan;BRAZEY-EN-MORVAN;21430;21;COTE D'OR;1
21103;;Brazey-en-Plaine;BRAZEY-EN-PLAINE;21470;21;COTE D'OR;1
21104;;Brémur-et-Vaurois;BREMUR-ET-VAUROIS;21400;21;COTE D'OR;1
21105;;Bressey-sur-Tille;BRESSEY-SUR-TILLE;21560;21;COTE D'OR;1
21106;;Bretenière;BRETENIERE;21110;21;COTE D'OR;1
21107;;Bretigny;BRETIGNY;21490;21;COTE D'OR;1
21108;;Brianny;BRIANNY;21390;21;COTE D'OR;1
21109;;Brion-sur-Ource;BRION-SUR-OURCE;21570;21;COTE D'OR;1
21110;;Brochon;BROCHON;21220;21;COTE D'OR;1
21111;;Brognon;BROGNON;21490;21;COTE D'OR;1
21112;;Broin;BROIN;21250;21;COTE D'OR;1
21113;;Broindon;BROINDON;21220;21;COTE D'OR;1
21114;;Buffon;BUFFON;21500;21;COTE D'OR;1
21115;;Buncey;BUNCEY;21400;21;COTE D'OR;1
21116;;Bure-les-Templiers;BURE-LES-TEMPLIERS;21290;21;COTE D'OR;1
21117;;Busseaut;BUSSEAUT;21510;21;COTE D'OR;1
21118;;Busserotte-et-Montenaille;BUSSEROTTE-ET-MONTENAILLE;21580;21;COTE D'OR;1
21119;;Bussières;BUSSIERES;21580;21;COTE D'OR;1
21120;La;Bussière-sur-Ouche;BUSSIERE-SUR-OUCHE;21360;21;COTE D'OR;1
21121;;Bussy-la-Pesle;BUSSY-LA-PESLE;21540;21;COTE D'OR;1
21122;;Bussy-le-Grand;BUSSY-LE-GRAND;21150;21;COTE D'OR;1
21123;;Buxerolles;BUXEROLLES;21290;21;COTE D'OR;1
21124;;Censerey;CENSEREY;21430;21;COTE D'OR;1
21125;;Cérilly;CERILLY;21330;21;COTE D'OR;1
21126;;Cessey-sur-Tille;CESSEY-SUR-TILLE;21110;21;COTE D'OR;1
21127;;Chaignay;CHAIGNAY;21120;21;COTE D'OR;1
21128;;Chailly-sur-Armançon;CHAILLY-SUR-ARMANCON;21320;21;COTE D'OR;1
21129;;Chambain;CHAMBAIN;21290;21;COTE D'OR;1
21130;;Chambeire;CHAMBEIRE;21110;21;COTE D'OR;1
21131;;Chamblanc;CHAMBLANC;21250;21;COTE D'OR;1
21132;;Chambœuf;CHAMBOEUF;21220;21;COTE D'OR;1
21133;;Chambolle-Musigny;CHAMBOLLE-MUSIGNY;21220;21;COTE D'OR;1
21134;;Chamesson;CHAMESSON;21400;21;COTE D'OR;1
21135;;Champagne-sur-Vingeanne;CHAMPAGNE-SUR-VINGEANNE;21310;21;COTE D'OR;1
21136;;Champagny;CHAMPAGNY;21440;21;COTE D'OR;1
21137;;Champ-d'Oiseau;CHAMP-D'OISEAU;21500;21;COTE D'OR;1
21138;;Champdôtre;CHAMPDOTRE;21130;21;COTE D'OR;1
21139;;Champeau-en-Morvan;CHAMPEAU-EN-MORVAN;21210;21;COTE D'OR;1
21140;;Champignolles;CHAMPIGNOLLES;21230;21;COTE D'OR;1
21141;;Champrenault;CHAMPRENAULT;21690;21;COTE D'OR;1
21142;;Chanceaux;CHANCEAUX;21440;21;COTE D'OR;1
21143;;Channay;CHANNAY;21330;21;COTE D'OR;1
21144;;Charencey;CHARENCEY;21690;21;COTE D'OR;1
21145;;Charigny;CHARIGNY;21140;21;COTE D'OR;1
21146;;Charmes;CHARMES;21310;21;COTE D'OR;1
21147;;Charny;CHARNY;21350;21;COTE D'OR;1
21148;;Charrey-sur-Saône;CHARREY-SUR-SAONE;21170;21;COTE D'OR;1
21149;;Charrey-sur-Seine;CHARREY-SUR-SEINE;21400;21;COTE D'OR;1
21150;;Chassagne-Montrachet;CHASSAGNE-MONTRACHET;21190;21;COTE D'OR;1
21151;;Chassey;CHASSEY;21150;21;COTE D'OR;1
21152;;Châteauneuf;CHATEAUNEUF;21320;21;COTE D'OR;1
21153;;Châtellenot;CHATELLENOT;21320;21;COTE D'OR;1
21154;;Châtillon-sur-Seine;CHATILLON-SUR-SEINE;21400;21;COTE D'OR;1
21155;;Chaudenay-la-Ville;CHAUDENAY-LA-VILLE;21360;21;COTE D'OR;1
21156;;Chaudenay-le-Château;CHAUDENAY-LE-CHATEAU;21360;21;COTE D'OR;1
21157;;Chaugey;CHAUGEY;21290;21;COTE D'OR;1
21158;;Chaume-et-Courchamp;CHAUME-ET-COURCHAMP;21610;21;COTE D'OR;1
21159;La;Chaume;CHAUME;21520;21;COTE D'OR;1
21160;;Chaume-lès-Baigneux;CHAUME-LES-BAIGNEUX;21450;21;COTE D'OR;1
21161;;Chaumont-le-Bois;CHAUMONT-LE-BOIS;21400;21;COTE D'OR;1
21162;;Chaux;CHAUX;21700;21;COTE D'OR;1
21163;;Chazeuil;CHAZEUIL;21260;21;COTE D'OR;1
21164;;Chazilly;CHAZILLY;21320;21;COTE D'OR;1
21165;;Chemin-d'Aisey;CHEMIN-D'AISEY;21400;21;COTE D'OR;1
21166;;Chenôve;CHENOVE;21300;21;COTE D'OR;1
21167;;Cheuge;CHEUGE;21310;21;COTE D'OR;1
21168;;Chevannay;CHEVANNAY;21540;21;COTE D'OR;1
21169;;Chevannes;CHEVANNES;21220;21;COTE D'OR;1
21170;;Chevigny-en-Valière;CHEVIGNY-EN-VALIERE;21200;21;COTE D'OR;1
21171;;Chevigny-Saint-Sauveur;CHEVIGNY-SAINT-SAUVEUR;21800;21;COTE D'OR;1
21172;;Chivres;CHIVRES;21820;21;COTE D'OR;1
21173;;Chorey-les-Beaune;CHOREY-LES-BEAUNE;21200;21;COTE D'OR;1
21175;;Cirey-lès-Pontailler;CIREY-LES-PONTAILLER;21270;21;COTE D'OR;1
21176;;Civry-en-Montagne;CIVRY-EN-MONTAGNE;21320;21;COTE D'OR;1
21177;;Clamerey;CLAMEREY;21390;21;COTE D'OR;1
21178;;Clémencey;CLEMENCEY;21220;21;COTE D'OR;1
21179;;Clénay;CLENAY;21490;21;COTE D'OR;1
21180;;Cléry;CLERY;21270;21;COTE D'OR;1
21181;;Clomot;CLOMOT;21230;21;COTE D'OR;1
21182;;Collonges-lès-Bévy;COLLONGES-LES-BEVY;21220;21;COTE D'OR;1
21183;;Collonges-lès-Premières;COLLONGES-LES-PREMIERES;21110;21;COTE D'OR;1
21184;;Colombier;COLOMBIER;21360;21;COTE D'OR;1
21185;;Combertault;COMBERTAULT;21200;21;COTE D'OR;1
21186;;Comblanchien;COMBLANCHIEN;21700;21;COTE D'OR;1
21187;;Commarin;COMMARIN;21320;21;COTE D'OR;1
21189;;Corberon;CORBERON;21250;21;COTE D'OR;1
21190;;Corcelles-les-Arts;CORCELLES-LES-ARTS;21190;21;COTE D'OR;1
21191;;Corcelles-lès-Cîteaux;CORCELLES-LES-CITEAUX;21910;21;COTE D'OR;1
21192;;Corcelles-les-Monts;CORCELLES-LES-MONTS;21160;21;COTE D'OR;1
21193;;Corgengoux;CORGENGOUX;21250;21;COTE D'OR;1
21194;;Corgoloin;CORGOLOIN;21700;21;COTE D'OR;1
21195;;Cormot-le-Grand;CORMOT-LE-GRAND;21340;21;COTE D'OR;1
21196;;Corpeau;CORPEAU;21190;21;COTE D'OR;1
21197;;Corpoyer-la-Chapelle;CORPOYER-LA-CHAPELLE;21150;21;COTE D'OR;1
21198;;Corrombles;CORROMBLES;21460;21;COTE D'OR;1
21199;;Corsaint;CORSAINT;21460;21;COTE D'OR;1
21200;;Couchey;COUCHEY;21160;21;COTE D'OR;1
21201;;Coulmier-le-Sec;COULMIER-LE-SEC;21400;21;COTE D'OR;1
21202;;Courban;COURBAN;21520;21;COTE D'OR;1
21203;;Courcelles-Frémoy;COURCELLES-FREMOY;21460;21;COTE D'OR;1
21204;;Courcelles-lès-Montbard;COURCELLES-LES-MONTBARD;21500;21;COTE D'OR;1
21205;;Courcelles-lès-Semur;COURCELLES-LES-SEMUR;21140;21;COTE D'OR;1
21207;;Courlon;COURLON;21580;21;COTE D'OR;1
21208;;Courtivron;COURTIVRON;21120;21;COTE D'OR;1
21209;;Couternon;COUTERNON;21560;21;COTE D'OR;1
21210;;Créancey;CREANCEY;21320;21;COTE D'OR;1
21211;;Crécey-sur-Tille;CRECEY-SUR-TILLE;21120;21;COTE D'OR;1
21212;;Crépand;CREPAND;21500;21;COTE D'OR;1
21213;;Crimolois;CRIMOLOIS;21800;21;COTE D'OR;1
21214;;Crugey;CRUGEY;21360;21;COTE D'OR;1
21215;;Cuiserey;CUISEREY;21310;21;COTE D'OR;1
21216;;Culètre;CULETRE;21230;21;COTE D'OR;1
21217;;Curley;CURLEY;21220;21;COTE D'OR;1
21218;;Curtil-Saint-Seine;CURTIL-SAINT-SEINE;21380;21;COTE D'OR;1
21219;;Curtil-Vergy;CURTIL-VERGY;21220;21;COTE D'OR;1
21220;;Cussey-les-Forges;CUSSEY-LES-FORGES;21580;21;COTE D'OR;1
21221;;Cussy-la-Colonne;CUSSY-LA-COLONNE;21360;21;COTE D'OR;1
21222;;Cussy-le-Châtel;CUSSY-LE-CHATEL;21230;21;COTE D'OR;1
21223;;Daix;DAIX;21121;21;COTE D'OR;1
21224;;Dampierre-en-Montagne;DAMPIERRE-EN-MONTAGNE;21350;21;COTE D'OR;1
21225;;Dampierre-et-Flée;DAMPIERRE-ET-FLEE;21310;21;COTE D'OR;1
21226;;Darcey;DARCEY;21150;21;COTE D'OR;1
21227;;Darois;DAROIS;21121;21;COTE D'OR;1
21228;;Détain-et-Bruant;DETAIN-ET-BRUANT;21220;21;COTE D'OR;1
21229;;Diancey;DIANCEY;21430;21;COTE D'OR;1
21230;;Diénay;DIENAY;21120;21;COTE D'OR;1
21231;;Dijon;DIJON;21000;21;COTE D'OR;1
21232;;Dompierre-en-Morvan;DOMPIERRE-EN-MORVAN;21390;21;COTE D'OR;1
21233;;Drambon;DRAMBON;21270;21;COTE D'OR;1
21234;;Drée;DREE;21540;21;COTE D'OR;1
21235;;Duesme;DUESME;21510;21;COTE D'OR;1
21236;;Ébaty;EBATY;21190;21;COTE D'OR;1
21237;;Échalot;ECHALOT;21510;21;COTE D'OR;1
21238;;Échannay;ECHANNAY;21540;21;COTE D'OR;1
21239;;Échenon;ECHENON;21170;21;COTE D'OR;1
21240;;Échevannes;ECHEVANNES;21120;21;COTE D'OR;1
21241;;Échevronne;ECHEVRONNE;21420;21;COTE D'OR;1
21242;;Échigey;ECHIGEY;21110;21;COTE D'OR;1
21243;;Écutigny;ECUTIGNY;21360;21;COTE D'OR;1
21244;;Éguilly;EGUILLY;21320;21;COTE D'OR;1
21245;;Épagny;EPAGNY;21380;21;COTE D'OR;1
21246;;Épernay-sous-Gevrey;EPERNAY-SOUS-GEVREY;21220;21;COTE D'OR;1
21247;;Époisses;EPOISSES;21460;21;COTE D'OR;1
21248;;Éringes;ERINGES;21500;21;COTE D'OR;1
21249;;Esbarres;ESBARRES;21170;21;COTE D'OR;1
21250;;Essarois;ESSAROIS;21290;21;COTE D'OR;1
21251;;Essey;ESSEY;21320;21;COTE D'OR;1
21252;;Étais;ETAIS;21500;21;COTE D'OR;1
21253;;Étalante;ETALANTE;21510;21;COTE D'OR;1
21254;L';Étang-Vergy;ETANG-VERGY;21220;21;COTE D'OR;1
21255;;Étaules;ETAULES;21121;21;COTE D'OR;1
21256;;Étevaux;ETEVAUX;21270;21;COTE D'OR;1
21257;;Étormay;ETORMAY;21450;21;COTE D'OR;1
21258;;Étrochey;ETROCHEY;21400;21;COTE D'OR;1
21259;;Fain-lès-Montbard;FAIN-LES-MONTBARD;21500;21;COTE D'OR;1
21260;;Fain-lès-Moutiers;FAIN-LES-MOUTIERS;21500;21;COTE D'OR;1
21261;;Fauverney;FAUVERNEY;21110;21;COTE D'OR;1
21262;;Faverolles-lès-Lucey;FAVEROLLES-LES-LUCEY;21290;21;COTE D'OR;1
21263;;Fénay;FENAY;21600;21;COTE D'OR;1
21264;Le;Fête;FETE;21230;21;COTE D'OR;1
21265;;Fixin;FIXIN;21220;21;COTE D'OR;1
21266;;Flacey;FLACEY;21490;21;COTE D'OR;1
21267;;Flagey-Echézeaux;FLAGEY-ECHEZEAUX;21640;21;COTE D'OR;1
21268;;Flagey-lès-Auxonne;FLAGEY-LES-AUXONNE;21130;21;COTE D'OR;1
21269;;Flammerans;FLAMMERANS;21130;21;COTE D'OR;1
21270;;Flavignerot;FLAVIGNEROT;21160;21;COTE D'OR;1
21271;;Flavigny-sur-Ozerain;FLAVIGNY-SUR-OZERAIN;21150;21;COTE D'OR;1
21272;;Flée;FLEE;21140;21;COTE D'OR;1
21273;;Fleurey-sur-Ouche;FLEUREY-SUR-OUCHE;21410;21;COTE D'OR;1
21274;;Foissy;FOISSY;21230;21;COTE D'OR;1
21275;;Foncegrive;FONCEGRIVE;21260;21;COTE D'OR;1
21276;;Fontaines-en-Duesmois;FONTAINES-EN-DUESMOIS;21450;21;COTE D'OR;1
21277;;Fontaine-Française;FONTAINE-FRANCAISE;21610;21;COTE D'OR;1
21278;;Fontaine-lès-Dijon;FONTAINE-LES-DIJON;21121;21;COTE D'OR;1
21279;;Fontaines-les-Sèches;FONTAINES-LES-SECHES;21330;21;COTE D'OR;1
21280;;Fontangy;FONTANGY;21390;21;COTE D'OR;1
21281;;Fontenelle;FONTENELLE;21610;21;COTE D'OR;1
21282;;Forléans;FORLEANS;21460;21;COTE D'OR;1
21283;;Fraignot-et-Vesvrotte;FRAIGNOT-ET-VESVROTTE;21580;21;COTE D'OR;1
21284;;Francheville;FRANCHEVILLE;21440;21;COTE D'OR;1
21285;;Franxault;FRANXAULT;21170;21;COTE D'OR;1
21286;;Frénois;FRENOIS;21120;21;COTE D'OR;1
21287;;Fresnes;FRESNES;21500;21;COTE D'OR;1
21288;;Frôlois;FROLOIS;21150;21;COTE D'OR;1
21289;;Fussey;FUSSEY;21700;21;COTE D'OR;1
21290;;Gemeaux;GEMEAUX;21120;21;COTE D'OR;1
21291;;Genay;GENAY;21140;21;COTE D'OR;1
21292;;Genlis;GENLIS;21110;21;COTE D'OR;1
21293;;Gergueil;GERGUEIL;21410;21;COTE D'OR;1
21294;;Gerland;GERLAND;21700;21;COTE D'OR;1
21295;;Gevrey-Chambertin;GEVREY-CHAMBERTIN;21220;21;COTE D'OR;1
21296;;Gevrolles;GEVROLLES;21520;21;COTE D'OR;1
21297;;Gilly-lès-Cîteaux;GILLY-LES-CITEAUX;21640;21;COTE D'OR;1
21298;;Gissey-le-Vieil;GISSEY-LE-VIEIL;21350;21;COTE D'OR;1
21299;;Gissey-sous-Flavigny;GISSEY-SOUS-FLAVIGNY;21150;21;COTE D'OR;1
21300;;Gissey-sur-Ouche;GISSEY-SUR-OUCHE;21410;21;COTE D'OR;1
21301;;Glanon;GLANON;21250;21;COTE D'OR;1
21302;;Gomméville;GOMMEVILLE;21400;21;COTE D'OR;1
21303;Les;Goulles;GOULLES;21520;21;COTE D'OR;1
21304;;Grancey-le-Château-Neuvelle;GRANCEY-LE-CHATEAU-NEUVELLE;21580;21;COTE D'OR;1
21305;;Grancey-sur-Ource;GRANCEY-SUR-OURCE;21570;21;COTE D'OR;1
21306;;Grenant-lès-Sombernon;GRENANT-LES-SOMBERNON;21540;21;COTE D'OR;1
21307;;Grésigny-Sainte-Reine;GRESIGNY-SAINTE-REINE;21150;21;COTE D'OR;1
21308;;Grignon;GRIGNON;21150;21;COTE D'OR;1
21309;;Griselles;GRISELLES;21330;21;COTE D'OR;1
21310;;Grosbois-en-Montagne;GROSBOIS-EN-MONTAGNE;21540;21;COTE D'OR;1
21311;;Grosbois-lès-Tichey;GROSBOIS-LES-TICHEY;21250;21;COTE D'OR;1
21312;;Gurgy-la-Ville;GURGY-LA-VILLE;21290;21;COTE D'OR;1
21313;;Gurgy-le-Château;GURGY-LE-CHATEAU;21290;21;COTE D'OR;1
21314;;Hauteroche;HAUTEROCHE;21150;21;COTE D'OR;1
21315;;Hauteville-lès-Dijon;HAUTEVILLE-LES-DIJON;21121;21;COTE D'OR;1
21316;;Heuilley-sur-Saône;HEUILLEY-SUR-SAONE;21270;21;COTE D'OR;1
21317;;Is-sur-Tille;IS-SUR-TILLE;21120;21;COTE D'OR;1
21318;;Ivry-en-Montagne;IVRY-EN-MONTAGNE;21340;21;COTE D'OR;1
21319;;Izeure;IZEURE;21110;21;COTE D'OR;1
21320;;Izier;IZIER;21110;21;COTE D'OR;1
21321;;Jailly-les-Moulins;JAILLY-LES-MOULINS;21150;21;COTE D'OR;1
21322;;Jallanges;JALLANGES;21250;21;COTE D'OR;1
21323;;Jancigny;JANCIGNY;21310;21;COTE D'OR;1
21324;;Jeux-lès-Bard;JEUX-LES-BARD;21460;21;COTE D'OR;1
21325;;Jouey;JOUEY;21230;21;COTE D'OR;1
21326;;Jours-lès-Baigneux;JOURS-LES-BAIGNEUX;21450;21;COTE D'OR;1
21327;;Jours-en-Vaux;JOURS-EN-VAUX;21340;21;COTE D'OR;1
21328;;Juillenay;JUILLENAY;21210;21;COTE D'OR;1
21329;;Juilly;JUILLY;21140;21;COTE D'OR;1
21330;;Labergement-Foigney;LABERGEMENT-FOIGNEY;21110;21;COTE D'OR;1
21331;;Labergement-lès-Auxonne;LABERGEMENT-LES-AUXONNE;21130;21;COTE D'OR;1
21332;;Labergement-lès-Seurre;LABERGEMENT-LES-SEURRE;21820;21;COTE D'OR;1
21333;;Labruyère;LABRUYERE;21250;21;COTE D'OR;1
21334;;Lacanche;LACANCHE;21230;21;COTE D'OR;1
21335;;Lacour-d'Arcenay;LACOUR-D'ARCENAY;21210;21;COTE D'OR;1
21336;;Laignes;LAIGNES;21330;21;COTE D'OR;1
21337;;Lamarche-sur-Saône;LAMARCHE-SUR-SAONE;21760;21;COTE D'OR;1
21338;;Lamargelle;LAMARGELLE;21440;21;COTE D'OR;1
21339;;Lantenay;LANTENAY;21370;21;COTE D'OR;1
21340;;Lanthes;LANTHES;21250;21;COTE D'OR;1
21341;;Lantilly;LANTILLY;21140;21;COTE D'OR;1
21342;;Laperrière-sur-Saône;LAPERRIERE-SUR-SAONE;21170;21;COTE D'OR;1
21343;;Larrey;LARREY;21330;21;COTE D'OR;1
21344;;Lechâtelet;LECHATELET;21250;21;COTE D'OR;1
21345;;Léry;LERY;21440;21;COTE D'OR;1
21346;;Leuglay;LEUGLAY;21290;21;COTE D'OR;1
21347;;Levernois;LEVERNOIS;21200;21;COTE D'OR;1
21348;;Licey-sur-Vingeanne;LICEY-SUR-VINGEANNE;21610;21;COTE D'OR;1
21349;;Liernais;LIERNAIS;21430;21;COTE D'OR;1
21350;;Lignerolles;LIGNEROLLES;21520;21;COTE D'OR;1
21351;;Longchamp;LONGCHAMP;21110;21;COTE D'OR;1
21352;;Longeault;LONGEAULT;21110;21;COTE D'OR;1
21353;;Longecourt-en-Plaine;LONGECOURT-EN-PLAINE;21110;21;COTE D'OR;1
21354;;Longecourt-lès-Culêtre;LONGECOURT-LES-CULETRE;21230;21;COTE D'OR;1
21355;;Longvic;LONGVIC;21600;21;COTE D'OR;1
21356;;Losne;LOSNE;21170;21;COTE D'OR;1
21357;;Louesme;LOUESME;21520;21;COTE D'OR;1
21358;;Lucenay-le-Duc;LUCENAY-LE-DUC;21150;21;COTE D'OR;1
21359;;Lucey;LUCEY;21290;21;COTE D'OR;1
21360;;Lusigny-sur-Ouche;LUSIGNY-SUR-OUCHE;21360;21;COTE D'OR;1
21361;;Lux;LUX;21120;21;COTE D'OR;1
21362;;Maconge;MACONGE;21320;21;COTE D'OR;1
21363;;Magnien;MAGNIEN;21230;21;COTE D'OR;1
21364;;Magny-Lambert;MAGNY-LAMBERT;21450;21;COTE D'OR;1
21365;;Magny-la-Ville;MAGNY-LA-VILLE;21140;21;COTE D'OR;1
21366;;Magny-lès-Aubigny;MAGNY-LES-AUBIGNY;21170;21;COTE D'OR;1
21367;;Magny-Montarlot;MAGNY-MONTARLOT;21130;21;COTE D'OR;1
21368;;Magny-lès-Villers;MAGNY-LES-VILLERS;21700;21;COTE D'OR;1
21369;;Magny-Saint-Médard;MAGNY-SAINT-MEDARD;21310;21;COTE D'OR;1
21370;;Magny-sur-Tille;MAGNY-SUR-TILLE;21110;21;COTE D'OR;1
21371;Les;Maillys;MAILLYS;21130;21;COTE D'OR;1
21372;;Maisey-le-Duc;MAISEY-LE-DUC;21400;21;COTE D'OR;1
21373;;Mâlain;MALAIN;21410;21;COTE D'OR;1
21374;;Maligny;MALIGNY;21230;21;COTE D'OR;1
21375;;Manlay;MANLAY;21430;21;COTE D'OR;1
21376;;Marandeuil;MARANDEUIL;21270;21;COTE D'OR;1
21377;;Marcellois;MARCELLOIS;21350;21;COTE D'OR;1
21378;;Marcenay;MARCENAY;21330;21;COTE D'OR;1
21379;;Marcheseuil;MARCHESEUIL;21430;21;COTE D'OR;1
21380;;Marcigny-sous-Thil;MARCIGNY-SOUS-THIL;21390;21;COTE D'OR;1
21381;;Marcilly-et-Dracy;MARCILLY-ET-DRACY;21350;21;COTE D'OR;1
21382;;Marcilly-Ogny;MARCILLY-OGNY;21320;21;COTE D'OR;1
21383;;Marcilly-sur-Tille;MARCILLY-SUR-TILLE;21120;21;COTE D'OR;1
21384;;Marey-lès-Fussey;MAREY-LES-FUSSEY;21700;21;COTE D'OR;1
21385;;Marey-sur-Tille;MAREY-SUR-TILLE;21120;21;COTE D'OR;1
21386;;Marigny-le-Cahouët;MARIGNY-LE-CAHOUET;21150;21;COTE D'OR;1
21387;;Marigny-lès-Reullée;MARIGNY-LES-REULLEE;21200;21;COTE D'OR;1
21388;;Marliens;MARLIENS;21110;21;COTE D'OR;1
21389;;Marmagne;MARMAGNE;21500;21;COTE D'OR;1
21390;;Marsannay-la-Côte;MARSANNAY-LA-COTE;21160;21;COTE D'OR;1
21391;;Marsannay-le-Bois;MARSANNAY-LE-BOIS;21380;21;COTE D'OR;1
21392;;Martrois;MARTROIS;21320;21;COTE D'OR;1
21393;;Massingy;MASSINGY;21400;21;COTE D'OR;1
21394;;Massingy-lès-Semur;MASSINGY-LES-SEMUR;21140;21;COTE D'OR;1
21395;;Massingy-lès-Vitteaux;MASSINGY-LES-VITTEAUX;21350;21;COTE D'OR;1
21396;;Mauvilly;MAUVILLY;21510;21;COTE D'OR;1
21397;;Mavilly-Mandelot;MAVILLY-MANDELOT;21190;21;COTE D'OR;1
21398;;Maxilly-sur-Saône;MAXILLY-SUR-SAONE;21270;21;COTE D'OR;1
21399;;Meilly-sur-Rouvres;MEILLY-SUR-ROUVRES;21320;21;COTE D'OR;1
21400;Le;Meix;MEIX;21580;21;COTE D'OR;1
21401;;Meloisey;MELOISEY;21190;21;COTE D'OR;1
21402;;Menesble;MENESBLE;21290;21;COTE D'OR;1
21403;;Ménessaire;MENESSAIRE;21430;21;COTE D'OR;1
21404;;Ménétreux-le-Pitois;MENETREUX-LE-PITOIS;21150;21;COTE D'OR;1
21405;;Merceuil;MERCEUIL;21190;21;COTE D'OR;1
21406;;Mesmont;MESMONT;21540;21;COTE D'OR;1
21407;;Messanges;MESSANGES;21220;21;COTE D'OR;1
21408;;Messigny-et-Vantoux;MESSIGNY-ET-VANTOUX;21380;21;COTE D'OR;1
21409;;Meuilley;MEUILLEY;21700;21;COTE D'OR;1
21410;;Meulson;MEULSON;21510;21;COTE D'OR;1
21411;;Meursanges;MEURSANGES;21200;21;COTE D'OR;1
21412;;Meursault;MEURSAULT;21190;21;COTE D'OR;1
21413;;Millery;MILLERY;21140;21;COTE D'OR;1
21414;;Mimeure;MIMEURE;21230;21;COTE D'OR;1
21415;;Minot;MINOT;21510;21;COTE D'OR;1
21416;;Mirebeau-sur-Bèze;MIREBEAU-SUR-BEZE;21310;21;COTE D'OR;1
21417;;Missery;MISSERY;21210;21;COTE D'OR;1
21418;;Moitron;MOITRON;21510;21;COTE D'OR;1
21419;;Molesme;MOLESME;21330;21;COTE D'OR;1
21420;;Molinot;MOLINOT;21340;21;COTE D'OR;1
21421;;Moloy;MOLOY;21120;21;COTE D'OR;1
21422;;Molphey;MOLPHEY;21210;21;COTE D'OR;1
21423;;Montagny-lès-Beaune;MONTAGNY-LES-BEAUNE;21200;21;COTE D'OR;1
21424;;Montagny-lès-Seurre;MONTAGNY-LES-SEURRE;21250;21;COTE D'OR;1
21425;;Montbard;MONTBARD;21500;21;COTE D'OR;1
21426;;Montberthault;MONTBERTHAULT;21460;21;COTE D'OR;1
21427;;Montceau-et-Écharnant;MONTCEAU-ET-ECHARNANT;21360;21;COTE D'OR;1
21428;;Monthelie;MONTHELIE;21190;21;COTE D'OR;1
21429;;Montigny-Montfort;MONTIGNY-MONTFORT;21500;21;COTE D'OR;1
21430;;Montigny-Saint-Barthélemy;MONTIGNY-SAINT-BARTHELEMY;21390;21;COTE D'OR;1
21431;;Montigny-sur-Armançon;MONTIGNY-SUR-ARMANCON;21140;21;COTE D'OR;1
21432;;Montigny-sur-Aube;MONTIGNY-SUR-AUBE;21520;21;COTE D'OR;1
21433;;Montigny-Mornay-Villeneuve-sur-Vingeanne;MONTIGNY-MORNAY-VILLENEUVE-SUR-VINGEANNE;21610;21;COTE D'OR;1
21434;;Montlay-en-Auxois;MONTLAY-EN-AUXOIS;21210;21;COTE D'OR;1
21435;;Montliot-et-Courcelles;MONTLIOT-ET-COURCELLES;21400;21;COTE D'OR;1
21436;;Montmain;MONTMAIN;21250;21;COTE D'OR;1
21437;;Montmançon;MONTMANCON;21270;21;COTE D'OR;1
21438;;Montmoyen;MONTMOYEN;21290;21;COTE D'OR;1
21439;;Montoillot;MONTOILLOT;21540;21;COTE D'OR;1
21440;;Montot;MONTOT;21170;21;COTE D'OR;1
21441;;Mont-Saint-Jean;MONT-SAINT-JEAN;21320;21;COTE D'OR;1
21442;;Morey-Saint-Denis;MOREY-SAINT-DENIS;21220;21;COTE D'OR;1
21444;;Mosson;MOSSON;21400;21;COTE D'OR;1
21445;La;Motte-Ternant;MOTTE-TERNANT;21210;21;COTE D'OR;1
21446;;Moutiers-Saint-Jean;MOUTIERS-SAINT-JEAN;21500;21;COTE D'OR;1
21447;;Musigny;MUSIGNY;21230;21;COTE D'OR;1
21448;;Mussy-la-Fosse;MUSSY-LA-FOSSE;21150;21;COTE D'OR;1
21449;;Nan-sous-Thil;NAN-SOUS-THIL;21390;21;COTE D'OR;1
21450;;Nantoux;NANTOUX;21190;21;COTE D'OR;1
21451;;Nesle-et-Massoult;NESLE-ET-MASSOULT;21330;21;COTE D'OR;1
21452;;Neuilly-lès-Dijon;NEUILLY-LES-DIJON;21800;21;COTE D'OR;1
21454;;Nicey;NICEY;21330;21;COTE D'OR;1
21455;;Nod-sur-Seine;NOD-SUR-SEINE;21400;21;COTE D'OR;1
21456;;Nogent-lès-Montbard;NOGENT-LES-MONTBARD;21500;21;COTE D'OR;1
21457;;Noidan;NOIDAN;21390;21;COTE D'OR;1
21458;;Noiron-sous-Gevrey;NOIRON-SOUS-GEVREY;21910;21;COTE D'OR;1
21459;;Noiron-sur-Bèze;NOIRON-SUR-BEZE;21310;21;COTE D'OR;1
21460;;Noiron-sur-Seine;NOIRON-SUR-SEINE;21400;21;COTE D'OR;1
21461;;Nolay;NOLAY;21340;21;COTE D'OR;1
21462;;Norges-la-Ville;NORGES-LA-VILLE;21490;21;COTE D'OR;1
21463;;Normier;NORMIER;21390;21;COTE D'OR;1
21464;;Nuits-Saint-Georges;NUITS-SAINT-GEORGES;21700;21;COTE D'OR;1
21465;;Obtrée;OBTREE;21400;21;COTE D'OR;1
21466;;Oigny;OIGNY;21450;21;COTE D'OR;1
21467;;Oisilly;OISILLY;21310;21;COTE D'OR;1
21468;;Orain;ORAIN;21610;21;COTE D'OR;1
21469;;Orgeux;ORGEUX;21490;21;COTE D'OR;1
21470;;Origny;ORIGNY;21510;21;COTE D'OR;1
21471;;Orret;ORRET;21450;21;COTE D'OR;1
21472;;Orville;ORVILLE;21260;21;COTE D'OR;1
21473;;Ouges;OUGES;21600;21;COTE D'OR;1
21474;;Pagny-la-Ville;PAGNY-LA-VILLE;21250;21;COTE D'OR;1
21475;;Pagny-le-Château;PAGNY-LE-CHATEAU;21250;21;COTE D'OR;1
21476;;Painblanc;PAINBLANC;21360;21;COTE D'OR;1
21477;;Panges;PANGES;21540;21;COTE D'OR;1
21478;;Pasques;PASQUES;21370;21;COTE D'OR;1
21479;;Pellerey;PELLEREY;21440;21;COTE D'OR;1
21480;;Pernand-Vergelesses;PERNAND-VERGELESSES;21420;21;COTE D'OR;1
21481;;Perrigny-lès-Dijon;PERRIGNY-LES-DIJON;21160;21;COTE D'OR;1
21482;;Perrigny-sur-l'Ognon;PERRIGNY-SUR-L'OGNON;21270;21;COTE D'OR;1
21483;;Pichanges;PICHANGES;21120;21;COTE D'OR;1
21484;;Planay;PLANAY;21500;21;COTE D'OR;1
21485;;Plombières-lès-Dijon;PLOMBIERES-LES-DIJON;21370;21;COTE D'OR;1
21486;;Pluvault;PLUVAULT;21110;21;COTE D'OR;1
21487;;Pluvet;PLUVET;21110;21;COTE D'OR;1
21488;;Poinçon-lès-Larrey;POINCON-LES-LARREY;21330;21;COTE D'OR;1
21489;;Poiseul-la-Grange;POISEUL-LA-GRANGE;21440;21;COTE D'OR;1
21490;;Poiseul-la-Ville-et-Laperrière;POISEUL-LA-VILLE-ET-LAPERRIERE;21450;21;COTE D'OR;1
21491;;Poiseul-lès-Saulx;POISEUL-LES-SAULX;21120;21;COTE D'OR;1
21492;;Pommard;POMMARD;21630;21;COTE D'OR;1
21493;;Poncey-lès-Athée;PONCEY-LES-ATHEE;21130;21;COTE D'OR;1
21494;;Poncey-sur-l'Ignon;PONCEY-SUR-L'IGNON;21440;21;COTE D'OR;1
21495;;Pont;PONT;21130;21;COTE D'OR;1
21496;;Pontailler-sur-Saône;PONTAILLER-SUR-SAONE;21270;21;COTE D'OR;1
21497;;Pont-et-Massène;PONT-ET-MASSENE;21140;21;COTE D'OR;1
21498;;Posanges;POSANGES;21350;21;COTE D'OR;1
21499;;Pothières;POTHIERES;21400;21;COTE D'OR;1
21500;;Pouillenay;POUILLENAY;21150;21;COTE D'OR;1
21501;;Pouilly-en-Auxois;POUILLY-EN-AUXOIS;21320;21;COTE D'OR;1
21502;;Pouilly-sur-Saône;POUILLY-SUR-SAONE;21250;21;COTE D'OR;1
21503;;Pouilly-sur-Vingeanne;POUILLY-SUR-VINGEANNE;21610;21;COTE D'OR;1
21504;;Prâlon;PRALON;21410;21;COTE D'OR;1
21505;;Précy-sous-Thil;PRECY-SOUS-THIL;21390;21;COTE D'OR;1
21506;;Premeaux-Prissey;PREMEAUX-PRISSEY;21700;21;COTE D'OR;1
21507;;Premières;PREMIERES;21110;21;COTE D'OR;1
21508;;Prenois;PRENOIS;21370;21;COTE D'OR;1
21510;;Prusly-sur-Ource;PRUSLY-SUR-OURCE;21400;21;COTE D'OR;1
21511;;Puits;PUITS;21400;21;COTE D'OR;1
21512;;Puligny-Montrachet;PULIGNY-MONTRACHET;21190;21;COTE D'OR;1
21513;;Quemigny-Poisot;QUEMIGNY-POISOT;21220;21;COTE D'OR;1
21514;;Quemigny-sur-Seine;QUEMIGNY-SUR-SEINE;21510;21;COTE D'OR;1
21515;;Quetigny;QUETIGNY;21800;21;COTE D'OR;1
21516;;Quincerot;QUINCEROT;21500;21;COTE D'OR;1
21517;;Quincey;QUINCEY;21700;21;COTE D'OR;1
21518;;Quincy-le-Vicomte;QUINCY-LE-VICOMTE;21500;21;COTE D'OR;1
21519;;Recey-sur-Ource;RECEY-SUR-OURCE;21290;21;COTE D'OR;1
21520;;Remilly-en-Montagne;REMILLY-EN-MONTAGNE;21540;21;COTE D'OR;1
21521;;Remilly-sur-Tille;REMILLY-SUR-TILLE;21560;21;COTE D'OR;1
21522;;Renève;RENEVE;21310;21;COTE D'OR;1
21523;;Reulle-Vergy;REULLE-VERGY;21220;21;COTE D'OR;1
21524;;Riel-les-Eaux;RIEL-LES-EAUX;21570;21;COTE D'OR;1
21525;La;Roche-en-Brenil;ROCHE-EN-BRENIL;21530;21;COTE D'OR;1
21526;;Rochefort-sur-Brévon;ROCHEFORT-SUR-BREVON;21510;21;COTE D'OR;1
21527;La;Rochepot;ROCHEPOT;21340;21;COTE D'OR;1
21528;La;Roche-Vanneau;ROCHE-VANNEAU;21150;21;COTE D'OR;1
21529;;Roilly;ROILLY;21390;21;COTE D'OR;1
21530;;Rougemont;ROUGEMONT;21500;21;COTE D'OR;1
21531;;Rouvray;ROUVRAY;21530;21;COTE D'OR;1
21532;;Rouvres-en-Plaine;ROUVRES-EN-PLAINE;21110;21;COTE D'OR;1
21533;;Rouvres-sous-Meilly;ROUVRES-SOUS-MEILLY;21320;21;COTE D'OR;1
21534;;Ruffey-lès-Beaune;RUFFEY-LES-BEAUNE;21200;21;COTE D'OR;1
21535;;Ruffey-lès-Echirey;RUFFEY-LES-ECHIREY;21490;21;COTE D'OR;1
21536;;Sacquenay;SACQUENAY;21260;21;COTE D'OR;1
21537;;Saffres;SAFFRES;21350;21;COTE D'OR;1
21538;;Saint-Andeux;SAINT-ANDEUX;21530;21;COTE D'OR;1
21539;;Saint-Anthot;SAINT-ANTHOT;21540;21;COTE D'OR;1
21540;;Saint-Apollinaire;SAINT-APOLLINAIRE;21850;21;COTE D'OR;1
21541;;Saint-Aubin;SAINT-AUBIN;21190;21;COTE D'OR;1
21542;;Saint-Bernard;SAINT-BERNARD;21700;21;COTE D'OR;1
21543;;Saint-Broing-les-Moines;SAINT-BROING-LES-MOINES;21290;21;COTE D'OR;1
21544;;Sainte-Colombe;SAINTE-COLOMBE;21350;21;COTE D'OR;1
21545;;Sainte-Colombe-sur-Seine;SAINTE-COLOMBE-SUR-SEINE;21400;21;COTE D'OR;1
21546;;Saint-Didier;SAINT-DIDIER;21210;21;COTE D'OR;1
21547;;Saint-Euphrône;SAINT-EUPHRONE;21140;21;COTE D'OR;1
21548;;Saint-Germain-de-Modéon;SAINT-GERMAIN-DE-MODEON;21530;21;COTE D'OR;1
21549;;Saint-Germain-le-Rocheux;SAINT-GERMAIN-LE-ROCHEUX;21510;21;COTE D'OR;1
21550;;Saint-Germain-lès-Senailly;SAINT-GERMAIN-LES-SENAILLY;21500;21;COTE D'OR;1
21552;;Saint-Hélier;SAINT-HELIER;21690;21;COTE D'OR;1
21553;;Saint-Jean-de-Bœuf;SAINT-JEAN-DE-BOEUF;21410;21;COTE D'OR;1
21554;;Saint-Jean-de-Losne;SAINT-JEAN-DE-LOSNE;21170;21;COTE D'OR;1
21555;;Saint-Julien;SAINT-JULIEN;21490;21;COTE D'OR;1
21556;;Saint-Léger-Triey;SAINT-LEGER-TRIEY;21270;21;COTE D'OR;1
21557;;Saint-Marc-sur-Seine;SAINT-MARC-SUR-SEINE;21450;21;COTE D'OR;1
21558;;Sainte-Marie-la-Blanche;SAINTE-MARIE-LA-BLANCHE;21200;21;COTE D'OR;1
21559;;Sainte-Marie-sur-Ouche;SAINTE-MARIE-SUR-OUCHE;21410;21;COTE D'OR;1
21560;;Saint-Martin-de-la-Mer;SAINT-MARTIN-DE-LA-MER;21210;21;COTE D'OR;1
21561;;Saint-Martin-du-Mont;SAINT-MARTIN-DU-MONT;21440;21;COTE D'OR;1
21562;;Saint-Maurice-sur-Vingeanne;SAINT-MAURICE-SUR-VINGEANNE;21610;21;COTE D'OR;1
21563;;Saint-Mesmin;SAINT-MESMIN;21540;21;COTE D'OR;1
21564;;Saint-Nicolas-lès-Cîteaux;SAINT-NICOLAS-LES-CITEAUX;21700;21;COTE D'OR;1
21565;;Saint-Philibert;SAINT-PHILIBERT;21220;21;COTE D'OR;1
21566;;Saint-Pierre-en-Vaux;SAINT-PIERRE-EN-VAUX;21230;21;COTE D'OR;1
21567;;Saint-Prix-lès-Arnay;SAINT-PRIX-LES-ARNAY;21230;21;COTE D'OR;1
21568;;Saint-Rémy;SAINT-REMY;21500;21;COTE D'OR;1
21569;;Saint-Romain;SAINT-ROMAIN;21190;21;COTE D'OR;1
21570;;Sainte-Sabine;SAINTE-SABINE;21320;21;COTE D'OR;1
21571;;Saint-Sauveur;SAINT-SAUVEUR;21270;21;COTE D'OR;1
21572;;Saint-Seine-en-Bâche;SAINT-SEINE-EN-BACHE;21130;21;COTE D'OR;1
21573;;Saint-Seine-l'Abbaye;SAINT-SEINE-L'ABBAYE;21440;21;COTE D'OR;1
21574;;Saint-Seine-sur-Vingeanne;SAINT-SEINE-SUR-VINGEANNE;21610;21;COTE D'OR;1
21575;;Saint-Symphorien-sur-Saône;SAINT-SYMPHORIEN-SUR-SAONE;21170;21;COTE D'OR;1
21576;;Saint-Thibault;SAINT-THIBAULT;21350;21;COTE D'OR;1
21577;;Saint-Usage;SAINT-USAGE;21170;21;COTE D'OR;1
21578;;Saint-Victor-sur-Ouche;SAINT-VICTOR-SUR-OUCHE;21410;21;COTE D'OR;1
21579;;Salives;SALIVES;21580;21;COTE D'OR;1
21580;;Salmaise;SALMAISE;21690;21;COTE D'OR;1
21581;;Samerey;SAMEREY;21170;21;COTE D'OR;1
21582;;Santenay;SANTENAY;21590;21;COTE D'OR;1
21583;;Santosse;SANTOSSE;21340;21;COTE D'OR;1
21584;;Saulieu;SAULIEU;21210;21;COTE D'OR;1
21585;;Saulon-la-Chapelle;SAULON-LA-CHAPELLE;21910;21;COTE D'OR;1
21586;;Saulon-la-Rue;SAULON-LA-RUE;21910;21;COTE D'OR;1
21587;;Saulx-le-Duc;SAULX-LE-DUC;21120;21;COTE D'OR;1
21588;;Saussey;SAUSSEY;21360;21;COTE D'OR;1
21589;;Saussy;SAUSSY;21380;21;COTE D'OR;1
21590;;Savigny-lès-Beaune;SAVIGNY-LES-BEAUNE;21420;21;COTE D'OR;1
21591;;Savigny-le-Sec;SAVIGNY-LE-SEC;21380;21;COTE D'OR;1
21592;;Savigny-sous-Mâlain;SAVIGNY-SOUS-MALAIN;21540;21;COTE D'OR;1
21593;;Savilly;SAVILLY;21430;21;COTE D'OR;1
21594;;Savoisy;SAVOISY;21500;21;COTE D'OR;1
21595;;Savolles;SAVOLLES;21310;21;COTE D'OR;1
21596;;Savouges;SAVOUGES;21910;21;COTE D'OR;1
21597;;Segrois;SEGROIS;21220;21;COTE D'OR;1
21598;;Seigny;SEIGNY;21150;21;COTE D'OR;1
21599;;Selongey;SELONGEY;21260;21;COTE D'OR;1
21600;;Semarey;SEMAREY;21320;21;COTE D'OR;1
21601;;Semezanges;SEMEZANGES;21220;21;COTE D'OR;1
21602;;Semond;SEMOND;21450;21;COTE D'OR;1
21603;;Semur-en-Auxois;SEMUR-EN-AUXOIS;21140;21;COTE D'OR;1
21604;;Senailly;SENAILLY;21500;21;COTE D'OR;1
21605;;Sennecey-lès-Dijon;SENNECEY-LES-DIJON;21800;21;COTE D'OR;1
21606;;Ladoix-Serrigny;LADOIX-SERRIGNY;21550;21;COTE D'OR;1
21607;;Seurre;SEURRE;21250;21;COTE D'OR;1
21608;;Sincey-lès-Rouvray;SINCEY-LES-ROUVRAY;21530;21;COTE D'OR;1
21609;;Soirans;SOIRANS;21110;21;COTE D'OR;1
21610;;Soissons-sur-Nacey;SOISSONS-SUR-NACEY;21270;21;COTE D'OR;1
21611;;Sombernon;SOMBERNON;21540;21;COTE D'OR;1
21612;;Souhey;SOUHEY;21140;21;COTE D'OR;1
21613;;Soussey-sur-Brionne;SOUSSEY-SUR-BRIONNE;21350;21;COTE D'OR;1
21614;;Spoy;SPOY;21120;21;COTE D'OR;1
21615;;Sussey;SUSSEY;21430;21;COTE D'OR;1
21616;;Tailly;TAILLY;21190;21;COTE D'OR;1
21617;;Talant;TALANT;21240;21;COTE D'OR;1
21618;;Talmay;TALMAY;21270;21;COTE D'OR;1
21619;;Tanay;TANAY;21310;21;COTE D'OR;1
21620;;Tarsul;TARSUL;21120;21;COTE D'OR;1
21621;;Tart-l'Abbaye;TART-L'ABBAYE;21110;21;COTE D'OR;1
21622;;Tart-le-Bas;TART-LE-BAS;21110;21;COTE D'OR;1
21623;;Tart-le-Haut;TART-LE-HAUT;21110;21;COTE D'OR;1
21624;;Tellecey;TELLECEY;21270;21;COTE D'OR;1
21625;;Ternant;TERNANT;21220;21;COTE D'OR;1
21626;;Terrefondrée;TERREFONDREE;21290;21;COTE D'OR;1
21627;;Thenissey;THENISSEY;21150;21;COTE D'OR;1
21628;;Thoires;THOIRES;21570;21;COTE D'OR;1
21629;;Thoisy-la-Berchère;THOISY-LA-BERCHERE;21210;21;COTE D'OR;1
21630;;Thoisy-le-Désert;THOISY-LE-DESERT;21320;21;COTE D'OR;1
21631;;Thomirey;THOMIREY;21360;21;COTE D'OR;1
21632;;Thorey-en-Plaine;THOREY-EN-PLAINE;21110;21;COTE D'OR;1
21633;;Thorey-sous-Charny;THOREY-SOUS-CHARNY;21350;21;COTE D'OR;1
21634;;Thorey-sur-Ouche;THOREY-SUR-OUCHE;21360;21;COTE D'OR;1
21635;;Thoste;THOSTE;21460;21;COTE D'OR;1
21636;;Thury;THURY;21340;21;COTE D'OR;1
21637;;Tichey;TICHEY;21250;21;COTE D'OR;1
21638;;Til-Châtel;TIL-CHATEL;21120;21;COTE D'OR;1
21639;;Tillenay;TILLENAY;21130;21;COTE D'OR;1
21640;;Torcy-et-Pouligny;TORCY-ET-POULIGNY;21460;21;COTE D'OR;1
21641;;Touillon;TOUILLON;21500;21;COTE D'OR;1
21642;;Toutry;TOUTRY;21460;21;COTE D'OR;1
21643;;Tréclun;TRECLUN;21130;21;COTE D'OR;1
21644;;Trochères;TROCHERES;21310;21;COTE D'OR;1
21645;;Trouhans;TROUHANS;21170;21;COTE D'OR;1
21646;;Trouhaut;TROUHAUT;21440;21;COTE D'OR;1
21647;;Trugny;TRUGNY;21250;21;COTE D'OR;1
21648;;Turcey;TURCEY;21540;21;COTE D'OR;1
21649;;Uncey-le-Franc;UNCEY-LE-FRANC;21350;21;COTE D'OR;1
21650;;Urcy;URCY;21220;21;COTE D'OR;1
21651;;Val-Suzon;VAL-SUZON;21121;21;COTE D'OR;1
21652;;Vandenesse-en-Auxois;VANDENESSE-EN-AUXOIS;21320;21;COTE D'OR;1
21653;;Vannaire;VANNAIRE;21400;21;COTE D'OR;1
21655;;Vanvey;VANVEY;21400;21;COTE D'OR;1
21656;;Varanges;VARANGES;21110;21;COTE D'OR;1
21657;;Varois-et-Chaignot;VAROIS-ET-CHAIGNOT;21490;21;COTE D'OR;1
21658;;Vauchignon;VAUCHIGNON;21340;21;COTE D'OR;1
21659;;Vaux-Saules;VAUX-SAULES;21440;21;COTE D'OR;1
21660;;Veilly;VEILLY;21360;21;COTE D'OR;1
21661;;Velars-sur-Ouche;VELARS-SUR-OUCHE;21370;21;COTE D'OR;1
21662;;Velogny;VELOGNY;21350;21;COTE D'OR;1
21663;;Venarey-les-Laumes;VENAREY-LES-LAUMES;21150;21;COTE D'OR;1
21664;;Verdonnet;VERDONNET;21330;21;COTE D'OR;1
21665;;Vernois-lès-Vesvres;VERNOIS-LES-VESVRES;21260;21;COTE D'OR;1
21666;;Vernot;VERNOT;21120;21;COTE D'OR;1
21667;;Véronnes;VERONNES;21260;21;COTE D'OR;1
21669;;Verrey-sous-Drée;VERREY-SOUS-DREE;21540;21;COTE D'OR;1
21670;;Verrey-sous-Salmaise;VERREY-SOUS-SALMAISE;21690;21;COTE D'OR;1
21671;;Vertault;VERTAULT;21330;21;COTE D'OR;1
21672;;Vesvres;VESVRES;21350;21;COTE D'OR;1
21673;;Veuvey-sur-Ouche;VEUVEY-SUR-OUCHE;21360;21;COTE D'OR;1
21674;;Veuxhaulles-sur-Aube;VEUXHAULLES-SUR-AUBE;21520;21;COTE D'OR;1
21675;;Vianges;VIANGES;21430;21;COTE D'OR;1
21676;;Vic-de-Chassenay;VIC-DE-CHASSENAY;21140;21;COTE D'OR;1
21677;;Vic-des-Prés;VIC-DES-PRES;21360;21;COTE D'OR;1
21678;;Vic-sous-Thil;VIC-SOUS-THIL;21390;21;COTE D'OR;1
21679;;Vieilmoulin;VIEILMOULIN;21540;21;COTE D'OR;1
21680;;Vielverge;VIELVERGE;21270;21;COTE D'OR;1
21681;;Vieux-Château;VIEUX-CHATEAU;21460;21;COTE D'OR;1
21682;;Viévigne;VIEVIGNE;21310;21;COTE D'OR;1
21683;;Viévy;VIEVY;21230;21;COTE D'OR;1
21684;;Vignoles;VIGNOLES;21200;21;COTE D'OR;1
21685;;Villaines-en-Duesmois;VILLAINES-EN-DUESMOIS;21450;21;COTE D'OR;1
21686;;Villaines-les-Prévôtes;VILLAINES-LES-PREVOTES;21500;21;COTE D'OR;1
21687;;Villargoix;VILLARGOIX;21210;21;COTE D'OR;1
21688;;Villars-Fontaine;VILLARS-FONTAINE;21700;21;COTE D'OR;1
21689;;Villars-et-Villenotte;VILLARS-ET-VILLENOTTE;21140;21;COTE D'OR;1
21690;;Villeberny;VILLEBERNY;21350;21;COTE D'OR;1
21691;;Villebichot;VILLEBICHOT;21700;21;COTE D'OR;1
21692;;Villecomte;VILLECOMTE;21120;21;COTE D'OR;1
21693;;Villedieu;VILLEDIEU;21330;21;COTE D'OR;1
21694;;Villeferry;VILLEFERRY;21350;21;COTE D'OR;1
21695;La;Villeneuve-les-Convers;VILLENEUVE-LES-CONVERS;21450;21;COTE D'OR;1
21696;;Villeneuve-sous-Charigny;VILLENEUVE-SOUS-CHARIGNY;21140;21;COTE D'OR;1
21698;;Villers-la-Faye;VILLERS-LA-FAYE;21700;21;COTE D'OR;1
21699;;Villers-les-Pots;VILLERS-LES-POTS;21130;21;COTE D'OR;1
21700;;Villers-Patras;VILLERS-PATRAS;21400;21;COTE D'OR;1
21701;;Villers-Rotin;VILLERS-ROTIN;21130;21;COTE D'OR;1
21702;;Villey-sur-Tille;VILLEY-SUR-TILLE;21120;21;COTE D'OR;1
21703;;Villiers-en-Morvan;VILLIERS-EN-MORVAN;21430;21;COTE D'OR;1
21704;;Villiers-le-Duc;VILLIERS-LE-DUC;21400;21;COTE D'OR;1
21705;;Villotte-Saint-Seine;VILLOTTE-SAINT-SEINE;21690;21;COTE D'OR;1
21706;;Villotte-sur-Ource;VILLOTTE-SUR-OURCE;21400;21;COTE D'OR;1
21707;;Villy-en-Auxois;VILLY-EN-AUXOIS;21350;21;COTE D'OR;1
21708;;Villy-le-Moutier;VILLY-LE-MOUTIER;21250;21;COTE D'OR;1
21709;;Viserny;VISERNY;21500;21;COTE D'OR;1
21710;;Vitteaux;VITTEAUX;21350;21;COTE D'OR;1
21711;;Vix;VIX;21400;21;COTE D'OR;1
21712;;Volnay;VOLNAY;21190;21;COTE D'OR;1
21713;;Vonges;VONGES;21270;21;COTE D'OR;1
21714;;Vosne-Romanée;VOSNE-ROMANEE;21700;21;COTE D'OR;1
21715;;Voudenay;VOUDENAY;21230;21;COTE D'OR;1
21716;;Vougeot;VOUGEOT;21640;21;COTE D'OR;1
21717;;Voulaines-les-Templiers;VOULAINES-LES-TEMPLIERS;21290;21;COTE D'OR;1
22001;;Allineuc;ALLINEUC;22460;22;COTES D'ARMOR;1
22002;;Andel;ANDEL;22400;22;COTES D'ARMOR;1
22003;;Aucaleuc;AUCALEUC;22100;22;COTES D'ARMOR;1
22004;;Bégard;BEGARD;22140;22;COTES D'ARMOR;1
22005;;Belle-Isle-en-Terre;BELLE-ISLE-EN-TERRE;22810;22;COTES D'ARMOR;1
22006;;Berhet;BERHET;22140;22;COTES D'ARMOR;1
22007;;Binic;BINIC;22520;22;COTES D'ARMOR;1
22008;;Bobital;BOBITAL;22100;22;COTES D'ARMOR;1
22009;Le;Bodéo;BODEO;22320;22;COTES D'ARMOR;1
22011;;Boqueho;BOQUEHO;22170;22;COTES D'ARMOR;1
22012;La;Bouillie;BOUILLIE;22240;22;COTES D'ARMOR;1
22013;;Bourbriac;BOURBRIAC;22390;22;COTES D'ARMOR;1
22014;;Bourseul;BOURSEUL;22130;22;COTES D'ARMOR;1
22015;;Bréhand;BREHAND;22510;22;COTES D'ARMOR;1
22016;;Île-de-Bréhat;ILE-DE-BREHAT;22870;22;COTES D'ARMOR;1
22018;;Brélidy;BRELIDY;22140;22;COTES D'ARMOR;1
22019;;Bringolo;BRINGOLO;22170;22;COTES D'ARMOR;1
22020;;Broons;BROONS;22250;22;COTES D'ARMOR;1
22021;;Brusvily;BRUSVILY;22100;22;COTES D'ARMOR;1
22023;;Bulat-Pestivien;BULAT-PESTIVIEN;22160;22;COTES D'ARMOR;1
22024;;Calanhel;CALANHEL;22160;22;COTES D'ARMOR;1
22025;;Callac;CALLAC;22160;22;COTES D'ARMOR;1
22026;;Calorguen;CALORGUEN;22100;22;COTES D'ARMOR;1
22027;Le;Cambout;CAMBOUT;22210;22;COTES D'ARMOR;1
22028;;Camlez;CAMLEZ;22450;22;COTES D'ARMOR;1
22029;;Canihuel;CANIHUEL;22480;22;COTES D'ARMOR;1
22030;;Caouënnec-Lanvézéac;CAOUENNEC-LANVEZEAC;22300;22;COTES D'ARMOR;1
22031;;Carnoët;CARNOET;22160;22;COTES D'ARMOR;1
22032;;Caulnes;CAULNES;22350;22;COTES D'ARMOR;1
22033;;Caurel;CAUREL;22530;22;COTES D'ARMOR;1
22034;;Cavan;CAVAN;22140;22;COTES D'ARMOR;1
22035;Les;Champs-Géraux;CHAMPS-GERAUX;22630;22;COTES D'ARMOR;1
22036;La;Chapelle-Blanche;CHAPELLE-BLANCHE;22350;22;COTES D'ARMOR;1
22037;La;Chapelle-Neuve;CHAPELLE-NEUVE;22160;22;COTES D'ARMOR;1
22038;;Châtelaudren;CHATELAUDREN;22170;22;COTES D'ARMOR;1
22039;La;Chèze;CHEZE;22210;22;COTES D'ARMOR;1
22040;;Coadout;COADOUT;22970;22;COTES D'ARMOR;1
22041;;Coatascorn;COATASCORN;22140;22;COTES D'ARMOR;1
22042;;Coatréven;COATREVEN;22450;22;COTES D'ARMOR;1
22043;;Coëtlogon;COETLOGON;22210;22;COTES D'ARMOR;1
22044;;Coëtmieux;COETMIEUX;22400;22;COTES D'ARMOR;1
22045;;Cohiniac;COHINIAC;22800;22;COTES D'ARMOR;1
22046;;Collinée;COLLINEE;22330;22;COTES D'ARMOR;1
22047;;Corlay;CORLAY;22320;22;COTES D'ARMOR;1
22048;;Corseul;CORSEUL;22130;22;COTES D'ARMOR;1
22049;;Créhen;CREHEN;22130;22;COTES D'ARMOR;1
22050;;Dinan;DINAN;22100;22;COTES D'ARMOR;1
22051;;Dolo;DOLO;22270;22;COTES D'ARMOR;1
22052;;Duault;DUAULT;22160;22;COTES D'ARMOR;1
22053;;Éréac;EREAC;22250;22;COTES D'ARMOR;1
22054;;Erquy;ERQUY;22430;22;COTES D'ARMOR;1
22055;;Étables-sur-Mer;ETABLES-SUR-MER;22680;22;COTES D'ARMOR;1
22056;;Évran;EVRAN;22630;22;COTES D'ARMOR;1
22057;Le;Faouët;FAOUET;22290;22;COTES D'ARMOR;1
22058;La;Ferrière;FERRIERE;22210;22;COTES D'ARMOR;1
22059;Le;Fœil;FOEIL;22800;22;COTES D'ARMOR;1
22060;;Gausson;GAUSSON;22150;22;COTES D'ARMOR;1
22061;;Glomel;GLOMEL;22110;22;COTES D'ARMOR;1
22062;;Gomené;GOMENE;22230;22;COTES D'ARMOR;1
22063;;Gommenec'h;GOMMENEC'H;22290;22;COTES D'ARMOR;1
22064;;Gouarec;GOUAREC;22570;22;COTES D'ARMOR;1
22065;;Goudelin;GOUDELIN;22290;22;COTES D'ARMOR;1
22066;Le;Gouray;GOURAY;22330;22;COTES D'ARMOR;1
22067;;Grâces;GRACES;22200;22;COTES D'ARMOR;1
22068;;Grâce-Uzel;GRACE-UZEL;22460;22;COTES D'ARMOR;1
22069;;Guenroc;GUENROC;22350;22;COTES D'ARMOR;1
22070;;Guingamp;GUINGAMP;22200;22;COTES D'ARMOR;1
22071;;Guitté;GUITTE;22350;22;COTES D'ARMOR;1
22072;;Gurunhuel;GURUNHUEL;22390;22;COTES D'ARMOR;1
22073;La;Harmoye;HARMOYE;22320;22;COTES D'ARMOR;1
22074;Le;Haut-Corlay;HAUT-CORLAY;22320;22;COTES D'ARMOR;1
22075;;Hémonstoir;HEMONSTOIR;22600;22;COTES D'ARMOR;1
22076;;Hénanbihen;HENANBIHEN;22550;22;COTES D'ARMOR;1
22077;;Hénansal;HENANSAL;22400;22;COTES D'ARMOR;1
22078;;Hengoat;HENGOAT;22450;22;COTES D'ARMOR;1
22079;;Hénon;HENON;22150;22;COTES D'ARMOR;1
22080;L';Hermitage-Lorge;HERMITAGE-LORGE;22150;22;COTES D'ARMOR;1
22081;;Hillion;HILLION;22120;22;COTES D'ARMOR;1
22082;Le;Hinglé;HINGLE;22100;22;COTES D'ARMOR;1
22083;;Illifaut;ILLIFAUT;22230;22;COTES D'ARMOR;1
22084;;Jugon-les-Lacs;JUGON-LES-LACS;22270;22;COTES D'ARMOR;1
22085;;Kerbors;KERBORS;22610;22;COTES D'ARMOR;1
22086;;Kerfot;KERFOT;22500;22;COTES D'ARMOR;1
22087;;Kergrist-Moëlou;KERGRIST-MOELOU;22110;22;COTES D'ARMOR;1
22088;;Kerien;KERIEN;22480;22;COTES D'ARMOR;1
22090;;Kermaria-Sulard;KERMARIA-SULARD;22450;22;COTES D'ARMOR;1
22091;;Kermoroc'h;KERMOROC'H;22140;22;COTES D'ARMOR;1
22092;;Kerpert;KERPERT;22480;22;COTES D'ARMOR;1
22093;;Lamballe;LAMBALLE;22400;22;COTES D'ARMOR;1
22094;;Lancieux;LANCIEUX;22770;22;COTES D'ARMOR;1
22095;;Landebaëron;LANDEBAERON;22140;22;COTES D'ARMOR;1
22096;;Landébia;LANDEBIA;22130;22;COTES D'ARMOR;1
22097;La;Landec;LANDEC;22980;22;COTES D'ARMOR;1
22098;;Landéhen;LANDEHEN;22400;22;COTES D'ARMOR;1
22099;;Lanfains;LANFAINS;22800;22;COTES D'ARMOR;1
22100;;Langast;LANGAST;22150;22;COTES D'ARMOR;1
22101;;Langoat;LANGOAT;22450;22;COTES D'ARMOR;1
22102;;Langourla;LANGOURLA;22330;22;COTES D'ARMOR;1
22103;;Langrolay-sur-Rance;LANGROLAY-SUR-RANCE;22490;22;COTES D'ARMOR;1
22104;;Languédias;LANGUEDIAS;22980;22;COTES D'ARMOR;1
22105;;Languenan;LANGUENAN;22130;22;COTES D'ARMOR;1
22106;;Langueux;LANGUEUX;22360;22;COTES D'ARMOR;1
22107;;Laniscat;LANISCAT;22570;22;COTES D'ARMOR;1
22108;;Lanleff;LANLEFF;22290;22;COTES D'ARMOR;1
22109;;Lanloup;LANLOUP;22580;22;COTES D'ARMOR;1
22110;;Lanmérin;LANMERIN;22300;22;COTES D'ARMOR;1
22111;;Lanmodez;LANMODEZ;22610;22;COTES D'ARMOR;1
22112;;Lannebert;LANNEBERT;22290;22;COTES D'ARMOR;1
22113;;Lannion;LANNION;22300;22;COTES D'ARMOR;1
22114;;Lanrelas;LANRELAS;22250;22;COTES D'ARMOR;1
22115;;Lanrivain;LANRIVAIN;22480;22;COTES D'ARMOR;1
22116;;Lanrodec;LANRODEC;22170;22;COTES D'ARMOR;1
22117;;Lantic;LANTIC;22410;22;COTES D'ARMOR;1
22118;;Lanvallay;LANVALLAY;22100;22;COTES D'ARMOR;1
22119;;Lanvellec;LANVELLEC;22420;22;COTES D'ARMOR;1
22121;;Lanvollon;LANVOLLON;22290;22;COTES D'ARMOR;1
22122;;Laurenan;LAURENAN;22230;22;COTES D'ARMOR;1
22123;;Léhon;LEHON;22100;22;COTES D'ARMOR;1
22124;;Lescouët-Gouarec;LESCOUET-GOUAREC;22570;22;COTES D'ARMOR;1
22126;Le;Leslay;LESLAY;22800;22;COTES D'ARMOR;1
22127;;Lézardrieux;LEZARDRIEUX;22740;22;COTES D'ARMOR;1
22128;;Locarn;LOCARN;22340;22;COTES D'ARMOR;1
22129;;Loc-Envel;LOC-ENVEL;22810;22;COTES D'ARMOR;1
22131;;Loguivy-Plougras;LOGUIVY-PLOUGRAS;22780;22;COTES D'ARMOR;1
22132;;Lohuec;LOHUEC;22160;22;COTES D'ARMOR;1
22133;;Loscouët-sur-Meu;LOSCOUET-SUR-MEU;22230;22;COTES D'ARMOR;1
22134;;Louannec;LOUANNEC;22700;22;COTES D'ARMOR;1
22135;;Louargat;LOUARGAT;22540;22;COTES D'ARMOR;1
22136;;Loudéac;LOUDEAC;22600;22;COTES D'ARMOR;1
22137;;Maël-Carhaix;MAEL-CARHAIX;22340;22;COTES D'ARMOR;1
22138;;Maël-Pestivien;MAEL-PESTIVIEN;22160;22;COTES D'ARMOR;1
22139;;Magoar;MAGOAR;22480;22;COTES D'ARMOR;1
22140;La;Malhoure;MALHOURE;22640;22;COTES D'ARMOR;1
22141;;Mantallot;MANTALLOT;22450;22;COTES D'ARMOR;1
22143;;Matignon;MATIGNON;22550;22;COTES D'ARMOR;1
22144;La;Méaugon;MEAUGON;22440;22;COTES D'ARMOR;1
22145;;Mégrit;MEGRIT;22270;22;COTES D'ARMOR;1
22146;;Mellionnec;MELLIONNEC;22110;22;COTES D'ARMOR;1
22147;;Merdrignac;MERDRIGNAC;22230;22;COTES D'ARMOR;1
22148;;Mérillac;MERILLAC;22230;22;COTES D'ARMOR;1
22149;;Merléac;MERLEAC;22460;22;COTES D'ARMOR;1
22150;Le;Merzer;MERZER;22200;22;COTES D'ARMOR;1
22151;;Meslin;MESLIN;22400;22;COTES D'ARMOR;1
22152;;Minihy-Tréguier;MINIHY-TREGUIER;22220;22;COTES D'ARMOR;1
22153;;Moncontour;MONCONTOUR;22510;22;COTES D'ARMOR;1
22154;;Morieux;MORIEUX;22400;22;COTES D'ARMOR;1
22155;La;Motte;MOTTE;22600;22;COTES D'ARMOR;1
22156;;Moustéru;MOUSTERU;22200;22;COTES D'ARMOR;1
22157;Le;Moustoir;MOUSTOIR;22340;22;COTES D'ARMOR;1
22158;;Mûr-de-Bretagne;MUR-DE-BRETAGNE;22530;22;COTES D'ARMOR;1
22160;;Noyal;NOYAL;22400;22;COTES D'ARMOR;1
22161;;Pabu;PABU;22200;22;COTES D'ARMOR;1
22162;;Paimpol;PAIMPOL;22500;22;COTES D'ARMOR;1
22163;;Paule;PAULE;22340;22;COTES D'ARMOR;1
22164;;Pédernec;PEDERNEC;22540;22;COTES D'ARMOR;1
22165;;Penguily;PENGUILY;22510;22;COTES D'ARMOR;1
22166;;Penvénan;PENVENAN;22710;22;COTES D'ARMOR;1
22167;;Perret;PERRET;22570;22;COTES D'ARMOR;1
22168;;Perros-Guirec;PERROS-GUIREC;22700;22;COTES D'ARMOR;1
22169;;Peumerit-Quintin;PEUMERIT-QUINTIN;22480;22;COTES D'ARMOR;1
22170;;Plaine-Haute;PLAINE-HAUTE;22800;22;COTES D'ARMOR;1
22171;;Plaintel;PLAINTEL;22940;22;COTES D'ARMOR;1
22172;;Plancoët;PLANCOET;22130;22;COTES D'ARMOR;1
22173;;Planguenoual;PLANGUENOUAL;22400;22;COTES D'ARMOR;1
22174;;Pléboulle;PLEBOULLE;22550;22;COTES D'ARMOR;1
22175;;Plédéliac;PLEDELIAC;22270;22;COTES D'ARMOR;1
22176;;Plédran;PLEDRAN;22960;22;COTES D'ARMOR;1
22177;;Pléguien;PLEGUIEN;22290;22;COTES D'ARMOR;1
22178;;Pléhédel;PLEHEDEL;22290;22;COTES D'ARMOR;1
22179;;Fréhel;FREHEL;22240;22;COTES D'ARMOR;1
22180;;Plélan-le-Petit;PLELAN-LE-PETIT;22980;22;COTES D'ARMOR;1
22181;;Plélauff;PLELAUFF;22570;22;COTES D'ARMOR;1
22182;;Plélo;PLELO;22170;22;COTES D'ARMOR;1
22183;;Plémet;PLEMET;22210;22;COTES D'ARMOR;1
22184;;Plémy;PLEMY;22150;22;COTES D'ARMOR;1
22185;;Plénée-Jugon;PLENEE-JUGON;22640;22;COTES D'ARMOR;1
22186;;Pléneuf-Val-André;PLENEUF-VAL-ANDRE;22370;22;COTES D'ARMOR;1
22187;;Plérin;PLERIN;22190;22;COTES D'ARMOR;1
22188;;Plerneuf;PLERNEUF;22170;22;COTES D'ARMOR;1
22189;;Plésidy;PLESIDY;22720;22;COTES D'ARMOR;1
22190;;Pleslin-Trigavou;PLESLIN-TRIGAVOU;22490;22;COTES D'ARMOR;1
22191;;Plessala;PLESSALA;22330;22;COTES D'ARMOR;1
22192;;Plessix-Balisson;PLESSIX-BALISSON;22650;22;COTES D'ARMOR;1
22193;;Plestan;PLESTAN;22640;22;COTES D'ARMOR;1
22194;;Plestin-les-Grèves;PLESTIN-LES-GREVES;22310;22;COTES D'ARMOR;1
22195;;Pleubian;PLEUBIAN;22610;22;COTES D'ARMOR;1
22196;;Pleudaniel;PLEUDANIEL;22740;22;COTES D'ARMOR;1
22197;;Pleudihen-sur-Rance;PLEUDIHEN-SUR-RANCE;22690;22;COTES D'ARMOR;1
22198;;Pleumeur-Bodou;PLEUMEUR-BODOU;22560;22;COTES D'ARMOR;1
22199;;Pleumeur-Gautier;PLEUMEUR-GAUTIER;22740;22;COTES D'ARMOR;1
22200;;Pléven;PLEVEN;22130;22;COTES D'ARMOR;1
22201;;Plévenon;PLEVENON;22240;22;COTES D'ARMOR;1
22202;;Plévin;PLEVIN;22340;22;COTES D'ARMOR;1
22203;;Plœuc-sur-Lié;PLOEUC-SUR-LIE;22150;22;COTES D'ARMOR;1
22204;;Ploëzal;PLOEZAL;22260;22;COTES D'ARMOR;1
22205;;Plorec-sur-Arguenon;PLOREC-SUR-ARGUENON;22130;22;COTES D'ARMOR;1
22206;;Plouagat;PLOUAGAT;22170;22;COTES D'ARMOR;1
22207;;Plouaret;PLOUARET;22420;22;COTES D'ARMOR;1
22208;;Plouasne;PLOUASNE;22830;22;COTES D'ARMOR;1
22209;;Ploubalay;PLOUBALAY;22650;22;COTES D'ARMOR;1
22210;;Ploubazlanec;PLOUBAZLANEC;22620;22;COTES D'ARMOR;1
22211;;Ploubezre;PLOUBEZRE;22300;22;COTES D'ARMOR;1
22212;;Plouëc-du-Trieux;PLOUEC-DU-TRIEUX;22260;22;COTES D'ARMOR;1
22213;;Plouër-sur-Rance;PLOUER-SUR-RANCE;22490;22;COTES D'ARMOR;1
22214;;Plouézec;PLOUEZEC;22470;22;COTES D'ARMOR;1
22215;;Ploufragan;PLOUFRAGAN;22440;22;COTES D'ARMOR;1
22216;;Plougonver;PLOUGONVER;22810;22;COTES D'ARMOR;1
22217;;Plougras;PLOUGRAS;22780;22;COTES D'ARMOR;1
22218;;Plougrescant;PLOUGRESCANT;22820;22;COTES D'ARMOR;1
22219;;Plouguenast;PLOUGUENAST;22150;22;COTES D'ARMOR;1
22220;;Plouguernével;PLOUGUERNEVEL;22110;22;COTES D'ARMOR;1
22221;;Plouguiel;PLOUGUIEL;22220;22;COTES D'ARMOR;1
22222;;Plouha;PLOUHA;22580;22;COTES D'ARMOR;1
22223;;Plouisy;PLOUISY;22200;22;COTES D'ARMOR;1
22224;;Ploulec'h;PLOULEC'H;22300;22;COTES D'ARMOR;1
22225;;Ploumagoar;PLOUMAGOAR;22970;22;COTES D'ARMOR;1
22226;;Ploumilliau;PLOUMILLIAU;22300;22;COTES D'ARMOR;1
22227;;Plounérin;PLOUNERIN;22780;22;COTES D'ARMOR;1
22228;;Plounévez-Moëdec;PLOUNEVEZ-MOEDEC;22810;22;COTES D'ARMOR;1
22229;;Plounévez-Quintin;PLOUNEVEZ-QUINTIN;22110;22;COTES D'ARMOR;1
22231;;Plourac'h;PLOURAC'H;22160;22;COTES D'ARMOR;1
22232;;Plourhan;PLOURHAN;22410;22;COTES D'ARMOR;1
22233;;Plourivo;PLOURIVO;22860;22;COTES D'ARMOR;1
22234;;Plouvara;PLOUVARA;22170;22;COTES D'ARMOR;1
22235;;Plouzélambre;PLOUZELAMBRE;22420;22;COTES D'ARMOR;1
22236;;Pludual;PLUDUAL;22290;22;COTES D'ARMOR;1
22237;;Pluduno;PLUDUNO;22130;22;COTES D'ARMOR;1
22238;;Plufur;PLUFUR;22310;22;COTES D'ARMOR;1
22239;;Plumaudan;PLUMAUDAN;22350;22;COTES D'ARMOR;1
22240;;Plumaugat;PLUMAUGAT;22250;22;COTES D'ARMOR;1
22241;;Plumieux;PLUMIEUX;22210;22;COTES D'ARMOR;1
22242;;Plurien;PLURIEN;22240;22;COTES D'ARMOR;1
22243;;Plusquellec;PLUSQUELLEC;22160;22;COTES D'ARMOR;1
22244;;Plussulien;PLUSSULIEN;22320;22;COTES D'ARMOR;1
22245;;Pluzunet;PLUZUNET;22140;22;COTES D'ARMOR;1
22246;;Pommeret;POMMERET;22120;22;COTES D'ARMOR;1
22247;;Pommerit-Jaudy;POMMERIT-JAUDY;22450;22;COTES D'ARMOR;1
22248;;Pommerit-le-Vicomte;POMMERIT-LE-VICOMTE;22200;22;COTES D'ARMOR;1
22249;;Pont-Melvez;PONT-MELVEZ;22390;22;COTES D'ARMOR;1
22250;;Pontrieux;PONTRIEUX;22260;22;COTES D'ARMOR;1
22251;;Pordic;PORDIC;22590;22;COTES D'ARMOR;1
22253;;Pouldouran;POULDOURAN;22450;22;COTES D'ARMOR;1
22254;;Prat;PRAT;22140;22;COTES D'ARMOR;1
22255;La;Prénessaye;PRENESSAYE;22210;22;COTES D'ARMOR;1
22256;;Quemper-Guézennec;QUEMPER-GUEZENNEC;22260;22;COTES D'ARMOR;1
22257;;Quemperven;QUEMPERVEN;22450;22;COTES D'ARMOR;1
22258;;Quessoy;QUESSOY;22120;22;COTES D'ARMOR;1
22259;;Quévert;QUEVERT;22100;22;COTES D'ARMOR;1
22260;Le;Quillio;QUILLIO;22460;22;COTES D'ARMOR;1
22261;;Quintenic;QUINTENIC;22400;22;COTES D'ARMOR;1
22262;;Quintin;QUINTIN;22800;22;COTES D'ARMOR;1
22263;Le;Quiou;QUIOU;22630;22;COTES D'ARMOR;1
22264;La;Roche-Derrien;ROCHE-DERRIEN;22450;22;COTES D'ARMOR;1
22265;;Rospez;ROSPEZ;22300;22;COTES D'ARMOR;1
22266;;Rostrenen;ROSTRENEN;22110;22;COTES D'ARMOR;1
22267;;Rouillac;ROUILLAC;22250;22;COTES D'ARMOR;1
22268;;Ruca;RUCA;22550;22;COTES D'ARMOR;1
22269;;Runan;RUNAN;22260;22;COTES D'ARMOR;1
22271;;Saint-Adrien;SAINT-ADRIEN;22390;22;COTES D'ARMOR;1
22272;;Saint-Agathon;SAINT-AGATHON;22200;22;COTES D'ARMOR;1
22273;;Saint-Alban;SAINT-ALBAN;22400;22;COTES D'ARMOR;1
22274;;Saint-André-des-Eaux;SAINT-ANDRE-DES-EAUX;22630;22;COTES D'ARMOR;1
22275;;Saint-Barnabé;SAINT-BARNABE;22600;22;COTES D'ARMOR;1
22276;;Saint-Bihy;SAINT-BIHY;22800;22;COTES D'ARMOR;1
22277;;Saint-Brandan;SAINT-BRANDAN;22800;22;COTES D'ARMOR;1
22278;;Saint-Brieuc;SAINT-BRIEUC;22000;22;COTES D'ARMOR;1
22279;;Saint-Caradec;SAINT-CARADEC;22600;22;COTES D'ARMOR;1
22280;;Saint-Carné;SAINT-CARNE;22100;22;COTES D'ARMOR;1
22281;;Saint-Carreuc;SAINT-CARREUC;22150;22;COTES D'ARMOR;1
22282;;Saint-Cast-le-Guildo;SAINT-CAST-LE-GUILDO;22380;22;COTES D'ARMOR;1
22283;;Saint-Clet;SAINT-CLET;22260;22;COTES D'ARMOR;1
22284;;Saint-Connan;SAINT-CONNAN;22480;22;COTES D'ARMOR;1
22285;;Saint-Connec;SAINT-CONNEC;22530;22;COTES D'ARMOR;1
22286;;Saint-Denoual;SAINT-DENOUAL;22400;22;COTES D'ARMOR;1
22287;;Saint-Donan;SAINT-DONAN;22800;22;COTES D'ARMOR;1
22288;;Saint-Étienne-du-Gué-de-l'Isle;SAINT-ETIENNE-DU-GUE-DE-L'ISLE;22210;22;COTES D'ARMOR;1
22289;;Saint-Fiacre;SAINT-FIACRE;22720;22;COTES D'ARMOR;1
22290;;Saint-Gelven;SAINT-GELVEN;22570;22;COTES D'ARMOR;1
22291;;Saint-Gildas;SAINT-GILDAS;22800;22;COTES D'ARMOR;1
22292;;Saint-Gilles-du-Mené;SAINT-GILLES-DU-MENE;22330;22;COTES D'ARMOR;1
22293;;Saint-Gilles-les-Bois;SAINT-GILLES-LES-BOIS;22290;22;COTES D'ARMOR;1
22294;;Saint-Gilles-Pligeaux;SAINT-GILLES-PLIGEAUX;22480;22;COTES D'ARMOR;1
22295;;Saint-Gilles-Vieux-Marché;SAINT-GILLES-VIEUX-MARCHE;22530;22;COTES D'ARMOR;1
22296;;Saint-Glen;SAINT-GLEN;22510;22;COTES D'ARMOR;1
22297;;Saint-Gouéno;SAINT-GOUENO;22330;22;COTES D'ARMOR;1
22298;;Saint-Guen;SAINT-GUEN;22530;22;COTES D'ARMOR;1
22299;;Saint-Hélen;SAINT-HELEN;22100;22;COTES D'ARMOR;1
22300;;Saint-Hervé;SAINT-HERVE;22460;22;COTES D'ARMOR;1
22302;;Saint-Jacut-de-la-Mer;SAINT-JACUT-DE-LA-MER;22750;22;COTES D'ARMOR;1
22303;;Saint-Jacut-du-Mené;SAINT-JACUT-DU-MENE;22330;22;COTES D'ARMOR;1
22304;;Saint-Jean-Kerdaniel;SAINT-JEAN-KERDANIEL;22170;22;COTES D'ARMOR;1
22305;;Saint-Jouan-de-l'Isle;SAINT-JOUAN-DE-L'ISLE;22350;22;COTES D'ARMOR;1
22306;;Saint-Judoce;SAINT-JUDOCE;22630;22;COTES D'ARMOR;1
22307;;Saint-Julien;SAINT-JULIEN;22940;22;COTES D'ARMOR;1
22308;;Saint-Juvat;SAINT-JUVAT;22630;22;COTES D'ARMOR;1
22309;;Saint-Launeuc;SAINT-LAUNEUC;22230;22;COTES D'ARMOR;1
22310;;Saint-Laurent;SAINT-LAURENT;22140;22;COTES D'ARMOR;1
22311;;Saint-Lormel;SAINT-LORMEL;22130;22;COTES D'ARMOR;1
22312;;Saint-Maden;SAINT-MADEN;22350;22;COTES D'ARMOR;1
22313;;Saint-Martin-des-Prés;SAINT-MARTIN-DES-PRES;22320;22;COTES D'ARMOR;1
22314;;Saint-Maudan;SAINT-MAUDAN;22600;22;COTES D'ARMOR;1
22315;;Saint-Maudez;SAINT-MAUDEZ;22980;22;COTES D'ARMOR;1
22316;;Saint-Mayeux;SAINT-MAYEUX;22320;22;COTES D'ARMOR;1
22317;;Saint-Méloir-des-Bois;SAINT-MELOIR-DES-BOIS;22980;22;COTES D'ARMOR;1
22318;;Saint-Michel-de-Plélan;SAINT-MICHEL-DE-PLELAN;22980;22;COTES D'ARMOR;1
22319;;Saint-Michel-en-Grève;SAINT-MICHEL-EN-GREVE;22300;22;COTES D'ARMOR;1
22320;;Saint-Nicodème;SAINT-NICODEME;22160;22;COTES D'ARMOR;1
22321;;Saint-Nicolas-du-Pélem;SAINT-NICOLAS-DU-PELEM;22480;22;COTES D'ARMOR;1
22322;;Saint-Péver;SAINT-PEVER;22720;22;COTES D'ARMOR;1
22323;;Saint-Pôtan;SAINT-POTAN;22550;22;COTES D'ARMOR;1
22324;;Saint-Quay-Perros;SAINT-QUAY-PERROS;22700;22;COTES D'ARMOR;1
22325;;Saint-Quay-Portrieux;SAINT-QUAY-PORTRIEUX;22410;22;COTES D'ARMOR;1
22326;;Saint-Rieul;SAINT-RIEUL;22270;22;COTES D'ARMOR;1
22327;;Saint-Samson-sur-Rance;SAINT-SAMSON-SUR-RANCE;22100;22;COTES D'ARMOR;1
22328;;Saint-Servais;SAINT-SERVAIS;22160;22;COTES D'ARMOR;1
22330;;Saint-Thélo;SAINT-THELO;22460;22;COTES D'ARMOR;1
22331;;Sainte-Tréphine;SAINTE-TREPHINE;22480;22;COTES D'ARMOR;1
22332;;Saint-Trimoël;SAINT-TRIMOEL;22510;22;COTES D'ARMOR;1
22333;;Saint-Vran;SAINT-VRAN;22230;22;COTES D'ARMOR;1
22334;;Saint-Igeaux;SAINT-IGEAUX;22570;22;COTES D'ARMOR;1
22335;;Senven-Léhart;SENVEN-LEHART;22720;22;COTES D'ARMOR;1
22337;;Sévignac;SEVIGNAC;22250;22;COTES D'ARMOR;1
22338;;Squiffiec;SQUIFFIEC;22200;22;COTES D'ARMOR;1
22339;;Taden;TADEN;22100;22;COTES D'ARMOR;1
22340;;Tonquédec;TONQUEDEC;22140;22;COTES D'ARMOR;1
22341;;Tramain;TRAMAIN;22640;22;COTES D'ARMOR;1
22342;;Trébédan;TREBEDAN;22980;22;COTES D'ARMOR;1
22343;;Trébeurden;TREBEURDEN;22560;22;COTES D'ARMOR;1
22344;;Trébrivan;TREBRIVAN;22340;22;COTES D'ARMOR;1
22345;;Trébry;TREBRY;22510;22;COTES D'ARMOR;1
22346;;Trédaniel;TREDANIEL;22510;22;COTES D'ARMOR;1
22347;;Trédarzec;TREDARZEC;22220;22;COTES D'ARMOR;1
22348;;Trédias;TREDIAS;22250;22;COTES D'ARMOR;1
22349;;Trédrez-Locquémeau;TREDREZ-LOCQUEMEAU;22300;22;COTES D'ARMOR;1
22350;;Tréduder;TREDUDER;22310;22;COTES D'ARMOR;1
22351;;Treffrin;TREFFRIN;22340;22;COTES D'ARMOR;1
22352;;Tréfumel;TREFUMEL;22630;22;COTES D'ARMOR;1
22353;;Trégastel;TREGASTEL;22730;22;COTES D'ARMOR;1
22354;;Tréglamus;TREGLAMUS;22540;22;COTES D'ARMOR;1
22356;;Trégomeur;TREGOMEUR;22590;22;COTES D'ARMOR;1
22357;;Trégon;TREGON;22650;22;COTES D'ARMOR;1
22358;;Trégonneau;TREGONNEAU;22200;22;COTES D'ARMOR;1
22359;;Trégrom;TREGROM;22420;22;COTES D'ARMOR;1
22360;;Trégueux;TREGUEUX;22950;22;COTES D'ARMOR;1
22361;;Tréguidel;TREGUIDEL;22290;22;COTES D'ARMOR;1
22362;;Tréguier;TREGUIER;22220;22;COTES D'ARMOR;1
22363;;Trélévern;TRELEVERN;22660;22;COTES D'ARMOR;1
22364;;Trélivan;TRELIVAN;22100;22;COTES D'ARMOR;1
22365;;Trémargat;TREMARGAT;22110;22;COTES D'ARMOR;1
22366;;Trémel;TREMEL;22310;22;COTES D'ARMOR;1
22367;;Tréméloir;TREMELOIR;22590;22;COTES D'ARMOR;1
22368;;Tréméreuc;TREMEREUC;22490;22;COTES D'ARMOR;1
22369;;Trémeur;TREMEUR;22250;22;COTES D'ARMOR;1
22370;;Tréméven;TREMEVEN;22290;22;COTES D'ARMOR;1
22371;;Trémorel;TREMOREL;22230;22;COTES D'ARMOR;1
22372;;Trémuson;TREMUSON;22440;22;COTES D'ARMOR;1
22373;;Tréogan;TREOGAN;22340;22;COTES D'ARMOR;1
22375;;Tressignaux;TRESSIGNAUX;22290;22;COTES D'ARMOR;1
22376;;Trévé;TREVE;22600;22;COTES D'ARMOR;1
22377;;Tréveneuc;TREVENEUC;22410;22;COTES D'ARMOR;1
22378;;Trévérec;TREVEREC;22290;22;COTES D'ARMOR;1
22379;;Trévou-Tréguignec;TREVOU-TREGUIGNEC;22660;22;COTES D'ARMOR;1
22380;;Trévron;TREVRON;22100;22;COTES D'ARMOR;1
22381;;Trézény;TREZENY;22450;22;COTES D'ARMOR;1
22383;;Troguéry;TROGUERY;22450;22;COTES D'ARMOR;1
22384;;Uzel;UZEL;22460;22;COTES D'ARMOR;1
22385;La;Vicomté-sur-Rance;VICOMTE-SUR-RANCE;22690;22;COTES D'ARMOR;1
22386;Le;Vieux-Bourg;VIEUX-BOURG;22800;22;COTES D'ARMOR;1
22387;Le;Vieux-Marché;VIEUX-MARCHE;22420;22;COTES D'ARMOR;1
22388;;Vildé-Guingalan;VILDE-GUINGALAN;22980;22;COTES D'ARMOR;1
22389;;Yffiniac;YFFINIAC;22120;22;COTES D'ARMOR;1
22390;;Yvias;YVIAS;22930;22;COTES D'ARMOR;1
22391;;Yvignac-la-Tour;YVIGNAC-LA-TOUR;22350;22;COTES D'ARMOR;1
23001;;Ahun;AHUN;23150;23;CREUSE;1
23002;;Ajain;AJAIN;23380;23;CREUSE;1
23003;;Alleyrat;ALLEYRAT;23200;23;CREUSE;1
23004;;Anzême;ANZEME;23000;23;CREUSE;1
23005;;Arfeuille-Châtain;ARFEUILLE-CHATAIN;23700;23;CREUSE;1
23006;;Arrènes;ARRENES;23210;23;CREUSE;1
23007;;Ars;ARS;23480;23;CREUSE;1
23008;;Aubusson;AUBUSSON;23200;23;CREUSE;1
23009;;Auge;AUGE;23170;23;CREUSE;1
23010;;Augères;AUGERES;23210;23;CREUSE;1
23011;;Aulon;AULON;23210;23;CREUSE;1
23012;;Auriat;AURIAT;23400;23;CREUSE;1
23013;;Auzances;AUZANCES;23700;23;CREUSE;1
23014;;Azat-Châtenet;AZAT-CHATENET;23210;23;CREUSE;1
23015;;Azerables;AZERABLES;23160;23;CREUSE;1
23016;;Banize;BANIZE;23120;23;CREUSE;1
23017;;Basville;BASVILLE;23260;23;CREUSE;1
23018;;Bazelat;BAZELAT;23160;23;CREUSE;1
23019;;Beissat;BEISSAT;23260;23;CREUSE;1
23020;;Bellegarde-en-Marche;BELLEGARDE-EN-MARCHE;23190;23;CREUSE;1
23021;;Bénévent-l'Abbaye;BENEVENT-L'ABBAYE;23210;23;CREUSE;1
23022;;Bétête;BETETE;23270;23;CREUSE;1
23023;;Blaudeix;BLAUDEIX;23140;23;CREUSE;1
23024;;Blessac;BLESSAC;23200;23;CREUSE;1
23025;;Bonnat;BONNAT;23220;23;CREUSE;1
23026;;Bord-Saint-Georges;BORD-SAINT-GEORGES;23230;23;CREUSE;1
23027;;Bosmoreau-les-Mines;BOSMOREAU-LES-MINES;23400;23;CREUSE;1
23028;;Bosroger;BOSROGER;23200;23;CREUSE;1
23029;Le;Bourg-d'Hem;BOURG-D'HEM;23220;23;CREUSE;1
23030;;Bourganeuf;BOURGANEUF;23400;23;CREUSE;1
23031;;Boussac;BOUSSAC;23600;23;CREUSE;1
23032;;Boussac-Bourg;BOUSSAC-BOURG;23600;23;CREUSE;1
23033;La;Brionne;BRIONNE;23000;23;CREUSE;1
23034;;Brousse;BROUSSE;23700;23;CREUSE;1
23035;;Budelière;BUDELIERE;23170;23;CREUSE;1
23036;;Bussière-Dunoise;BUSSIERE-DUNOISE;23320;23;CREUSE;1
23037;;Bussière-Nouvelle;BUSSIERE-NOUVELLE;23700;23;CREUSE;1
23038;;Bussière-Saint-Georges;BUSSIERE-SAINT-GEORGES;23600;23;CREUSE;1
23039;La;Celle-Dunoise;CELLE-DUNOISE;23800;23;CREUSE;1
23040;La;Celle-sous-Gouzon;CELLE-SOUS-GOUZON;23230;23;CREUSE;1
23041;La;Cellette;CELLETTE;23350;23;CREUSE;1
23042;;Ceyroux;CEYROUX;23210;23;CREUSE;1
23043;;Chamberaud;CHAMBERAUD;23480;23;CREUSE;1
23044;;Chambon-Sainte-Croix;CHAMBON-SAINTE-CROIX;23220;23;CREUSE;1
23045;;Chambon-sur-Voueize;CHAMBON-SUR-VOUEIZE;23170;23;CREUSE;1
23046;;Chambonchard;CHAMBONCHARD;23110;23;CREUSE;1
23047;;Chamborand;CHAMBORAND;23240;23;CREUSE;1
23048;;Champagnat;CHAMPAGNAT;23190;23;CREUSE;1
23049;;Champsanglard;CHAMPSANGLARD;23220;23;CREUSE;1
23050;La;Chapelle-Baloue;CHAPELLE-BALOUE;23160;23;CREUSE;1
23051;La;Chapelle-Saint-Martial;CHAPELLE-SAINT-MARTIAL;23250;23;CREUSE;1
23052;La;Chapelle-Taillefert;CHAPELLE-TAILLEFERT;23000;23;CREUSE;1
23053;;Chard;CHARD;23700;23;CREUSE;1
23054;;Charron;CHARRON;23700;23;CREUSE;1
23055;;Châtelard;CHATELARD;23700;23;CREUSE;1
23056;;Châtelus-le-Marcheix;CHATELUS-LE-MARCHEIX;23430;23;CREUSE;1
23057;;Châtelus-Malvaleix;CHATELUS-MALVALEIX;23270;23;CREUSE;1
23058;Le;Chauchet;CHAUCHET;23130;23;CREUSE;1
23059;La;Chaussade;CHAUSSADE;23200;23;CREUSE;1
23060;;Chavanat;CHAVANAT;23250;23;CREUSE;1
23061;;Chénérailles;CHENERAILLES;23130;23;CREUSE;1
23062;;Chéniers;CHENIERS;23220;23;CREUSE;1
23063;;Clairavaux;CLAIRAVAUX;23500;23;CREUSE;1
23064;;Clugnat;CLUGNAT;23270;23;CREUSE;1
23065;;Colondannes;COLONDANNES;23800;23;CREUSE;1
23066;Le;Compas;COMPAS;23700;23;CREUSE;1
23067;La;Courtine;COURTINE;23100;23;CREUSE;1
23068;;Cressat;CRESSAT;23140;23;CREUSE;1
23069;;Crocq;CROCQ;23260;23;CREUSE;1
23070;;Crozant;CROZANT;23160;23;CREUSE;1
23071;;Croze;CROZE;23500;23;CREUSE;1
23072;;Domeyrot;DOMEYROT;23140;23;CREUSE;1
23073;;Dontreix;DONTREIX;23700;23;CREUSE;1
23074;Le;Donzeil;DONZEIL;23480;23;CREUSE;1
23075;;Dun-le-Palestel;DUN-LE-PALESTEL;23800;23;CREUSE;1
23076;;Évaux-les-Bains;EVAUX-LES-BAINS;23110;23;CREUSE;1
23077;;Faux-la-Montagne;FAUX-LA-MONTAGNE;23340;23;CREUSE;1
23078;;Faux-Mazuras;FAUX-MAZURAS;23400;23;CREUSE;1
23079;;Felletin;FELLETIN;23500;23;CREUSE;1
23080;;Féniers;FENIERS;23100;23;CREUSE;1
23081;;Flayat;FLAYAT;23260;23;CREUSE;1
23082;;Fleurat;FLEURAT;23320;23;CREUSE;1
23083;;Fontanières;FONTANIERES;23110;23;CREUSE;1
23084;La;Forêt-du-Temple;FORET-DU-TEMPLE;23360;23;CREUSE;1
23086;;Fransèches;FRANSECHES;23480;23;CREUSE;1
23087;;Fresselines;FRESSELINES;23450;23;CREUSE;1
23088;;Gartempe;GARTEMPE;23320;23;CREUSE;1
23089;;Genouillac;GENOUILLAC;23350;23;CREUSE;1
23090;;Gentioux-Pigerolles;GENTIOUX-PIGEROLLES;23340;23;CREUSE;1
23091;;Gioux;GIOUX;23500;23;CREUSE;1
23092;;Glénic;GLENIC;23380;23;CREUSE;1
23093;;Gouzon;GOUZON;23230;23;CREUSE;1
23095;Le;Grand-Bourg;GRAND-BOURG;23240;23;CREUSE;1
23096;;Guéret;GUERET;23000;23;CREUSE;1
23097;;Issoudun-Létrieix;ISSOUDUN-LETRIEIX;23130;23;CREUSE;1
23098;;Jalesches;JALESCHES;23270;23;CREUSE;1
23099;;Janaillat;JANAILLAT;23250;23;CREUSE;1
23100;;Jarnages;JARNAGES;23140;23;CREUSE;1
23101;;Jouillat;JOUILLAT;23220;23;CREUSE;1
23102;;Ladapeyre;LADAPEYRE;23270;23;CREUSE;1
23103;;Lafat;LAFAT;23800;23;CREUSE;1
23104;;Lavaufranche;LAVAUFRANCHE;23600;23;CREUSE;1
23105;;Lavaveix-les-Mines;LAVAVEIX-LES-MINES;23150;23;CREUSE;1
23106;;Lépaud;LEPAUD;23170;23;CREUSE;1
23107;;Lépinas;LEPINAS;23150;23;CREUSE;1
23108;;Leyrat;LEYRAT;23600;23;CREUSE;1
23109;;Linard;LINARD;23220;23;CREUSE;1
23110;;Lioux-les-Monges;LIOUX-LES-MONGES;23700;23;CREUSE;1
23111;;Lizières;LIZIERES;23240;23;CREUSE;1
23112;;Lourdoueix-Saint-Pierre;LOURDOUEIX-SAINT-PIERRE;23360;23;CREUSE;1
23113;;Lupersat;LUPERSAT;23190;23;CREUSE;1
23114;;Lussat;LUSSAT;23170;23;CREUSE;1
23115;;Magnat-l'Étrange;MAGNAT-L'ETRANGE;23260;23;CREUSE;1
23116;;Mainsat;MAINSAT;23700;23;CREUSE;1
23117;;Maison-Feyne;MAISON-FEYNE;23800;23;CREUSE;1
23118;;Maisonnisses;MAISONNISSES;23150;23;CREUSE;1
23119;;Malleret;MALLERET;23260;23;CREUSE;1
23120;;Malleret-Boussac;MALLERET-BOUSSAC;23600;23;CREUSE;1
23121;;Malval;MALVAL;23220;23;CREUSE;1
23122;;Mansat-la-Courrière;MANSAT-LA-COURRIERE;23400;23;CREUSE;1
23123;Les;Mars;MARS;23700;23;CREUSE;1
23124;;Marsac;MARSAC;23210;23;CREUSE;1
23125;Le;Mas-d'Artige;MAS-D'ARTIGE;23100;23;CREUSE;1
23126;;Masbaraud-Mérignat;MASBARAUD-MERIGNAT;23400;23;CREUSE;1
23127;;Mautes;MAUTES;23190;23;CREUSE;1
23128;;Mazeirat;MAZEIRAT;23150;23;CREUSE;1
23129;La;Mazière-aux-Bons-Hommes;MAZIERE-AUX-BONS-HOMMES;23260;23;CREUSE;1
23130;;Méasnes;MEASNES;23360;23;CREUSE;1
23131;;Mérinchal;MERINCHAL;23420;23;CREUSE;1
23132;;Montaigut-le-Blanc;MONTAIGUT-LE-BLANC;23320;23;CREUSE;1
23133;;Montboucher;MONTBOUCHER;23400;23;CREUSE;1
23134;Le;Monteil-au-Vicomte;MONTEIL-AU-VICOMTE;23460;23;CREUSE;1
23136;;Mortroux;MORTROUX;23220;23;CREUSE;1
23137;;Mourioux-Vieilleville;MOURIOUX-VIEILLEVILLE;23210;23;CREUSE;1
23138;;Moutier-d'Ahun;MOUTIER-D'AHUN;23150;23;CREUSE;1
23139;;Moutier-Malcard;MOUTIER-MALCARD;23220;23;CREUSE;1
23140;;Moutier-Rozeille;MOUTIER-ROZEILLE;23200;23;CREUSE;1
23141;;Naillat;NAILLAT;23800;23;CREUSE;1
23142;;Néoux;NEOUX;23200;23;CREUSE;1
23143;;Noth;NOTH;23300;23;CREUSE;1
23144;La;Nouaille;NOUAILLE;23500;23;CREUSE;1
23145;;Nouhant;NOUHANT;23170;23;CREUSE;1
23146;;Nouzerines;NOUZERINES;23600;23;CREUSE;1
23147;;Nouzerolles;NOUZEROLLES;23360;23;CREUSE;1
23148;;Nouziers;NOUZIERS;23350;23;CREUSE;1
23149;;Parsac;PARSAC;23140;23;CREUSE;1
23150;;Peyrabout;PEYRABOUT;23000;23;CREUSE;1
23151;;Peyrat-la-Nonière;PEYRAT-LA-NONIERE;23130;23;CREUSE;1
23152;;Pierrefitte;PIERREFITTE;23130;23;CREUSE;1
23154;;Pionnat;PIONNAT;23140;23;CREUSE;1
23155;;Pontarion;PONTARION;23250;23;CREUSE;1
23156;;Pontcharraud;PONTCHARRAUD;23260;23;CREUSE;1
23157;La;Pouge;POUGE;23250;23;CREUSE;1
23158;;Poussanges;POUSSANGES;23500;23;CREUSE;1
23159;;Puy-Malsignat;PUY-MALSIGNAT;23130;23;CREUSE;1
23160;;Reterre;RETERRE;23110;23;CREUSE;1
23161;;Rimondeix;RIMONDEIX;23140;23;CREUSE;1
23162;;Roches;ROCHES;23270;23;CREUSE;1
23164;;Rougnat;ROUGNAT;23700;23;CREUSE;1
23165;;Royère-de-Vassivière;ROYERE-DE-VASSIVIERE;23460;23;CREUSE;1
23166;;Sagnat;SAGNAT;23800;23;CREUSE;1
23167;;Sannat;SANNAT;23110;23;CREUSE;1
23168;;Sardent;SARDENT;23250;23;CREUSE;1
23169;La;Saunière;SAUNIERE;23000;23;CREUSE;1
23170;;Savennes;SAVENNES;23000;23;CREUSE;1
23171;;Sermur;SERMUR;23700;23;CREUSE;1
23172;La;Serre-Bussière-Vieille;SERRE-BUSSIERE-VIEILLE;23190;23;CREUSE;1
23173;;Soubrebost;SOUBREBOST;23250;23;CREUSE;1
23174;;Soumans;SOUMANS;23600;23;CREUSE;1
23175;;Sous-Parsat;SOUS-PARSAT;23150;23;CREUSE;1
23176;La;Souterraine;SOUTERRAINE;23300;23;CREUSE;1
23177;;Saint-Agnant-de-Versillat;SAINT-AGNANT-DE-VERSILLAT;23300;23;CREUSE;1
23178;;Saint-Agnant-près-Crocq;SAINT-AGNANT-PRES-CROCQ;23260;23;CREUSE;1
23179;;Saint-Alpinien;SAINT-ALPINIEN;23200;23;CREUSE;1
23180;;Saint-Amand;SAINT-AMAND;23200;23;CREUSE;1
23181;;Saint-Amand-Jartoudeix;SAINT-AMAND-JARTOUDEIX;23400;23;CREUSE;1
23182;;Saint-Avit-de-Tardes;SAINT-AVIT-DE-TARDES;23200;23;CREUSE;1
23183;;Saint-Avit-le-Pauvre;SAINT-AVIT-LE-PAUVRE;23480;23;CREUSE;1
23184;;Saint-Bard;SAINT-BARD;23260;23;CREUSE;1
23185;;Saint-Chabrais;SAINT-CHABRAIS;23130;23;CREUSE;1
23186;;Saint-Christophe;SAINT-CHRISTOPHE;23000;23;CREUSE;1
23187;;Saint-Dizier-la-Tour;SAINT-DIZIER-LA-TOUR;23130;23;CREUSE;1
23188;;Saint-Dizier-les-Domaines;SAINT-DIZIER-LES-DOMAINES;23270;23;CREUSE;1
23189;;Saint-Dizier-Leyrenne;SAINT-DIZIER-LEYRENNE;23400;23;CREUSE;1
23190;;Saint-Domet;SAINT-DOMET;23190;23;CREUSE;1
23191;;Saint-Éloi;SAINT-ELOI;23000;23;CREUSE;1
23192;;Saint-Étienne-de-Fursac;SAINT-ETIENNE-DE-FURSAC;23290;23;CREUSE;1
23193;;Sainte-Feyre;SAINTE-FEYRE;23000;23;CREUSE;1
23194;;Sainte-Feyre-la-Montagne;SAINTE-FEYRE-LA-MONTAGNE;23500;23;CREUSE;1
23195;;Saint-Fiel;SAINT-FIEL;23000;23;CREUSE;1
23196;;Saint-Frion;SAINT-FRION;23500;23;CREUSE;1
23197;;Saint-Georges-la-Pouge;SAINT-GEORGES-LA-POUGE;23250;23;CREUSE;1
23198;;Saint-Georges-Nigremont;SAINT-GEORGES-NIGREMONT;23500;23;CREUSE;1
23199;;Saint-Germain-Beaupré;SAINT-GERMAIN-BEAUPRE;23160;23;CREUSE;1
23200;;Saint-Goussaud;SAINT-GOUSSAUD;23430;23;CREUSE;1
23201;;Saint-Hilaire-la-Plaine;SAINT-HILAIRE-LA-PLAINE;23150;23;CREUSE;1
23202;;Saint-Hilaire-le-Château;SAINT-HILAIRE-LE-CHATEAU;23250;23;CREUSE;1
23203;;Saint-Julien-la-Genête;SAINT-JULIEN-LA-GENETE;23110;23;CREUSE;1
23204;;Saint-Julien-le-Châtel;SAINT-JULIEN-LE-CHATEL;23130;23;CREUSE;1
23205;;Saint-Junien-la-Bregère;SAINT-JUNIEN-LA-BREGERE;23400;23;CREUSE;1
23206;;Saint-Laurent;SAINT-LAURENT;23000;23;CREUSE;1
23207;;Saint-Léger-Bridereix;SAINT-LEGER-BRIDEREIX;23300;23;CREUSE;1
23208;;Saint-Léger-le-Guérétois;SAINT-LEGER-LE-GUERETOIS;23000;23;CREUSE;1
23209;;Saint-Loup;SAINT-LOUP;23130;23;CREUSE;1
23210;;Saint-Maixant;SAINT-MAIXANT;23200;23;CREUSE;1
23211;;Saint-Marc-à-Frongier;SAINT-MARC-A-FRONGIER;23200;23;CREUSE;1
23212;;Saint-Marc-à-Loubaud;SAINT-MARC-A-LOUBAUD;23460;23;CREUSE;1
23213;;Saint-Marien;SAINT-MARIEN;23600;23;CREUSE;1
23214;;Saint-Martial-le-Mont;SAINT-MARTIAL-LE-MONT;23150;23;CREUSE;1
23215;;Saint-Martial-le-Vieux;SAINT-MARTIAL-LE-VIEUX;23100;23;CREUSE;1
23216;;Saint-Martin-Château;SAINT-MARTIN-CHATEAU;23460;23;CREUSE;1
23217;;Saint-Martin-Sainte-Catherine;SAINT-MARTIN-SAINTE-CATHERINE;23430;23;CREUSE;1
23218;;Saint-Maurice-près-Crocq;SAINT-MAURICE-PRES-CROCQ;23260;23;CREUSE;1
23219;;Saint-Maurice-la-Souterraine;SAINT-MAURICE-LA-SOUTERRAINE;23300;23;CREUSE;1
23220;;Saint-Médard-la-Rochette;SAINT-MEDARD-LA-ROCHETTE;23200;23;CREUSE;1
23221;;Saint-Merd-la-Breuille;SAINT-MERD-LA-BREUILLE;23100;23;CREUSE;1
23222;;Saint-Michel-de-Veisse;SAINT-MICHEL-DE-VEISSE;23480;23;CREUSE;1
23223;;Saint-Moreil;SAINT-MOREIL;23400;23;CREUSE;1
23224;;Saint-Oradoux-de-Chirouze;SAINT-ORADOUX-DE-CHIROUZE;23100;23;CREUSE;1
23225;;Saint-Oradoux-près-Crocq;SAINT-ORADOUX-PRES-CROCQ;23260;23;CREUSE;1
23226;;Saint-Pardoux-d'Arnet;SAINT-PARDOUX-D'ARNET;23260;23;CREUSE;1
23227;;Saint-Pardoux-Morterolles;SAINT-PARDOUX-MORTEROLLES;23400;23;CREUSE;1
23228;;Saint-Pardoux-le-Neuf;SAINT-PARDOUX-LE-NEUF;23200;23;CREUSE;1
23229;;Saint-Pardoux-les-Cards;SAINT-PARDOUX-LES-CARDS;23150;23;CREUSE;1
23230;;Saint-Pierre-Chérignat;SAINT-PIERRE-CHERIGNAT;23430;23;CREUSE;1
23231;;Saint-Pierre-de-Fursac;SAINT-PIERRE-DE-FURSAC;23290;23;CREUSE;1
23232;;Saint-Pierre-Bellevue;SAINT-PIERRE-BELLEVUE;23460;23;CREUSE;1
23233;;Saint-Pierre-le-Bost;SAINT-PIERRE-LE-BOST;23600;23;CREUSE;1
23234;;Saint-Priest;SAINT-PRIEST;23110;23;CREUSE;1
23235;;Saint-Priest-la-Feuille;SAINT-PRIEST-LA-FEUILLE;23300;23;CREUSE;1
23236;;Saint-Priest-la-Plaine;SAINT-PRIEST-LA-PLAINE;23240;23;CREUSE;1
23237;;Saint-Priest-Palus;SAINT-PRIEST-PALUS;23400;23;CREUSE;1
23238;;Saint-Quentin-la-Chabanne;SAINT-QUENTIN-LA-CHABANNE;23500;23;CREUSE;1
23239;;Saint-Sébastien;SAINT-SEBASTIEN;23160;23;CREUSE;1
23240;;Saint-Silvain-Bas-le-Roc;SAINT-SILVAIN-BAS-LE-ROC;23600;23;CREUSE;1
23241;;Saint-Silvain-Bellegarde;SAINT-SILVAIN-BELLEGARDE;23190;23;CREUSE;1
23242;;Saint-Silvain-Montaigut;SAINT-SILVAIN-MONTAIGUT;23320;23;CREUSE;1
23243;;Saint-Silvain-sous-Toulx;SAINT-SILVAIN-SOUS-TOULX;23140;23;CREUSE;1
23244;;Saint-Sulpice-le-Dunois;SAINT-SULPICE-LE-DUNOIS;23800;23;CREUSE;1
23245;;Saint-Sulpice-le-Guérétois;SAINT-SULPICE-LE-GUERETOIS;23000;23;CREUSE;1
23246;;Saint-Sulpice-les-Champs;SAINT-SULPICE-LES-CHAMPS;23480;23;CREUSE;1
23247;;Saint-Vaury;SAINT-VAURY;23320;23;CREUSE;1
23248;;Saint-Victor-en-Marche;SAINT-VICTOR-EN-MARCHE;23000;23;CREUSE;1
23249;;Saint-Yrieix-la-Montagne;SAINT-YRIEIX-LA-MONTAGNE;23460;23;CREUSE;1
23250;;Saint-Yrieix-les-Bois;SAINT-YRIEIX-LES-BOIS;23150;23;CREUSE;1
23251;;Tardes;TARDES;23170;23;CREUSE;1
23252;;Tercillat;TERCILLAT;23350;23;CREUSE;1
23253;;Thauron;THAURON;23250;23;CREUSE;1
23254;;Toulx-Sainte-Croix;TOULX-SAINTE-CROIX;23600;23;CREUSE;1
23255;;Trois-Fonds;TROIS-FONDS;23230;23;CREUSE;1
23257;;Vallière;VALLIERE;23120;23;CREUSE;1
23258;;Vareilles;VAREILLES;23300;23;CREUSE;1
23259;;Verneiges;VERNEIGES;23170;23;CREUSE;1
23260;;Vidaillat;VIDAILLAT;23250;23;CREUSE;1
23261;;Viersat;VIERSAT;23170;23;CREUSE;1
23262;;Vigeville;VIGEVILLE;23140;23;CREUSE;1
23263;;Villard;VILLARD;23800;23;CREUSE;1
23264;La;Villedieu;VILLEDIEU;23340;23;CREUSE;1
23265;La;Villeneuve;VILLENEUVE;23260;23;CREUSE;1
23266;La;Villetelle;VILLETELLE;23260;23;CREUSE;1
24001;;Abjat-sur-Bandiat;ABJAT-SUR-BANDIAT;24300;24;DORDOGNE;1
24002;;Agonac;AGONAC;24460;24;DORDOGNE;1
24004;;Ajat;AJAT;24210;24;DORDOGNE;1
24005;;Alles-sur-Dordogne;ALLES-SUR-DORDOGNE;24480;24;DORDOGNE;1
24006;;Allas-les-Mines;ALLAS-LES-MINES;24220;24;DORDOGNE;1
24007;;Allemans;ALLEMANS;24600;24;DORDOGNE;1
24008;;Angoisse;ANGOISSE;24270;24;DORDOGNE;1
24009;;Anlhiac;ANLHIAC;24160;24;DORDOGNE;1
24010;;Annesse-et-Beaulieu;ANNESSE-ET-BEAULIEU;24430;24;DORDOGNE;1
24011;;Antonne-et-Trigonant;ANTONNE-ET-TRIGONANT;24420;24;DORDOGNE;1
24012;;Archignac;ARCHIGNAC;24590;24;DORDOGNE;1
24013;;Atur;ATUR;24750;24;DORDOGNE;1
24014;;Aubas;AUBAS;24290;24;DORDOGNE;1
24015;;Audrix;AUDRIX;24260;24;DORDOGNE;1
24016;;Augignac;AUGIGNAC;24300;24;DORDOGNE;1
24018;;Auriac-du-Périgord;AURIAC-DU-PERIGORD;24290;24;DORDOGNE;1
24019;;Azerat;AZERAT;24210;24;DORDOGNE;1
24020;La;Bachellerie;BACHELLERIE;24210;24;DORDOGNE;1
24021;;Badefols-d'Ans;BADEFOLS-D'ANS;24390;24;DORDOGNE;1
24022;;Badefols-sur-Dordogne;BADEFOLS-SUR-DORDOGNE;24150;24;DORDOGNE;1
24023;;Baneuil;BANEUIL;24150;24;DORDOGNE;1
24024;;Bardou;BARDOU;24560;24;DORDOGNE;1
24025;;Bars;BARS;24210;24;DORDOGNE;1
24026;;Bassillac;BASSILLAC;24330;24;DORDOGNE;1
24027;;Bayac;BAYAC;24150;24;DORDOGNE;1
24028;;Beaumont-du-Périgord;BEAUMONT-DU-PERIGORD;24440;24;DORDOGNE;1
24029;;Beaupouyet;BEAUPOUYET;24400;24;DORDOGNE;1
24030;;Beauregard-de-Terrasson;BEAUREGARD-DE-TERRASSON;24120;24;DORDOGNE;1
24031;;Beauregard-et-Bassac;BEAUREGARD-ET-BASSAC;24140;24;DORDOGNE;1
24032;;Beauronne;BEAURONNE;24400;24;DORDOGNE;1
24033;;Beaussac;BEAUSSAC;24340;24;DORDOGNE;1
24034;;Beleymas;BELEYMAS;24140;24;DORDOGNE;1
24035;;Belvès;BELVES;24170;24;DORDOGNE;1
24036;;Berbiguières;BERBIGUIERES;24220;24;DORDOGNE;1
24037;;Bergerac;BERGERAC;24100;24;DORDOGNE;1
24038;;Bertric-Burée;BERTRIC-BUREE;24320;24;DORDOGNE;1
24039;;Besse;BESSE;24550;24;DORDOGNE;1
24040;;Beynac-et-Cazenac;BEYNAC-ET-CAZENAC;24220;24;DORDOGNE;1
24041;;Bézenac;BEZENAC;24220;24;DORDOGNE;1
24042;;Biras;BIRAS;24310;24;DORDOGNE;1
24043;;Biron;BIRON;24540;24;DORDOGNE;1
24044;;Blis-et-Born;BLIS-ET-BORN;24330;24;DORDOGNE;1
24045;;Boisse;BOISSE;24560;24;DORDOGNE;1
24046;;Boisseuilh;BOISSEUILH;24390;24;DORDOGNE;1
24047;La;Boissière-d'Ans;BOISSIERE-D'ANS;24640;24;DORDOGNE;1
24048;;Bonneville-et-Saint-Avit-de-Fumadières;BONNEVILLE-ET-SAINT-AVIT-DE-FUMADIERES;24230;24;DORDOGNE;1
24050;;Borrèze;BORREZE;24590;24;DORDOGNE;1
24051;;Bosset;BOSSET;24130;24;DORDOGNE;1
24052;;Bouillac;BOUILLAC;24480;24;DORDOGNE;1
24053;;Boulazac;BOULAZAC;24750;24;DORDOGNE;1
24054;;Bouniagues;BOUNIAGUES;24560;24;DORDOGNE;1
24055;;Bourdeilles;BOURDEILLES;24310;24;DORDOGNE;1
24056;Le;Bourdeix;BOURDEIX;24300;24;DORDOGNE;1
24057;;Bourg-des-Maisons;BOURG-DES-MAISONS;24320;24;DORDOGNE;1
24058;;Bourg-du-Bost;BOURG-DU-BOST;24600;24;DORDOGNE;1
24059;;Bourgnac;BOURGNAC;24400;24;DORDOGNE;1
24060;;Bourniquel;BOURNIQUEL;24150;24;DORDOGNE;1
24061;;Bourrou;BOURROU;24110;24;DORDOGNE;1
24062;;Bouteilles-Saint-Sébastien;BOUTEILLES-SAINT-SEBASTIEN;24320;24;DORDOGNE;1
24063;;Bouzic;BOUZIC;24250;24;DORDOGNE;1
24064;;Brantôme;BRANTOME;24310;24;DORDOGNE;1
24065;;Breuilh;BREUILH;24380;24;DORDOGNE;1
24066;;Brouchaud;BROUCHAUD;24210;24;DORDOGNE;1
24067;Le;Bugue;BUGUE;24260;24;DORDOGNE;1
24068;Le;Buisson-de-Cadouin;BUISSON-DE-CADOUIN;24480;24;DORDOGNE;1
24069;;Bussac;BUSSAC;24350;24;DORDOGNE;1
24070;;Busserolles;BUSSEROLLES;24360;24;DORDOGNE;1
24071;;Bussière-Badil;BUSSIERE-BADIL;24360;24;DORDOGNE;1
24073;;Calès;CALES;24150;24;DORDOGNE;1
24074;;Calviac-en-Périgord;CALVIAC-EN-PERIGORD;24370;24;DORDOGNE;1
24075;;Campagnac-lès-Quercy;CAMPAGNAC-LES-QUERCY;24550;24;DORDOGNE;1
24076;;Campagne;CAMPAGNE;24260;24;DORDOGNE;1
24077;;Campsegret;CAMPSEGRET;24140;24;DORDOGNE;1
24079;;Cantillac;CANTILLAC;24530;24;DORDOGNE;1
24080;;Capdrot;CAPDROT;24540;24;DORDOGNE;1
24081;;Carlux;CARLUX;24370;24;DORDOGNE;1
24082;;Carsac-Aillac;CARSAC-AILLAC;24200;24;DORDOGNE;1
24083;;Carsac-de-Gurson;CARSAC-DE-GURSON;24610;24;DORDOGNE;1
24084;;Carves;CARVES;24170;24;DORDOGNE;1
24085;La;Cassagne;CASSAGNE;24120;24;DORDOGNE;1
24086;;Castelnaud-la-Chapelle;CASTELNAUD-LA-CHAPELLE;24250;24;DORDOGNE;1
24087;;Castels;CASTELS;24220;24;DORDOGNE;1
24088;;Cause-de-Clérans;CAUSE-DE-CLERANS;24150;24;DORDOGNE;1
24089;;Cazoulès;CAZOULES;24370;24;DORDOGNE;1
24090;;Celles;CELLES;24600;24;DORDOGNE;1
24091;;Cénac-et-Saint-Julien;CENAC-ET-SAINT-JULIEN;24250;24;DORDOGNE;1
24092;;Cendrieux;CENDRIEUX;24380;24;DORDOGNE;1
24093;;Cercles;CERCLES;24320;24;DORDOGNE;1
24094;;Chalagnac;CHALAGNAC;24380;24;DORDOGNE;1
24095;;Chalais;CHALAIS;24800;24;DORDOGNE;1
24096;;Champagnac-de-Belair;CHAMPAGNAC-DE-BELAIR;24530;24;DORDOGNE;1
24097;;Champagne-et-Fontaine;CHAMPAGNE-ET-FONTAINE;24320;24;DORDOGNE;1
24098;;Champcevinel;CHAMPCEVINEL;24750;24;DORDOGNE;1
24099;;Champeaux-et-la-Chapelle-Pommier;CHAMPEAUX-ET-LA-CHAPELLE-POMMIER;24340;24;DORDOGNE;1
24100;;Champniers-et-Reilhac;CHAMPNIERS-ET-REILHAC;24360;24;DORDOGNE;1
24101;;Champs-Romain;CHAMPS-ROMAIN;24470;24;DORDOGNE;1
24102;;Chancelade;CHANCELADE;24650;24;DORDOGNE;1
24103;Le;Change;CHANGE;24640;24;DORDOGNE;1
24104;;Chantérac;CHANTERAC;24190;24;DORDOGNE;1
24105;;Chapdeuil;CHAPDEUIL;24320;24;DORDOGNE;1
24106;La;Chapelle-Aubareil;CHAPELLE-AUBAREIL;24290;24;DORDOGNE;1
24107;La;Chapelle-Faucher;CHAPELLE-FAUCHER;24530;24;DORDOGNE;1
24108;La;Chapelle-Gonaguet;CHAPELLE-GONAGUET;24350;24;DORDOGNE;1
24109;La;Chapelle-Grésignac;CHAPELLE-GRESIGNAC;24320;24;DORDOGNE;1
24110;La;Chapelle-Montabourlet;CHAPELLE-MONTABOURLET;24320;24;DORDOGNE;1
24111;La;Chapelle-Montmoreau;CHAPELLE-MONTMOREAU;24300;24;DORDOGNE;1
24113;La;Chapelle-Saint-Jean;CHAPELLE-SAINT-JEAN;24390;24;DORDOGNE;1
24114;;Chassaignes;CHASSAIGNES;24600;24;DORDOGNE;1
24115;;Château-l'Évêque;CHATEAU-L'EVEQUE;24460;24;DORDOGNE;1
24116;;Châtres;CHATRES;24120;24;DORDOGNE;1
24117;;Chavagnac;CHAVAGNAC;24120;24;DORDOGNE;1
24118;;Chenaud;CHENAUD;24410;24;DORDOGNE;1
24119;;Cherval;CHERVAL;24320;24;DORDOGNE;1
24120;;Cherveix-Cubas;CHERVEIX-CUBAS;24390;24;DORDOGNE;1
24121;;Chourgnac;CHOURGNAC;24640;24;DORDOGNE;1
24122;;Cladech;CLADECH;24170;24;DORDOGNE;1
24123;;Clermont-de-Beauregard;CLERMONT-DE-BEAUREGARD;24140;24;DORDOGNE;1
24124;;Clermont-d'Excideuil;CLERMONT-D'EXCIDEUIL;24160;24;DORDOGNE;1
24126;;Colombier;COLOMBIER;24560;24;DORDOGNE;1
24127;;Coly;COLY;24120;24;DORDOGNE;1
24128;;Comberanche-et-Épeluche;COMBERANCHE-ET-EPELUCHE;24600;24;DORDOGNE;1
24129;;Condat-sur-Trincou;CONDAT-SUR-TRINCOU;24530;24;DORDOGNE;1
24130;;Condat-sur-Vézère;CONDAT-SUR-VEZERE;24570;24;DORDOGNE;1
24131;;Connezac;CONNEZAC;24300;24;DORDOGNE;1
24132;;Conne-de-Labarde;CONNE-DE-LABARDE;24560;24;DORDOGNE;1
24133;La;Coquille;COQUILLE;24450;24;DORDOGNE;1
24134;;Corgnac-sur-l'Isle;CORGNAC-SUR-L'ISLE;24800;24;DORDOGNE;1
24135;;Cornille;CORNILLE;24750;24;DORDOGNE;1
24136;;Coubjours;COUBJOURS;24390;24;DORDOGNE;1
24137;;Coulaures;COULAURES;24420;24;DORDOGNE;1
24138;;Coulounieix-Chamiers;COULOUNIEIX-CHAMIERS;24660;24;DORDOGNE;1
24139;;Coursac;COURSAC;24430;24;DORDOGNE;1
24140;;Cours-de-Pile;COURS-DE-PILE;24520;24;DORDOGNE;1
24141;;Coutures;COUTURES;24320;24;DORDOGNE;1
24142;;Coux-et-Bigaroque;COUX-ET-BIGAROQUE;24220;24;DORDOGNE;1
24143;;Couze-et-Saint-Front;COUZE-ET-SAINT-FRONT;24150;24;DORDOGNE;1
24144;;Creyssac;CREYSSAC;24350;24;DORDOGNE;1
24145;;Creysse;CREYSSE;24100;24;DORDOGNE;1
24146;;Creyssensac-et-Pissot;CREYSSENSAC-ET-PISSOT;24380;24;DORDOGNE;1
24147;;Cubjac;CUBJAC;24640;24;DORDOGNE;1
24148;;Cunèges;CUNEGES;24240;24;DORDOGNE;1
24150;;Daglan;DAGLAN;24250;24;DORDOGNE;1
24151;;Doissat;DOISSAT;24170;24;DORDOGNE;1
24152;;Domme;DOMME;24250;24;DORDOGNE;1
24153;La;Dornac;DORNAC;24120;24;DORDOGNE;1
24154;;Douchapt;DOUCHAPT;24350;24;DORDOGNE;1
24155;;Douville;DOUVILLE;24140;24;DORDOGNE;1
24156;La;Douze;DOUZE;24330;24;DORDOGNE;1
24157;;Douzillac;DOUZILLAC;24190;24;DORDOGNE;1
24158;;Dussac;DUSSAC;24270;24;DORDOGNE;1
24159;;Échourgnac;ECHOURGNAC;24410;24;DORDOGNE;1
24160;;Église-Neuve-de-Vergt;EGLISE-NEUVE-DE-VERGT;24380;24;DORDOGNE;1
24161;;Église-Neuve-d'Issac;EGLISE-NEUVE-D'ISSAC;24400;24;DORDOGNE;1
24162;;Escoire;ESCOIRE;24420;24;DORDOGNE;1
24163;;Étouars;ETOUARS;24360;24;DORDOGNE;1
24164;;Excideuil;EXCIDEUIL;24160;24;DORDOGNE;1
24165;;Eygurande-et-Gardedeuil;EYGURANDE-ET-GARDEDEUIL;24700;24;DORDOGNE;1
24166;;Eyliac;EYLIAC;24330;24;DORDOGNE;1
24167;;Eymet;EYMET;24500;24;DORDOGNE;1
24168;;Plaisance;PLAISANCE;24560;24;DORDOGNE;1
24170;;Eyvirat;EYVIRAT;24460;24;DORDOGNE;1
24171;;Eyzerac;EYZERAC;24800;24;DORDOGNE;1
24172;Les;Eyzies-de-Tayac-Sireuil;EYZIES-DE-TAYAC-SIREUIL;24620;24;DORDOGNE;1
24174;;Fanlac;FANLAC;24290;24;DORDOGNE;1
24175;Les;Farges;FARGES;24290;24;DORDOGNE;1
24176;;Faurilles;FAURILLES;24560;24;DORDOGNE;1
24177;;Faux;FAUX;24560;24;DORDOGNE;1
24178;;Festalemps;FESTALEMPS;24410;24;DORDOGNE;1
24179;La;Feuillade;FEUILLADE;19600;24;CORREZE;1
24180;;Firbeix;FIRBEIX;24450;24;DORDOGNE;1
24181;;Flaugeac;FLAUGEAC;24240;24;DORDOGNE;1
24182;Le;Fleix;FLEIX;24130;24;DORDOGNE;1
24183;;Fleurac;FLEURAC;24580;24;DORDOGNE;1
24184;;Florimont-Gaumier;FLORIMONT-GAUMIER;24250;24;DORDOGNE;1
24186;;Fonroque;FONROQUE;24500;24;DORDOGNE;1
24188;;Fossemagne;FOSSEMAGNE;24210;24;DORDOGNE;1
24189;;Fougueyrolles;FOUGUEYROLLES;33220;24;GIRONDE;1
24190;;Fouleix;FOULEIX;24380;24;DORDOGNE;1
24191;;Fraisse;FRAISSE;24130;24;DORDOGNE;1
24192;;Gabillou;GABILLOU;24210;24;DORDOGNE;1
24193;;Gageac-et-Rouillac;GAGEAC-ET-ROUILLAC;24240;24;DORDOGNE;1
24194;;Gardonne;GARDONNE;24680;24;DORDOGNE;1
24195;;Gaugeac;GAUGEAC;24540;24;DORDOGNE;1
24196;;Génis;GENIS;24160;24;DORDOGNE;1
24197;;Ginestet;GINESTET;24130;24;DORDOGNE;1
24198;La;Gonterie-Boulouneix;GONTERIE-BOULOUNEIX;24310;24;DORDOGNE;1
24199;;Gout-Rossignol;GOUT-ROSSIGNOL;24320;24;DORDOGNE;1
24200;;Grand-Brassac;GRAND-BRASSAC;24350;24;DORDOGNE;1
24202;;Granges-d'Ans;GRANGES-D'ANS;24390;24;DORDOGNE;1
24203;Les;Graulges;GRAULGES;24340;24;DORDOGNE;1
24204;;Grèzes;GREZES;24120;24;DORDOGNE;1
24205;;Grignols;GRIGNOLS;24110;24;DORDOGNE;1
24206;;Grives;GRIVES;24170;24;DORDOGNE;1
24207;;Groléjac;GROLEJAC;24250;24;DORDOGNE;1
24208;;Grun-Bordas;GRUN-BORDAS;24380;24;DORDOGNE;1
24209;;Hautefaye;HAUTEFAYE;24300;24;DORDOGNE;1
24210;;Hautefort;HAUTEFORT;24390;24;DORDOGNE;1
24211;;Issac;ISSAC;24400;24;DORDOGNE;1
24212;;Issigeac;ISSIGEAC;24560;24;DORDOGNE;1
24213;;Jaure;JAURE;24140;24;DORDOGNE;1
24214;;Javerlhac-et-la-Chapelle-Saint-Robert;JAVERLHAC-ET-LA-CHAPELLE-SAINT-ROBERT;24300;24;DORDOGNE;1
24215;;Jayac;JAYAC;24590;24;DORDOGNE;1
24216;La;Jemaye;JEMAYE;24410;24;DORDOGNE;1
24217;;Journiac;JOURNIAC;24260;24;DORDOGNE;1
24218;;Jumilhac-le-Grand;JUMILHAC-LE-GRAND;24630;24;DORDOGNE;1
24219;;Labouquerie;LABOUQUERIE;24440;24;DORDOGNE;1
24220;;Lacropte;LACROPTE;24380;24;DORDOGNE;1
24221;;Rudeau-Ladosse;RUDEAU-LADOSSE;24340;24;DORDOGNE;1
24222;La;Force;FORCE;24130;24;DORDOGNE;1
24223;;Lalinde;LALINDE;24150;24;DORDOGNE;1
24224;;Lamonzie-Montastruc;LAMONZIE-MONTASTRUC;24520;24;DORDOGNE;1
24225;;Lamonzie-Saint-Martin;LAMONZIE-SAINT-MARTIN;24680;24;DORDOGNE;1
24226;;Lamothe-Montravel;LAMOTHE-MONTRAVEL;24230;24;DORDOGNE;1
24227;;Lanouaille;LANOUAILLE;24270;24;DORDOGNE;1
24228;;Lanquais;LANQUAIS;24150;24;DORDOGNE;1
24229;Le;Lardin-Saint-Lazare;LARDIN-SAINT-LAZARE;24570;24;DORDOGNE;1
24230;;Larzac;LARZAC;24170;24;DORDOGNE;1
24231;;Lavalade;LAVALADE;24540;24;DORDOGNE;1
24232;;Lavaur;LAVAUR;24550;24;DORDOGNE;1
24233;;Laveyssière;LAVEYSSIERE;24130;24;DORDOGNE;1
24234;Les;Lèches;LECHES;24400;24;DORDOGNE;1
24235;;Léguillac-de-Cercles;LEGUILLAC-DE-CERCLES;24340;24;DORDOGNE;1
24236;;Léguillac-de-l'Auche;LEGUILLAC-DE-L'AUCHE;24110;24;DORDOGNE;1
24237;;Lembras;LEMBRAS;24100;24;DORDOGNE;1
24238;;Lempzours;LEMPZOURS;24800;24;DORDOGNE;1
24239;;Ligueux;LIGUEUX;24460;24;DORDOGNE;1
24240;;Limeuil;LIMEUIL;24510;24;DORDOGNE;1
24241;;Limeyrat;LIMEYRAT;24210;24;DORDOGNE;1
24242;;Liorac-sur-Louyre;LIORAC-SUR-LOUYRE;24520;24;DORDOGNE;1
24243;;Lisle;LISLE;24350;24;DORDOGNE;1
24244;;Lolme;LOLME;24540;24;DORDOGNE;1
24245;;Loubejac;LOUBEJAC;24550;24;DORDOGNE;1
24246;;Lunas;LUNAS;24130;24;DORDOGNE;1
24247;;Lusignac;LUSIGNAC;24320;24;DORDOGNE;1
24248;;Lussas-et-Nontronneau;LUSSAS-ET-NONTRONNEAU;24300;24;DORDOGNE;1
24249;;Manaurie;MANAURIE;24620;24;DORDOGNE;1
24251;;Manzac-sur-Vern;MANZAC-SUR-VERN;24110;24;DORDOGNE;1
24252;;Marcillac-Saint-Quentin;MARCILLAC-SAINT-QUENTIN;24200;24;DORDOGNE;1
24253;;Mareuil;MAREUIL;24340;24;DORDOGNE;1
24254;;Marnac;MARNAC;24220;24;DORDOGNE;1
24255;;Marquay;MARQUAY;24620;24;DORDOGNE;1
24256;;Marsac-sur-l'Isle;MARSAC-SUR-L'ISLE;24430;24;DORDOGNE;1
24257;;Marsalès;MARSALES;24540;24;DORDOGNE;1
24258;;Marsaneix;MARSANEIX;24750;24;DORDOGNE;1
24259;;Maurens;MAURENS;24140;24;DORDOGNE;1
24260;;Mauzac-et-Grand-Castang;MAUZAC-ET-GRAND-CASTANG;24150;24;DORDOGNE;1
24261;;Mauzens-et-Miremont;MAUZENS-ET-MIREMONT;24260;24;DORDOGNE;1
24262;;Mayac;MAYAC;24420;24;DORDOGNE;1
24263;;Mazeyrolles;MAZEYROLLES;24550;24;DORDOGNE;1
24264;;Ménesplet;MENESPLET;24700;24;DORDOGNE;1
24266;;Mensignac;MENSIGNAC;24350;24;DORDOGNE;1
24267;;Mescoules;MESCOULES;24240;24;DORDOGNE;1
24268;;Meyrals;MEYRALS;24220;24;DORDOGNE;1
24269;;Mialet;MIALET;24450;24;DORDOGNE;1
24270;;Milhac-d'Auberoche;MILHAC-D'AUBEROCHE;24330;24;DORDOGNE;1
24271;;Milhac-de-Nontron;MILHAC-DE-NONTRON;24470;24;DORDOGNE;1
24272;;Minzac;MINZAC;24610;24;DORDOGNE;1
24273;;Molières;MOLIERES;24480;24;DORDOGNE;1
24274;;Monbazillac;MONBAZILLAC;24240;24;DORDOGNE;1
24276;;Monestier;MONESTIER;24240;24;DORDOGNE;1
24277;;Monfaucon;MONFAUCON;24130;24;DORDOGNE;1
24278;;Monmadalès;MONMADALES;24560;24;DORDOGNE;1
24279;;Monmarvès;MONMARVES;24560;24;DORDOGNE;1
24280;;Monpazier;MONPAZIER;24540;24;DORDOGNE;1
24281;;Monsac;MONSAC;24440;24;DORDOGNE;1
24282;;Monsaguel;MONSAGUEL;24560;24;DORDOGNE;1
24283;;Monsec;MONSEC;24340;24;DORDOGNE;1
24284;;Montagnac-d'Auberoche;MONTAGNAC-D'AUBEROCHE;24210;24;DORDOGNE;1
24285;;Montagnac-la-Crempse;MONTAGNAC-LA-CREMPSE;24140;24;DORDOGNE;1
24286;;Montagrier;MONTAGRIER;24350;24;DORDOGNE;1
24287;;Montaut;MONTAUT;24560;24;DORDOGNE;1
24288;;Montazeau;MONTAZEAU;24230;24;DORDOGNE;1
24289;;Montcaret;MONTCARET;24230;24;DORDOGNE;1
24290;;Montferrand-du-Périgord;MONTFERRAND-DU-PERIGORD;24440;24;DORDOGNE;1
24291;;Montignac;MONTIGNAC;24290;24;DORDOGNE;1
24292;;Montpeyroux;MONTPEYROUX;24610;24;DORDOGNE;1
24293;;Monplaisant;MONPLAISANT;24170;24;DORDOGNE;1
24294;;Montpon-Ménestérol;MONTPON-MENESTEROL;24700;24;DORDOGNE;1
24295;;Montrem;MONTREM;24110;24;DORDOGNE;1
24296;;Mouleydier;MOULEYDIER;24520;24;DORDOGNE;1
24297;;Moulin-Neuf;MOULIN-NEUF;24700;24;DORDOGNE;1
24298;;Mouzens;MOUZENS;24220;24;DORDOGNE;1
24299;;Mussidan;MUSSIDAN;24400;24;DORDOGNE;1
24300;;Nabirat;NABIRAT;24250;24;DORDOGNE;1
24301;;Nadaillac;NADAILLAC;24590;24;DORDOGNE;1
24302;;Nailhac;NAILHAC;24390;24;DORDOGNE;1
24303;;Nanteuil-Auriac-de-Bourzac;NANTEUIL-AURIAC-DE-BOURZAC;24320;24;DORDOGNE;1
24304;;Nantheuil;NANTHEUIL;24800;24;DORDOGNE;1
24305;;Nanthiat;NANTHIAT;24800;24;DORDOGNE;1
24306;;Nastringues;NASTRINGUES;24230;24;DORDOGNE;1
24307;;Naussannes;NAUSSANNES;24440;24;DORDOGNE;1
24308;;Négrondes;NEGRONDES;24460;24;DORDOGNE;1
24309;;Neuvic;NEUVIC;24190;24;DORDOGNE;1
24310;;Nojals-et-Clotte;NOJALS-ET-CLOTTE;24440;24;DORDOGNE;1
24311;;Nontron;NONTRON;24300;24;DORDOGNE;1
24312;;Notre-Dame-de-Sanilhac;NOTRE-DAME-DE-SANILHAC;24660;24;DORDOGNE;1
24313;;Orliac;ORLIAC;24170;24;DORDOGNE;1
24314;;Orliaguet;ORLIAGUET;24370;24;DORDOGNE;1
24316;;Parcoul;PARCOUL;24410;24;DORDOGNE;1
24317;;Paulin;PAULIN;24590;24;DORDOGNE;1
24318;;Paunat;PAUNAT;24510;24;DORDOGNE;1
24319;;Paussac-et-Saint-Vivien;PAUSSAC-ET-SAINT-VIVIEN;24310;24;DORDOGNE;1
24320;;Payzac;PAYZAC;24270;24;DORDOGNE;1
24321;;Pazayac;PAZAYAC;24120;24;DORDOGNE;1
24322;;Périgueux;PERIGUEUX;24000;24;DORDOGNE;1
24323;;Petit-Bersac;PETIT-BERSAC;24600;24;DORDOGNE;1
24324;;Peyrignac;PEYRIGNAC;24210;24;DORDOGNE;1
24325;;Peyrillac-et-Millac;PEYRILLAC-ET-MILLAC;24370;24;DORDOGNE;1
24326;;Peyzac-le-Moustier;PEYZAC-LE-MOUSTIER;24620;24;DORDOGNE;1
24327;;Pezuls;PEZULS;24510;24;DORDOGNE;1
24328;;Piégut-Pluviers;PIEGUT-PLUVIERS;24360;24;DORDOGNE;1
24329;Le;Pizou;PIZOU;24700;24;DORDOGNE;1
24330;;Plazac;PLAZAC;24580;24;DORDOGNE;1
24331;;Pomport;POMPORT;24240;24;DORDOGNE;1
24333;;Ponteyraud;PONTEYRAUD;24410;24;DORDOGNE;1
24334;;Pontours;PONTOURS;24150;24;DORDOGNE;1
24335;;Port-Sainte-Foy-et-Ponchapt;PORT-SAINTE-FOY-ET-PONCHAPT;33220;24;GIRONDE;1
24336;;Prats-de-Carlux;PRATS-DE-CARLUX;24370;24;DORDOGNE;1
24337;;Prats-du-Périgord;PRATS-DU-PERIGORD;24550;24;DORDOGNE;1
24338;;Pressignac-Vicq;PRESSIGNAC-VICQ;24150;24;DORDOGNE;1
24339;;Preyssac-d'Excideuil;PREYSSAC-D'EXCIDEUIL;24160;24;DORDOGNE;1
24340;;Prigonrieux;PRIGONRIEUX;24130;24;DORDOGNE;1
24341;;Proissans;PROISSANS;24200;24;DORDOGNE;1
24343;;Puymangou;PUYMANGOU;24410;24;DORDOGNE;1
24344;;Puyrenier;PUYRENIER;24340;24;DORDOGNE;1
24345;;Queyssac;QUEYSSAC;24140;24;DORDOGNE;1
24346;;Quinsac;QUINSAC;24530;24;DORDOGNE;1
24347;;Rampieux;RAMPIEUX;24440;24;DORDOGNE;1
24348;;Razac-d'Eymet;RAZAC-D'EYMET;24500;24;DORDOGNE;1
24349;;Razac-de-Saussignac;RAZAC-DE-SAUSSIGNAC;24240;24;DORDOGNE;1
24350;;Razac-sur-l'Isle;RAZAC-SUR-L'ISLE;24430;24;DORDOGNE;1
24351;;Ribagnac;RIBAGNAC;24240;24;DORDOGNE;1
24352;;Ribérac;RIBERAC;24600;24;DORDOGNE;1
24353;La;Rochebeaucourt-et-Argentine;ROCHEBEAUCOURT-ET-ARGENTINE;24340;24;DORDOGNE;1
24354;La;Roche-Chalais;ROCHE-CHALAIS;24490;24;DORDOGNE;1
24355;La;Roque-Gageac;ROQUE-GAGEAC;24250;24;DORDOGNE;1
24356;;Rouffignac-Saint-Cernin-de-Reilhac;ROUFFIGNAC-SAINT-CERNIN-DE-REILHAC;24580;24;DORDOGNE;1
24357;;Rouffignac-de-Sigoulès;ROUFFIGNAC-DE-SIGOULES;24240;24;DORDOGNE;1
24359;;Sadillac;SADILLAC;24500;24;DORDOGNE;1
24360;;Sagelat;SAGELAT;24170;24;DORDOGNE;1
24361;;Saint-Agne;SAINT-AGNE;24520;24;DORDOGNE;1
24362;;Sainte-Alvère;SAINTE-ALVERE;24510;24;DORDOGNE;1
24363;;Saint-Amand-de-Belvès;SAINT-AMAND-DE-BELVES;24170;24;DORDOGNE;1
24364;;Saint-Amand-de-Coly;SAINT-AMAND-DE-COLY;24290;24;DORDOGNE;1
24365;;Saint-Amand-de-Vergt;SAINT-AMAND-DE-VERGT;24380;24;DORDOGNE;1
24366;;Saint-André-d'Allas;SAINT-ANDRE-D'ALLAS;24200;24;DORDOGNE;1
24367;;Saint-André-de-Double;SAINT-ANDRE-DE-DOUBLE;24190;24;DORDOGNE;1
24368;;Saint-Antoine-Cumond;SAINT-ANTOINE-CUMOND;24410;24;DORDOGNE;1
24369;;Saint-Antoine-d'Auberoche;SAINT-ANTOINE-D'AUBEROCHE;24330;24;DORDOGNE;1
24370;;Saint-Antoine-de-Breuilh;SAINT-ANTOINE-DE-BREUILH;24230;24;DORDOGNE;1
24371;;Saint-Aquilin;SAINT-AQUILIN;24110;24;DORDOGNE;1
24372;;Saint-Astier;SAINT-ASTIER;24110;24;DORDOGNE;1
24373;;Saint-Aubin-de-Cadelech;SAINT-AUBIN-DE-CADELECH;24500;24;DORDOGNE;1
24374;;Saint-Aubin-de-Lanquais;SAINT-AUBIN-DE-LANQUAIS;24560;24;DORDOGNE;1
24375;;Saint-Aubin-de-Nabirat;SAINT-AUBIN-DE-NABIRAT;24250;24;DORDOGNE;1
24376;;Saint-Aulaye;SAINT-AULAYE;24410;24;DORDOGNE;1
24377;;Saint-Avit-de-Vialard;SAINT-AVIT-DE-VIALARD;24260;24;DORDOGNE;1
24378;;Saint-Avit-Rivière;SAINT-AVIT-RIVIERE;24540;24;DORDOGNE;1
24379;;Saint-Avit-Sénieur;SAINT-AVIT-SENIEUR;24440;24;DORDOGNE;1
24380;;Saint-Barthélemy-de-Bellegarde;SAINT-BARTHELEMY-DE-BELLEGARDE;24700;24;DORDOGNE;1
24381;;Saint-Barthélemy-de-Bussière;SAINT-BARTHELEMY-DE-BUSSIERE;24360;24;DORDOGNE;1
24382;;Saint-Capraise-de-Lalinde;SAINT-CAPRAISE-DE-LALINDE;24150;24;DORDOGNE;1
24383;;Saint-Capraise-d'Eymet;SAINT-CAPRAISE-D'EYMET;24500;24;DORDOGNE;1
24384;;Saint-Cassien;SAINT-CASSIEN;24540;24;DORDOGNE;1
24385;;Saint-Cernin-de-Labarde;SAINT-CERNIN-DE-LABARDE;24560;24;DORDOGNE;1
24386;;Saint-Cernin-de-l'Herm;SAINT-CERNIN-DE-L'HERM;24550;24;DORDOGNE;1
24388;;Saint-Chamassy;SAINT-CHAMASSY;24260;24;DORDOGNE;1
24389;;Saint-Cirq;SAINT-CIRQ;24260;24;DORDOGNE;1
24390;;Saint-Crépin-d'Auberoche;SAINT-CREPIN-D'AUBEROCHE;24330;24;DORDOGNE;1
24391;;Saint-Crépin-de-Richemont;SAINT-CREPIN-DE-RICHEMONT;24310;24;DORDOGNE;1
24392;;Saint-Crépin-et-Carlucet;SAINT-CREPIN-ET-CARLUCET;24590;24;DORDOGNE;1
24393;;Sainte-Croix;SAINTE-CROIX;24440;24;DORDOGNE;1
24394;;Sainte-Croix-de-Mareuil;SAINTE-CROIX-DE-MAREUIL;24340;24;DORDOGNE;1
24395;;Saint-Cybranet;SAINT-CYBRANET;24250;24;DORDOGNE;1
24396;;Saint-Cyprien;SAINT-CYPRIEN;24220;24;DORDOGNE;1
24397;;Saint-Cyr-les-Champagnes;SAINT-CYR-LES-CHAMPAGNES;24270;24;DORDOGNE;1
24398;;Saint-Estèphe;SAINT-ESTEPHE;24360;24;DORDOGNE;1
24399;;Saint-Étienne-de-Puycorbier;SAINT-ETIENNE-DE-PUYCORBIER;24400;24;DORDOGNE;1
24401;;Sainte-Eulalie-d'Ans;SAINTE-EULALIE-D'ANS;24640;24;DORDOGNE;1
24402;;Sainte-Eulalie-d'Eymet;SAINTE-EULALIE-D'EYMET;24500;24;DORDOGNE;1
24403;;Saint-Félix-de-Bourdeilles;SAINT-FELIX-DE-BOURDEILLES;24340;24;DORDOGNE;1
24404;;Saint-Félix-de-Reillac-et-Mortemart;SAINT-FELIX-DE-REILLAC-ET-MORTEMART;24260;24;DORDOGNE;1
24405;;Saint-Félix-de-Villadeix;SAINT-FELIX-DE-VILLADEIX;24510;24;DORDOGNE;1
24406;;Sainte-Foy-de-Belvès;SAINTE-FOY-DE-BELVES;24170;24;DORDOGNE;1
24407;;Sainte-Foy-de-Longas;SAINTE-FOY-DE-LONGAS;24510;24;DORDOGNE;1
24408;;Saint-Front-d'Alemps;SAINT-FRONT-D'ALEMPS;24460;24;DORDOGNE;1
24409;;Saint-Front-de-Pradoux;SAINT-FRONT-DE-PRADOUX;24400;24;DORDOGNE;1
24410;;Saint-Front-la-Rivière;SAINT-FRONT-LA-RIVIERE;24300;24;DORDOGNE;1
24411;;Saint-Front-sur-Nizonne;SAINT-FRONT-SUR-NIZONNE;24300;24;DORDOGNE;1
24412;;Saint-Geniès;SAINT-GENIES;24590;24;DORDOGNE;1
24413;;Saint-Georges-Blancaneix;SAINT-GEORGES-BLANCANEIX;24130;24;DORDOGNE;1
24414;;Saint-Georges-de-Montclard;SAINT-GEORGES-DE-MONTCLARD;24140;24;DORDOGNE;1
24415;;Saint-Géraud-de-Corps;SAINT-GERAUD-DE-CORPS;24700;24;DORDOGNE;1
24416;;Saint-Germain-de-Belvès;SAINT-GERMAIN-DE-BELVES;24170;24;DORDOGNE;1
24417;;Saint-Germain-des-Prés;SAINT-GERMAIN-DES-PRES;24160;24;DORDOGNE;1
24418;;Saint-Germain-du-Salembre;SAINT-GERMAIN-DU-SALEMBRE;24190;24;DORDOGNE;1
24419;;Saint-Germain-et-Mons;SAINT-GERMAIN-ET-MONS;24520;24;DORDOGNE;1
24420;;Saint-Géry;SAINT-GERY;24400;24;DORDOGNE;1
24421;;Saint-Geyrac;SAINT-GEYRAC;24330;24;DORDOGNE;1
24422;;Saint-Hilaire-d'Estissac;SAINT-HILAIRE-D'ESTISSAC;24140;24;DORDOGNE;1
24423;;Sainte-Innocence;SAINTE-INNOCENCE;24500;24;DORDOGNE;1
24424;;Saint-Jean-d'Ataux;SAINT-JEAN-D'ATAUX;24190;24;DORDOGNE;1
24425;;Saint-Jean-de-Côle;SAINT-JEAN-DE-COLE;24800;24;DORDOGNE;1
24426;;Saint-Jean-d'Estissac;SAINT-JEAN-D'ESTISSAC;24140;24;DORDOGNE;1
24427;;Saint-Jean-d'Eyraud;SAINT-JEAN-D'EYRAUD;24140;24;DORDOGNE;1
24428;;Saint-Jory-de-Chalais;SAINT-JORY-DE-CHALAIS;24800;24;DORDOGNE;1
24429;;Saint-Jory-las-Bloux;SAINT-JORY-LAS-BLOUX;24160;24;DORDOGNE;1
24430;;Saint-Julien-de-Bourdeilles;SAINT-JULIEN-DE-BOURDEILLES;24310;24;DORDOGNE;1
24431;;Saint-Julien-de-Crempse;SAINT-JULIEN-DE-CREMPSE;24140;24;DORDOGNE;1
24432;;Saint-Julien-de-Lampon;SAINT-JULIEN-DE-LAMPON;24370;24;DORDOGNE;1
24433;;Saint-Julien-d'Eymet;SAINT-JULIEN-D'EYMET;24500;24;DORDOGNE;1
24434;;Saint-Just;SAINT-JUST;24320;24;DORDOGNE;1
24435;;Saint-Laurent-des-Bâtons;SAINT-LAURENT-DES-BATONS;24510;24;DORDOGNE;1
24436;;Saint-Laurent-des-Hommes;SAINT-LAURENT-DES-HOMMES;24400;24;DORDOGNE;1
24437;;Saint-Laurent-des-Vignes;SAINT-LAURENT-DES-VIGNES;24100;24;DORDOGNE;1
24438;;Saint-Laurent-la-Vallée;SAINT-LAURENT-LA-VALLEE;24170;24;DORDOGNE;1
24439;;Saint-Laurent-sur-Manoire;SAINT-LAURENT-SUR-MANOIRE;24330;24;DORDOGNE;1
24441;;Saint-Léon-d'Issigeac;SAINT-LEON-D'ISSIGEAC;24560;24;DORDOGNE;1
24442;;Saint-Léon-sur-l'Isle;SAINT-LEON-SUR-L'ISLE;24110;24;DORDOGNE;1
24443;;Saint-Léon-sur-Vézère;SAINT-LEON-SUR-VEZERE;24290;24;DORDOGNE;1
24444;;Saint-Louis-en-l'Isle;SAINT-LOUIS-EN-L'ISLE;24400;24;DORDOGNE;1
24445;;Saint-Marcel-du-Périgord;SAINT-MARCEL-DU-PERIGORD;24510;24;DORDOGNE;1
24446;;Saint-Marcory;SAINT-MARCORY;24540;24;DORDOGNE;1
24447;;Sainte-Marie-de-Chignac;SAINTE-MARIE-DE-CHIGNAC;24330;24;DORDOGNE;1
24448;;Saint-Martial-d'Albarède;SAINT-MARTIAL-D'ALBAREDE;24160;24;DORDOGNE;1
24449;;Saint-Martial-d'Artenset;SAINT-MARTIAL-D'ARTENSET;24700;24;DORDOGNE;1
24450;;Saint-Martial-de-Nabirat;SAINT-MARTIAL-DE-NABIRAT;24250;24;DORDOGNE;1
24451;;Saint-Martial-de-Valette;SAINT-MARTIAL-DE-VALETTE;24300;24;DORDOGNE;1
24452;;Saint-Martial-Viveyrol;SAINT-MARTIAL-VIVEYROL;24320;24;DORDOGNE;1
24453;;Saint-Martin-de-Fressengeas;SAINT-MARTIN-DE-FRESSENGEAS;24800;24;DORDOGNE;1
24454;;Saint-Martin-de-Gurson;SAINT-MARTIN-DE-GURSON;24610;24;DORDOGNE;1
24455;;Saint-Martin-de-Ribérac;SAINT-MARTIN-DE-RIBERAC;24600;24;DORDOGNE;1
24456;;Saint-Martin-des-Combes;SAINT-MARTIN-DES-COMBES;24140;24;DORDOGNE;1
24457;;Saint-Martin-l'Astier;SAINT-MARTIN-L'ASTIER;24400;24;DORDOGNE;1
24458;;Saint-Martin-le-Pin;SAINT-MARTIN-LE-PIN;24300;24;DORDOGNE;1
24459;;Saint-Maime-de-Péreyrol;SAINT-MAIME-DE-PEREYROL;24380;24;DORDOGNE;1
24460;;Saint-Méard-de-Drône;SAINT-MEARD-DE-DRONE;24600;24;DORDOGNE;1
24461;;Saint-Méard-de-Gurçon;SAINT-MEARD-DE-GURCON;24610;24;DORDOGNE;1
24462;;Saint-Médard-de-Mussidan;SAINT-MEDARD-DE-MUSSIDAN;24400;24;DORDOGNE;1
24463;;Saint-Médard-d'Excideuil;SAINT-MEDARD-D'EXCIDEUIL;24160;24;DORDOGNE;1
24464;;Saint-Mesmin;SAINT-MESMIN;24270;24;DORDOGNE;1
24465;;Saint-Michel-de-Double;SAINT-MICHEL-DE-DOUBLE;24400;24;DORDOGNE;1
24466;;Saint-Michel-de-Montaigne;SAINT-MICHEL-DE-MONTAIGNE;24230;24;DORDOGNE;1
24468;;Saint-Michel-de-Villadeix;SAINT-MICHEL-DE-VILLADEIX;24380;24;DORDOGNE;1
24470;;Sainte-Mondane;SAINTE-MONDANE;24370;24;DORDOGNE;1
24471;;Sainte-Nathalène;SAINTE-NATHALENE;24200;24;DORDOGNE;1
24472;;Saint-Nexans;SAINT-NEXANS;24520;24;DORDOGNE;1
24473;;Sainte-Orse;SAINTE-ORSE;24210;24;DORDOGNE;1
24474;;Saint-Pancrace;SAINT-PANCRACE;24530;24;DORDOGNE;1
24475;;Saint-Pantaly-d'Ans;SAINT-PANTALY-D'ANS;24640;24;DORDOGNE;1
24476;;Saint-Pantaly-d'Excideuil;SAINT-PANTALY-D'EXCIDEUIL;24160;24;DORDOGNE;1
24477;;Saint-Pardoux-de-Drône;SAINT-PARDOUX-DE-DRONE;24600;24;DORDOGNE;1
24478;;Saint-Pardoux-et-Vielvic;SAINT-PARDOUX-ET-VIELVIC;24170;24;DORDOGNE;1
24479;;Saint-Pardoux-la-Rivière;SAINT-PARDOUX-LA-RIVIERE;24470;24;DORDOGNE;1
24480;;Saint-Paul-de-Serre;SAINT-PAUL-DE-SERRE;24380;24;DORDOGNE;1
24481;;Saint-Paul-la-Roche;SAINT-PAUL-LA-ROCHE;24800;24;DORDOGNE;1
24482;;Saint-Paul-Lizonne;SAINT-PAUL-LIZONNE;24320;24;DORDOGNE;1
24483;;Saint-Perdoux;SAINT-PERDOUX;24560;24;DORDOGNE;1
24484;;Saint-Pierre-de-Chignac;SAINT-PIERRE-DE-CHIGNAC;24330;24;DORDOGNE;1
24485;;Saint-Pierre-de-Côle;SAINT-PIERRE-DE-COLE;24800;24;DORDOGNE;1
24486;;Saint-Pierre-de-Frugie;SAINT-PIERRE-DE-FRUGIE;24450;24;DORDOGNE;1
24487;;Saint-Pierre-d'Eyraud;SAINT-PIERRE-D'EYRAUD;24130;24;DORDOGNE;1
24488;;Saint-Pompont;SAINT-POMPONT;24170;24;DORDOGNE;1
24489;;Saint-Priest-les-Fougères;SAINT-PRIEST-LES-FOUGERES;24450;24;DORDOGNE;1
24490;;Saint-Privat-des-Prés;SAINT-PRIVAT-DES-PRES;24410;24;DORDOGNE;1
24491;;Saint-Rabier;SAINT-RABIER;24210;24;DORDOGNE;1
24492;;Sainte-Radegonde;SAINTE-RADEGONDE;24560;24;DORDOGNE;1
24493;;Saint-Raphaël;SAINT-RAPHAEL;24160;24;DORDOGNE;1
24494;;Saint-Rémy;SAINT-REMY;24700;24;DORDOGNE;1
24495;;Saint-Romain-de-Monpazier;SAINT-ROMAIN-DE-MONPAZIER;24540;24;DORDOGNE;1
24496;;Saint-Romain-et-Saint-Clément;SAINT-ROMAIN-ET-SAINT-CLEMENT;24800;24;DORDOGNE;1
24497;;Sainte-Sabine-Born;SAINTE-SABINE-BORN;24440;24;DORDOGNE;1
24498;;Saint-Saud-Lacoussière;SAINT-SAUD-LACOUSSIERE;24470;24;DORDOGNE;1
24499;;Saint-Sauveur;SAINT-SAUVEUR;24520;24;DORDOGNE;1
24500;;Saint-Sauveur-Lalande;SAINT-SAUVEUR-LALANDE;24700;24;DORDOGNE;1
24501;;Saint-Seurin-de-Prats;SAINT-SEURIN-DE-PRATS;24230;24;DORDOGNE;1
24502;;Saint-Séverin-d'Estissac;SAINT-SEVERIN-D'ESTISSAC;24190;24;DORDOGNE;1
24503;;Saint-Sulpice-de-Mareuil;SAINT-SULPICE-DE-MAREUIL;24340;24;DORDOGNE;1
24504;;Saint-Sulpice-de-Roumagnac;SAINT-SULPICE-DE-ROUMAGNAC;24600;24;DORDOGNE;1
24505;;Saint-Sulpice-d'Excideuil;SAINT-SULPICE-D'EXCIDEUIL;24800;24;DORDOGNE;1
24507;;Sainte-Trie;SAINTE-TRIE;24160;24;DORDOGNE;1
24508;;Saint-Victor;SAINT-VICTOR;24350;24;DORDOGNE;1
24509;;Saint-Vincent-de-Connezac;SAINT-VINCENT-DE-CONNEZAC;24190;24;DORDOGNE;1
24510;;Saint-Vincent-de-Cosse;SAINT-VINCENT-DE-COSSE;24220;24;DORDOGNE;1
24511;;Saint-Vincent-Jalmoutiers;SAINT-VINCENT-JALMOUTIERS;24410;24;DORDOGNE;1
24512;;Saint-Vincent-le-Paluel;SAINT-VINCENT-LE-PALUEL;24200;24;DORDOGNE;1
24513;;Saint-Vincent-sur-l'Isle;SAINT-VINCENT-SUR-L'ISLE;24420;24;DORDOGNE;1
24514;;Saint-Vivien;SAINT-VIVIEN;24230;24;DORDOGNE;1
24515;;Salagnac;SALAGNAC;24160;24;DORDOGNE;1
24516;;Salignac-Eyvigues;SALIGNAC-EYVIGUES;24590;24;DORDOGNE;1
24517;;Salles-de-Belvès;SALLES-DE-BELVES;24170;24;DORDOGNE;1
24518;;Salon;SALON;24380;24;DORDOGNE;1
24519;;Sarlande;SARLANDE;24270;24;DORDOGNE;1
24520;;Sarlat-la-Canéda;SARLAT-LA-CANEDA;24200;24;DORDOGNE;1
24521;;Sarliac-sur-l'Isle;SARLIAC-SUR-L'ISLE;24420;24;DORDOGNE;1
24522;;Sarrazac;SARRAZAC;24800;24;DORDOGNE;1
24523;;Saussignac;SAUSSIGNAC;24240;24;DORDOGNE;1
24524;;Savignac-de-Miremont;SAVIGNAC-DE-MIREMONT;24260;24;DORDOGNE;1
24525;;Savignac-de-Nontron;SAVIGNAC-DE-NONTRON;24300;24;DORDOGNE;1
24526;;Savignac-Lédrier;SAVIGNAC-LEDRIER;24270;24;DORDOGNE;1
24527;;Savignac-les-Églises;SAVIGNAC-LES-EGLISES;24420;24;DORDOGNE;1
24528;;Sceau-Saint-Angel;SCEAU-SAINT-ANGEL;24300;24;DORDOGNE;1
24529;;Segonzac;SEGONZAC;24600;24;DORDOGNE;1
24530;;Sencenac-Puy-de-Fourches;SENCENAC-PUY-DE-FOURCHES;24310;24;DORDOGNE;1
24531;;Sergeac;SERGEAC;24290;24;DORDOGNE;1
24532;;Serres-et-Montguyard;SERRES-ET-MONTGUYARD;24500;24;DORDOGNE;1
24533;;Servanches;SERVANCHES;24410;24;DORDOGNE;1
24534;;Sigoulès;SIGOULES;24240;24;DORDOGNE;1
24535;;Simeyrols;SIMEYROLS;24370;24;DORDOGNE;1
24536;;Singleyrac;SINGLEYRAC;24500;24;DORDOGNE;1
24537;;Siorac-de-Ribérac;SIORAC-DE-RIBERAC;24600;24;DORDOGNE;1
24538;;Siorac-en-Périgord;SIORAC-EN-PERIGORD;24170;24;DORDOGNE;1
24540;;Sorges;SORGES;24420;24;DORDOGNE;1
24541;;Soudat;SOUDAT;24360;24;DORDOGNE;1
24542;;Soulaures;SOULAURES;24540;24;DORDOGNE;1
24543;;Sourzac;SOURZAC;24400;24;DORDOGNE;1
24544;;Tamniès;TAMNIES;24620;24;DORDOGNE;1
24545;;Teillots;TEILLOTS;24390;24;DORDOGNE;1
24546;;Temple-Laguyon;TEMPLE-LAGUYON;24390;24;DORDOGNE;1
24547;;Terrasson-Lavilledieu;TERRASSON-LAVILLEDIEU;24120;24;DORDOGNE;1
24548;;Teyjat;TEYJAT;24300;24;DORDOGNE;1
24549;;Thénac;THENAC;24240;24;DORDOGNE;1
24550;;Thenon;THENON;24210;24;DORDOGNE;1
24551;;Thiviers;THIVIERS;24800;24;DORDOGNE;1
24552;;Thonac;THONAC;24290;24;DORDOGNE;1
24553;;Tocane-Saint-Apre;TOCANE-SAINT-APRE;24350;24;DORDOGNE;1
24554;La;Tour-Blanche;TOUR-BLANCHE;24320;24;DORDOGNE;1
24555;;Tourtoirac;TOURTOIRAC;24390;24;DORDOGNE;1
24557;;Trélissac;TRELISSAC;24750;24;DORDOGNE;1
24558;;Trémolat;TREMOLAT;24510;24;DORDOGNE;1
24559;;Tursac;TURSAC;24620;24;DORDOGNE;1
24560;;Urval;URVAL;24480;24;DORDOGNE;1
24561;;Valeuil;VALEUIL;24310;24;DORDOGNE;1
24562;;Vallereuil;VALLEREUIL;24190;24;DORDOGNE;1
24563;;Valojoulx;VALOJOULX;24290;24;DORDOGNE;1
24564;;Vanxains;VANXAINS;24600;24;DORDOGNE;1
24565;;Varaignes;VARAIGNES;24360;24;DORDOGNE;1
24566;;Varennes;VARENNES;24150;24;DORDOGNE;1
24567;;Vaunac;VAUNAC;24800;24;DORDOGNE;1
24568;;Vélines;VELINES;24230;24;DORDOGNE;1
24569;;Vendoire;VENDOIRE;24320;24;DORDOGNE;1
24570;;Verdon;VERDON;24520;24;DORDOGNE;1
24571;;Vergt;VERGT;24380;24;DORDOGNE;1
24572;;Vergt-de-Biron;VERGT-DE-BIRON;24540;24;DORDOGNE;1
24573;;Verteillac;VERTEILLAC;24320;24;DORDOGNE;1
24574;;Veyrignac;VEYRIGNAC;24370;24;DORDOGNE;1
24575;;Veyrines-de-Domme;VEYRINES-DE-DOMME;24250;24;DORDOGNE;1
24576;;Veyrines-de-Vergt;VEYRINES-DE-VERGT;24380;24;DORDOGNE;1
24577;;Vézac;VEZAC;24220;24;DORDOGNE;1
24579;;Vieux-Mareuil;VIEUX-MAREUIL;24340;24;DORDOGNE;1
24580;;Villac;VILLAC;24120;24;DORDOGNE;1
24581;;Villamblard;VILLAMBLARD;24140;24;DORDOGNE;1
24582;;Villars;VILLARS;24530;24;DORDOGNE;1
24584;;Villefranche-de-Lonchat;VILLEFRANCHE-DE-LONCHAT;24610;24;DORDOGNE;1
24585;;Villefranche-du-Périgord;VILLEFRANCHE-DU-PERIGORD;24550;24;DORDOGNE;1
24586;;Villetoureix;VILLETOUREIX;24600;24;DORDOGNE;1
24587;;Vitrac;VITRAC;24200;24;DORDOGNE;1
25001;;Abbans-Dessous;ABBANS-DESSOUS;25320;25;DOUBS;1
25002;;Abbans-Dessus;ABBANS-DESSUS;25440;25;DOUBS;1
25003;;Abbenans;ABBENANS;25340;25;DOUBS;1
25004;;Abbévillers;ABBEVILLERS;25310;25;DOUBS;1
25005;;Accolans;ACCOLANS;25250;25;DOUBS;1
25006;;Adam-lès-Passavant;ADAM-LES-PASSAVANT;25360;25;DOUBS;1
25007;;Adam-lès-Vercel;ADAM-LES-VERCEL;25530;25;DOUBS;1
25008;;Aibre;AIBRE;25750;25;DOUBS;1
25009;;Aïssey;AISSEY;25360;25;DOUBS;1
25011;;Allenjoie;ALLENJOIE;25490;25;DOUBS;1
25012;Les;Alliés;ALLIES;25300;25;DOUBS;1
25013;;Allondans;ALLONDANS;25550;25;DOUBS;1
25014;;Amagney;AMAGNEY;25220;25;DOUBS;1
25015;;Amancey;AMANCEY;25330;25;DOUBS;1
25016;;Amathay-Vésigneux;AMATHAY-VESIGNEUX;25330;25;DOUBS;1
25017;;Amondans;AMONDANS;25330;25;DOUBS;1
25018;;Anteuil;ANTEUIL;25340;25;DOUBS;1
25019;;Appenans;APPENANS;25250;25;DOUBS;1
25020;;Arbouans;ARBOUANS;25400;25;DOUBS;1
25021;;Arc-et-Senans;ARC-ET-SENANS;25610;25;DOUBS;1
25022;;Arcey;ARCEY;25750;25;DOUBS;1
25024;;Arçon;ARCON;25300;25;DOUBS;1
25025;;Arc-sous-Cicon;ARC-SOUS-CICON;25520;25;DOUBS;1
25026;;Arc-sous-Montenot;ARC-SOUS-MONTENOT;25270;25;DOUBS;1
25027;;Arguel;ARGUEL;25720;25;DOUBS;1
25028;;Athose;ATHOSE;25580;25;DOUBS;1
25029;;Aubonne;AUBONNE;25520;25;DOUBS;1
25030;;Audeux;AUDEUX;25170;25;DOUBS;1
25031;;Audincourt;AUDINCOURT;25400;25;DOUBS;1
25032;;Autechaux;AUTECHAUX;25110;25;DOUBS;1
25033;;Autechaux-Roide;AUTECHAUX-ROIDE;25150;25;DOUBS;1
25034;;Auxon-Dessous;AUXON-DESSOUS;25870;25;DOUBS;1
25035;;Auxon-Dessus;AUXON-DESSUS;25870;25;DOUBS;1
25036;;Avanne-Aveney;AVANNE-AVENEY;25720;25;DOUBS;1
25038;;Avilley;AVILLEY;25680;25;DOUBS;1
25039;;Avoudrey;AVOUDREY;25690;25;DOUBS;1
25040;;Badevel;BADEVEL;25490;25;DOUBS;1
25041;;Bannans;BANNANS;25560;25;DOUBS;1
25042;Le;Barboux;BARBOUX;25210;25;DOUBS;1
25043;;Bart;BART;25420;25;DOUBS;1
25044;;Bartherans;BARTHERANS;25440;25;DOUBS;1
25045;;Battenans-les-Mines;BATTENANS-LES-MINES;25640;25;DOUBS;1
25046;;Battenans-Varin;BATTENANS-VARIN;25380;25;DOUBS;1
25047;;Baume-les-Dames;BAUME-LES-DAMES;25110;25;DOUBS;1
25048;;Bavans;BAVANS;25550;25;DOUBS;1
25049;;Belfays;BELFAYS;25470;25;DOUBS;1
25050;Le;Bélieu;BELIEU;25500;25;DOUBS;1
25051;;Belleherbe;BELLEHERBE;25380;25;DOUBS;1
25052;;Belmont;BELMONT;25530;25;DOUBS;1
25053;;Belvoir;BELVOIR;25430;25;DOUBS;1
25054;;Berche;BERCHE;25420;25;DOUBS;1
25055;;Berthelange;BERTHELANGE;25410;25;DOUBS;1
25056;;Besançon;BESANCON;25000;25;DOUBS;1
25057;;Bethoncourt;BETHONCOURT;25200;25;DOUBS;1
25058;;Beure;BEURE;25720;25;DOUBS;1
25059;;Beutal;BEUTAL;25250;25;DOUBS;1
25060;;Bians-les-Usiers;BIANS-LES-USIERS;25520;25;DOUBS;1
25061;;Bief;BIEF;25190;25;DOUBS;1
25062;Le;Bizot;BIZOT;25210;25;DOUBS;1
25063;;Blamont;BLAMONT;25310;25;DOUBS;1
25065;;Blarians;BLARIANS;25640;25;DOUBS;1
25066;;Blussangeaux;BLUSSANGEAUX;25250;25;DOUBS;1
25067;;Blussans;BLUSSANS;25250;25;DOUBS;1
25070;;Bolandoz;BOLANDOZ;25330;25;DOUBS;1
25071;;Bondeval;BONDEVAL;25230;25;DOUBS;1
25072;;Bonnal;BONNAL;25680;25;DOUBS;1
25073;;Bonnay;BONNAY;25870;25;DOUBS;1
25074;;Bonnétage;BONNETAGE;25210;25;DOUBS;1
25075;;Bonnevaux;BONNEVAUX;25560;25;DOUBS;1
25076;;Bonnevaux-le-Prieuré;BONNEVAUX-LE-PRIEURE;25620;25;DOUBS;1
25077;La;Bosse;BOSSE;25210;25;DOUBS;1
25078;;Bouclans;BOUCLANS;25360;25;DOUBS;1
25079;;Boujailles;BOUJAILLES;25560;25;DOUBS;1
25082;;Bourguignon;BOURGUIGNON;25150;25;DOUBS;1
25083;;Bournois;BOURNOIS;25250;25;DOUBS;1
25084;;Boussières;BOUSSIERES;25320;25;DOUBS;1
25085;;Bouverans;BOUVERANS;25560;25;DOUBS;1
25086;;Braillans;BRAILLANS;25640;25;DOUBS;1
25087;;Branne;BRANNE;25340;25;DOUBS;1
25088;;Breconchaux;BRECONCHAUX;25640;25;DOUBS;1
25089;;Bremondans;BREMONDANS;25530;25;DOUBS;1
25090;;Brères;BRERES;25440;25;DOUBS;1
25091;Les;Bréseux;BRESEUX;25120;25;DOUBS;1
25092;La;Bretenière;BRETENIERE;25640;25;DOUBS;1
25093;;Bretigney;BRETIGNEY;25250;25;DOUBS;1
25094;;Bretigney-Notre-Dame;BRETIGNEY-NOTRE-DAME;25110;25;DOUBS;1
25095;;Bretonvillers;BRETONVILLERS;25380;25;DOUBS;1
25096;;Brey-et-Maison-du-Bois;BREY-ET-MAISON-DU-BOIS;25240;25;DOUBS;1
25097;;Brognard;BROGNARD;25600;25;DOUBS;1
25098;;Buffard;BUFFARD;25440;25;DOUBS;1
25099;;Bugny;BUGNY;25520;25;DOUBS;1
25100;;Bulle;BULLE;25560;25;DOUBS;1
25101;;Burgille;BURGILLE;25170;25;DOUBS;1
25102;;Burnevillers;BURNEVILLERS;25470;25;DOUBS;1
25103;;Busy;BUSY;25320;25;DOUBS;1
25104;;By;BY;25440;25;DOUBS;1
25105;;Byans-sur-Doubs;BYANS-SUR-DOUBS;25320;25;DOUBS;1
25106;;Cademène;CADEMENE;25290;25;DOUBS;1
25107;;Cendrey;CENDREY;25640;25;DOUBS;1
25108;;Cernay-l'Église;CERNAY-L'EGLISE;25120;25;DOUBS;1
25109;;Cessey;CESSEY;25440;25;DOUBS;1
25110;;Chaffois;CHAFFOIS;25300;25;DOUBS;1
25111;;Chalèze;CHALEZE;25220;25;DOUBS;1
25112;;Chalezeule;CHALEZEULE;25220;25;DOUBS;1
25113;;Chamesey;CHAMESEY;25380;25;DOUBS;1
25114;;Chamesol;CHAMESOL;25190;25;DOUBS;1
25115;;Champagney;CHAMPAGNEY;25170;25;DOUBS;1
25116;;Champlive;CHAMPLIVE;25360;25;DOUBS;1
25117;;Champoux;CHAMPOUX;25640;25;DOUBS;1
25119;;Champvans-les-Moulins;CHAMPVANS-LES-MOULINS;25170;25;DOUBS;1
25120;;Chantrans;CHANTRANS;25330;25;DOUBS;1
25121;;Chapelle-des-Bois;CHAPELLE-DES-BOIS;25240;25;DOUBS;1
25122;;Chapelle-d'Huin;CHAPELLE-D'HUIN;25270;25;DOUBS;1
25123;;Charbonnières-les-Sapins;CHARBONNIERES-LES-SAPINS;25620;25;DOUBS;1
25124;;Charmauvillers;CHARMAUVILLERS;25470;25;DOUBS;1
25125;;Charmoille;CHARMOILLE;25380;25;DOUBS;1
25126;;Charnay;CHARNAY;25440;25;DOUBS;1
25127;;Charquemont;CHARQUEMONT;25140;25;DOUBS;1
25128;;Chasnans;CHASNANS;25580;25;DOUBS;1
25129;;Chassagne-Saint-Denis;CHASSAGNE-SAINT-DENIS;25290;25;DOUBS;1
25130;;Châteauvieux-les-Fossés;CHATEAUVIEUX-LES-FOSSES;25840;25;DOUBS;1
25131;;Châtelblanc;CHATELBLANC;25240;25;DOUBS;1
25132;;Châtillon-Guyotte;CHATILLON-GUYOTTE;25640;25;DOUBS;1
25133;;Châtillon-le-Duc;CHATILLON-LE-DUC;25870;25;DOUBS;1
25134;;Châtillon-sur-Lison;CHATILLON-SUR-LISON;25440;25;DOUBS;1
25136;;Chaucenne;CHAUCENNE;25170;25;DOUBS;1
25137;;Chaudefontaine;CHAUDEFONTAINE;25640;25;DOUBS;1
25138;Les;Terres-de-Chaux;TERRES-DE-CHAUX;25190;25;DOUBS;1
25139;La;Chaux;CHAUX;25650;25;DOUBS;1
25140;;Chaux-lès-Clerval;CHAUX-LES-CLERVAL;25340;25;DOUBS;1
25141;;Chaux-lès-Passavant;CHAUX-LES-PASSAVANT;25530;25;DOUBS;1
25142;;Chaux-Neuve;CHAUX-NEUVE;25240;25;DOUBS;1
25143;;Chay;CHAY;25440;25;DOUBS;1
25145;;Chazot;CHAZOT;25430;25;DOUBS;1
25147;;Chemaudin;CHEMAUDIN;25320;25;DOUBS;1
25148;La;Chenalotte;CHENALOTTE;25500;25;DOUBS;1
25149;;Chenecey-Buillon;CHENECEY-BUILLON;25440;25;DOUBS;1
25150;;Chevigney-sur-l'Ognon;CHEVIGNEY-SUR-L'OGNON;25170;25;DOUBS;1
25151;;Chevigney-lès-Vercel;CHEVIGNEY-LES-VERCEL;25530;25;DOUBS;1
25152;La;Chevillotte;CHEVILLOTTE;25620;25;DOUBS;1
25153;;Chevroz;CHEVROZ;25870;25;DOUBS;1
25154;;Chouzelot;CHOUZELOT;25440;25;DOUBS;1
25155;;Cléron;CLERON;25330;25;DOUBS;1
25156;;Clerval;CLERVAL;25340;25;DOUBS;1
25157;La;Cluse-et-Mijoux;CLUSE-ET-MIJOUX;25300;25;DOUBS;1
25159;;Colombier-Fontaine;COLOMBIER-FONTAINE;25260;25;DOUBS;1
25160;Les;Combes;COMBES;25500;25;DOUBS;1
25161;;Consolation-Maisonnettes;CONSOLATION-MAISONNETTES;25390;25;DOUBS;1
25162;;Corcelles-Ferrières;CORCELLES-FERRIERES;25410;25;DOUBS;1
25163;;Corcelle-Mieslot;CORCELLE-MIESLOT;25640;25;DOUBS;1
25164;;Corcondray;CORCONDRAY;25410;25;DOUBS;1
25166;;Côtebrune;COTEBRUNE;25360;25;DOUBS;1
25170;;Courcelles-lès-Montbéliard;COURCELLES-LES-MONTBELIARD;25420;25;DOUBS;1
25171;;Courcelles;COURCELLES;25440;25;DOUBS;1
25172;;Courchapon;COURCHAPON;25170;25;DOUBS;1
25173;;Cour-Saint-Maurice;COUR-SAINT-MAURICE;25380;25;DOUBS;1
25174;;Courtefontaine;COURTEFONTAINE;25470;25;DOUBS;1
25175;;Courtetain-et-Salans;COURTETAIN-ET-SALANS;25530;25;DOUBS;1
25176;;Courvières;COURVIERES;25560;25;DOUBS;1
25177;;Crosey-le-Grand;CROSEY-LE-GRAND;25340;25;DOUBS;1
25178;;Crosey-le-Petit;CROSEY-LE-PETIT;25340;25;DOUBS;1
25179;Le;Crouzet;CROUZET;25240;25;DOUBS;1
25180;;Crouzet-Migette;CROUZET-MIGETTE;25270;25;DOUBS;1
25181;;Cubrial;CUBRIAL;25680;25;DOUBS;1
25182;;Cubry;CUBRY;25680;25;DOUBS;1
25183;;Cusance;CUSANCE;25110;25;DOUBS;1
25184;;Cuse-et-Adrisans;CUSE-ET-ADRISANS;25680;25;DOUBS;1
25185;;Cussey-sur-Lison;CUSSEY-SUR-LISON;25440;25;DOUBS;1
25186;;Cussey-sur-l'Ognon;CUSSEY-SUR-L'OGNON;25870;25;DOUBS;1
25187;;Dambelin;DAMBELIN;25150;25;DOUBS;1
25188;;Dambenois;DAMBENOIS;25600;25;DOUBS;1
25189;;Dammartin-les-Templiers;DAMMARTIN-LES-TEMPLIERS;25110;25;DOUBS;1
25190;;Dampierre-les-Bois;DAMPIERRE-LES-BOIS;25490;25;DOUBS;1
25191;;Dampierre-sur-le-Doubs;DAMPIERRE-SUR-LE-DOUBS;25420;25;DOUBS;1
25192;;Dampjoux;DAMPJOUX;25190;25;DOUBS;1
25193;;Damprichard;DAMPRICHARD;25450;25;DOUBS;1
25194;;Dannemarie;DANNEMARIE;25310;25;DOUBS;1
25195;;Dannemarie-sur-Crète;DANNEMARIE-SUR-CRETE;25410;25;DOUBS;1
25196;;Dasle;DASLE;25230;25;DOUBS;1
25197;;Deluz;DELUZ;25960;25;DOUBS;1
25198;;Désandans;DESANDANS;25750;25;DOUBS;1
25199;;Déservillers;DESERVILLERS;25330;25;DOUBS;1
25200;;Devecey;DEVECEY;25870;25;DOUBS;1
25201;;Dommartin;DOMMARTIN;25300;25;DOUBS;1
25202;;Dompierre-les-Tilleuls;DOMPIERRE-LES-TILLEULS;25560;25;DOUBS;1
25203;;Domprel;DOMPREL;25510;25;DOUBS;1
25204;;Doubs;DOUBS;25300;25;DOUBS;1
25207;;Dung;DUNG;25550;25;DOUBS;1
25208;;Durnes;DURNES;25580;25;DOUBS;1
25209;;Échay;ECHAY;25440;25;DOUBS;1
25210;;Échenans;ECHENANS;25550;25;DOUBS;1
25211;;Échevannes;ECHEVANNES;25580;25;DOUBS;1
25212;;École-Valentin;ECOLE-VALENTIN;25480;25;DOUBS;1
25213;Les;Écorces;ECORCES;25140;25;DOUBS;1
25214;;Écot;ECOT;25150;25;DOUBS;1
25215;L';Écouvotte;ECOUVOTTE;25640;25;DOUBS;1
25216;;Écurcey;ECURCEY;25150;25;DOUBS;1
25217;;Émagny;EMAGNY;25170;25;DOUBS;1
25218;;Épenouse;EPENOUSE;25530;25;DOUBS;1
25219;;Épenoy;EPENOY;25800;25;DOUBS;1
25220;;Épeugney;EPEUGNEY;25290;25;DOUBS;1
25221;;Esnans;ESNANS;25110;25;DOUBS;1
25222;;Étalans;ETALANS;25580;25;DOUBS;1
25223;;Éternoz;ETERNOZ;25330;25;DOUBS;1
25224;;Étouvans;ETOUVANS;25260;25;DOUBS;1
25225;;Étrabonne;ETRABONNE;25170;25;DOUBS;1
25226;;Étrappe;ETRAPPE;25250;25;DOUBS;1
25227;;Étray;ETRAY;25800;25;DOUBS;1
25228;;Étupes;ETUPES;25460;25;DOUBS;1
25229;;Évillers;EVILLERS;25520;25;DOUBS;1
25230;;Exincourt;EXINCOURT;25400;25;DOUBS;1
25231;;Eysson;EYSSON;25530;25;DOUBS;1
25232;;Faimbe;FAIMBE;25250;25;DOUBS;1
25233;;Fallerans;FALLERANS;25580;25;DOUBS;1
25234;;Ferrières-le-Lac;FERRIERES-LE-LAC;25470;25;DOUBS;1
25235;;Ferrières-les-Bois;FERRIERES-LES-BOIS;25410;25;DOUBS;1
25236;;Fertans;FERTANS;25330;25;DOUBS;1
25237;;Fesches-le-Châtel;FESCHES-LE-CHATEL;25490;25;DOUBS;1
25238;;Fessevillers;FESSEVILLERS;25470;25;DOUBS;1
25239;;Feule;FEULE;25190;25;DOUBS;1
25240;Les;Fins;FINS;25500;25;DOUBS;1
25241;;Flagey;FLAGEY;25330;25;DOUBS;1
25242;;Flagey-Rigney;FLAGEY-RIGNEY;25640;25;DOUBS;1
25243;;Flangebouche;FLANGEBOUCHE;25690;25;DOUBS;1
25244;;Fleurey;FLEUREY;25190;25;DOUBS;1
25245;;Fontain;FONTAIN;25660;25;DOUBS;1
25246;;Fontaine-lès-Clerval;FONTAINE-LES-CLERVAL;25340;25;DOUBS;1
25247;;Fontenelle-Montby;FONTENELLE-MONTBY;25340;25;DOUBS;1
25248;Les;Fontenelles;FONTENELLES;25210;25;DOUBS;1
25249;;Fontenotte;FONTENOTTE;25110;25;DOUBS;1
25250;;Foucherans;FOUCHERANS;25620;25;DOUBS;1
25251;;Fourbanne;FOURBANNE;25110;25;DOUBS;1
25252;;Fourcatier-et-Maison-Neuve;FOURCATIER-ET-MAISON-NEUVE;25370;25;DOUBS;1
25253;;Fourg;FOURG;25440;25;DOUBS;1
25254;Les;Fourgs;FOURGS;25300;25;DOUBS;1
25255;;Fournet-Blancheroche;FOURNET-BLANCHEROCHE;25140;25;DOUBS;1
25256;;Frambouhans;FRAMBOUHANS;25140;25;DOUBS;1
25257;;Franey;FRANEY;25170;25;DOUBS;1
25258;;Franois;FRANOIS;25770;25;DOUBS;1
25259;;Frasne;FRASNE;25560;25;DOUBS;1
25261;;Froidevaux;FROIDEVAUX;25190;25;DOUBS;1
25262;;Fuans;FUANS;25390;25;DOUBS;1
25263;;Gellin;GELLIN;25240;25;DOUBS;1
25264;;Gémonval;GEMONVAL;25250;25;DOUBS;1
25265;;Geneuille;GENEUILLE;25870;25;DOUBS;1
25266;;Geney;GENEY;25250;25;DOUBS;1
25267;;Gennes;GENNES;25660;25;DOUBS;1
25268;;Germéfontaine;GERMEFONTAINE;25510;25;DOUBS;1
25269;;Germondans;GERMONDANS;25640;25;DOUBS;1
25270;;Gevresin;GEVRESIN;25270;25;DOUBS;1
25271;;Gilley;GILLEY;25650;25;DOUBS;1
25273;;Glamondans;GLAMONDANS;25360;25;DOUBS;1
25274;;Glay;GLAY;25310;25;DOUBS;1
25275;;Glère;GLERE;25190;25;DOUBS;1
25276;;Gondenans-Montby;GONDENANS-MONTBY;25340;25;DOUBS;1
25277;;Gondenans-les-Moulins;GONDENANS-LES-MOULINS;25680;25;DOUBS;1
25278;;Gonsans;GONSANS;25360;25;DOUBS;1
25279;;Gouhelans;GOUHELANS;25680;25;DOUBS;1
25280;;Goumois;GOUMOIS;25470;25;DOUBS;1
25281;;Goux-lès-Dambelin;GOUX-LES-DAMBELIN;25150;25;DOUBS;1
25282;;Goux-les-Usiers;GOUX-LES-USIERS;25520;25;DOUBS;1
25283;;Goux-sous-Landet;GOUX-SOUS-LANDET;25440;25;DOUBS;1
25284;;Grand-Charmont;GRAND-CHARMONT;25200;25;DOUBS;1
25285;;Grand'Combe-Châteleu;GRAND'COMBE-CHATELEU;25570;25;DOUBS;1
25286;;Grand'Combe-des-Bois;GRAND'COMBE-DES-BOIS;25210;25;DOUBS;1
25287;;Grandfontaine;GRANDFONTAINE;25320;25;DOUBS;1
25288;;Fournets-Luisans;FOURNETS-LUISANS;25390;25;DOUBS;1
25289;;Grandfontaine-sur-Creuse;GRANDFONTAINE-SUR-CREUSE;25510;25;DOUBS;1
25290;La;Grange;GRANGE;25380;25;DOUBS;1
25293;;Granges-Narboz;GRANGES-NARBOZ;25300;25;DOUBS;1
25295;Les;Grangettes;GRANGETTES;25160;25;DOUBS;1
25296;Les;Gras;GRAS;25790;25;DOUBS;1
25297;Le;Gratteris;GRATTERIS;25620;25;DOUBS;1
25298;;Grosbois;GROSBOIS;25110;25;DOUBS;1
25299;;Guillon-les-Bains;GUILLON-LES-BAINS;25110;25;DOUBS;1
25300;;Guyans-Durnes;GUYANS-DURNES;25580;25;DOUBS;1
25301;;Guyans-Vennes;GUYANS-VENNES;25390;25;DOUBS;1
25302;;Hautepierre-le-Châtelet;HAUTEPIERRE-LE-CHATELET;25580;25;DOUBS;1
25303;;Hauterive-la-Fresse;HAUTERIVE-LA-FRESSE;25650;25;DOUBS;1
25304;;Hérimoncourt;HERIMONCOURT;25310;25;DOUBS;1
25305;L';Hôpital-du-Grosbois;HOPITAL-DU-GROSBOIS;25620;25;DOUBS;1
25306;L';Hôpital-Saint-Lieffroy;HOPITAL-SAINT-LIEFFROY;25340;25;DOUBS;1
25307;Les;Hôpitaux-Neufs;HOPITAUX-NEUFS;25370;25;DOUBS;1
25308;Les;Hôpitaux-Vieux;HOPITAUX-VIEUX;25370;25;DOUBS;1
25309;;Houtaud;HOUTAUD;25300;25;DOUBS;1
25310;;Huanne-Montmartin;HUANNE-MONTMARTIN;25680;25;DOUBS;1
25311;;Hyémondans;HYEMONDANS;25250;25;DOUBS;1
25312;;Hyèvre-Magny;HYEVRE-MAGNY;25110;25;DOUBS;1
25313;;Hyèvre-Paroisse;HYEVRE-PAROISSE;25110;25;DOUBS;1
25314;;Indevillers;INDEVILLERS;25470;25;DOUBS;1
25315;L';Isle-sur-le-Doubs;ISLE-SUR-LE-DOUBS;25250;25;DOUBS;1
25316;;Issans;ISSANS;25550;25;DOUBS;1
25317;;Jallerange;JALLERANGE;25170;25;DOUBS;1
25318;;Jougne;JOUGNE;25370;25;DOUBS;1
25319;;Labergement-du-Navois;LABERGEMENT-DU-NAVOIS;25270;25;DOUBS;1
25320;;Labergement-Sainte-Marie;LABERGEMENT-SAINTE-MARIE;25160;25;DOUBS;1
25321;;Villers-le-Lac;VILLERS-LE-LAC;25130;25;DOUBS;1
25322;;Laire;LAIRE;25550;25;DOUBS;1
25323;;Laissey;LAISSEY;25820;25;DOUBS;1
25324;;Lanans;LANANS;25360;25;DOUBS;1
25325;;Landresse;LANDRESSE;25530;25;DOUBS;1
25326;;Lantenne-Vertière;LANTENNE-VERTIERE;25170;25;DOUBS;1
25327;;Lanthenans;LANTHENANS;25250;25;DOUBS;1
25328;;Larnod;LARNOD;25720;25;DOUBS;1
25329;;Laval-le-Prieuré;LAVAL-LE-PRIEURE;25210;25;DOUBS;1
25330;;Lavans-Quingey;LAVANS-QUINGEY;25440;25;DOUBS;1
25331;;Lavans-Vuillafans;LAVANS-VUILLAFANS;25580;25;DOUBS;1
25332;;Lavernay;LAVERNAY;25170;25;DOUBS;1
25333;;Laviron;LAVIRON;25510;25;DOUBS;1
25334;;Levier;LEVIER;25270;25;DOUBS;1
25335;;Liebvillers;LIEBVILLERS;25190;25;DOUBS;1
25336;;Liesle;LIESLE;25440;25;DOUBS;1
25338;;Lizine;LIZINE;25330;25;DOUBS;1
25339;;Lods;LODS;25930;25;DOUBS;1
25340;;Lombard;LOMBARD;25440;25;DOUBS;1
25341;;Lomont-sur-Crête;LOMONT-SUR-CRETE;25110;25;DOUBS;1
25342;;Longechaux;LONGECHAUX;25690;25;DOUBS;1
25343;;Longemaison;LONGEMAISON;25690;25;DOUBS;1
25344;;Longevelle-lès-Russey;LONGEVELLE-LES-RUSSEY;25380;25;DOUBS;1
25345;;Longevelle-sur-Doubs;LONGEVELLE-SUR-DOUBS;25260;25;DOUBS;1
25346;;Longeville;LONGEVILLE;25330;25;DOUBS;1
25347;La;Longeville;LONGEVILLE;25650;25;DOUBS;1
25348;;Longevilles-Mont-d'Or;LONGEVILLES-MONT-D'OR;25370;25;DOUBS;1
25349;;Loray;LORAY;25390;25;DOUBS;1
25350;;Lougres;LOUGRES;25260;25;DOUBS;1
25351;Le;Luhier;LUHIER;25210;25;DOUBS;1
25354;;Luxiol;LUXIOL;25110;25;DOUBS;1
25355;;Magny-Châtelard;MAGNY-CHATELARD;25360;25;DOUBS;1
25356;;Maîche;MAICHE;25120;25;DOUBS;1
25357;;Maisons-du-Bois-Lièvremont;MAISONS-DU-BOIS-LIEVREMONT;25650;25;DOUBS;1
25359;;Malans;MALANS;25330;25;DOUBS;1
25360;;Malbrans;MALBRANS;25620;25;DOUBS;1
25361;;Malbuisson;MALBUISSON;25160;25;DOUBS;1
25362;;Malpas;MALPAS;25160;25;DOUBS;1
25364;;Mamirolle;MAMIROLLE;25620;25;DOUBS;1
25365;;Mancenans;MANCENANS;25250;25;DOUBS;1
25366;;Mancenans-Lizerne;MANCENANS-LIZERNE;25120;25;DOUBS;1
25367;;Mandeure;MANDEURE;25350;25;DOUBS;1
25368;;Marchaux;MARCHAUX;25640;25;DOUBS;1
25369;;Marvelise;MARVELISE;25250;25;DOUBS;1
25370;;Mathay;MATHAY;25700;25;DOUBS;1
25371;;Mazerolles-le-Salin;MAZEROLLES-LE-SALIN;25170;25;DOUBS;1
25372;;Médière;MEDIERE;25250;25;DOUBS;1
25373;Le;Mémont;MEMONT;25210;25;DOUBS;1
25374;;Mercey-le-Grand;MERCEY-LE-GRAND;25410;25;DOUBS;1
25375;;Mérey-sous-Montrond;MEREY-SOUS-MONTROND;25660;25;DOUBS;1
25376;;Mérey-Vieilley;MEREY-VIEILLEY;25870;25;DOUBS;1
25377;;Mésandans;MESANDANS;25680;25;DOUBS;1
25378;;Meslières;MESLIERES;25310;25;DOUBS;1
25379;;Mesmay;MESMAY;25440;25;DOUBS;1
25380;;Métabief;METABIEF;25370;25;DOUBS;1
25381;;Miserey-Salines;MISEREY-SALINES;25480;25;DOUBS;1
25382;;Moncey;MONCEY;25870;25;DOUBS;1
25383;;Moncley;MONCLEY;25170;25;DOUBS;1
25384;;Mondon;MONDON;25680;25;DOUBS;1
25385;;Montagney-Servigney;MONTAGNEY-SERVIGNEY;25680;25;DOUBS;1
25386;;Montancy;MONTANCY;25190;25;DOUBS;1
25387;;Montandon;MONTANDON;25190;25;DOUBS;1
25388;;Montbéliard;MONTBELIARD;25200;25;DOUBS;1
25389;;Montbéliardot;MONTBELIARDOT;25210;25;DOUBS;1
25390;;Montbenoît;MONTBENOIT;25650;25;DOUBS;1
25391;;Mont-de-Laval;MONT-DE-LAVAL;25210;25;DOUBS;1
25392;;Mont-de-Vougney;MONT-DE-VOUGNEY;25120;25;DOUBS;1
25393;;Montécheroux;MONTECHEROUX;25190;25;DOUBS;1
25394;;Montenois;MONTENOIS;25260;25;DOUBS;1
25395;;Montfaucon;MONTFAUCON;25660;25;DOUBS;1
25397;;Montferrand-le-Château;MONTFERRAND-LE-CHATEAU;25320;25;DOUBS;1
25398;;Montflovin;MONTFLOVIN;25650;25;DOUBS;1
25399;;Montfort;MONTFORT;25440;25;DOUBS;1
25400;;Montgesoye;MONTGESOYE;25111;25;DOUBS;1
25401;;Montivernage;MONTIVERNAGE;25110;25;DOUBS;1
25402;;Montjoie-le-Château;MONTJOIE-LE-CHATEAU;25190;25;DOUBS;1
25403;;Montlebon;MONTLEBON;25500;25;DOUBS;1
25404;;Montmahoux;MONTMAHOUX;25270;25;DOUBS;1
25405;;Montperreux;MONTPERREUX;25160;25;DOUBS;1
25406;;Montrond-le-Château;MONTROND-LE-CHATEAU;25660;25;DOUBS;1
25408;;Montussaint;MONTUSSAINT;25680;25;DOUBS;1
25410;;Morre;MORRE;25660;25;DOUBS;1
25411;;Morteau;MORTEAU;25500;25;DOUBS;1
25413;;Mouthe;MOUTHE;25240;25;DOUBS;1
25414;Le;Moutherot;MOUTHEROT;25170;25;DOUBS;1
25415;;Mouthier-Haute-Pierre;MOUTHIER-HAUTE-PIERRE;25920;25;DOUBS;1
25416;;Myon;MYON;25440;25;DOUBS;1
25417;;Naisey-les-Granges;NAISEY-LES-GRANGES;25360;25;DOUBS;1
25418;;Nancray;NANCRAY;25360;25;DOUBS;1
25419;;Nans;NANS;25680;25;DOUBS;1
25420;;Nans-sous-Sainte-Anne;NANS-SOUS-SAINTE-ANNE;25330;25;DOUBS;1
25421;;Narbief;NARBIEF;25210;25;DOUBS;1
25422;;Neuchâtel-Urtière;NEUCHATEL-URTIERE;25150;25;DOUBS;1
25424;;Nods;NODS;25580;25;DOUBS;1
25425;;Noël-Cerneux;NOEL-CERNEUX;25500;25;DOUBS;1
25426;;Noirefontaine;NOIREFONTAINE;25190;25;DOUBS;1
25427;;Noironte;NOIRONTE;25170;25;DOUBS;1
25428;;Nommay;NOMMAY;25600;25;DOUBS;1
25429;;Novillars;NOVILLARS;25220;25;DOUBS;1
25430;;Ollans;OLLANS;25640;25;DOUBS;1
25431;;Onans;ONANS;25250;25;DOUBS;1
25432;;Orchamps-Vennes;ORCHAMPS-VENNES;25390;25;DOUBS;1
25433;;Orgeans-Blanchefontaine;ORGEANS-BLANCHEFONTAINE;25120;25;DOUBS;1
25434;;Ornans;ORNANS;25290;25;DOUBS;1
25435;;Orsans;ORSANS;25530;25;DOUBS;1
25436;;Orve;ORVE;25430;25;DOUBS;1
25437;;Osse;OSSE;25360;25;DOUBS;1
25438;;Osselle;OSSELLE;25320;25;DOUBS;1
25439;;Ougney-Douvot;OUGNEY-DOUVOT;25640;25;DOUBS;1
25440;;Ouhans;OUHANS;25520;25;DOUBS;1
25441;;Ouvans;OUVANS;25530;25;DOUBS;1
25442;;Oye-et-Pallet;OYE-ET-PALLET;25160;25;DOUBS;1
25443;;Palantine;PALANTINE;25440;25;DOUBS;1
25444;;Palise;PALISE;25870;25;DOUBS;1
25445;;Paroy;PAROY;25440;25;DOUBS;1
25446;;Passavant;PASSAVANT;25360;25;DOUBS;1
25447;;Passonfontaine;PASSONFONTAINE;25690;25;DOUBS;1
25448;;Pelousey;PELOUSEY;25170;25;DOUBS;1
25449;;Péseux;PESEUX;25190;25;DOUBS;1
25450;;Pessans;PESSANS;25440;25;DOUBS;1
25451;;Petite-Chaux;PETITE-CHAUX;25240;25;DOUBS;1
25452;;Pierrefontaine-lès-Blamont;PIERREFONTAINE-LES-BLAMONT;25310;25;DOUBS;1
25453;;Pierrefontaine-les-Varans;PIERREFONTAINE-LES-VARANS;25510;25;DOUBS;1
25454;;Pirey;PIREY;25480;25;DOUBS;1
25455;;Placey;PLACEY;25170;25;DOUBS;1
25456;;Plaimbois-du-Miroir;PLAIMBOIS-DU-MIROIR;25210;25;DOUBS;1
25457;;Plaimbois-Vennes;PLAIMBOIS-VENNES;25390;25;DOUBS;1
25458;Les;Plains-et-Grands-Essarts;PLAINS-ET-GRANDS-ESSARTS;25470;25;DOUBS;1
25459;La;Planée;PLANEE;25160;25;DOUBS;1
25460;;Pointvillers;POINTVILLERS;25440;25;DOUBS;1
25461;;Pompierre-sur-Doubs;POMPIERRE-SUR-DOUBS;25340;25;DOUBS;1
25462;;Pontarlier;PONTARLIER;25300;25;DOUBS;1
25463;;Pont-de-Roide;PONT-DE-ROIDE;25150;25;DOUBS;1
25464;Les;Pontets;PONTETS;25240;25;DOUBS;1
25465;;Pont-les-Moulins;PONT-LES-MOULINS;25110;25;DOUBS;1
25466;;Pouilley-Français;POUILLEY-FRANCAIS;25410;25;DOUBS;1
25467;;Pouilley-les-Vignes;POUILLEY-LES-VIGNES;25115;25;DOUBS;1
25468;;Pouligney-Lusans;POULIGNEY-LUSANS;25640;25;DOUBS;1
25469;;Présentevillers;PRESENTEVILLERS;25550;25;DOUBS;1
25470;La;Prétière;PRETIERE;25250;25;DOUBS;1
25471;;Provenchère;PROVENCHERE;25380;25;DOUBS;1
25472;;Puessans;PUESSANS;25680;25;DOUBS;1
25473;;Pugey;PUGEY;25720;25;DOUBS;1
25474;Le;Puy;PUY;25640;25;DOUBS;1
25475;;Quingey;QUINGEY;25440;25;DOUBS;1
25476;;Rahon;RAHON;25430;25;DOUBS;1
25477;;Rancenay;RANCENAY;25320;25;DOUBS;1
25478;;Randevillers;RANDEVILLERS;25430;25;DOUBS;1
25479;;Rang;RANG;25250;25;DOUBS;1
25480;;Rantechaux;RANTECHAUX;25580;25;DOUBS;1
25481;;Raynans;RAYNANS;25550;25;DOUBS;1
25482;;Recologne;RECOLOGNE;25170;25;DOUBS;1
25483;;Reculfoz;RECULFOZ;25240;25;DOUBS;1
25485;;Rémondans-Vaivre;REMONDANS-VAIVRE;25150;25;DOUBS;1
25486;;Remoray-Boujeons;REMORAY-BOUJEONS;25160;25;DOUBS;1
25487;;Renédale;RENEDALE;25520;25;DOUBS;1
25488;;Rennes-sur-Loue;RENNES-SUR-LOUE;25440;25;DOUBS;1
25489;;Reugney;REUGNEY;25330;25;DOUBS;1
25490;;Rigney;RIGNEY;25640;25;DOUBS;1
25491;;Rignosot;RIGNOSOT;25640;25;DOUBS;1
25492;;Rillans;RILLANS;25110;25;DOUBS;1
25493;La;Rivière-Drugeon;RIVIERE-DRUGEON;25560;25;DOUBS;1
25494;;Rochejean;ROCHEJEAN;25370;25;DOUBS;1
25495;;Roche-lez-Beaupré;ROCHE-LEZ-BEAUPRE;25220;25;DOUBS;1
25496;;Roche-lès-Clerval;ROCHE-LES-CLERVAL;25340;25;DOUBS;1
25497;;Roches-lès-Blamont;ROCHES-LES-BLAMONT;25310;25;DOUBS;1
25498;;Rognon;ROGNON;25680;25;DOUBS;1
25499;;Romain;ROMAIN;25680;25;DOUBS;1
25500;;Ronchaux;RONCHAUX;25440;25;DOUBS;1
25501;;Rondefontaine;RONDEFONTAINE;25240;25;DOUBS;1
25502;;Roset-Fluans;ROSET-FLUANS;25410;25;DOUBS;1
25503;;Rosières-sur-Barbèche;ROSIERES-SUR-BARBECHE;25190;25;DOUBS;1
25504;;Rosureux;ROSUREUX;25380;25;DOUBS;1
25505;;Rougemont;ROUGEMONT;25680;25;DOUBS;1
25506;;Rougemontot;ROUGEMONTOT;25640;25;DOUBS;1
25507;;Rouhe;ROUHE;25440;25;DOUBS;1
25508;;Roulans;ROULANS;25640;25;DOUBS;1
25509;;Routelle;ROUTELLE;25410;25;DOUBS;1
25510;;Ruffey-le-Château;RUFFEY-LE-CHATEAU;25170;25;DOUBS;1
25511;;Rurey;RUREY;25290;25;DOUBS;1
25512;Le;Russey;RUSSEY;25210;25;DOUBS;1
25513;;Sainte-Anne;SAINTE-ANNE;25270;25;DOUBS;1
25514;;Saint-Antoine;SAINT-ANTOINE;25370;25;DOUBS;1
25515;;Sainte-Colombe;SAINTE-COLOMBE;25300;25;DOUBS;1
25516;;Saint-Georges-Armont;SAINT-GEORGES-ARMONT;25340;25;DOUBS;1
25517;;Saint-Gorgon-Main;SAINT-GORGON-MAIN;25520;25;DOUBS;1
25518;;Saint-Hilaire;SAINT-HILAIRE;25640;25;DOUBS;1
25519;;Saint-Hippolyte;SAINT-HIPPOLYTE;25190;25;DOUBS;1
25520;;Saint-Juan;SAINT-JUAN;25360;25;DOUBS;1
25521;;Saint-Julien-lès-Montbéliard;SAINT-JULIEN-LES-MONTBELIARD;25550;25;DOUBS;1
25522;;Saint-Julien-lès-Russey;SAINT-JULIEN-LES-RUSSEY;25210;25;DOUBS;1
25523;;Sainte-Marie;SAINTE-MARIE;25113;25;DOUBS;1
25524;;Saint-Maurice-Colombier;SAINT-MAURICE-COLOMBIER;25260;25;DOUBS;1
25525;;Saint-Point-Lac;SAINT-POINT-LAC;25160;25;DOUBS;1
25526;;Sainte-Suzanne;SAINTE-SUZANNE;25630;25;DOUBS;1
25527;;Saint-Vit;SAINT-VIT;25410;25;DOUBS;1
25528;;Samson;SAMSON;25440;25;DOUBS;1
25529;;Sancey-le-Grand;SANCEY-LE-GRAND;25430;25;DOUBS;1
25530;;Sancey-le-Long;SANCEY-LE-LONG;25430;25;DOUBS;1
25531;;Santoche;SANTOCHE;25340;25;DOUBS;1
25532;;Saône;SAONE;25660;25;DOUBS;1
25533;;Saraz;SARAZ;25330;25;DOUBS;1
25534;;Sarrageois;SARRAGEOIS;25240;25;DOUBS;1
25535;;Saules;SAULES;25580;25;DOUBS;1
25536;;Sauvagney;SAUVAGNEY;25170;25;DOUBS;1
25537;;Scey-Maisières;SCEY-MAISIERES;25290;25;DOUBS;1
25538;;Séchin;SECHIN;25110;25;DOUBS;1
25539;;Seloncourt;SELONCOURT;25230;25;DOUBS;1
25540;;Semondans;SEMONDANS;25750;25;DOUBS;1
25541;;Septfontaines;SEPTFONTAINES;25270;25;DOUBS;1
25542;;Serre-les-Sapins;SERRE-LES-SAPINS;25770;25;DOUBS;1
25544;;Servin;SERVIN;25430;25;DOUBS;1
25545;;Silley-Amancey;SILLEY-AMANCEY;25330;25;DOUBS;1
25546;;Silley-Bléfond;SILLEY-BLEFOND;25110;25;DOUBS;1
25547;;Sochaux;SOCHAUX;25600;25;DOUBS;1
25548;;Solemont;SOLEMONT;25190;25;DOUBS;1
25549;;Sombacour;SOMBACOUR;25520;25;DOUBS;1
25550;La;Sommette;SOMMETTE;25510;25;DOUBS;1
25551;;Soulce-Cernay;SOULCE-CERNAY;25190;25;DOUBS;1
25552;;Sourans;SOURANS;25250;25;DOUBS;1
25553;;Soye;SOYE;25250;25;DOUBS;1
25554;;Surmont;SURMONT;25380;25;DOUBS;1
25555;;Taillecourt;TAILLECOURT;25400;25;DOUBS;1
25556;;Tallans;TALLANS;25680;25;DOUBS;1
25557;;Tallenay;TALLENAY;25870;25;DOUBS;1
25558;;Tarcenay;TARCENAY;25620;25;DOUBS;1
25559;;Thiébouhans;THIEBOUHANS;25470;25;DOUBS;1
25560;;Thise;THISE;25220;25;DOUBS;1
25561;;Thoraise;THORAISE;25320;25;DOUBS;1
25562;;Thulay;THULAY;25310;25;DOUBS;1
25563;;Thurey-le-Mont;THUREY-LE-MONT;25870;25;DOUBS;1
25564;;Torpes;TORPES;25320;25;DOUBS;1
25565;;Touillon-et-Loutelet;TOUILLON-ET-LOUTELET;25370;25;DOUBS;1
25566;La;Tour-de-Sçay;TOUR-DE-SCAY;25640;25;DOUBS;1
25567;;Tournans;TOURNANS;25680;25;DOUBS;1
25569;;Trépot;TREPOT;25620;25;DOUBS;1
25570;;Tressandans;TRESSANDANS;25680;25;DOUBS;1
25571;;Trévillers;TREVILLERS;25470;25;DOUBS;1
25572;;Trouvans;TROUVANS;25680;25;DOUBS;1
25573;;Urtière;URTIERE;25470;25;DOUBS;1
25574;;Uzelle;UZELLE;25340;25;DOUBS;1
25575;;Vaire-Arcier;VAIRE-ARCIER;25220;25;DOUBS;1
25576;;Vaire-le-Petit;VAIRE-LE-PETIT;25220;25;DOUBS;1
25578;;Valdahon;VALDAHON;25800;25;DOUBS;1
25579;;Val-de-Roulans;VAL-DE-ROULANS;25640;25;DOUBS;1
25580;;Valentigney;VALENTIGNEY;25700;25;DOUBS;1
25582;;Valleroy;VALLEROY;25870;25;DOUBS;1
25583;;Valonne;VALONNE;25190;25;DOUBS;1
25584;;Valoreille;VALOREILLE;25190;25;DOUBS;1
25585;;Vanclans;VANCLANS;25580;25;DOUBS;1
25586;;Vandoncourt;VANDONCOURT;25230;25;DOUBS;1
25587;;Vauchamps;VAUCHAMPS;25360;25;DOUBS;1
25588;;Vaucluse;VAUCLUSE;25380;25;DOUBS;1
25589;;Vauclusotte;VAUCLUSOTTE;25380;25;DOUBS;1
25590;;Vaudrivillers;VAUDRIVILLERS;25360;25;DOUBS;1
25591;;Vaufrey;VAUFREY;25190;25;DOUBS;1
25592;;Vaux-et-Chantegrue;VAUX-ET-CHANTEGRUE;25160;25;DOUBS;1
25593;;Vaux-les-Prés;VAUX-LES-PRES;25770;25;DOUBS;1
25594;;Velesmes-Essarts;VELESMES-ESSARTS;25410;25;DOUBS;1
25595;;Vellerot-lès-Belvoir;VELLEROT-LES-BELVOIR;25430;25;DOUBS;1
25596;;Vellerot-lès-Vercel;VELLEROT-LES-VERCEL;25530;25;DOUBS;1
25597;;Vellevans;VELLEVANS;25430;25;DOUBS;1
25598;;Venise;VENISE;25870;25;DOUBS;1
25599;;Vennans;VENNANS;25640;25;DOUBS;1
25600;;Vennes;VENNES;25390;25;DOUBS;1
25601;;Vercel-Villedieu-le-Camp;VERCEL-VILLEDIEU-LE-CAMP;25530;25;DOUBS;1
25602;;Vergranne;VERGRANNE;25110;25;DOUBS;1
25604;;Verne;VERNE;25110;25;DOUBS;1
25605;;Vernierfontaine;VERNIERFONTAINE;25580;25;DOUBS;1
25607;;Vernois-lès-Belvoir;VERNOIS-LES-BELVOIR;25430;25;DOUBS;1
25608;Le;Vernoy;VERNOY;25750;25;DOUBS;1
25609;;Verrières-de-Joux;VERRIERES-DE-JOUX;25300;25;DOUBS;1
25610;;Verrières-du-Grosbois;VERRIERES-DU-GROSBOIS;25580;25;DOUBS;1
25611;La;Vèze;VEZE;25660;25;DOUBS;1
25612;;Vieilley;VIEILLEY;25870;25;DOUBS;1
25613;;Viéthorey;VIETHOREY;25340;25;DOUBS;1
25614;;Vieux-Charmont;VIEUX-CHARMONT;25600;25;DOUBS;1
25615;;Villars-lès-Blamont;VILLARS-LES-BLAMONT;25310;25;DOUBS;1
25616;;Villars-Saint-Georges;VILLARS-SAINT-GEORGES;25410;25;DOUBS;1
25617;;Villars-sous-Dampjoux;VILLARS-SOUS-DAMPJOUX;25190;25;DOUBS;1
25618;;Villars-sous-Écot;VILLARS-SOUS-ECOT;25150;25;DOUBS;1
25619;Les;Villedieu;VILLEDIEU;25240;25;DOUBS;1
25620;;Ville-du-Pont;VILLE-DU-PONT;25650;25;DOUBS;1
25621;;Villeneuve-d'Amont;VILLENEUVE-D'AMONT;25270;25;DOUBS;1
25622;;Villers-Buzon;VILLERS-BUZON;25170;25;DOUBS;1
25623;;Villers-Chief;VILLERS-CHIEF;25530;25;DOUBS;1
25624;;Villers-Grélot;VILLERS-GRELOT;25640;25;DOUBS;1
25625;;Villers-la-Combe;VILLERS-LA-COMBE;25510;25;DOUBS;1
25626;;Villers-Saint-Martin;VILLERS-SAINT-MARTIN;25110;25;DOUBS;1
25627;;Villers-sous-Chalamont;VILLERS-SOUS-CHALAMONT;25270;25;DOUBS;1
25628;;Villers-sous-Montrond;VILLERS-SOUS-MONTROND;25620;25;DOUBS;1
25629;;Voillans;VOILLANS;25110;25;DOUBS;1
25630;;Voires;VOIRES;25580;25;DOUBS;1
25631;;Vorges-les-Pins;VORGES-LES-PINS;25320;25;DOUBS;1
25632;;Voujeaucourt;VOUJEAUCOURT;25420;25;DOUBS;1
25633;;Vuillafans;VUILLAFANS;25840;25;DOUBS;1
25634;;Vuillecin;VUILLECIN;25300;25;DOUBS;1
25635;;Vyt-lès-Belvoir;VYT-LES-BELVOIR;25430;25;DOUBS;1
26001;;Aix-en-Diois;AIX-EN-DIOIS;26150;26;DROME;1
26002;;Albon;ALBON;26140;26;DROME;1
26003;;Aleyrac;ALEYRAC;26770;26;DROME;1
26004;;Alixan;ALIXAN;26300;26;DROME;1
26005;;Allan;ALLAN;26780;26;DROME;1
26006;;Allex;ALLEX;26400;26;DROME;1
26007;;Ambonil;AMBONIL;26800;26;DROME;1
26008;;Ancône;ANCONE;26200;26;DROME;1
26009;;Andancette;ANDANCETTE;26140;26;DROME;1
26010;;Anneyron;ANNEYRON;26140;26;DROME;1
26011;;Aouste-sur-Sye;AOUSTE-SUR-SYE;26400;26;DROME;1
26012;;Arnayon;ARNAYON;26470;26;DROME;1
26013;;Arpavon;ARPAVON;26110;26;DROME;1
26014;;Arthémonay;ARTHEMONAY;26260;26;DROME;1
26015;;Aubenasson;AUBENASSON;26340;26;DROME;1
26016;;Aubres;AUBRES;26110;26;DROME;1
26017;;Aucelon;AUCELON;26340;26;DROME;1
26018;;Aulan;AULAN;26570;26;DROME;1
26019;;Aurel;AUREL;26340;26;DROME;1
26020;La;Répara-Auriples;REPARA-AURIPLES;26400;26;DROME;1
26021;;Autichamp;AUTICHAMP;26400;26;DROME;1
26022;;Ballons;BALLONS;26560;26;DROME;1
26023;;Barbières;BARBIERES;26300;26;DROME;1
26024;;Barcelonne;BARCELONNE;26120;26;DROME;1
26025;;Barnave;BARNAVE;26310;26;DROME;1
26026;;Barret-de-Lioure;BARRET-DE-LIOURE;26570;26;DROME;1
26027;;Barsac;BARSAC;26150;26;DROME;1
26028;;Bathernay;BATHERNAY;26260;26;DROME;1
26030;La;Bâtie-des-Fonds;BATIE-DES-FONDS;26310;26;DROME;1
26031;La;Bâtie-Rolland;BATIE-ROLLAND;26160;26;DROME;1
26032;La;Baume-Cornillane;BAUME-CORNILLANE;26120;26;DROME;1
26033;La;Baume-de-Transit;BAUME-DE-TRANSIT;26790;26;DROME;1
26034;La;Baume-d'Hostun;BAUME-D'HOSTUN;26730;26;DROME;1
26035;;Beaufort-sur-Gervanne;BEAUFORT-SUR-GERVANNE;26400;26;DROME;1
26036;;Beaumont-en-Diois;BEAUMONT-EN-DIOIS;26310;26;DROME;1
26037;;Beaumont-lès-Valence;BEAUMONT-LES-VALENCE;26760;26;DROME;1
26038;;Beaumont-Monteux;BEAUMONT-MONTEUX;26600;26;DROME;1
26039;;Beauregard-Baret;BEAUREGARD-BARET;26300;26;DROME;1
26040;;Beaurières;BEAURIERES;26310;26;DROME;1
26041;;Beausemblant;BEAUSEMBLANT;26240;26;DROME;1
26042;;Beauvallon;BEAUVALLON;26800;26;DROME;1
26043;;Beauvoisin;BEAUVOISIN;26170;26;DROME;1
26045;La;Bégude-de-Mazenc;BEGUDE-DE-MAZENC;26160;26;DROME;1
26046;;Bellecombe-Tarendol;BELLECOMBE-TARENDOL;26110;26;DROME;1
26047;;Bellegarde-en-Diois;BELLEGARDE-EN-DIOIS;26470;26;DROME;1
26048;;Bénivay-Ollon;BENIVAY-OLLON;26170;26;DROME;1
26049;;Bésayes;BESAYES;26300;26;DROME;1
26050;;Bésignan;BESIGNAN;26110;26;DROME;1
26051;;Bézaudun-sur-Bîne;BEZAUDUN-SUR-BINE;26460;26;DROME;1
26052;;Bonlieu-sur-Roubion;BONLIEU-SUR-ROUBION;26160;26;DROME;1
26054;;Bouchet;BOUCHET;26790;26;DROME;1
26055;;Boulc;BOULC;26410;26;DROME;1
26056;;Bourdeaux;BOURDEAUX;26460;26;DROME;1
26057;;Bourg-de-Péage;BOURG-DE-PEAGE;26300;26;DROME;1
26058;;Bourg-lès-Valence;BOURG-LES-VALENCE;26500;26;DROME;1
26059;;Bouvante;BOUVANTE;26190;26;DROME;1
26060;;Bouvières;BOUVIERES;26460;26;DROME;1
26061;;Bren;BREN;26260;26;DROME;1
26062;;Brette;BRETTE;26340;26;DROME;1
26063;;Buis-les-Baronnies;BUIS-LES-BARONNIES;26170;26;DROME;1
26064;;Chabeuil;CHABEUIL;26120;26;DROME;1
26065;;Chabrillan;CHABRILLAN;26400;26;DROME;1
26066;Le;Chaffal;CHAFFAL;26190;26;DROME;1
26067;;Chalancon;CHALANCON;26340;26;DROME;1
26068;Le;Chalon;CHALON;26350;26;DROME;1
26069;;Chamaloc;CHAMALOC;26150;26;DROME;1
26070;;Chamaret;CHAMARET;26230;26;DROME;1
26071;;Chanos-Curson;CHANOS-CURSON;26600;26;DROME;1
26072;;Chantemerle-les-Blés;CHANTEMERLE-LES-BLES;26600;26;DROME;1
26073;;Chantemerle-lès-Grignan;CHANTEMERLE-LES-GRIGNAN;26230;26;DROME;1
26074;La;Chapelle-en-Vercors;CHAPELLE-EN-VERCORS;26420;26;DROME;1
26075;La;Charce;CHARCE;26470;26;DROME;1
26076;;Charens;CHARENS;26310;26;DROME;1
26077;;Charmes-sur-l'Herbasse;CHARMES-SUR-L'HERBASSE;26260;26;DROME;1
26078;;Charols;CHAROLS;26450;26;DROME;1
26079;;Charpey;CHARPEY;26300;26;DROME;1
26080;;Chastel-Arnaud;CHASTEL-ARNAUD;26340;26;DROME;1
26081;;Châteaudouble;CHATEAUDOUBLE;26120;26;DROME;1
26082;;Châteauneuf-de-Bordette;CHATEAUNEUF-DE-BORDETTE;26110;26;DROME;1
26083;;Châteauneuf-de-Galaure;CHATEAUNEUF-DE-GALAURE;26330;26;DROME;1
26084;;Châteauneuf-sur-Isère;CHATEAUNEUF-SUR-ISERE;26300;26;DROME;1
26085;;Châteauneuf-du-Rhône;CHATEAUNEUF-DU-RHONE;26780;26;DROME;1
26086;;Châtillon-en-Diois;CHATILLON-EN-DIOIS;26410;26;DROME;1
26087;;Châtillon-Saint-Jean;CHATILLON-SAINT-JEAN;26750;26;DROME;1
26088;;Chatuzange-le-Goubet;CHATUZANGE-LE-GOUBET;26300;26;DROME;1
26089;;Chaudebonne;CHAUDEBONNE;26110;26;DROME;1
26090;La;Chaudière;CHAUDIERE;26340;26;DROME;1
26091;;Chauvac-Laux-Montaux;CHAUVAC-LAUX-MONTAUX;26510;26;DROME;1
26092;;Chavannes;CHAVANNES;26260;26;DROME;1
26093;;Clansayes;CLANSAYES;26130;26;DROME;1
26094;;Claveyson;CLAVEYSON;26240;26;DROME;1
26095;;Cléon-d'Andran;CLEON-D'ANDRAN;26450;26;DROME;1
26096;;Clérieux;CLERIEUX;26260;26;DROME;1
26097;;Cliousclat;CLIOUSCLAT;26270;26;DROME;1
26098;;Cobonne;COBONNE;26400;26;DROME;1
26099;;Colonzelle;COLONZELLE;26230;26;DROME;1
26100;;Combovin;COMBOVIN;26120;26;DROME;1
26101;;Comps;COMPS;26220;26;DROME;1
26102;;Condillac;CONDILLAC;26740;26;DROME;1
26103;;Condorcet;CONDORCET;26110;26;DROME;1
26104;;Cornillac;CORNILLAC;26510;26;DROME;1
26105;;Cornillon-sur-l'Oule;CORNILLON-SUR-L'OULE;26510;26;DROME;1
26106;La;Coucourde;COUCOURDE;26740;26;DROME;1
26107;;Crépol;CREPOL;26350;26;DROME;1
26108;;Crest;CREST;26400;26;DROME;1
26110;;Crozes-Hermitage;CROZES-HERMITAGE;26600;26;DROME;1
26111;;Crupies;CRUPIES;26460;26;DROME;1
26112;;Curnier;CURNIER;26110;26;DROME;1
26113;;Die;DIE;26150;26;DROME;1
26114;;Dieulefit;DIEULEFIT;26220;26;DROME;1
26115;;Divajeu;DIVAJEU;26400;26;DROME;1
26116;;Donzère;DONZERE;26290;26;DROME;1
26117;;Échevis;ECHEVIS;26190;26;DROME;1
26118;;Épinouze;EPINOUZE;26210;26;DROME;1
26119;;Érôme;EROME;26600;26;DROME;1
26121;;Espeluche;ESPELUCHE;26780;26;DROME;1
26122;;Espenel;ESPENEL;26340;26;DROME;1
26123;;Establet;ESTABLET;26470;26;DROME;1
26124;;Étoile-sur-Rhône;ETOILE-SUR-RHONE;26800;26;DROME;1
26125;;Eurre;EURRE;26400;26;DROME;1
26126;;Eygalayes;EYGALAYES;26560;26;DROME;1
26127;;Eygaliers;EYGALIERS;26170;26;DROME;1
26128;;Eygluy-Escoulin;EYGLUY-ESCOULIN;26400;26;DROME;1
26129;;Eymeux;EYMEUX;26730;26;DROME;1
26130;;Eyroles;EYROLES;26110;26;DROME;1
26131;;Eyzahut;EYZAHUT;26160;26;DROME;1
26133;;Fay-le-Clos;FAY-LE-CLOS;26240;26;DROME;1
26134;;Félines-sur-Rimandoule;FELINES-SUR-RIMANDOULE;26160;26;DROME;1
26135;;Ferrassières;FERRASSIERES;26570;26;DROME;1
26136;;Val-Maravel;VAL-MARAVEL;26310;26;DROME;1
26137;;Francillon-sur-Roubion;FRANCILLON-SUR-ROUBION;26400;26;DROME;1
26138;La;Garde-Adhémar;GARDE-ADHEMAR;26700;26;DROME;1
26139;;Génissieux;GENISSIEUX;26750;26;DROME;1
26140;;Geyssans;GEYSSANS;26750;26;DROME;1
26141;;Gigors-et-Lozeron;GIGORS-ET-LOZERON;26400;26;DROME;1
26142;;Glandage;GLANDAGE;26410;26;DROME;1
26143;Le;Grand-Serre;GRAND-SERRE;26530;26;DROME;1
26144;;Grane;GRANE;26400;26;DROME;1
26145;Les;Granges-Gontardes;GRANGES-GONTARDES;26290;26;DROME;1
26146;;Grignan;GRIGNAN;26230;26;DROME;1
26147;;Gumiane;GUMIANE;26470;26;DROME;1
26148;;Hauterives;HAUTERIVES;26390;26;DROME;1
26149;;Hostun;HOSTUN;26730;26;DROME;1
26150;;Izon-la-Bruisse;IZON-LA-BRUISSE;26560;26;DROME;1
26152;;Jonchères;JONCHERES;26310;26;DROME;1
26153;;Laborel;LABOREL;26560;26;DROME;1
26154;;Lachau;LACHAU;26560;26;DROME;1
26155;;Lapeyrouse-Mornay;LAPEYROUSE-MORNAY;26210;26;DROME;1
26156;;Larnage;LARNAGE;26600;26;DROME;1
26157;La;Laupie;LAUPIE;26740;26;DROME;1
26159;;Laval-d'Aix;LAVAL-D'AIX;26150;26;DROME;1
26160;;Laveyron;LAVEYRON;26240;26;DROME;1
26161;;Lemps;LEMPS;26510;26;DROME;1
26162;;Lens-Lestang;LENS-LESTANG;26210;26;DROME;1
26163;;Léoncel;LEONCEL;26190;26;DROME;1
26164;;Lesches-en-Diois;LESCHES-EN-DIOIS;26310;26;DROME;1
26165;;Livron-sur-Drôme;LIVRON-SUR-DROME;26250;26;DROME;1
26166;;Loriol-sur-Drôme;LORIOL-SUR-DROME;26270;26;DROME;1
26167;;Luc-en-Diois;LUC-EN-DIOIS;26310;26;DROME;1
26168;;Lus-la-Croix-Haute;LUS-LA-CROIX-HAUTE;26620;26;DROME;1
26169;;Malataverne;MALATAVERNE;26780;26;DROME;1
26170;;Malissard;MALISSARD;26120;26;DROME;1
26171;;Manas;MANAS;26160;26;DROME;1
26172;;Manthes;MANTHES;26210;26;DROME;1
26173;;Marches;MARCHES;26300;26;DROME;1
26174;;Margès;MARGES;26260;26;DROME;1
26175;;Marignac-en-Diois;MARIGNAC-EN-DIOIS;26150;26;DROME;1
26176;;Marsanne;MARSANNE;26740;26;DROME;1
26177;;Marsaz;MARSAZ;26260;26;DROME;1
26178;;Menglon;MENGLON;26410;26;DROME;1
26179;;Mercurol;MERCUROL;26600;26;DROME;1
26180;;Mérindol-les-Oliviers;MERINDOL-LES-OLIVIERS;26170;26;DROME;1
26181;;Mévouillon;MEVOUILLON;26560;26;DROME;1
26182;;Mirabel-aux-Baronnies;MIRABEL-AUX-BARONNIES;26110;26;DROME;1
26183;;Mirabel-et-Blacons;MIRABEL-ET-BLACONS;26400;26;DROME;1
26184;;Miribel;MIRIBEL;26350;26;DROME;1
26185;;Mirmande;MIRMANDE;26270;26;DROME;1
26186;;Miscon;MISCON;26310;26;DROME;1
26187;;Molières-Glandaz;MOLIERES-GLANDAZ;26150;26;DROME;1
26188;;Mollans-sur-Ouvèze;MOLLANS-SUR-OUVEZE;26170;26;DROME;1
26189;;Montauban-sur-l'Ouvèze;MONTAUBAN-SUR-L'OUVEZE;26170;26;DROME;1
26190;;Montaulieu;MONTAULIEU;26110;26;DROME;1
26191;;Montboucher-sur-Jabron;MONTBOUCHER-SUR-JABRON;26740;26;DROME;1
26192;;Montbrison-sur-Lez;MONTBRISON-SUR-LEZ;26770;26;DROME;1
26193;;Montbrun-les-Bains;MONTBRUN-LES-BAINS;26570;26;DROME;1
26194;;Montchenu;MONTCHENU;26350;26;DROME;1
26195;;Montclar-sur-Gervanne;MONTCLAR-SUR-GERVANNE;26400;26;DROME;1
26196;;Montéléger;MONTELEGER;26760;26;DROME;1
26197;;Montélier;MONTELIER;26120;26;DROME;1
26198;;Montélimar;MONTELIMAR;26200;26;DROME;1
26199;;Montferrand-la-Fare;MONTFERRAND-LA-FARE;26510;26;DROME;1
26200;;Montfroc;MONTFROC;26560;26;DROME;1
26201;;Montguers;MONTGUERS;26170;26;DROME;1
26202;;Montjoux;MONTJOUX;26220;26;DROME;1
26203;;Montjoyer;MONTJOYER;26230;26;DROME;1
26204;;Montlaur-en-Diois;MONTLAUR-EN-DIOIS;26310;26;DROME;1
26205;;Montmaur-en-Diois;MONTMAUR-EN-DIOIS;26150;26;DROME;1
26206;;Montmeyran;MONTMEYRAN;26120;26;DROME;1
26207;;Montmiral;MONTMIRAL;26750;26;DROME;1
26208;;Montoison;MONTOISON;26800;26;DROME;1
26209;;Montréal-les-Sources;MONTREAL-LES-SOURCES;26510;26;DROME;1
26210;;Montrigaud;MONTRIGAUD;26350;26;DROME;1
26211;;Montségur-sur-Lauzon;MONTSEGUR-SUR-LAUZON;26130;26;DROME;1
26212;;Montvendre;MONTVENDRE;26120;26;DROME;1
26213;;Moras-en-Valloire;MORAS-EN-VALLOIRE;26210;26;DROME;1
26214;;Mornans;MORNANS;26460;26;DROME;1
26215;La;Motte-Chalancon;MOTTE-CHALANCON;26470;26;DROME;1
26216;La;Motte-de-Galaure;MOTTE-DE-GALAURE;26240;26;DROME;1
26217;La;Motte-Fanjas;MOTTE-FANJAS;26190;26;DROME;1
26218;;Mours-Saint-Eusèbe;MOURS-SAINT-EUSEBE;26540;26;DROME;1
26219;;Mureils;MUREILS;26240;26;DROME;1
26220;;Nyons;NYONS;26110;26;DROME;1
26221;;Omblèze;OMBLEZE;26400;26;DROME;1
26222;;Orcinas;ORCINAS;26220;26;DROME;1
26223;;Oriol-en-Royans;ORIOL-EN-ROYANS;26190;26;DROME;1
26224;;Ourches;OURCHES;26120;26;DROME;1
26225;;Parnans;PARNANS;26750;26;DROME;1
26226;Le;Pègue;PEGUE;26770;26;DROME;1
26227;;Pelonne;PELONNE;26510;26;DROME;1
26228;;Pennes-le-Sec;PENNES-LE-SEC;26340;26;DROME;1
26229;La;Penne-sur-l'Ouvèze;PENNE-SUR-L'OUVEZE;26170;26;DROME;1
26231;;Peyrins;PEYRINS;26380;26;DROME;1
26232;;Peyrus;PEYRUS;26120;26;DROME;1
26233;;Piégon;PIEGON;26110;26;DROME;1
26234;;Piégros-la-Clastre;PIEGROS-LA-CLASTRE;26400;26;DROME;1
26235;;Pierrelatte;PIERRELATTE;26700;26;DROME;1
26236;;Pierrelongue;PIERRELONGUE;26170;26;DROME;1
26238;Les;Pilles;PILLES;26110;26;DROME;1
26239;;Plaisians;PLAISIANS;26170;26;DROME;1
26240;;Plan-de-Baix;PLAN-DE-BAIX;26400;26;DROME;1
26241;Le;Poët-Célard;POET-CELARD;26460;26;DROME;1
26242;Le;Poët-en-Percip;POET-EN-PERCIP;26170;26;DROME;1
26243;Le;Poët-Laval;POET-LAVAL;26160;26;DROME;1
26244;Le;Poët-Sigillat;POET-SIGILLAT;26110;26;DROME;1
26245;;Pommerol;POMMEROL;26470;26;DROME;1
26246;;Ponet-et-Saint-Auban;PONET-ET-SAINT-AUBAN;26150;26;DROME;1
26247;;Ponsas;PONSAS;26240;26;DROME;1
26248;;Pontaix;PONTAIX;26150;26;DROME;1
26249;;Pont-de-Barret;PONT-DE-BARRET;26160;26;DROME;1
26250;;Pont-de-l'Isère;PONT-DE-L'ISERE;26600;26;DROME;1
26251;;Portes-en-Valdaine;PORTES-EN-VALDAINE;26160;26;DROME;1
26252;;Portes-lès-Valence;PORTES-LES-VALENCE;26800;26;DROME;1
26253;;Poyols;POYOLS;26310;26;DROME;1
26254;;Pradelle;PRADELLE;26340;26;DROME;1
26255;Les;Prés;PRES;26310;26;DROME;1
26256;;Propiac;PROPIAC;26170;26;DROME;1
26257;;Puygiron;PUYGIRON;26160;26;DROME;1
26258;;Puy-Saint-Martin;PUY-SAINT-MARTIN;26450;26;DROME;1
26259;;Ratières;RATIERES;26330;26;DROME;1
26261;;Réauville;REAUVILLE;26230;26;DROME;1
26262;;Recoubeau-Jansac;RECOUBEAU-JANSAC;26310;26;DROME;1
26263;;Reilhanette;REILHANETTE;26570;26;DROME;1
26264;;Rémuzat;REMUZAT;26510;26;DROME;1
26266;;Rimon-et-Savel;RIMON-ET-SAVEL;26340;26;DROME;1
26267;;Rioms;RIOMS;26170;26;DROME;1
26268;;Rochebaudin;ROCHEBAUDIN;26160;26;DROME;1
26269;;Rochebrune;ROCHEBRUNE;26110;26;DROME;1
26270;;Rochechinard;ROCHECHINARD;26190;26;DROME;1
26271;La;Roche-de-Glun;ROCHE-DE-GLUN;26600;26;DROME;1
26272;;Rochefort-en-Valdaine;ROCHEFORT-EN-VALDAINE;26160;26;DROME;1
26273;;Rochefort-Samson;ROCHEFORT-SAMSON;26300;26;DROME;1
26274;;Rochefourchat;ROCHEFOURCHAT;26340;26;DROME;1
26275;;Rochegude;ROCHEGUDE;26790;26;DROME;1
26276;;Roche-Saint-Secret-Béconne;ROCHE-SAINT-SECRET-BECONNE;26770;26;DROME;1
26277;La;Roche-sur-Grane;ROCHE-SUR-GRANE;26400;26;DROME;1
26278;La;Roche-sur-le-Buis;ROCHE-SUR-LE-BUIS;26170;26;DROME;1
26279;La;Rochette-du-Buis;ROCHETTE-DU-BUIS;26170;26;DROME;1
26281;;Romans-sur-Isère;ROMANS-SUR-ISERE;26100;26;DROME;1
26282;;Romeyer;ROMEYER;26150;26;DROME;1
26283;;Rottier;ROTTIER;26470;26;DROME;1
26284;;Roussas;ROUSSAS;26230;26;DROME;1
26285;;Rousset-les-Vignes;ROUSSET-LES-VIGNES;26770;26;DROME;1
26286;;Roussieux;ROUSSIEUX;26510;26;DROME;1
26287;;Roynac;ROYNAC;26450;26;DROME;1
26288;;Sahune;SAHUNE;26510;26;DROME;1
26289;;Saillans;SAILLANS;26340;26;DROME;1
26290;;Saint-Agnan-en-Vercors;SAINT-AGNAN-EN-VERCORS;26420;26;DROME;1
26291;;Saint-Andéol;SAINT-ANDEOL;26150;26;DROME;1
26292;;Saint-Auban-sur-l'Ouvèze;SAINT-AUBAN-SUR-L'OUVEZE;26170;26;DROME;1
26293;;Saint-Avit;SAINT-AVIT;26330;26;DROME;1
26294;;Saint-Bardoux;SAINT-BARDOUX;26260;26;DROME;1
26295;;Saint-Barthélemy-de-Vals;SAINT-BARTHELEMY-DE-VALS;26240;26;DROME;1
26296;;Saint-Benoit-en-Diois;SAINT-BENOIT-EN-DIOIS;26340;26;DROME;1
26297;;Saint-Bonnet-de-Valclérieux;SAINT-BONNET-DE-VALCLERIEUX;26350;26;DROME;1
26298;;Saint-Christophe-et-le-Laris;SAINT-CHRISTOPHE-ET-LE-LARIS;26350;26;DROME;1
26299;;Sainte-Croix;SAINTE-CROIX;26150;26;DROME;1
26300;;Saint-Dizier-en-Diois;SAINT-DIZIER-EN-DIOIS;26310;26;DROME;1
26301;;Saint-Donat-sur-l'Herbasse;SAINT-DONAT-SUR-L'HERBASSE;26260;26;DROME;1
26302;;Sainte-Eulalie-en-Royans;SAINTE-EULALIE-EN-ROYANS;26190;26;DROME;1
26303;;Sainte-Euphémie-sur-Ouvèze;SAINTE-EUPHEMIE-SUR-OUVEZE;26170;26;DROME;1
26304;;Saint-Ferréol-Trente-Pas;SAINT-FERREOL-TRENTE-PAS;26110;26;DROME;1
26305;;Saint-Gervais-sur-Roubion;SAINT-GERVAIS-SUR-ROUBION;26160;26;DROME;1
26306;;Sainte-Jalle;SAINTE-JALLE;26110;26;DROME;1
26307;;Saint-Jean-en-Royans;SAINT-JEAN-EN-ROYANS;26190;26;DROME;1
26308;;Saint-Julien-en-Quint;SAINT-JULIEN-EN-QUINT;26150;26;DROME;1
26309;;Saint-Julien-en-Vercors;SAINT-JULIEN-EN-VERCORS;26420;26;DROME;1
26310;;Saint-Laurent-d'Onay;SAINT-LAURENT-D'ONAY;26350;26;DROME;1
26311;;Saint-Laurent-en-Royans;SAINT-LAURENT-EN-ROYANS;26190;26;DROME;1
26312;;Saint-Marcel-lès-Sauzet;SAINT-MARCEL-LES-SAUZET;26740;26;DROME;1
26313;;Saint-Marcel-lès-Valence;SAINT-MARCEL-LES-VALENCE;26320;26;DROME;1
26314;;Saint-Martin-d'Août;SAINT-MARTIN-D'AOUT;26330;26;DROME;1
26315;;Saint-Martin-en-Vercors;SAINT-MARTIN-EN-VERCORS;26420;26;DROME;1
26316;;Saint-Martin-le-Colonel;SAINT-MARTIN-LE-COLONEL;26190;26;DROME;1
26317;;Saint-Maurice-sur-Eygues;SAINT-MAURICE-SUR-EYGUES;26110;26;DROME;1
26318;;Saint-May;SAINT-MAY;26510;26;DROME;1
26319;;Saint-Michel-sur-Savasse;SAINT-MICHEL-SUR-SAVASSE;26750;26;DROME;1
26320;;Saint-Nazaire-en-Royans;SAINT-NAZAIRE-EN-ROYANS;26190;26;DROME;1
26321;;Saint-Nazaire-le-Désert;SAINT-NAZAIRE-LE-DESERT;26340;26;DROME;1
26322;;Saint-Pantaléon-les-Vignes;SAINT-PANTALEON-LES-VIGNES;26770;26;DROME;1
26323;;Saint-Paul-lès-Romans;SAINT-PAUL-LES-ROMANS;26750;26;DROME;1
26324;;Saint-Paul-Trois-Châteaux;SAINT-PAUL-TROIS-CHATEAUX;26130;26;DROME;1
26325;;Saint-Rambert-d'Albon;SAINT-RAMBERT-D'ALBON;26140;26;DROME;1
26326;;Saint-Restitut;SAINT-RESTITUT;26130;26;DROME;1
26327;;Saint-Roman;SAINT-ROMAN;26410;26;DROME;1
26328;;Saint-Sauveur-en-Diois;SAINT-SAUVEUR-EN-DIOIS;26340;26;DROME;1
26329;;Saint-Sauveur-Gouvernet;SAINT-SAUVEUR-GOUVERNET;26110;26;DROME;1
26330;;Saint-Sorlin-en-Valloire;SAINT-SORLIN-EN-VALLOIRE;26210;26;DROME;1
26331;;Saint-Thomas-en-Royans;SAINT-THOMAS-EN-ROYANS;26190;26;DROME;1
26332;;Saint-Uze;SAINT-UZE;26240;26;DROME;1
26333;;Saint-Vallier;SAINT-VALLIER;26240;26;DROME;1
26334;;Salettes;SALETTES;26160;26;DROME;1
26335;;Salles-sous-Bois;SALLES-SOUS-BOIS;26770;26;DROME;1
26336;;Saou;SAOU;26400;26;DROME;1
26337;;Saulce-sur-Rhône;SAULCE-SUR-RHONE;26270;26;DROME;1
26338;;Sauzet;SAUZET;26740;26;DROME;1
26339;;Savasse;SAVASSE;26740;26;DROME;1
26340;;Séderon;SEDERON;26560;26;DROME;1
26341;;Serves-sur-Rhône;SERVES-SUR-RHONE;26600;26;DROME;1
26342;;Solérieux;SOLERIEUX;26130;26;DROME;1
26343;;Souspierre;SOUSPIERRE;26160;26;DROME;1
26344;;Soyans;SOYANS;26400;26;DROME;1
26345;;Suze-la-Rousse;SUZE-LA-ROUSSE;26790;26;DROME;1
26346;;Suze;SUZE;26400;26;DROME;1
26347;;Tain-l'Hermitage;TAIN-L'HERMITAGE;26600;26;DROME;1
26348;;Taulignan;TAULIGNAN;26770;26;DROME;1
26349;;Tersanne;TERSANNE;26390;26;DROME;1
26350;;Teyssières;TEYSSIERES;26220;26;DROME;1
26351;Les;Tonils;TONILS;26460;26;DROME;1
26352;La;Touche;TOUCHE;26160;26;DROME;1
26353;Les;Tourrettes;TOURRETTES;26740;26;DROME;1
26354;;Treschenu-Creyers;TRESCHENU-CREYERS;26410;26;DROME;1
26355;;Triors;TRIORS;26750;26;DROME;1
26356;;Truinas;TRUINAS;26460;26;DROME;1
26357;;Tulette;TULETTE;26790;26;DROME;1
26358;;Upie;UPIE;26120;26;DROME;1
26359;;Vachères-en-Quint;VACHERES-EN-QUINT;26150;26;DROME;1
26360;;Valaurie;VALAURIE;26230;26;DROME;1
26361;;Valdrôme;VALDROME;26310;26;DROME;1
26362;;Valence;VALENCE;26000;26;DROME;1
26363;;Valouse;VALOUSE;26110;26;DROME;1
26364;;Vassieux-en-Vercors;VASSIEUX-EN-VERCORS;26420;26;DROME;1
26365;;Vaunaveys-la-Rochette;VAUNAVEYS-LA-ROCHETTE;26400;26;DROME;1
26366;;Veaunes;VEAUNES;26600;26;DROME;1
26367;;Venterol;VENTEROL;26110;26;DROME;1
26368;;Vercheny;VERCHENY;26340;26;DROME;1
26369;;Verclause;VERCLAUSE;26510;26;DROME;1
26370;;Vercoiran;VERCOIRAN;26170;26;DROME;1
26371;;Véronne;VERONNE;26340;26;DROME;1
26372;;Vers-sur-Méouge;VERS-SUR-MEOUGE;26560;26;DROME;1
26373;;Vesc;VESC;26220;26;DROME;1
26374;;Villebois-les-Pins;VILLEBOIS-LES-PINS;05700;26;HAUTES ALPES;1
26375;;Villefranche-le-Château;VILLEFRANCHE-LE-CHATEAU;26560;26;DROME;1
26376;;Villeperdrix;VILLEPERDRIX;26510;26;DROME;1
26377;;Vinsobres;VINSOBRES;26110;26;DROME;1
26378;;Volvent;VOLVENT;26470;26;DROME;1
26379;;Granges-les-Beaumont;GRANGES-LES-BEAUMONT;26600;26;DROME;1
26380;;Gervans;GERVANS;26600;26;DROME;1
26381;;Jaillans;JAILLANS;26300;26;DROME;1
26382;;Saint-Vincent-la-Commanderie;SAINT-VINCENT-LA-COMMANDERIE;26300;26;DROME;1
27001;;Aclou;ACLOU;27800;27;EURE;1
27002;;Acon;ACON;27570;27;EURE;1
27003;;Acquigny;ACQUIGNY;27400;27;EURE;1
27004;;Aigleville;AIGLEVILLE;27120;27;EURE;1
27005;;Ailly;AILLY;27600;27;EURE;1
27006;;Aizier;AIZIER;27500;27;EURE;1
27007;;Ajou;AJOU;27410;27;EURE;1
27008;;Alizay;ALIZAY;27460;27;EURE;1
27009;;Ambenay;AMBENAY;27250;27;EURE;1
27010;;Amécourt;AMECOURT;27140;27;EURE;1
27011;;Amfreville-la-Campagne;AMFREVILLE-LA-CAMPAGNE;27370;27;EURE;1
27012;;Amfreville-les-Champs;AMFREVILLE-LES-CHAMPS;27380;27;EURE;1
27013;;Amfreville-sous-les-Monts;AMFREVILLE-SOUS-LES-MONTS;27380;27;EURE;1
27014;;Amfreville-sur-Iton;AMFREVILLE-SUR-ITON;27400;27;EURE;1
27015;;Andé;ANDE;27430;27;EURE;1
27016;Les;Andelys;ANDELYS;27700;27;EURE;1
27017;;Angerville-la-Campagne;ANGERVILLE-LA-CAMPAGNE;27930;27;EURE;1
27018;;Appeville-Annebault;APPEVILLE-ANNEBAULT;27290;27;EURE;1
27019;;Armentières-sur-Avre;ARMENTIERES-SUR-AVRE;27820;27;EURE;1
27020;;Arnières-sur-Iton;ARNIERES-SUR-ITON;27180;27;EURE;1
27021;;Asnières;ASNIERES;27260;27;EURE;1
27022;;Aubevoye;AUBEVOYE;27940;27;EURE;1
27023;;Aulnay-sur-Iton;AULNAY-SUR-ITON;27180;27;EURE;1
27024;Le;Roncenay-Authenay;RONCENAY-AUTHENAY;27240;27;EURE;1
27025;;Autheuil-Authouillet;AUTHEUIL-AUTHOUILLET;27490;27;EURE;1
27026;;Authevernes;AUTHEVERNES;27420;27;EURE;1
27027;Les;Authieux;AUTHIEUX;27220;27;EURE;1
27028;;Authou;AUTHOU;27290;27;EURE;1
27031;;Aviron;AVIRON;27930;27;EURE;1
27032;;Avrilly;AVRILLY;27240;27;EURE;1
27033;;Bacquepuis;BACQUEPUIS;27930;27;EURE;1
27034;;Bacqueville;BACQUEVILLE;27440;27;EURE;1
27035;;Bailleul-la-Vallée;BAILLEUL-LA-VALLEE;27260;27;EURE;1
27036;;Bâlines;BALINES;27130;27;EURE;1
27037;;Barc;BARC;27170;27;EURE;1
27038;Les;Barils;BARILS;27130;27;EURE;1
27039;;Barneville-sur-Seine;BARNEVILLE-SUR-SEINE;27310;27;EURE;1
27040;;Barquet;BARQUET;27170;27;EURE;1
27041;La;Barre-en-Ouche;BARRE-EN-OUCHE;27330;27;EURE;1
27042;;Barville;BARVILLE;27230;27;EURE;1
27043;Les;Baux-de-Breteuil;BAUX-DE-BRETEUIL;27160;27;EURE;1
27044;Les;Baux-Sainte-Croix;BAUX-SAINTE-CROIX;27180;27;EURE;1
27045;;Bazincourt-sur-Epte;BAZINCOURT-SUR-EPTE;27140;27;EURE;1
27046;;Bazoques;BAZOQUES;27230;27;EURE;1
27047;;Beaubray;BEAUBRAY;27190;27;EURE;1
27048;;Beauficel-en-Lyons;BEAUFICEL-EN-LYONS;27480;27;EURE;1
27049;;Beaumesnil;BEAUMESNIL;27410;27;EURE;1
27050;;Beaumontel;BEAUMONTEL;27170;27;EURE;1
27051;;Beaumont-le-Roger;BEAUMONT-LE-ROGER;27170;27;EURE;1
27052;Le;Bec-Hellouin;BEC-HELLOUIN;27800;27;EURE;1
27053;Le;Bec-Thomas;BEC-THOMAS;27370;27;EURE;1
27054;;Bémécourt;BEMECOURT;27160;27;EURE;1
27055;;Bérengeville-la-Campagne;BERENGEVILLE-LA-CAMPAGNE;27110;27;EURE;1
27056;;Bernay;BERNAY;27300;27;EURE;1
27057;;Bernienville;BERNIENVILLE;27180;27;EURE;1
27058;;Bernières-sur-Seine;BERNIERES-SUR-SEINE;27700;27;EURE;1
27059;;Bernouville;BERNOUVILLE;27660;27;EURE;1
27060;;Berthenonville;BERTHENONVILLE;27630;27;EURE;1
27061;;Berthouville;BERTHOUVILLE;27800;27;EURE;1
27062;;Berville-en-Roumois;BERVILLE-EN-ROUMOIS;27520;27;EURE;1
27063;;Berville-la-Campagne;BERVILLE-LA-CAMPAGNE;27170;27;EURE;1
27064;;Berville-sur-Mer;BERVILLE-SUR-MER;27210;27;EURE;1
27065;;Beuzeville;BEUZEVILLE;27210;27;EURE;1
27066;;Bézu-la-Forêt;BEZU-LA-FORET;27480;27;EURE;1
27067;;Bézu-Saint-Éloi;BEZU-SAINT-ELOI;27660;27;EURE;1
27068;;Bois-Anzeray;BOIS-ANZERAY;27330;27;EURE;1
27069;;Bois-Arnault;BOIS-ARNAULT;27250;27;EURE;1
27070;;Boisemont;BOISEMONT;27150;27;EURE;1
27071;Le;Bois-Hellain;BOIS-HELLAIN;27260;27;EURE;1
27072;;Bois-Jérôme-Saint-Ouen;BOIS-JEROME-SAINT-OUEN;27620;27;EURE;1
27073;;Bois-le-Roi;BOIS-LE-ROI;27220;27;EURE;1
27074;;Boisney;BOISNEY;27800;27;EURE;1
27075;;Bois-Normand-près-Lyre;BOIS-NORMAND-PRES-LYRE;27330;27;EURE;1
27076;;Boisset-les-Prévanches;BOISSET-LES-PREVANCHES;27120;27;EURE;1
27077;;Boissey-le-Châtel;BOISSEY-LE-CHATEL;27520;27;EURE;1
27078;La;Boissière;BOISSIERE;27220;27;EURE;1
27079;;Boissy-Lamberville;BOISSY-LAMBERVILLE;27300;27;EURE;1
27081;;Boncourt;BONCOURT;27120;27;EURE;1
27082;La;Bonneville-sur-Iton;BONNEVILLE-SUR-ITON;27190;27;EURE;1
27083;;Bonneville-Aptot;BONNEVILLE-APTOT;27290;27;EURE;1
27084;;Bosc-Bénard-Commin;BOSC-BENARD-COMMIN;27520;27;EURE;1
27085;;Bosc-Bénard-Crescy;BOSC-BENARD-CRESCY;27310;27;EURE;1
27088;;Bosc-Renoult-en-Ouche;BOSC-RENOULT-EN-OUCHE;27330;27;EURE;1
27089;;Bosc-Renoult-en-Roumois;BOSC-RENOULT-EN-ROUMOIS;27520;27;EURE;1
27090;Le;Bosc-Roger-en-Roumois;BOSC-ROGER-EN-ROUMOIS;27670;27;EURE;1
27091;;Bosgouet;BOSGOUET;27310;27;EURE;1
27092;;Bosguérard-de-Marcouville;BOSGUERARD-DE-MARCOUVILLE;27520;27;EURE;1
27093;;Bosnormand;BOSNORMAND;27670;27;EURE;1
27094;;Bosquentin;BOSQUENTIN;27480;27;EURE;1
27095;;Bosrobert;BOSROBERT;27800;27;EURE;1
27096;Les;Bottereaux;BOTTEREAUX;27250;27;EURE;1
27097;;Bouafles;BOUAFLES;27700;27;EURE;1
27098;;Bouchevilliers;BOUCHEVILLIERS;27150;27;EURE;1
27099;Le;Boulay-Morin;BOULAY-MORIN;27930;27;EURE;1
27100;;Boulleville;BOULLEVILLE;27210;27;EURE;1
27101;;Bouquelon;BOUQUELON;27500;27;EURE;1
27102;;Bouquetot;BOUQUETOT;27310;27;EURE;1
27103;;Bourg-Achard;BOURG-ACHARD;27310;27;EURE;1
27104;;Bourg-Beaudouin;BOURG-BEAUDOUIN;27380;27;EURE;1
27105;;Bourgtheroulde-Infreville;BOURGTHEROULDE-INFREVILLE;27520;27;EURE;1
27106;;Bournainville-Faverolles;BOURNAINVILLE-FAVEROLLES;27230;27;EURE;1
27107;;Bourneville;BOURNEVILLE;27500;27;EURE;1
27108;;Bourth;BOURTH;27580;27;EURE;1
27109;;Bray;BRAY;27170;27;EURE;1
27110;;Brestot;BRESTOT;27350;27;EURE;1
27111;;Bretagnolles;BRETAGNOLLES;27220;27;EURE;1
27112;;Breteuil;BRETEUIL;27160;27;EURE;1
27113;;Brétigny;BRETIGNY;27800;27;EURE;1
27114;;Breuilpont;BREUILPONT;27640;27;EURE;1
27115;;Breux-sur-Avre;BREUX-SUR-AVRE;27570;27;EURE;1
27116;;Brionne;BRIONNE;27800;27;EURE;1
27117;;Broglie;BROGLIE;27270;27;EURE;1
27118;;Brosville;BROSVILLE;27930;27;EURE;1
27119;;Bueil;BUEIL;27730;27;EURE;1
27120;;Burey;BUREY;27190;27;EURE;1
27121;;Bus-Saint-Rémy;BUS-SAINT-REMY;27630;27;EURE;1
27122;;Cahaignes;CAHAIGNES;27420;27;EURE;1
27123;;Caillouet-Orgeville;CAILLOUET-ORGEVILLE;27120;27;EURE;1
27124;;Cailly-sur-Eure;CAILLY-SUR-EURE;27490;27;EURE;1
27125;;Calleville;CALLEVILLE;27800;27;EURE;1
27126;;Campigny;CAMPIGNY;27500;27;EURE;1
27127;;Canappeville;CANAPPEVILLE;27400;27;EURE;1
27128;;Cantiers;CANTIERS;27420;27;EURE;1
27129;;Caorches-Saint-Nicolas;CAORCHES-SAINT-NICOLAS;27300;27;EURE;1
27130;;Capelle-les-Grands;CAPELLE-LES-GRANDS;27270;27;EURE;1
27131;;Carsix;CARSIX;27300;27;EURE;1
27132;;Caugé;CAUGE;27180;27;EURE;1
27133;;Caumont;CAUMONT;27310;27;EURE;1
27134;;Cauverville-en-Roumois;CAUVERVILLE-EN-ROUMOIS;27350;27;EURE;1
27135;;Cesseville;CESSEVILLE;27110;27;EURE;1
27136;;Chaignes;CHAIGNES;27120;27;EURE;1
27137;;Chaise-Dieu-du-Theil;CHAISE-DIEU-DU-THEIL;27580;27;EURE;1
27138;;Chamblac;CHAMBLAC;27270;27;EURE;1
27139;;Chambord;CHAMBORD;27250;27;EURE;1
27140;;Chambray;CHAMBRAY;27120;27;EURE;1
27141;;Champ-Dolent;CHAMP-DOLENT;27190;27;EURE;1
27142;;Champenard;CHAMPENARD;27600;27;EURE;1
27143;;Champignolles;CHAMPIGNOLLES;27330;27;EURE;1
27144;;Champigny-la-Futelaye;CHAMPIGNY-LA-FUTELAYE;27220;27;EURE;1
27145;;Chanteloup;CHANTELOUP;27240;27;EURE;1
27146;La;Chapelle-Bayvel;CHAPELLE-BAYVEL;27260;27;EURE;1
27147;La;Chapelle-du-Bois-des-Faulx;CHAPELLE-DU-BOIS-DES-FAULX;27930;27;EURE;1
27148;La;Chapelle-Gauthier;CHAPELLE-GAUTHIER;27270;27;EURE;1
27149;La;Chapelle-Hareng;CHAPELLE-HARENG;27230;27;EURE;1
27150;La;Chapelle-Réanville;CHAPELLE-REANVILLE;27950;27;EURE;1
27151;;Charleval;CHARLEVAL;27380;27;EURE;1
27152;;Château-sur-Epte;CHATEAU-SUR-EPTE;27420;27;EURE;1
27153;;Chauvincourt-Provemont;CHAUVINCOURT-PROVEMONT;27150;27;EURE;1
27154;;Chavigny-Bailleul;CHAVIGNY-BAILLEUL;27220;27;EURE;1
27155;;Chennebrun;CHENNEBRUN;27820;27;EURE;1
27156;;Chéronvilliers;CHERONVILLIERS;27250;27;EURE;1
27157;Le;Chesne;CHESNE;27160;27;EURE;1
27158;;Cierrey;CIERREY;27930;27;EURE;1
27159;;Cintray;CINTRAY;27160;27;EURE;1
27160;;Civières;CIVIERES;27630;27;EURE;1
27161;;Claville;CLAVILLE;27180;27;EURE;1
27162;;Collandres-Quincarnon;COLLANDRES-QUINCARNON;27190;27;EURE;1
27163;;Colletot;COLLETOT;27500;27;EURE;1
27164;;Combon;COMBON;27170;27;EURE;1
27165;;Conches-en-Ouche;CONCHES-EN-OUCHE;27190;27;EURE;1
27166;;Condé-sur-Iton;CONDE-SUR-ITON;27160;27;EURE;1
27167;;Condé-sur-Risle;CONDE-SUR-RISLE;27290;27;EURE;1
27168;;Connelles;CONNELLES;27430;27;EURE;1
27169;;Conteville;CONTEVILLE;27210;27;EURE;1
27170;;Cormeilles;CORMEILLES;27260;27;EURE;1
27171;Le;Cormier;CORMIER;27120;27;EURE;1
27172;;Corneuil;CORNEUIL;27240;27;EURE;1
27173;;Corneville-la-Fouquetière;CORNEVILLE-LA-FOUQUETIERE;27300;27;EURE;1
27174;;Corneville-sur-Risle;CORNEVILLE-SUR-RISLE;27500;27;EURE;1
27175;;Corny;CORNY;27700;27;EURE;1
27176;;Coudray;COUDRAY;27150;27;EURE;1
27177;;Coudres;COUDRES;27220;27;EURE;1
27179;;Courbépine;COURBEPINE;27300;27;EURE;1
27180;;Courcelles-sur-Seine;COURCELLES-SUR-SEINE;27940;27;EURE;1
27181;;Courdemanche;COURDEMANCHE;27320;27;EURE;1
27182;;Courteilles;COURTEILLES;27130;27;EURE;1
27183;La;Couture-Boussey;COUTURE-BOUSSEY;27750;27;EURE;1
27184;;Crasville;CRASVILLE;27400;27;EURE;1
27185;;Crestot;CRESTOT;27110;27;EURE;1
27187;;Criquebeuf-la-Campagne;CRIQUEBEUF-LA-CAMPAGNE;27110;27;EURE;1
27188;;Criquebeuf-sur-Seine;CRIQUEBEUF-SUR-SEINE;27340;27;EURE;1
27189;La;Croisille;CROISILLE;27190;27;EURE;1
27190;;Croisy-sur-Eure;CROISY-SUR-EURE;27120;27;EURE;1
27191;La;Croix-Saint-Leufroy;CROIX-SAINT-LEUFROY;27490;27;EURE;1
27192;;Crosville-la-Vieille;CROSVILLE-LA-VIEILLE;27110;27;EURE;1
27193;;Croth;CROTH;28520;27;EURE ET LOIR;1
27194;;Cuverville;CUVERVILLE;27700;27;EURE;1
27195;;Dame-Marie;DAME-MARIE;27160;27;EURE;1
27196;Les;Damps;DAMPS;27340;27;EURE;1
27197;;Dampsmesnil;DAMPSMESNIL;27630;27;EURE;1
27198;;Damville;DAMVILLE;27240;27;EURE;1
27199;;Dangu;DANGU;27720;27;EURE;1
27200;;Dardez;DARDEZ;27930;27;EURE;1
27201;;Daubeuf-la-Campagne;DAUBEUF-LA-CAMPAGNE;27110;27;EURE;1
27202;;Daubeuf-près-Vatteville;DAUBEUF-PRES-VATTEVILLE;27430;27;EURE;1
27203;;Douains;DOUAINS;27120;27;EURE;1
27204;;Doudeauville-en-Vexin;DOUDEAUVILLE-EN-VEXIN;27150;27;EURE;1
27205;;Douville-sur-Andelle;DOUVILLE-SUR-ANDELLE;27380;27;EURE;1
27206;;Droisy;DROISY;27320;27;EURE;1
27207;;Drucourt;DRUCOURT;27230;27;EURE;1
27208;;Duranville;DURANVILLE;27230;27;EURE;1
27209;;Écaquelon;ECAQUELON;27290;27;EURE;1
27210;;Écardenville-la-Campagne;ECARDENVILLE-LA-CAMPAGNE;27170;27;EURE;1
27211;;Écardenville-sur-Eure;ECARDENVILLE-SUR-EURE;27490;27;EURE;1
27212;;Écauville;ECAUVILLE;27110;27;EURE;1
27213;;Écos;ECOS;27630;27;EURE;1
27214;;Écouis;ECOUIS;27440;27;EURE;1
27215;;Ecquetot;ECQUETOT;27110;27;EURE;1
27216;;Émalleville;EMALLEVILLE;27930;27;EURE;1
27217;;Émanville;EMANVILLE;27190;27;EURE;1
27218;;Épaignes;EPAIGNES;27260;27;EURE;1
27219;;Épégard;EPEGARD;27110;27;EURE;1
27220;;Épieds;EPIEDS;27730;27;EURE;1
27221;;Épinay;EPINAY;27330;27;EURE;1
27222;;Épreville-en-Lieuvin;EPREVILLE-EN-LIEUVIN;27560;27;EURE;1
27223;;Épreville-en-Roumois;EPREVILLE-EN-ROUMOIS;27310;27;EURE;1
27224;;Épreville-près-le-Neubourg;EPREVILLE-PRES-LE-NEUBOURG;27110;27;EURE;1
27225;Les;Essarts;ESSARTS;27240;27;EURE;1
27226;;Étrépagny;ETREPAGNY;27150;27;EURE;1
27227;;Étréville;ETREVILLE;27350;27;EURE;1
27228;;Éturqueraye;ETURQUERAYE;27350;27;EURE;1
27229;;Évreux;EVREUX;27000;27;EURE;1
27230;;Ézy-sur-Eure;EZY-SUR-EURE;27530;27;EURE;1
27231;;Fains;FAINS;27120;27;EURE;1
27232;;Farceaux;FARCEAUX;27150;27;EURE;1
27233;;Fatouville-Grestain;FATOUVILLE-GRESTAIN;27210;27;EURE;1
27234;;Fauville;FAUVILLE;27930;27;EURE;1
27235;;Faverolles-la-Campagne;FAVEROLLES-LA-CAMPAGNE;27190;27;EURE;1
27237;Le;Favril;FAVRIL;27230;27;EURE;1
27238;;Ferrières-Haut-Clocher;FERRIERES-HAUT-CLOCHER;27190;27;EURE;1
27239;;Ferrières-Saint-Hilaire;FERRIERES-SAINT-HILAIRE;27270;27;EURE;1
27240;La;Ferrière-sur-Risle;FERRIERE-SUR-RISLE;27760;27;EURE;1
27241;;Feuguerolles;FEUGUEROLLES;27110;27;EURE;1
27242;Le;Fidelaire;FIDELAIRE;27190;27;EURE;1
27243;;Fiquefleur-Équainville;FIQUEFLEUR-EQUAINVILLE;27210;27;EURE;1
27244;;Flancourt-Catelon;FLANCOURT-CATELON;27310;27;EURE;1
27245;;Fleury-la-Forêt;FLEURY-LA-FORET;27480;27;EURE;1
27246;;Fleury-sur-Andelle;FLEURY-SUR-ANDELLE;27380;27;EURE;1
27247;;Flipou;FLIPOU;27380;27;EURE;1
27248;;Folleville;FOLLEVILLE;27230;27;EURE;1
27249;;Fontaine-Bellenger;FONTAINE-BELLENGER;27600;27;EURE;1
27250;;Fontaine-Heudebourg;FONTAINE-HEUDEBOURG;27490;27;EURE;1
27251;;Fontaine-l'Abbé;FONTAINE-L'ABBE;27300;27;EURE;1
27252;;Fontaine-la-Louvet;FONTAINE-LA-LOUVET;27230;27;EURE;1
27253;;Fontaine-la-Soret;FONTAINE-LA-SORET;27550;27;EURE;1
27254;;Fontaine-sous-Jouy;FONTAINE-SOUS-JOUY;27120;27;EURE;1
27255;;Fontenay;FONTENAY;27510;27;EURE;1
27256;La;Forêt-du-Parc;FORET-DU-PARC;27220;27;EURE;1
27257;;Forêt-la-Folie;FORET-LA-FOLIE;27510;27;EURE;1
27258;;Fort-Moville;FORT-MOVILLE;27210;27;EURE;1
27259;;Foucrainville;FOUCRAINVILLE;27220;27;EURE;1
27260;;Foulbec;FOULBEC;27210;27;EURE;1
27261;;Fouqueville;FOUQUEVILLE;27370;27;EURE;1
27262;;Fourges;FOURGES;27630;27;EURE;1
27263;;Fourmetot;FOURMETOT;27500;27;EURE;1
27264;;Fours-en-Vexin;FOURS-EN-VEXIN;27630;27;EURE;1
27265;;Francheville;FRANCHEVILLE;27160;27;EURE;1
27266;;Franqueville;FRANQUEVILLE;27800;27;EURE;1
27267;;Freneuse-sur-Risle;FRENEUSE-SUR-RISLE;27290;27;EURE;1
27268;Le;Fresne;FRESNE;27190;27;EURE;1
27269;;Fresne-Cauverville;FRESNE-CAUVERVILLE;27260;27;EURE;1
27270;;Fresne-l'Archevêque;FRESNE-L'ARCHEVEQUE;27700;27;EURE;1
27271;;Fresney;FRESNEY;27220;27;EURE;1
27273;;Gadencourt;GADENCOURT;27120;27;EURE;1
27274;;Gaillardbois-Cressenville;GAILLARDBOIS-CRESSENVILLE;27440;27;EURE;1
27275;;Gaillon;GAILLON;27600;27;EURE;1
27276;;Gamaches-en-Vexin;GAMACHES-EN-VEXIN;27150;27;EURE;1
27277;;Garencières;GARENCIERES;27220;27;EURE;1
27278;;Garennes-sur-Eure;GARENNES-SUR-EURE;27780;27;EURE;1
27279;;Gasny;GASNY;27620;27;EURE;1
27280;;Gauciel;GAUCIEL;27930;27;EURE;1
27281;;Gaudreville-la-Rivière;GAUDREVILLE-LA-RIVIERE;27190;27;EURE;1
27282;;Gauville-la-Campagne;GAUVILLE-LA-CAMPAGNE;27930;27;EURE;1
27283;;Gisay-la-Coudre;GISAY-LA-COUDRE;27330;27;EURE;1
27284;;Gisors;GISORS;27140;27;EURE;1
27285;;Giverny;GIVERNY;27620;27;EURE;1
27286;;Giverville;GIVERVILLE;27560;27;EURE;1
27287;;Glisolles;GLISOLLES;27190;27;EURE;1
27288;;Glos-sur-Risle;GLOS-SUR-RISLE;27290;27;EURE;1
27289;La;Goulafrière;GOULAFRIERE;27390;27;EURE;1
27290;;Goupillières;GOUPILLIERES;27170;27;EURE;1
27291;;Gournay-le-Guérin;GOURNAY-LE-GUERIN;27580;27;EURE;1
27292;;Gouttières;GOUTTIERES;27410;27;EURE;1
27293;;Gouville;GOUVILLE;27240;27;EURE;1
27294;;Grainville;GRAINVILLE;27380;27;EURE;1
27295;;Grand-Camp;GRAND-CAMP;27270;27;EURE;1
27296;;Granchain;GRANCHAIN;27410;27;EURE;1
27297;;Grandvilliers;GRANDVILLIERS;27240;27;EURE;1
27298;;Graveron-Sémerville;GRAVERON-SEMERVILLE;27110;27;EURE;1
27299;;Gravigny;GRAVIGNY;27930;27;EURE;1
27300;;Grosley-sur-Risle;GROSLEY-SUR-RISLE;27170;27;EURE;1
27301;;Grossœuvre;GROSSOEUVRE;27220;27;EURE;1
27302;Le;Gros-Theil;GROS-THEIL;27370;27;EURE;1
27303;;Guernanville;GUERNANVILLE;27160;27;EURE;1
27304;;Guerny;GUERNY;27720;27;EURE;1
27305;La;Guéroulde;GUEROULDE;27160;27;EURE;1
27306;;Guichainville;GUICHAINVILLE;27930;27;EURE;1
27307;;Guiseniers;GUISENIERS;27700;27;EURE;1
27308;;Guitry;GUITRY;27510;27;EURE;1
27309;L';Habit;HABIT;27220;27;EURE;1
27310;;Hacqueville;HACQUEVILLE;27150;27;EURE;1
27311;;Harcourt;HARCOURT;27800;27;EURE;1
27312;;Hardencourt-Cocherel;HARDENCOURT-COCHEREL;27120;27;EURE;1
27313;La;Harengère;HARENGERE;27370;27;EURE;1
27315;;Harquency;HARQUENCY;27700;27;EURE;1
27316;;Hauville;HAUVILLE;27350;27;EURE;1
27317;La;Haye-Aubrée;HAYE-AUBREE;27350;27;EURE;1
27318;La;Haye-de-Calleville;HAYE-DE-CALLEVILLE;27800;27;EURE;1
27319;La;Haye-de-Routot;HAYE-DE-ROUTOT;27350;27;EURE;1
27320;La;Haye-du-Theil;HAYE-DU-THEIL;27370;27;EURE;1
27321;La;Haye-le-Comte;HAYE-LE-COMTE;27400;27;EURE;1
27322;La;Haye-Malherbe;HAYE-MALHERBE;27400;27;EURE;1
27323;La;Haye-Saint-Sylvestre;HAYE-SAINT-SYLVESTRE;27330;27;EURE;1
27324;;Hébécourt;HEBECOURT;27150;27;EURE;1
27325;;Hecmanville;HECMANVILLE;27800;27;EURE;1
27326;;Hécourt;HECOURT;27120;27;EURE;1
27327;;Hectomare;HECTOMARE;27110;27;EURE;1
27329;;Hennezis;HENNEZIS;27700;27;EURE;1
27330;;Herqueville;HERQUEVILLE;27430;27;EURE;1
27331;;Heubécourt-Haricourt;HEUBECOURT-HARICOURT;27630;27;EURE;1
27332;;Heudebouville;HEUDEBOUVILLE;27400;27;EURE;1
27333;;Heudicourt;HEUDICOURT;27860;27;EURE;1
27334;;Heudreville-en-Lieuvin;HEUDREVILLE-EN-LIEUVIN;27230;27;EURE;1
27335;;Heudreville-sur-Eure;HEUDREVILLE-SUR-EURE;27400;27;EURE;1
27336;La;Heunière;HEUNIERE;27950;27;EURE;1
27337;;Heuqueville;HEUQUEVILLE;27700;27;EURE;1
27338;Les;Hogues;HOGUES;27910;27;EURE;1
27339;;Hondouville;HONDOUVILLE;27400;27;EURE;1
27340;;Honguemare-Guenouville;HONGUEMARE-GUENOUVILLE;27310;27;EURE;1
27341;L';Hosmes;HOSMES;27570;27;EURE;1
27342;;Houetteville;HOUETTEVILLE;27400;27;EURE;1
27343;;Houlbec-Cocherel;HOULBEC-COCHEREL;27120;27;EURE;1
27344;;Houlbec-près-le-Gros-Theil;HOULBEC-PRES-LE-GROS-THEIL;27370;27;EURE;1
27345;La;Houssaye;HOUSSAYE;27410;27;EURE;1
27346;;Houville-en-Vexin;HOUVILLE-EN-VEXIN;27440;27;EURE;1
27347;;Huest;HUEST;27930;27;EURE;1
27348;;Igoville;IGOVILLE;27460;27;EURE;1
27349;;Illeville-sur-Montfort;ILLEVILLE-SUR-MONTFORT;27290;27;EURE;1
27350;;Illiers-l'Évêque;ILLIERS-L'EVEQUE;27770;27;EURE;1
27351;;Incarville;INCARVILLE;27400;27;EURE;1
27353;;Irreville;IRREVILLE;27930;27;EURE;1
27354;;Iville;IVILLE;27110;27;EURE;1
27355;;Ivry-la-Bataille;IVRY-LA-BATAILLE;27540;27;EURE;1
27356;;Jonquerets-de-Livet;JONQUERETS-DE-LIVET;27410;27;EURE;1
27358;;Jouy-sur-Eure;JOUY-SUR-EURE;27120;27;EURE;1
27359;;Juignettes;JUIGNETTES;27250;27;EURE;1
27360;;Jumelles;JUMELLES;27220;27;EURE;1
27361;La;Lande-Saint-Léger;LANDE-SAINT-LEGER;27210;27;EURE;1
27362;;Landepéreuse;LANDEPEREUSE;27410;27;EURE;1
27363;Le;Landin;LANDIN;27350;27;EURE;1
27364;;Launay;LAUNAY;27470;27;EURE;1
27365;;Léry;LERY;27690;27;EURE;1
27366;;Letteguives;LETTEGUIVES;27910;27;EURE;1
27367;;Lieurey;LIEUREY;27560;27;EURE;1
27368;;Lignerolles;LIGNEROLLES;27220;27;EURE;1
27369;;Lilly;LILLY;27480;27;EURE;1
27370;;Lisors;LISORS;27440;27;EURE;1
27371;;Livet-sur-Authou;LIVET-SUR-AUTHOU;27800;27;EURE;1
27372;;Longchamps;LONGCHAMPS;27150;27;EURE;1
27373;;Lorleau;LORLEAU;27480;27;EURE;1
27374;;Louversey;LOUVERSEY;27190;27;EURE;1
27375;;Louviers;LOUVIERS;27400;27;EURE;1
27376;;Louye;LOUYE;27650;27;EURE;1
27377;;Lyons-la-Forêt;LYONS-LA-FORET;27480;27;EURE;1
27378;La;Madeleine-de-Nonancourt;MADELEINE-DE-NONANCOURT;27320;27;EURE;1
27379;;Mainneville;MAINNEVILLE;27150;27;EURE;1
27380;;Malleville-sur-le-Bec;MALLEVILLE-SUR-LE-BEC;27800;27;EURE;1
27381;;Malouy;MALOUY;27300;27;EURE;1
27382;;Mandeville;MANDEVILLE;27370;27;EURE;1
27383;;Mandres;MANDRES;27130;27;EURE;1
27384;;Manneville-la-Raoult;MANNEVILLE-LA-RAOULT;27210;27;EURE;1
27385;;Manneville-sur-Risle;MANNEVILLE-SUR-RISLE;27500;27;EURE;1
27386;Le;Manoir;MANOIR;27460;27;EURE;1
27387;;Manthelon;MANTHELON;27240;27;EURE;1
27388;;Marais-Vernier;MARAIS-VERNIER;27680;27;EURE;1
27389;;Marbeuf;MARBEUF;27110;27;EURE;1
27390;;Marcilly-la-Campagne;MARCILLY-LA-CAMPAGNE;27320;27;EURE;1
27391;;Marcilly-sur-Eure;MARCILLY-SUR-EURE;27810;27;EURE;1
27392;;Martagny;MARTAGNY;27150;27;EURE;1
27393;;Martainville;MARTAINVILLE;27210;27;EURE;1
27394;;Martot;MARTOT;27340;27;EURE;1
27395;;Mélicourt;MELICOURT;27390;27;EURE;1
27396;;Ménesqueville;MENESQUEVILLE;27850;27;EURE;1
27397;;Ménilles;MENILLES;27120;27;EURE;1
27398;;Menneval;MENNEVAL;27300;27;EURE;1
27399;;Mercey;MERCEY;27950;27;EURE;1
27400;;Merey;MEREY;27640;27;EURE;1
27401;Le;Mesnil-Fuguet;MESNIL-FUGUET;27930;27;EURE;1
27402;Le;Mesnil-Hardray;MESNIL-HARDRAY;27190;27;EURE;1
27403;Le;Mesnil-Jourdain;MESNIL-JOURDAIN;27400;27;EURE;1
27404;;Mesnil-Rousset;MESNIL-ROUSSET;27390;27;EURE;1
27405;;Mesnil-sous-Vienne;MESNIL-SOUS-VIENNE;27150;27;EURE;1
27406;;Mesnil-sur-l'Estrée;MESNIL-SUR-L'ESTREE;27650;27;EURE;1
27407;;Mesnil-Verclives;MESNIL-VERCLIVES;27440;27;EURE;1
27408;;Mézières-en-Vexin;MEZIERES-EN-VEXIN;27510;27;EURE;1
27410;;Miserey;MISEREY;27930;27;EURE;1
27411;;Moisville;MOISVILLE;27320;27;EURE;1
27412;;Montaure;MONTAURE;27400;27;EURE;1
27413;;Montfort-sur-Risle;MONTFORT-SUR-RISLE;27290;27;EURE;1
27414;;Montreuil-l'Argillé;MONTREUIL-L'ARGILLE;27390;27;EURE;1
27415;;Morainville-Jouveaux;MORAINVILLE-JOUVEAUX;27260;27;EURE;1
27416;;Buis-sur-Damville;BUIS-SUR-DAMVILLE;27240;27;EURE;1
27417;;Morgny;MORGNY;27150;27;EURE;1
27418;;Morsan;MORSAN;27800;27;EURE;1
27419;;Mouettes;MOUETTES;27220;27;EURE;1
27420;;Mouflaines;MOUFLAINES;27420;27;EURE;1
27421;;Mousseaux-Neuville;MOUSSEAUX-NEUVILLE;27220;27;EURE;1
27422;;Muids;MUIDS;27430;27;EURE;1
27423;;Muzy;MUZY;27650;27;EURE;1
27424;;Nagel-Séez-Mesnil;NAGEL-SEEZ-MESNIL;27190;27;EURE;1
27425;;Nassandres;NASSANDRES;27550;27;EURE;1
27426;;Neaufles-Saint-Martin;NEAUFLES-SAINT-MARTIN;27830;27;EURE;1
27427;;Neaufles-Auvergny;NEAUFLES-AUVERGNY;27250;27;EURE;1
27428;Le;Neubourg;NEUBOURG;27110;27;EURE;1
27429;;Neuilly;NEUILLY;27730;27;EURE;1
27430;La;Neuve-Grange;NEUVE-GRANGE;27150;27;EURE;1
27431;La;Neuve-Lyre;NEUVE-LYRE;27330;27;EURE;1
27432;La;Neuville-du-Bosc;NEUVILLE-DU-BOSC;27890;27;EURE;1
27433;;Neuville-sur-Authou;NEUVILLE-SUR-AUTHOU;27800;27;EURE;1
27434;;Noards;NOARDS;27560;27;EURE;1
27435;La;Noë-Poulain;NOE-POULAIN;27560;27;EURE;1
27436;;Nogent-le-Sec;NOGENT-LE-SEC;27190;27;EURE;1
27437;;Nojeon-en-Vexin;NOJEON-EN-VEXIN;27150;27;EURE;1
27438;;Nonancourt;NONANCOURT;27320;27;EURE;1
27439;;Normanville;NORMANVILLE;27930;27;EURE;1
27440;;Notre-Dame-de-l'Isle;NOTRE-DAME-DE-L'ISLE;27940;27;EURE;1
27441;;Notre-Dame-d'Épine;NOTRE-DAME-D'EPINE;27800;27;EURE;1
27442;;Notre-Dame-du-Hamel;NOTRE-DAME-DU-HAMEL;27390;27;EURE;1
27444;Le;Noyer-en-Ouche;NOYER-EN-OUCHE;27410;27;EURE;1
27445;;Noyers;NOYERS;27720;27;EURE;1
27446;;Ormes;ORMES;27190;27;EURE;1
27447;;Orvaux;ORVAUX;27190;27;EURE;1
27448;;Pacy-sur-Eure;PACY-SUR-EURE;27120;27;EURE;1
27449;;Panilleuse;PANILLEUSE;27510;27;EURE;1
27451;;Parville;PARVILLE;27180;27;EURE;1
27452;;Perriers-la-Campagne;PERRIERS-LA-CAMPAGNE;27170;27;EURE;1
27453;;Perriers-sur-Andelle;PERRIERS-SUR-ANDELLE;27910;27;EURE;1
27454;;Perruel;PERRUEL;27910;27;EURE;1
27455;;Piencourt;PIENCOURT;27230;27;EURE;1
27456;;Pinterville;PINTERVILLE;27400;27;EURE;1
27457;;Piseux;PISEUX;27130;27;EURE;1
27458;;Pîtres;PITRES;27590;27;EURE;1
27459;Les;Places;PLACES;27230;27;EURE;1
27460;;Plainville;PLAINVILLE;27300;27;EURE;1
27462;Le;Planquay;PLANQUAY;27230;27;EURE;1
27463;;Plasnes;PLASNES;27300;27;EURE;1
27464;Le;Plessis-Grohan;PLESSIS-GROHAN;27180;27;EURE;1
27465;Le;Plessis-Hébert;PLESSIS-HEBERT;27120;27;EURE;1
27466;Le;Plessis-Sainte-Opportune;PLESSIS-SAINTE-OPPORTUNE;27170;27;EURE;1
27467;;Pont-Audemer;PONT-AUDEMER;27500;27;EURE;1
27468;;Pont-Authou;PONT-AUTHOU;27290;27;EURE;1
27469;;Pont-de-l'Arche;PONT-DE-L'ARCHE;27340;27;EURE;1
27470;;Pont-Saint-Pierre;PONT-SAINT-PIERRE;27360;27;EURE;1
27471;;Porte-Joie;PORTE-JOIE;27430;27;EURE;1
27472;;Portes;PORTES;27190;27;EURE;1
27473;;Port-Mort;PORT-MORT;27940;27;EURE;1
27474;;Poses;POSES;27740;27;EURE;1
27475;La;Poterie-Mathieu;POTERIE-MATHIEU;27560;27;EURE;1
27476;Les;Préaux;PREAUX;27500;27;EURE;1
27477;;Pressagny-l'Orgueilleux;PRESSAGNY-L'ORGUEILLEUX;27510;27;EURE;1
27478;;Prey;PREY;27220;27;EURE;1
27480;;Puchay;PUCHAY;27150;27;EURE;1
27481;;Pullay;PULLAY;27130;27;EURE;1
27482;La;Pyle;PYLE;27370;27;EURE;1
27483;;Quatremare;QUATREMARE;27400;27;EURE;1
27484;;Quessigny;QUESSIGNY;27220;27;EURE;1
27485;;Quillebeuf-sur-Seine;QUILLEBEUF-SUR-SEINE;27680;27;EURE;1
27486;;Quittebeuf;QUITTEBEUF;27110;27;EURE;1
27487;;Radepont;RADEPONT;27380;27;EURE;1
27488;;Renneville;RENNEVILLE;27910;27;EURE;1
27489;;Reuilly;REUILLY;27930;27;EURE;1
27490;;Richeville;RICHEVILLE;27420;27;EURE;1
27491;;Roman;ROMAN;27240;27;EURE;1
27492;;Romilly-la-Puthenaye;ROMILLY-LA-PUTHENAYE;27170;27;EURE;1
27493;;Romilly-sur-Andelle;ROMILLY-SUR-ANDELLE;27610;27;EURE;1
27495;La;Roquette;ROQUETTE;27700;27;EURE;1
27496;;Rosay-sur-Lieure;ROSAY-SUR-LIEURE;27790;27;EURE;1
27497;;Rougemontiers;ROUGEMONTIERS;27350;27;EURE;1
27498;;Rouge-Perriers;ROUGE-PERRIERS;27110;27;EURE;1
27499;La;Roussière;ROUSSIERE;27270;27;EURE;1
27500;;Routot;ROUTOT;27350;27;EURE;1
27501;;Rouvray;ROUVRAY;27120;27;EURE;1
27502;;Rugles;RUGLES;27250;27;EURE;1
27503;Le;Sacq;SACQ;27240;27;EURE;1
27504;;Sacquenville;SACQUENVILLE;27930;27;EURE;1
27505;;Saint-Agnan-de-Cernières;SAINT-AGNAN-DE-CERNIERES;27390;27;EURE;1
27506;;Saint-Amand-des-Hautes-Terres;SAINT-AMAND-DES-HAUTES-TERRES;27370;27;EURE;1
27507;;Saint-André-de-l'Eure;SAINT-ANDRE-DE-L'EURE;27220;27;EURE;1
27508;;Saint-Antonin-de-Sommaire;SAINT-ANTONIN-DE-SOMMAIRE;27250;27;EURE;1
27510;;Saint-Aquilin-de-Pacy;SAINT-AQUILIN-DE-PACY;27120;27;EURE;1
27511;;Saint-Aubin-d'Écrosville;SAINT-AUBIN-D'ECROSVILLE;27110;27;EURE;1
27512;;Saint-Aubin-de-Scellon;SAINT-AUBIN-DE-SCELLON;27230;27;EURE;1
27513;;Saint-Aubin-des-Hayes;SAINT-AUBIN-DES-HAYES;27410;27;EURE;1
27514;;Saint-Aubin-du-Thenney;SAINT-AUBIN-DU-THENNEY;27270;27;EURE;1
27515;;Saint-Aubin-le-Guichard;SAINT-AUBIN-LE-GUICHARD;27410;27;EURE;1
27516;;Saint-Aubin-le-Vertueux;SAINT-AUBIN-LE-VERTUEUX;27300;27;EURE;1
27517;;Saint-Aubin-sur-Gaillon;SAINT-AUBIN-SUR-GAILLON;27600;27;EURE;1
27518;;Saint-Aubin-sur-Quillebeuf;SAINT-AUBIN-SUR-QUILLEBEUF;27680;27;EURE;1
27519;;Sainte-Barbe-sur-Gaillon;SAINTE-BARBE-SUR-GAILLON;27600;27;EURE;1
27520;;Saint-Benoît-des-Ombres;SAINT-BENOIT-DES-OMBRES;27450;27;EURE;1
27521;;Saint-Christophe-sur-Avre;SAINT-CHRISTOPHE-SUR-AVRE;27820;27;EURE;1
27522;;Saint-Christophe-sur-Condé;SAINT-CHRISTOPHE-SUR-CONDE;27450;27;EURE;1
27523;;Saint-Clair-d'Arcey;SAINT-CLAIR-D'ARCEY;27300;27;EURE;1
27524;;Sainte-Colombe-la-Commanderie;SAINTE-COLOMBE-LA-COMMANDERIE;27110;27;EURE;1
27525;;Sainte-Colombe-près-Vernon;SAINTE-COLOMBE-PRES-VERNON;27950;27;EURE;1
27526;;Sainte-Croix-sur-Aizier;SAINTE-CROIX-SUR-AIZIER;27500;27;EURE;1
27527;;Saint-Cyr-de-Salerne;SAINT-CYR-DE-SALERNE;27800;27;EURE;1
27528;Le;Vaudreuil;VAUDREUIL;27100;27;EURE;1
27529;;Saint-Cyr-la-Campagne;SAINT-CYR-LA-CAMPAGNE;27370;27;EURE;1
27530;;Saint-Denis-d'Augerons;SAINT-DENIS-D'AUGERONS;27390;27;EURE;1
27531;;Saint-Denis-des-Monts;SAINT-DENIS-DES-MONTS;27520;27;EURE;1
27532;;Saint-Denis-du-Béhélan;SAINT-DENIS-DU-BEHELAN;27160;27;EURE;1
27533;;Saint-Denis-le-Ferment;SAINT-DENIS-LE-FERMENT;27140;27;EURE;1
27534;;Saint-Didier-des-Bois;SAINT-DIDIER-DES-BOIS;27370;27;EURE;1
27535;;Saint-Élier;SAINT-ELIER;27190;27;EURE;1
27536;;Saint-Éloi-de-Fourques;SAINT-ELOI-DE-FOURQUES;27800;27;EURE;1
27537;;Saint-Étienne-du-Vauvray;SAINT-ETIENNE-DU-VAUVRAY;27430;27;EURE;1
27538;;Saint-Étienne-l'Allier;SAINT-ETIENNE-L'ALLIER;27450;27;EURE;1
27539;;Saint-Étienne-sous-Bailleul;SAINT-ETIENNE-SOUS-BAILLEUL;27920;27;EURE;1
27540;;Sainte-Geneviève-lès-Gasny;SAINTE-GENEVIEVE-LES-GASNY;27620;27;EURE;1
27541;;Saint-Georges-du-Mesnil;SAINT-GEORGES-DU-MESNIL;27560;27;EURE;1
27542;;Saint-Georges-du-Vièvre;SAINT-GEORGES-DU-VIEVRE;27450;27;EURE;1
27543;;Saint-Georges-Motel;SAINT-GEORGES-MOTEL;27710;27;EURE;1
27544;;Saint-Germain-de-Fresney;SAINT-GERMAIN-DE-FRESNEY;27220;27;EURE;1
27545;;Saint-Germain-de-Pasquier;SAINT-GERMAIN-DE-PASQUIER;27370;27;EURE;1
27546;;Saint-Germain-des-Angles;SAINT-GERMAIN-DES-ANGLES;27930;27;EURE;1
27547;;Saint-Germain-la-Campagne;SAINT-GERMAIN-LA-CAMPAGNE;27230;27;EURE;1
27548;;Saint-Germain-sur-Avre;SAINT-GERMAIN-SUR-AVRE;27320;27;EURE;1
27549;;Saint-Germain-Village;SAINT-GERMAIN-VILLAGE;27500;27;EURE;1
27550;;Saint-Grégoire-du-Vièvre;SAINT-GREGOIRE-DU-VIEVRE;27450;27;EURE;1
27551;;Saint-Jean-de-la-Léqueraye;SAINT-JEAN-DE-LA-LEQUERAYE;27560;27;EURE;1
27552;;Saint-Jean-du-Thenney;SAINT-JEAN-DU-THENNEY;27270;27;EURE;1
27553;;Saint-Julien-de-la-Liègue;SAINT-JULIEN-DE-LA-LIEGUE;27600;27;EURE;1
27554;;Saint-Just;SAINT-JUST;27950;27;EURE;1
27555;;Saint-Laurent-des-Bois;SAINT-LAURENT-DES-BOIS;27220;27;EURE;1
27556;;Saint-Laurent-du-Tencement;SAINT-LAURENT-DU-TENCEMENT;27390;27;EURE;1
27557;;Saint-Léger-de-Rôtes;SAINT-LEGER-DE-ROTES;27300;27;EURE;1
27558;;Saint-Léger-du-Gennetey;SAINT-LEGER-DU-GENNETEY;27520;27;EURE;1
27560;;Saint-Luc;SAINT-LUC;27930;27;EURE;1
27561;;Saint-Maclou;SAINT-MACLOU;27210;27;EURE;1
27562;;Saint-Marcel;SAINT-MARCEL;27950;27;EURE;1
27563;;Saint-Mards-de-Blacarville;SAINT-MARDS-DE-BLACARVILLE;27500;27;EURE;1
27564;;Saint-Mards-de-Fresne;SAINT-MARDS-DE-FRESNE;27230;27;EURE;1
27565;;Sainte-Marguerite-de-l'Autel;SAINTE-MARGUERITE-DE-L'AUTEL;27160;27;EURE;1
27566;;Sainte-Marguerite-en-Ouche;SAINTE-MARGUERITE-EN-OUCHE;27410;27;EURE;1
27567;;Sainte-Marie-de-Vatimesnil;SAINTE-MARIE-DE-VATIMESNIL;27150;27;EURE;1
27568;;Sainte-Marthe;SAINTE-MARTHE;27190;27;EURE;1
27569;;Saint-Martin-du-Tilleul;SAINT-MARTIN-DU-TILLEUL;27300;27;EURE;1
27570;;Saint-Martin-la-Campagne;SAINT-MARTIN-LA-CAMPAGNE;27930;27;EURE;1
27571;;Saint-Martin-Saint-Firmin;SAINT-MARTIN-SAINT-FIRMIN;27450;27;EURE;1
27572;;Saint-Meslin-du-Bosc;SAINT-MESLIN-DU-BOSC;27370;27;EURE;1
27573;;Saint-Nicolas-d'Attez;SAINT-NICOLAS-D'ATTEZ;27160;27;EURE;1
27574;;Saint-Nicolas-du-Bosc;SAINT-NICOLAS-DU-BOSC;27370;27;EURE;1
27576;;Sainte-Opportune-du-Bosc;SAINTE-OPPORTUNE-DU-BOSC;27110;27;EURE;1
27577;;Sainte-Opportune-la-Mare;SAINTE-OPPORTUNE-LA-MARE;27680;27;EURE;1
27578;;Saint-Ouen-d'Attez;SAINT-OUEN-D'ATTEZ;27160;27;EURE;1
27579;;Saint-Ouen-de-Pontcheuil;SAINT-OUEN-DE-PONTCHEUIL;27370;27;EURE;1
27580;;Saint-Ouen-de-Thouberville;SAINT-OUEN-DE-THOUBERVILLE;27310;27;EURE;1
27581;;Saint-Ouen-des-Champs;SAINT-OUEN-DES-CHAMPS;27680;27;EURE;1
27582;;Saint-Ouen-du-Tilleul;SAINT-OUEN-DU-TILLEUL;27670;27;EURE;1
27584;;Saint-Paul-de-Fourques;SAINT-PAUL-DE-FOURQUES;27800;27;EURE;1
27586;;Saint-Philbert-sur-Boissey;SAINT-PHILBERT-SUR-BOISSEY;27520;27;EURE;1
27587;;Saint-Philbert-sur-Risle;SAINT-PHILBERT-SUR-RISLE;27290;27;EURE;1
27588;;Saint-Pierre-d'Autils;SAINT-PIERRE-D'AUTILS;27950;27;EURE;1
27589;;Saint-Pierre-de-Bailleul;SAINT-PIERRE-DE-BAILLEUL;27920;27;EURE;1
27590;;Saint-Pierre-de-Cernières;SAINT-PIERRE-DE-CERNIERES;27390;27;EURE;1
27591;;Saint-Pierre-de-Cormeilles;SAINT-PIERRE-DE-CORMEILLES;27260;27;EURE;1
27592;;Saint-Pierre-de-Salerne;SAINT-PIERRE-DE-SALERNE;27800;27;EURE;1
27593;;Saint-Pierre-des-Fleurs;SAINT-PIERRE-DES-FLEURS;27370;27;EURE;1
27594;;Saint-Pierre-des-Ifs;SAINT-PIERRE-DES-IFS;27450;27;EURE;1
27595;;Saint-Pierre-du-Bosguérard;SAINT-PIERRE-DU-BOSGUERARD;27370;27;EURE;1
27596;;Saint-Pierre-du-Mesnil;SAINT-PIERRE-DU-MESNIL;27330;27;EURE;1
27597;;Saint-Pierre-du-Val;SAINT-PIERRE-DU-VAL;27210;27;EURE;1
27598;;Saint-Pierre-du-Vauvray;SAINT-PIERRE-DU-VAUVRAY;27430;27;EURE;1
27599;;Saint-Pierre-la-Garenne;SAINT-PIERRE-LA-GARENNE;27600;27;EURE;1
27600;;Saint-Quentin-des-Isles;SAINT-QUENTIN-DES-ISLES;27270;27;EURE;1
27601;;Saint-Samson-de-la-Roque;SAINT-SAMSON-DE-LA-ROQUE;27680;27;EURE;1
27602;;Saint-Sébastien-de-Morsent;SAINT-SEBASTIEN-DE-MORSENT;27180;27;EURE;1
27603;;Saint-Siméon;SAINT-SIMEON;27560;27;EURE;1
27604;;Saint-Sulpice-de-Grimbouville;SAINT-SULPICE-DE-GRIMBOUVILLE;27210;27;EURE;1
27605;;Saint-Sylvestre-de-Cormeilles;SAINT-SYLVESTRE-DE-CORMEILLES;27260;27;EURE;1
27606;;Saint-Symphorien;SAINT-SYMPHORIEN;27500;27;EURE;1
27607;;Saint-Thurien;SAINT-THURIEN;27680;27;EURE;1
27608;;Saint-Victor-de-Chrétienville;SAINT-VICTOR-DE-CHRETIENVILLE;27300;27;EURE;1
27609;;Saint-Victor-d'Épine;SAINT-VICTOR-D'EPINE;27800;27;EURE;1
27610;;Saint-Victor-sur-Avre;SAINT-VICTOR-SUR-AVRE;27130;27;EURE;1
27611;;Saint-Vigor;SAINT-VIGOR;27930;27;EURE;1
27612;;Saint-Vincent-des-Bois;SAINT-VINCENT-DES-BOIS;27950;27;EURE;1
27613;;Saint-Vincent-du-Boulay;SAINT-VINCENT-DU-BOULAY;27230;27;EURE;1
27614;;Sancourt;SANCOURT;27150;27;EURE;1
27615;;Sassey;SASSEY;27930;27;EURE;1
27616;La;Saussaye;SAUSSAYE;27370;27;EURE;1
27617;;Saussay-la-Campagne;SAUSSAY-LA-CAMPAGNE;27150;27;EURE;1
27618;;Sébécourt;SEBECOURT;27190;27;EURE;1
27620;;Selles;SELLES;27500;27;EURE;1
27621;;Serez;SEREZ;27220;27;EURE;1
27622;;Serquigny;SERQUIGNY;27470;27;EURE;1
27623;;Surtauville;SURTAUVILLE;27400;27;EURE;1
27624;;Surville;SURVILLE;27400;27;EURE;1
27625;;Suzay;SUZAY;27420;27;EURE;1
27626;;Theillement;THEILLEMENT;27520;27;EURE;1
27627;Le;Theil-Nolent;THEIL-NOLENT;27230;27;EURE;1
27628;;Thevray;THEVRAY;27330;27;EURE;1
27629;;Thiberville;THIBERVILLE;27230;27;EURE;1
27630;;Thibouville;THIBOUVILLE;27800;27;EURE;1
27631;;Thierville;THIERVILLE;27290;27;EURE;1
27632;Le;Thil;THIL;27150;27;EURE;1
27633;Les;Thilliers-en-Vexin;THILLIERS-EN-VEXIN;27420;27;EURE;1
27634;;Thomer-la-Sôgne;THOMER-LA-SOGNE;27240;27;EURE;1
27635;Le;Thuit;THUIT;27700;27;EURE;1
27636;Le;Thuit-Anger;THUIT-ANGER;27370;27;EURE;1
27637;;Thuit-Hébert;THUIT-HEBERT;27520;27;EURE;1
27638;Le;Thuit-Signol;THUIT-SIGNOL;27370;27;EURE;1
27639;Le;Thuit-Simer;THUIT-SIMER;27370;27;EURE;1
27640;;Tilleul-Dame-Agnès;TILLEUL-DAME-AGNES;27170;27;EURE;1
27641;Le;Tilleul-Lambert;TILLEUL-LAMBERT;27110;27;EURE;1
27642;Le;Tilleul-Othon;TILLEUL-OTHON;27170;27;EURE;1
27643;;Tillières-sur-Avre;TILLIERES-SUR-AVRE;27570;27;EURE;1
27644;;Tilly;TILLY;27510;27;EURE;1
27645;;Tocqueville;TOCQUEVILLE;27500;27;EURE;1
27646;Le;Torpt;TORPT;27210;27;EURE;1
27647;;Tosny;TOSNY;27700;27;EURE;1
27648;;Tostes;TOSTES;27340;27;EURE;1
27649;;Touffreville;TOUFFREVILLE;27440;27;EURE;1
27650;;Tournedos-Bois-Hubert;TOURNEDOS-BOIS-HUBERT;27180;27;EURE;1
27651;;Tournedos-sur-Seine;TOURNEDOS-SUR-SEINE;27100;27;EURE;1
27652;;Tourneville;TOURNEVILLE;27930;27;EURE;1
27653;;Tourny;TOURNY;27510;27;EURE;1
27654;;Tourville-la-Campagne;TOURVILLE-LA-CAMPAGNE;27370;27;EURE;1
27655;;Tourville-sur-Pont-Audemer;TOURVILLE-SUR-PONT-AUDEMER;27500;27;EURE;1
27656;;Toutainville;TOUTAINVILLE;27500;27;EURE;1
27657;;Touville;TOUVILLE;27290;27;EURE;1
27658;Le;Tremblay-Omonville;TREMBLAY-OMONVILLE;27110;27;EURE;1
27659;La;Trinité;TRINITE;27930;27;EURE;1
27660;La;Trinité-de-Réville;TRINITE-DE-REVILLE;27270;27;EURE;1
27661;La;Trinité-de-Thouberville;TRINITE-DE-THOUBERVILLE;27310;27;EURE;1
27662;;Triqueville;TRIQUEVILLE;27500;27;EURE;1
27663;Le;Troncq;TRONCQ;27110;27;EURE;1
27664;Le;Tronquay;TRONQUAY;27480;27;EURE;1
27665;;Trouville-la-Haule;TROUVILLE-LA-HAULE;27680;27;EURE;1
27666;La;Vacherie;VACHERIE;27400;27;EURE;1
27667;;Valailles;VALAILLES;27300;27;EURE;1
27668;Le;Val-David;VAL-DAVID;27120;27;EURE;1
27669;;Valletot;VALLETOT;27350;27;EURE;1
27670;;Vandrimare;VANDRIMARE;27380;27;EURE;1
27671;;Vannecrocq;VANNECROCQ;27210;27;EURE;1
27672;;Vascœuil;VASCOEUIL;27910;27;EURE;1
27673;;Vatteville;VATTEVILLE;27430;27;EURE;1
27674;;Vaux-sur-Eure;VAUX-SUR-EURE;27120;27;EURE;1
27676;;Venables;VENABLES;27940;27;EURE;1
27677;;Venon;VENON;27110;27;EURE;1
27678;Les;Ventes;VENTES;27180;27;EURE;1
27679;;Verneuil-sur-Avre;VERNEUIL-SUR-AVRE;27130;27;EURE;1
27680;;Verneusses;VERNEUSSES;27390;27;EURE;1
27681;;Vernon;VERNON;27200;27;EURE;1
27682;;Vesly;VESLY;27870;27;EURE;1
27683;;Vézillon;VEZILLON;27700;27;EURE;1
27684;Le;Vieil-Évreux;VIEIL-EVREUX;27930;27;EURE;1
27685;La;Vieille-Lyre;VIEILLE-LYRE;27330;27;EURE;1
27686;;Vieux-Port;VIEUX-PORT;27680;27;EURE;1
27687;;Vieux-Villez;VIEUX-VILLEZ;27600;27;EURE;1
27688;;Villalet;VILLALET;27240;27;EURE;1
27689;;Villegats;VILLEGATS;27120;27;EURE;1
27690;;Villers-en-Vexin;VILLERS-EN-VEXIN;27420;27;EURE;1
27691;;Villers-sur-le-Roule;VILLERS-SUR-LE-ROULE;27940;27;EURE;1
27692;;Villettes;VILLETTES;27110;27;EURE;1
27693;;Sylvains-les-Moulins;SYLVAINS-LES-MOULINS;27240;27;EURE;1
27694;;Villez-sous-Bailleul;VILLEZ-SOUS-BAILLEUL;27950;27;EURE;1
27695;;Villez-sur-le-Neubourg;VILLEZ-SUR-LE-NEUBOURG;27110;27;EURE;1
27696;;Villiers-en-Désœuvre;VILLIERS-EN-DESOEUVRE;27640;27;EURE;1
27697;;Vironvay;VIRONVAY;27400;27;EURE;1
27698;;Vitot;VITOT;27110;27;EURE;1
27699;;Voiscreville;VOISCREVILLE;27520;27;EURE;1
27700;;Vraiville;VRAIVILLE;27370;27;EURE;1
27701;;Val-de-Reuil;VAL-DE-REUIL;27100;27;EURE;1
28001;;Abondant;ABONDANT;28570;28;EURE ET LOIR;1
28002;;Allaines-Mervilliers;ALLAINES-MERVILLIERS;28310;28;EURE ET LOIR;1
28003;;Allainville;ALLAINVILLE;28500;28;EURE ET LOIR;1
28004;;Allonnes;ALLONNES;28150;28;EURE ET LOIR;1
28005;;Alluyes;ALLUYES;28800;28;EURE ET LOIR;1
28006;;Amilly;AMILLY;28300;28;EURE ET LOIR;1
28007;;Anet;ANET;28260;28;EURE ET LOIR;1
28008;;Ardelles;ARDELLES;28170;28;EURE ET LOIR;1
28009;;Ardelu;ARDELU;28700;28;EURE ET LOIR;1
28010;;Argenvilliers;ARGENVILLIERS;28420;28;EURE ET LOIR;1
28012;;Arrou;ARROU;28290;28;EURE ET LOIR;1
28013;;Aunay-sous-Auneau;AUNAY-SOUS-AUNEAU;28700;28;EURE ET LOIR;1
28014;;Aunay-sous-Crécy;AUNAY-SOUS-CRECY;28500;28;EURE ET LOIR;1
28015;;Auneau;AUNEAU;28700;28;EURE ET LOIR;1
28016;Les;Autels-Villevillon;AUTELS-VILLEVILLON;28330;28;EURE ET LOIR;1
28017;;Autheuil;AUTHEUIL;28220;28;EURE ET LOIR;1
28018;;Authon-du-Perche;AUTHON-DU-PERCHE;28330;28;EURE ET LOIR;1
28019;;Baigneaux;BAIGNEAUX;28140;28;EURE ET LOIR;1
28020;;Baignolet;BAIGNOLET;28150;28;EURE ET LOIR;1
28021;;Bailleau-le-Pin;BAILLEAU-LE-PIN;28120;28;EURE ET LOIR;1
28022;;Bailleau-l'Évêque;BAILLEAU-L'EVEQUE;28300;28;EURE ET LOIR;1
28023;;Bailleau-Armenonville;BAILLEAU-ARMENONVILLE;28320;28;EURE ET LOIR;1
28024;;Barjouville;BARJOUVILLE;28630;28;EURE ET LOIR;1
28025;;Barmainville;BARMAINVILLE;28310;28;EURE ET LOIR;1
28026;;Baudreville;BAUDREVILLE;28310;28;EURE ET LOIR;1
28027;La;Bazoche-Gouet;BAZOCHE-GOUET;28330;28;EURE ET LOIR;1
28028;;Bazoches-en-Dunois;BAZOCHES-EN-DUNOIS;28140;28;EURE ET LOIR;1
28029;;Bazoches-les-Hautes;BAZOCHES-LES-HAUTES;28140;28;EURE ET LOIR;1
28030;;Beauche;BEAUCHE;28270;28;EURE ET LOIR;1
28031;;Beaumont-les-Autels;BEAUMONT-LES-AUTELS;28420;28;EURE ET LOIR;1
28032;;Beauvilliers;BEAUVILLIERS;28150;28;EURE ET LOIR;1
28033;;Belhomert-Guéhouville;BELHOMERT-GUEHOUVILLE;28240;28;EURE ET LOIR;1
28034;;Berchères-Saint-Germain;BERCHERES-SAINT-GERMAIN;28300;28;EURE ET LOIR;1
28035;;Berchères-les-Pierres;BERCHERES-LES-PIERRES;28630;28;EURE ET LOIR;1
28036;;Berchères-sur-Vesgre;BERCHERES-SUR-VESGRE;28560;28;EURE ET LOIR;1
28037;;Bérou-la-Mulotière;BEROU-LA-MULOTIERE;28270;28;EURE ET LOIR;1
28038;;Béthonvilliers;BETHONVILLIERS;28330;28;EURE ET LOIR;1
28039;;Béville-le-Comte;BEVILLE-LE-COMTE;28700;28;EURE ET LOIR;1
28040;;Billancelles;BILLANCELLES;28190;28;EURE ET LOIR;1
28041;;Blandainville;BLANDAINVILLE;28120;28;EURE ET LOIR;1
28044;;Boisgasson;BOISGASSON;28220;28;EURE ET LOIR;1
28045;;Boissy-en-Drouais;BOISSY-EN-DROUAIS;28500;28;EURE ET LOIR;1
28046;;Boissy-lès-Perche;BOISSY-LES-PERCHE;28340;28;EURE ET LOIR;1
28047;;Boisville-la-Saint-Père;BOISVILLE-LA-SAINT-PERE;28150;28;EURE ET LOIR;1
28048;La;Bourdinière-Saint-Loup;BOURDINIERE-SAINT-LOUP;28360;28;EURE ET LOIR;1
28049;;Boncé;BONCE;28150;28;EURE ET LOIR;1
28050;;Boncourt;BONCOURT;28260;28;EURE ET LOIR;1
28051;;Bonneval;BONNEVAL;28800;28;EURE ET LOIR;1
28052;;Bouglainval;BOUGLAINVAL;28130;28;EURE ET LOIR;1
28053;Le;Boullay-les-Deux-Églises;BOULLAY-LES-DEUX-EGLISES;28170;28;EURE ET LOIR;1
28054;Le;Boullay-Mivoye;BOULLAY-MIVOYE;28210;28;EURE ET LOIR;1
28055;Le;Boullay-Thierry;BOULLAY-THIERRY;28210;28;EURE ET LOIR;1
28056;;Boutigny-Prouais;BOUTIGNY-PROUAIS;28410;28;EURE ET LOIR;1
28057;;Bouville;BOUVILLE;28800;28;EURE ET LOIR;1
28058;;Bréchamps;BRECHAMPS;28210;28;EURE ET LOIR;1
28059;;Brezolles;BREZOLLES;28270;28;EURE ET LOIR;1
28060;;Briconville;BRICONVILLE;28300;28;EURE ET LOIR;1
28061;;Brou;BROU;28160;28;EURE ET LOIR;1
28062;;Broué;BROUE;28410;28;EURE ET LOIR;1
28063;;Brunelles;BRUNELLES;28400;28;EURE ET LOIR;1
28064;;Bû;BU;28410;28;EURE ET LOIR;1
28065;;Bullainville;BULLAINVILLE;28800;28;EURE ET LOIR;1
28066;;Bullou;BULLOU;28160;28;EURE ET LOIR;1
28067;;Cernay;CERNAY;28120;28;EURE ET LOIR;1
28068;;Challet;CHALLET;28300;28;EURE ET LOIR;1
28069;;Champagne;CHAMPAGNE;28410;28;EURE ET LOIR;1
28070;;Champhol;CHAMPHOL;28300;28;EURE ET LOIR;1
28071;;Champrond-en-Gâtine;CHAMPROND-EN-GATINE;28240;28;EURE ET LOIR;1
28072;;Champrond-en-Perchet;CHAMPROND-EN-PERCHET;28400;28;EURE ET LOIR;1
28073;;Champseru;CHAMPSERU;28700;28;EURE ET LOIR;1
28074;La;Chapelle-d'Aunainville;CHAPELLE-D'AUNAINVILLE;28700;28;EURE ET LOIR;1
28075;La;Chapelle-du-Noyer;CHAPELLE-DU-NOYER;28200;28;EURE ET LOIR;1
28076;La;Chapelle-Forainvilliers;CHAPELLE-FORAINVILLIERS;28500;28;EURE ET LOIR;1
28077;La;Chapelle-Fortin;CHAPELLE-FORTIN;28340;28;EURE ET LOIR;1
28078;;Chapelle-Guillaume;CHAPELLE-GUILLAUME;28330;28;EURE ET LOIR;1
28079;;Chapelle-Royale;CHAPELLE-ROYALE;28290;28;EURE ET LOIR;1
28080;;Charbonnières;CHARBONNIERES;28330;28;EURE ET LOIR;1
28081;;Charonville;CHARONVILLE;28120;28;EURE ET LOIR;1
28082;;Charpont;CHARPONT;28500;28;EURE ET LOIR;1
28083;;Charray;CHARRAY;28220;28;EURE ET LOIR;1
28084;;Chartainvilliers;CHARTAINVILLIERS;28130;28;EURE ET LOIR;1
28085;;Chartres;CHARTRES;28000;28;EURE ET LOIR;1
28086;;Chassant;CHASSANT;28480;28;EURE ET LOIR;1
28087;;Châtaincourt;CHATAINCOURT;28270;28;EURE ET LOIR;1
28088;;Châteaudun;CHATEAUDUN;28200;28;EURE ET LOIR;1
28089;;Châteauneuf-en-Thymerais;CHATEAUNEUF-EN-THYMERAIS;28170;28;EURE ET LOIR;1
28090;Les;Châtelets;CHATELETS;28270;28;EURE ET LOIR;1
28091;Les;Châtelliers-Notre-Dame;CHATELLIERS-NOTRE-DAME;28120;28;EURE ET LOIR;1
28092;;Châtenay;CHATENAY;28700;28;EURE ET LOIR;1
28093;;Châtillon-en-Dunois;CHATILLON-EN-DUNOIS;28290;28;EURE ET LOIR;1
28094;;Chaudon;CHAUDON;28210;28;EURE ET LOIR;1
28095;;Chauffours;CHAUFFOURS;28120;28;EURE ET LOIR;1
28096;La;Chaussée-d'Ivry;CHAUSSEE-D'IVRY;28260;28;EURE ET LOIR;1
28098;;Cherisy;CHERISY;28500;28;EURE ET LOIR;1
28099;;Chuisnes;CHUISNES;28190;28;EURE ET LOIR;1
28100;;Cintray;CINTRAY;28300;28;EURE ET LOIR;1
28101;;Civry;CIVRY;28200;28;EURE ET LOIR;1
28102;;Clévilliers;CLEVILLIERS;28300;28;EURE ET LOIR;1
28103;;Cloyes-sur-le-Loir;CLOYES-SUR-LE-LOIR;28220;28;EURE ET LOIR;1
28104;;Coltainville;COLTAINVILLE;28300;28;EURE ET LOIR;1
28105;;Combres;COMBRES;28480;28;EURE ET LOIR;1
28106;;Conie-Molitard;CONIE-MOLITARD;28200;28;EURE ET LOIR;1
28107;;Corancez;CORANCEZ;28630;28;EURE ET LOIR;1
28108;;Cormainville;CORMAINVILLE;28140;28;EURE ET LOIR;1
28109;Les;Corvées-les-Yys;CORVEES-LES-YYS;28240;28;EURE ET LOIR;1
28110;Le;Coudray;COUDRAY;28630;28;EURE ET LOIR;1
28111;;Coudray-au-Perche;COUDRAY-AU-PERCHE;28330;28;EURE ET LOIR;1
28112;;Coudreceau;COUDRECEAU;28400;28;EURE ET LOIR;1
28113;;Coulombs;COULOMBS;28210;28;EURE ET LOIR;1
28114;;Courbehaye;COURBEHAYE;28140;28;EURE ET LOIR;1
28115;;Courtalain;COURTALAIN;28290;28;EURE ET LOIR;1
28116;;Courville-sur-Eure;COURVILLE-SUR-EURE;28190;28;EURE ET LOIR;1
28117;;Crécy-Couvé;CRECY-COUVE;28500;28;EURE ET LOIR;1
28118;;Croisilles;CROISILLES;28210;28;EURE ET LOIR;1
28119;La;Croix-du-Perche;CROIX-DU-PERCHE;28480;28;EURE ET LOIR;1
28120;;Crucey-Villages;CRUCEY-VILLAGES;28270;28;EURE ET LOIR;1
28121;;Dambron;DAMBRON;28140;28;EURE ET LOIR;1
28122;;Dammarie;DAMMARIE;28360;28;EURE ET LOIR;1
28123;;Dampierre-sous-Brou;DAMPIERRE-SOUS-BROU;28160;28;EURE ET LOIR;1
28124;;Dampierre-sur-Avre;DAMPIERRE-SUR-AVRE;28350;28;EURE ET LOIR;1
28126;;Dancy;DANCY;28800;28;EURE ET LOIR;1
28127;;Dangeau;DANGEAU;28160;28;EURE ET LOIR;1
28128;;Dangers;DANGERS;28190;28;EURE ET LOIR;1
28129;;Denonville;DENONVILLE;28700;28;EURE ET LOIR;1
28130;;Digny;DIGNY;28250;28;EURE ET LOIR;1
28132;;Donnemain-Saint-Mamès;DONNEMAIN-SAINT-MAMES;28200;28;EURE ET LOIR;1
28133;;Douy;DOUY;28220;28;EURE ET LOIR;1
28134;;Dreux;DREUX;28100;28;EURE ET LOIR;1
28135;;Droue-sur-Drouette;DROUE-SUR-DROUETTE;28230;28;EURE ET LOIR;1
28136;;Écluzelles;ECLUZELLES;28500;28;EURE ET LOIR;1
28137;;Écrosnes;ECROSNES;28320;28;EURE ET LOIR;1
28139;;Épeautrolles;EPEAUTROLLES;28120;28;EURE ET LOIR;1
28140;;Épernon;EPERNON;28230;28;EURE ET LOIR;1
28141;;Ermenonville-la-Grande;ERMENONVILLE-LA-GRANDE;28120;28;EURE ET LOIR;1
28142;;Ermenonville-la-Petite;ERMENONVILLE-LA-PETITE;28120;28;EURE ET LOIR;1
28143;;Escorpain;ESCORPAIN;28270;28;EURE ET LOIR;1
28144;Les;Étilleux;ETILLEUX;28330;28;EURE ET LOIR;1
28145;;Fains-la-Folie;FAINS-LA-FOLIE;28150;28;EURE ET LOIR;1
28146;;Faverolles;FAVEROLLES;28210;28;EURE ET LOIR;1
28147;;Favières;FAVIERES;28170;28;EURE ET LOIR;1
28148;Le;Favril;FAVRIL;28190;28;EURE ET LOIR;1
28149;La;Ferté-Vidame;FERTE-VIDAME;28340;28;EURE ET LOIR;1
28150;La;Ferté-Villeneuil;FERTE-VILLENEUIL;28220;28;EURE ET LOIR;1
28151;;Fessanvilliers-Mattanvilliers;FESSANVILLIERS-MATTANVILLIERS;28270;28;EURE ET LOIR;1
28153;;Flacey;FLACEY;28800;28;EURE ET LOIR;1
28154;;Fontaine-la-Guyon;FONTAINE-LA-GUYON;28190;28;EURE ET LOIR;1
28155;;Fontaine-les-Ribouts;FONTAINE-LES-RIBOUTS;28170;28;EURE ET LOIR;1
28156;;Fontaine-Simon;FONTAINE-SIMON;28240;28;EURE ET LOIR;1
28157;;Fontenay-sur-Conie;FONTENAY-SUR-CONIE;28140;28;EURE ET LOIR;1
28158;;Fontenay-sur-Eure;FONTENAY-SUR-EURE;28630;28;EURE ET LOIR;1
28159;La;Framboisière;FRAMBOISIERE;28250;28;EURE ET LOIR;1
28160;;Francourville;FRANCOURVILLE;28700;28;EURE ET LOIR;1
28161;;Frazé;FRAZE;28160;28;EURE ET LOIR;1
28162;;Fresnay-le-Comte;FRESNAY-LE-COMTE;28360;28;EURE ET LOIR;1
28163;;Fresnay-le-Gilmert;FRESNAY-LE-GILMERT;28300;28;EURE ET LOIR;1
28164;;Fresnay-l'Évêque;FRESNAY-L'EVEQUE;28310;28;EURE ET LOIR;1
28165;;Frétigny;FRETIGNY;28480;28;EURE ET LOIR;1
28166;;Friaize;FRIAIZE;28240;28;EURE ET LOIR;1
28167;;Fruncé;FRUNCE;28190;28;EURE ET LOIR;1
28168;;Gallardon;GALLARDON;28320;28;EURE ET LOIR;1
28169;;Garancières-en-Beauce;GARANCIERES-EN-BEAUCE;28700;28;EURE ET LOIR;1
28170;;Garancières-en-Drouais;GARANCIERES-EN-DROUAIS;28500;28;EURE ET LOIR;1
28171;;Garnay;GARNAY;28500;28;EURE ET LOIR;1
28172;;Gas;GAS;28320;28;EURE ET LOIR;1
28173;;Gasville-Oisème;GASVILLE-OISEME;28300;28;EURE ET LOIR;1
28175;La;Gaudaine;GAUDAINE;28400;28;EURE ET LOIR;1
28176;Le;Gault-Saint-Denis;GAULT-SAINT-DENIS;28800;28;EURE ET LOIR;1
28177;;Gellainville;GELLAINVILLE;28630;28;EURE ET LOIR;1
28178;;Germainville;GERMAINVILLE;28500;28;EURE ET LOIR;1
28179;;Germignonville;GERMIGNONVILLE;28140;28;EURE ET LOIR;1
28180;;Gilles;GILLES;28260;28;EURE ET LOIR;1
28182;;Gohory;GOHORY;28160;28;EURE ET LOIR;1
28183;;Gommerville;GOMMERVILLE;28310;28;EURE ET LOIR;1
28184;;Gouillons;GOUILLONS;28310;28;EURE ET LOIR;1
28185;;Goussainville;GOUSSAINVILLE;28410;28;EURE ET LOIR;1
28187;;Guainville;GUAINVILLE;28260;28;EURE ET LOIR;1
28188;Le;Gué-de-Longroi;GUE-DE-LONGROI;28700;28;EURE ET LOIR;1
28189;;Guilleville;GUILLEVILLE;28310;28;EURE ET LOIR;1
28190;;Guillonville;GUILLONVILLE;28140;28;EURE ET LOIR;1
28191;;Hanches;HANCHES;28130;28;EURE ET LOIR;1
28192;;Happonvilliers;HAPPONVILLIERS;28480;28;EURE ET LOIR;1
28193;;Havelu;HAVELU;28410;28;EURE ET LOIR;1
28194;;Houville-la-Branche;HOUVILLE-LA-BRANCHE;28700;28;EURE ET LOIR;1
28195;;Houx;HOUX;28130;28;EURE ET LOIR;1
28196;;Illiers-Combray;ILLIERS-COMBRAY;28120;28;EURE ET LOIR;1
28197;;Intréville;INTREVILLE;28310;28;EURE ET LOIR;1
28198;;Jallans;JALLANS;28200;28;EURE ET LOIR;1
28199;;Janville;JANVILLE;28310;28;EURE ET LOIR;1
28200;;Jaudrais;JAUDRAIS;28250;28;EURE ET LOIR;1
28201;;Jouy;JOUY;28300;28;EURE ET LOIR;1
28202;;Lamblore;LAMBLORE;28340;28;EURE ET LOIR;1
28203;;Landelles;LANDELLES;28190;28;EURE ET LOIR;1
28204;;Langey;LANGEY;28220;28;EURE ET LOIR;1
28205;;Lanneray;LANNERAY;28200;28;EURE ET LOIR;1
28206;;Laons;LAONS;28270;28;EURE ET LOIR;1
28207;;Léthuin;LETHUIN;28700;28;EURE ET LOIR;1
28208;;Levainville;LEVAINVILLE;28700;28;EURE ET LOIR;1
28209;;Lèves;LEVES;28300;28;EURE ET LOIR;1
28210;;Levesville-la-Chenard;LEVESVILLE-LA-CHENARD;28310;28;EURE ET LOIR;1
28211;;Logron;LOGRON;28200;28;EURE ET LOIR;1
28212;;Loigny-la-Bataille;LOIGNY-LA-BATAILLE;28140;28;EURE ET LOIR;1
28213;;Lormaye;LORMAYE;28210;28;EURE ET LOIR;1
28214;La;Loupe;LOUPE;28240;28;EURE ET LOIR;1
28215;;Louville-la-Chenard;LOUVILLE-LA-CHENARD;28150;28;EURE ET LOIR;1
28216;;Louvilliers-en-Drouais;LOUVILLIERS-EN-DROUAIS;28500;28;EURE ET LOIR;1
28217;;Louvilliers-lès-Perche;LOUVILLIERS-LES-PERCHE;28250;28;EURE ET LOIR;1
28218;;Lucé;LUCE;28110;28;EURE ET LOIR;1
28219;;Luigny;LUIGNY;28420;28;EURE ET LOIR;1
28220;;Luisant;LUISANT;28600;28;EURE ET LOIR;1
28221;;Lumeau;LUMEAU;28140;28;EURE ET LOIR;1
28222;;Luplanté;LUPLANTE;28360;28;EURE ET LOIR;1
28223;;Luray;LURAY;28500;28;EURE ET LOIR;1
28224;;Lutz-en-Dunois;LUTZ-EN-DUNOIS;28200;28;EURE ET LOIR;1
28225;;Magny;MAGNY;28120;28;EURE ET LOIR;1
28226;;Maillebois;MAILLEBOIS;28170;28;EURE ET LOIR;1
28227;;Maintenon;MAINTENON;28130;28;EURE ET LOIR;1
28229;;Mainvilliers;MAINVILLIERS;28300;28;EURE ET LOIR;1
28230;;Maisons;MAISONS;28700;28;EURE ET LOIR;1
28231;La;Mancelière;MANCELIERE;28270;28;EURE ET LOIR;1
28232;;Manou;MANOU;28240;28;EURE ET LOIR;1
28233;;Marboué;MARBOUE;28200;28;EURE ET LOIR;1
28234;;Marchéville;MARCHEVILLE;28120;28;EURE ET LOIR;1
28235;;Marchezais;MARCHEZAIS;28410;28;EURE ET LOIR;1
28236;;Margon;MARGON;28400;28;EURE ET LOIR;1
28237;;Marolles-les-Buis;MAROLLES-LES-BUIS;28400;28;EURE ET LOIR;1
28239;;Marville-Moutiers-Brûlé;MARVILLE-MOUTIERS-BRULE;28500;28;EURE ET LOIR;1
28240;;Meaucé;MEAUCE;28240;28;EURE ET LOIR;1
28241;Le;Mée;MEE;28220;28;EURE ET LOIR;1
28242;;Méréglise;MEREGLISE;28120;28;EURE ET LOIR;1
28243;;Mérouville;MEROUVILLE;28310;28;EURE ET LOIR;1
28245;;Meslay-le-Grenet;MESLAY-LE-GRENET;28120;28;EURE ET LOIR;1
28246;;Meslay-le-Vidame;MESLAY-LE-VIDAME;28360;28;EURE ET LOIR;1
28247;Le;Mesnil-Simon;MESNIL-SIMON;28260;28;EURE ET LOIR;1
28248;Le;Mesnil-Thomas;MESNIL-THOMAS;28250;28;EURE ET LOIR;1
28249;;Mévoisins;MEVOISINS;28130;28;EURE ET LOIR;1
28250;;Mézières-au-Perche;MEZIERES-AU-PERCHE;28160;28;EURE ET LOIR;1
28251;;Mézières-en-Drouais;MEZIERES-EN-DROUAIS;28500;28;EURE ET LOIR;1
28252;;Miermaigne;MIERMAIGNE;28420;28;EURE ET LOIR;1
28253;;Mignières;MIGNIERES;28630;28;EURE ET LOIR;1
28254;;Mittainvilliers;MITTAINVILLIERS;28190;28;EURE ET LOIR;1
28255;;Moinville-la-Jeulin;MOINVILLE-LA-JEULIN;28700;28;EURE ET LOIR;1
28256;;Moléans;MOLEANS;28200;28;EURE ET LOIR;1
28257;;Mondonville-Saint-Jean;MONDONVILLE-SAINT-JEAN;28700;28;EURE ET LOIR;1
28258;;Montainville;MONTAINVILLE;28150;28;EURE ET LOIR;1
28259;;Montboissier;MONTBOISSIER;28800;28;EURE ET LOIR;1
28260;;Montharville;MONTHARVILLE;28800;28;EURE ET LOIR;1
28261;;Montigny-le-Chartif;MONTIGNY-LE-CHARTIF;28120;28;EURE ET LOIR;1
28262;;Montigny-le-Gannelon;MONTIGNY-LE-GANNELON;28220;28;EURE ET LOIR;1
28263;;Montigny-sur-Avre;MONTIGNY-SUR-AVRE;28270;28;EURE ET LOIR;1
28264;;Montireau;MONTIREAU;28240;28;EURE ET LOIR;1
28265;;Montlandon;MONTLANDON;28240;28;EURE ET LOIR;1
28267;;Montreuil;MONTREUIL;28500;28;EURE ET LOIR;1
28268;;Morainville;MORAINVILLE;28700;28;EURE ET LOIR;1
28269;;Morancez;MORANCEZ;28630;28;EURE ET LOIR;1
28270;;Moriers;MORIERS;28800;28;EURE ET LOIR;1
28271;;Morvilliers;MORVILLIERS;28340;28;EURE ET LOIR;1
28272;;Mottereau;MOTTEREAU;28160;28;EURE ET LOIR;1
28273;;Moulhard;MOULHARD;28160;28;EURE ET LOIR;1
28274;;Moutiers;MOUTIERS;28150;28;EURE ET LOIR;1
28275;;Néron;NERON;28210;28;EURE ET LOIR;1
28276;;Neuvy-en-Beauce;NEUVY-EN-BEAUCE;28310;28;EURE ET LOIR;1
28277;;Neuvy-en-Dunois;NEUVY-EN-DUNOIS;28800;28;EURE ET LOIR;1
28278;;Nogent-le-Phaye;NOGENT-LE-PHAYE;28630;28;EURE ET LOIR;1
28279;;Nogent-le-Roi;NOGENT-LE-ROI;28210;28;EURE ET LOIR;1
28280;;Nogent-le-Rotrou;NOGENT-LE-ROTROU;28400;28;EURE ET LOIR;1
28281;;Nogent-sur-Eure;NOGENT-SUR-EURE;28120;28;EURE ET LOIR;1
28282;;Nonvilliers-Grandhoux;NONVILLIERS-GRANDHOUX;28120;28;EURE ET LOIR;1
28283;;Nottonville;NOTTONVILLE;28140;28;EURE ET LOIR;1
28284;;Oinville-Saint-Liphard;OINVILLE-SAINT-LIPHARD;28310;28;EURE ET LOIR;1
28285;;Oinville-sous-Auneau;OINVILLE-SOUS-AUNEAU;28700;28;EURE ET LOIR;1
28286;;Ollé;OLLE;28120;28;EURE ET LOIR;1
28287;;Orgères-en-Beauce;ORGERES-EN-BEAUCE;28140;28;EURE ET LOIR;1
28288;;Orlu;ORLU;28700;28;EURE ET LOIR;1
28289;;Ormoy;ORMOY;28210;28;EURE ET LOIR;1
28290;;Orrouer;ORROUER;28190;28;EURE ET LOIR;1
28291;;Ouarville;OUARVILLE;28150;28;EURE ET LOIR;1
28292;;Ouerre;OUERRE;28500;28;EURE ET LOIR;1
28293;;Oulins;OULINS;28260;28;EURE ET LOIR;1
28294;;Oysonville;OYSONVILLE;28700;28;EURE ET LOIR;1
28295;;Ozoir-le-Breuil;OZOIR-LE-BREUIL;28200;28;EURE ET LOIR;1
28296;;Péronville;PERONVILLE;28140;28;EURE ET LOIR;1
28297;;Pézy;PEZY;28150;28;EURE ET LOIR;1
28298;;Pierres;PIERRES;28130;28;EURE ET LOIR;1
28299;Les;Pinthières;PINTHIERES;28210;28;EURE ET LOIR;1
28300;;Poinville;POINVILLE;28310;28;EURE ET LOIR;1
28301;;Poisvilliers;POISVILLIERS;28300;28;EURE ET LOIR;1
28302;;Pontgouin;PONTGOUIN;28190;28;EURE ET LOIR;1
28303;;Poupry;POUPRY;28140;28;EURE ET LOIR;1
28304;;Prasville;PRASVILLE;28150;28;EURE ET LOIR;1
28305;;Pré-Saint-Évroult;PRE-SAINT-EVROULT;28800;28;EURE ET LOIR;1
28306;;Pré-Saint-Martin;PRE-SAINT-MARTIN;28800;28;EURE ET LOIR;1
28308;;Prudemanche;PRUDEMANCHE;28270;28;EURE ET LOIR;1
28309;;Prunay-le-Gillon;PRUNAY-LE-GILLON;28360;28;EURE ET LOIR;1
28310;La;Puisaye;PUISAYE;28250;28;EURE ET LOIR;1
28311;Le;Puiset;PUISET;28310;28;EURE ET LOIR;1
28312;;Puiseux;PUISEUX;28170;28;EURE ET LOIR;1
28313;;Réclainville;RECLAINVILLE;28150;28;EURE ET LOIR;1
28314;Les;Ressuintes;RESSUINTES;28340;28;EURE ET LOIR;1
28315;;Revercourt;REVERCOURT;28270;28;EURE ET LOIR;1
28316;;Rohaire;ROHAIRE;28340;28;EURE ET LOIR;1
28317;;Roinville;ROINVILLE;28700;28;EURE ET LOIR;1
28318;;Romilly-sur-Aigre;ROMILLY-SUR-AIGRE;28220;28;EURE ET LOIR;1
28319;;Rouvray-Saint-Denis;ROUVRAY-SAINT-DENIS;28310;28;EURE ET LOIR;1
28320;;Rouvray-Saint-Florentin;ROUVRAY-SAINT-FLORENTIN;28150;28;EURE ET LOIR;1
28321;;Rouvres;ROUVRES;28260;28;EURE ET LOIR;1
28322;;Rueil-la-Gadelière;RUEIL-LA-GADELIERE;28270;28;EURE ET LOIR;1
28323;;Saint-Ange-et-Torçay;SAINT-ANGE-ET-TORCAY;28170;28;EURE ET LOIR;1
28324;;Saint-Arnoult-des-Bois;SAINT-ARNOULT-DES-BOIS;28190;28;EURE ET LOIR;1
28325;;Saint-Aubin-des-Bois;SAINT-AUBIN-DES-BOIS;28300;28;EURE ET LOIR;1
28326;;Saint-Avit-les-Guespières;SAINT-AVIT-LES-GUESPIERES;28120;28;EURE ET LOIR;1
28327;;Saint-Bomer;SAINT-BOMER;28330;28;EURE ET LOIR;1
28329;;Saint-Christophe;SAINT-CHRISTOPHE;28200;28;EURE ET LOIR;1
28330;;Saint-Cloud-en-Dunois;SAINT-CLOUD-EN-DUNOIS;28200;28;EURE ET LOIR;1
28331;;Saint-Denis-d'Authou;SAINT-DENIS-D'AUTHOU;28480;28;EURE ET LOIR;1
28332;;Sainte-Gemme-Moronval;SAINTE-GEMME-MORONVAL;28500;28;EURE ET LOIR;1
28333;;Saint-Denis-des-Puits;SAINT-DENIS-DES-PUITS;28240;28;EURE ET LOIR;1
28334;;Saint-Denis-les-Ponts;SAINT-DENIS-LES-PONTS;28200;28;EURE ET LOIR;1
28335;;Saint-Éliph;SAINT-ELIPH;28240;28;EURE ET LOIR;1
28336;;Saint-Éman;SAINT-EMAN;28120;28;EURE ET LOIR;1
28337;;Saint-Georges-sur-Eure;SAINT-GEORGES-SUR-EURE;28190;28;EURE ET LOIR;1
28339;;Saint-Germain-le-Gaillard;SAINT-GERMAIN-LE-GAILLARD;28190;28;EURE ET LOIR;1
28340;;Saint-Hilaire-sur-Yerre;SAINT-HILAIRE-SUR-YERRE;28220;28;EURE ET LOIR;1
28341;;Saint-Jean-de-Rebervilliers;SAINT-JEAN-DE-REBERVILLIERS;28170;28;EURE ET LOIR;1
28342;;Saint-Jean-Pierre-Fixte;SAINT-JEAN-PIERRE-FIXTE;28400;28;EURE ET LOIR;1
28343;;Saint-Laurent-la-Gâtine;SAINT-LAURENT-LA-GATINE;28210;28;EURE ET LOIR;1
28344;;Saint-Léger-des-Aubées;SAINT-LEGER-DES-AUBEES;28700;28;EURE ET LOIR;1
28346;;Saint-Lubin-de-Cravant;SAINT-LUBIN-DE-CRAVANT;28270;28;EURE ET LOIR;1
28347;;Saint-Lubin-de-la-Haye;SAINT-LUBIN-DE-LA-HAYE;28410;28;EURE ET LOIR;1
28348;;Saint-Lubin-des-Joncherets;SAINT-LUBIN-DES-JONCHERETS;28350;28;EURE ET LOIR;1
28349;;Saint-Lucien;SAINT-LUCIEN;28210;28;EURE ET LOIR;1
28350;;Saint-Luperce;SAINT-LUPERCE;28190;28;EURE ET LOIR;1
28351;;Saint-Maixme-Hauterive;SAINT-MAIXME-HAUTERIVE;28170;28;EURE ET LOIR;1
28352;;Saint-Martin-de-Nigelles;SAINT-MARTIN-DE-NIGELLES;28130;28;EURE ET LOIR;1
28353;;Saint-Maur-sur-le-Loir;SAINT-MAUR-SUR-LE-LOIR;28800;28;EURE ET LOIR;1
28354;;Saint-Maurice-Saint-Germain;SAINT-MAURICE-SAINT-GERMAIN;28240;28;EURE ET LOIR;1
28355;;Saint-Ouen-Marchefroy;SAINT-OUEN-MARCHEFROY;28560;28;EURE ET LOIR;1
28356;;Saint-Pellerin;SAINT-PELLERIN;28290;28;EURE ET LOIR;1
28357;;Saint-Piat;SAINT-PIAT;28130;28;EURE ET LOIR;1
28358;;Saint-Prest;SAINT-PREST;28300;28;EURE ET LOIR;1
28359;;Saint-Rémy-sur-Avre;SAINT-REMY-SUR-AVRE;28380;28;EURE ET LOIR;1
28360;;Saint-Sauveur-Marville;SAINT-SAUVEUR-MARVILLE;28170;28;EURE ET LOIR;1
28361;;-;BLEURY;28700;28;EURE ET LOIR;1
28362;;Saint-Victor-de-Buthon;SAINT-VICTOR-DE-BUTHON;28240;28;EURE ET LOIR;1
28363;;Sainville;SAINVILLE;28700;28;EURE ET LOIR;1
28364;;Sancheville;SANCHEVILLE;28800;28;EURE ET LOIR;1
28365;;Sandarville;SANDARVILLE;28120;28;EURE ET LOIR;1
28366;;Santeuil;SANTEUIL;28700;28;EURE ET LOIR;1
28367;;Santilly;SANTILLY;28310;28;EURE ET LOIR;1
28368;La;Saucelle;SAUCELLE;28250;28;EURE ET LOIR;1
28369;;Saulnières;SAULNIERES;28500;28;EURE ET LOIR;1
28370;;Saumeray;SAUMERAY;28800;28;EURE ET LOIR;1
28371;;Saussay;SAUSSAY;28260;28;EURE ET LOIR;1
28372;;Senantes;SENANTES;28210;28;EURE ET LOIR;1
28373;;Senonches;SENONCHES;28250;28;EURE ET LOIR;1
28374;;Serazereux;SERAZEREUX;28170;28;EURE ET LOIR;1
28375;;Serville;SERVILLE;28410;28;EURE ET LOIR;1
28376;;Soizé;SOIZE;28330;28;EURE ET LOIR;1
28377;;Sorel-Moussel;SOREL-MOUSSEL;28520;28;EURE ET LOIR;1
28378;;Souancé-au-Perche;SOUANCE-AU-PERCHE;28400;28;EURE ET LOIR;1
28379;;Soulaires;SOULAIRES;28130;28;EURE ET LOIR;1
28380;;Sours;SOURS;28630;28;EURE ET LOIR;1
28382;;Terminiers;TERMINIERS;28140;28;EURE ET LOIR;1
28383;;Theuville;THEUVILLE;28360;28;EURE ET LOIR;1
28385;Le;Thieulin;THIEULIN;28240;28;EURE ET LOIR;1
28386;;Thimert-Gâtelles;THIMERT-GATELLES;28170;28;EURE ET LOIR;1
28387;;Thiron-Gardais;THIRON-GARDAIS;28480;28;EURE ET LOIR;1
28388;;Thivars;THIVARS;28630;28;EURE ET LOIR;1
28389;;Thiville;THIVILLE;28200;28;EURE ET LOIR;1
28390;;Tillay-le-Péneux;TILLAY-LE-PENEUX;28140;28;EURE ET LOIR;1
28391;;Toury;TOURY;28390;28;EURE ET LOIR;1
28392;;Trancrainville;TRANCRAINVILLE;28310;28;EURE ET LOIR;1
28393;;Tremblay-les-Villages;TREMBLAY-LES-VILLAGES;28170;28;EURE ET LOIR;1
28394;;Tréon;TREON;28500;28;EURE ET LOIR;1
28395;;Trizay-Coutretot-Saint-Serge;TRIZAY-COUTRETOT-SAINT-SERGE;28400;28;EURE ET LOIR;1
28396;;Trizay-lès-Bonneval;TRIZAY-LES-BONNEVAL;28800;28;EURE ET LOIR;1
28397;;Umpeau;UMPEAU;28700;28;EURE ET LOIR;1
28398;;Unverre;UNVERRE;28160;28;EURE ET LOIR;1
28400;;Varize;VARIZE;28140;28;EURE ET LOIR;1
28401;;Vaupillon;VAUPILLON;28240;28;EURE ET LOIR;1
28402;;Vérigny;VERIGNY;28190;28;EURE ET LOIR;1
28403;;Ver-lès-Chartres;VER-LES-CHARTRES;28630;28;EURE ET LOIR;1
28404;;Vernouillet;VERNOUILLET;28500;28;EURE ET LOIR;1
28405;;Vert-en-Drouais;VERT-EN-DROUAIS;28500;28;EURE ET LOIR;1
28406;;Viabon;VIABON;28150;28;EURE ET LOIR;1
28407;;Vichères;VICHERES;28420;28;EURE ET LOIR;1
28408;;Vierville;VIERVILLE;28700;28;EURE ET LOIR;1
28409;;Vieuvicq;VIEUVICQ;28120;28;EURE ET LOIR;1
28410;;Villampuy;VILLAMPUY;28200;28;EURE ET LOIR;1
28411;;Villars;VILLARS;28150;28;EURE ET LOIR;1
28412;;Villeau;VILLEAU;28150;28;EURE ET LOIR;1
28414;;Villebon;VILLEBON;28190;28;EURE ET LOIR;1
28415;;Villemeux-sur-Eure;VILLEMEUX-SUR-EURE;28210;28;EURE ET LOIR;1
28416;;Villeneuve-Saint-Nicolas;VILLENEUVE-SAINT-NICOLAS;28150;28;EURE ET LOIR;1
28417;;Villiers-le-Morhier;VILLIERS-LE-MORHIER;28130;28;EURE ET LOIR;1
28418;;Villiers-Saint-Orien;VILLIERS-SAINT-ORIEN;28800;28;EURE ET LOIR;1
28419;;Vitray-en-Beauce;VITRAY-EN-BEAUCE;28360;28;EURE ET LOIR;1
28421;;Voise;VOISE;28700;28;EURE ET LOIR;1
28422;;Voves;VOVES;28150;28;EURE ET LOIR;1
28423;;Yermenonville;YERMENONVILLE;28130;28;EURE ET LOIR;1
28424;;Yèvres;YEVRES;28160;28;EURE ET LOIR;1
28425;;Ymeray;YMERAY;28320;28;EURE ET LOIR;1
28426;;Ymonville;YMONVILLE;28150;28;EURE ET LOIR;1
29001;;Argol;ARGOL;29560;29;FINISTERE;1
29002;;Arzano;ARZANO;29300;29;FINISTERE;1
29003;;Audierne;AUDIERNE;29770;29;FINISTERE;1
29004;;Bannalec;BANNALEC;29380;29;FINISTERE;1
29005;;Baye;BAYE;29300;29;FINISTERE;1
29006;;Bénodet;BENODET;29950;29;FINISTERE;1
29007;;Berrien;BERRIEN;29690;29;FINISTERE;1
29008;;Beuzec-Cap-Sizun;BEUZEC-CAP-SIZUN;29790;29;FINISTERE;1
29010;;Bodilis;BODILIS;29400;29;FINISTERE;1
29011;;Bohars;BOHARS;29820;29;FINISTERE;1
29012;;Bolazec;BOLAZEC;29640;29;FINISTERE;1
29013;;Botmeur;BOTMEUR;29690;29;FINISTERE;1
29014;;Botsorhel;BOTSORHEL;29650;29;FINISTERE;1
29015;;Bourg-Blanc;BOURG-BLANC;29860;29;FINISTERE;1
29016;;Brasparts;BRASPARTS;29190;29;FINISTERE;1
29017;;Brélès;BRELES;29810;29;FINISTERE;1
29018;;Brennilis;BRENNILIS;29690;29;FINISTERE;1
29019;;Brest;BREST;29200;29;FINISTERE;1
29020;;Briec;BRIEC;29510;29;FINISTERE;1
29021;;Brignogan-Plage;BRIGNOGAN-PLAGE;29890;29;FINISTERE;1
29022;;Camaret-sur-Mer;CAMARET-SUR-MER;29570;29;FINISTERE;1
29023;;Carantec;CARANTEC;29660;29;FINISTERE;1
29024;;Carhaix-Plouguer;CARHAIX-PLOUGUER;29270;29;FINISTERE;1
29025;;Cast;CAST;29150;29;FINISTERE;1
29026;;Châteaulin;CHATEAULIN;29150;29;FINISTERE;1
29027;;Châteauneuf-du-Faou;CHATEAUNEUF-DU-FAOU;29520;29;FINISTERE;1
29028;;Cléden-Cap-Sizun;CLEDEN-CAP-SIZUN;29770;29;FINISTERE;1
29029;;Cléden-Poher;CLEDEN-POHER;29270;29;FINISTERE;1
29030;;Cléder;CLEDER;29233;29;FINISTERE;1
29031;;Clohars-Carnoët;CLOHARS-CARNOET;29360;29;FINISTERE;1
29032;;Clohars-Fouesnant;CLOHARS-FOUESNANT;29950;29;FINISTERE;1
29033;Le;Cloître-Pleyben;CLOITRE-PLEYBEN;29190;29;FINISTERE;1
29034;Le;Cloître-Saint-Thégonnec;CLOITRE-SAINT-THEGONNEC;29410;29;FINISTERE;1
29035;;Coat-Méal;COAT-MEAL;29870;29;FINISTERE;1
29036;;Collorec;COLLOREC;29530;29;FINISTERE;1
29037;;Combrit;COMBRIT;29120;29;FINISTERE;1
29038;;Commana;COMMANA;29450;29;FINISTERE;1
29039;;Concarneau;CONCARNEAU;29900;29;FINISTERE;1
29040;Le;Conquet;CONQUET;29217;29;FINISTERE;1
29041;;Coray;CORAY;29370;29;FINISTERE;1
29042;;Crozon;CROZON;29160;29;FINISTERE;1
29043;;Daoulas;DAOULAS;29460;29;FINISTERE;1
29044;;Dinéault;DINEAULT;29150;29;FINISTERE;1
29045;;Dirinon;DIRINON;29460;29;FINISTERE;1
29046;;Douarnenez;DOUARNENEZ;29100;29;FINISTERE;1
29047;Le;Drennec;DRENNEC;29860;29;FINISTERE;1
29048;;Edern;EDERN;29510;29;FINISTERE;1
29049;;Elliant;ELLIANT;29370;29;FINISTERE;1
29051;;Ergué-Gabéric;ERGUE-GABERIC;29500;29;FINISTERE;1
29052;;Esquibien;ESQUIBIEN;29770;29;FINISTERE;1
29053;Le;Faou;FAOU;29590;29;FINISTERE;1
29054;La;Feuillée;FEUILLEE;29690;29;FINISTERE;1
29055;Le;Folgoët;FOLGOET;29260;29;FINISTERE;1
29056;La;Forest-Landerneau;FOREST-LANDERNEAU;29800;29;FINISTERE;1
29057;La;Forêt-Fouesnant;FORET-FOUESNANT;29940;29;FINISTERE;1
29058;;Fouesnant;FOUESNANT;29170;29;FINISTERE;1
29059;;Garlan;GARLAN;29610;29;FINISTERE;1
29060;;Gouesnach;GOUESNACH;29950;29;FINISTERE;1
29061;;Gouesnou;GOUESNOU;29850;29;FINISTERE;1
29062;;Gouézec;GOUEZEC;29190;29;FINISTERE;1
29063;;Goulien;GOULIEN;29770;29;FINISTERE;1
29064;;Goulven;GOULVEN;29890;29;FINISTERE;1
29065;;Gourlizon;GOURLIZON;29710;29;FINISTERE;1
29066;;Guengat;GUENGAT;29180;29;FINISTERE;1
29067;;Guerlesquin;GUERLESQUIN;29650;29;FINISTERE;1
29068;;Guiclan;GUICLAN;29410;29;FINISTERE;1
29069;;Guilers;GUILERS;29820;29;FINISTERE;1
29070;;Guiler-sur-Goyen;GUILER-SUR-GOYEN;29710;29;FINISTERE;1
29071;;Guilligomarc'h;GUILLIGOMARC'H;29300;29;FINISTERE;1
29072;;Guilvinec;GUILVINEC;29730;29;FINISTERE;1
29073;;Guimaëc;GUIMAEC;29620;29;FINISTERE;1
29074;;Guimiliau;GUIMILIAU;29400;29;FINISTERE;1
29075;;Guipavas;GUIPAVAS;29490;29;FINISTERE;1
29076;;Guipronvel;GUIPRONVEL;29290;29;FINISTERE;1
29077;;Guissény;GUISSENY;29880;29;FINISTERE;1
29078;;Hanvec;HANVEC;29460;29;FINISTERE;1
29079;;Henvic;HENVIC;29670;29;FINISTERE;1
29080;;Hôpital-Camfrout;HOPITAL-CAMFROUT;29460;29;FINISTERE;1
29081;;Huelgoat;HUELGOAT;29690;29;FINISTERE;1
29082;;Île-de-Batz;ILE-DE-BATZ;29253;29;FINISTERE;1
29083;;Île-de-Sein;ILE-DE-SEIN;29990;29;FINISTERE;1
29084;;Île-Molène;ILE-MOLENE;29259;29;FINISTERE;1
29085;;Île-Tudy;ILE-TUDY;29980;29;FINISTERE;1
29086;;Irvillac;IRVILLAC;29460;29;FINISTERE;1
29087;Le;Juch;JUCH;29100;29;FINISTERE;1
29089;;Kergloff;KERGLOFF;29270;29;FINISTERE;1
29090;;Kerlaz;KERLAZ;29100;29;FINISTERE;1
29091;;Kerlouan;KERLOUAN;29890;29;FINISTERE;1
29093;;Kernilis;KERNILIS;29260;29;FINISTERE;1
29094;;Kernouës;KERNOUES;29260;29;FINISTERE;1
29095;;Kersaint-Plabennec;KERSAINT-PLABENNEC;29860;29;FINISTERE;1
29097;;Lampaul-Guimiliau;LAMPAUL-GUIMILIAU;29400;29;FINISTERE;1
29098;;Lampaul-Plouarzel;LAMPAUL-PLOUARZEL;29810;29;FINISTERE;1
29099;;Lampaul-Ploudalmézeau;LAMPAUL-PLOUDALMEZEAU;29830;29;FINISTERE;1
29100;;Lanarvily;LANARVILY;29260;29;FINISTERE;1
29101;;Landéda;LANDEDA;29870;29;FINISTERE;1
29102;;Landeleau;LANDELEAU;29530;29;FINISTERE;1
29103;;Landerneau;LANDERNEAU;29800;29;FINISTERE;1
29104;;Landévennec;LANDEVENNEC;29560;29;FINISTERE;1
29105;;Landivisiau;LANDIVISIAU;29400;29;FINISTERE;1
29106;;Landrévarzec;LANDREVARZEC;29510;29;FINISTERE;1
29107;;Landudal;LANDUDAL;29510;29;FINISTERE;1
29108;;Landudec;LANDUDEC;29710;29;FINISTERE;1
29109;;Landunvez;LANDUNVEZ;29840;29;FINISTERE;1
29110;;Langolen;LANGOLEN;29510;29;FINISTERE;1
29111;;Lanhouarneau;LANHOUARNEAU;29430;29;FINISTERE;1
29112;;Lanildut;LANILDUT;29840;29;FINISTERE;1
29113;;Lanmeur;LANMEUR;29620;29;FINISTERE;1
29114;;Lannéanou;LANNEANOU;29640;29;FINISTERE;1
29115;;Lannédern;LANNEDERN;29190;29;FINISTERE;1
29116;;Lanneuffret;LANNEUFFRET;29400;29;FINISTERE;1
29117;;Lannilis;LANNILIS;29870;29;FINISTERE;1
29119;;Lanrivoaré;LANRIVOARE;29290;29;FINISTERE;1
29120;;Lanvéoc;LANVEOC;29160;29;FINISTERE;1
29122;;Laz;LAZ;29520;29;FINISTERE;1
29123;;Lennon;LENNON;29190;29;FINISTERE;1
29124;;Lesneven;LESNEVEN;29260;29;FINISTERE;1
29125;;Leuhan;LEUHAN;29390;29;FINISTERE;1
29126;;Loc-Brévalaire;LOC-BREVALAIRE;29260;29;FINISTERE;1
29127;;Loc-Eguiner-Saint-Thégonnec;LOC-EGUINER-SAINT-THEGONNEC;29410;29;FINISTERE;1
29128;;Loc-Eguiner;LOC-EGUINER;29400;29;FINISTERE;1
29129;;Locmaria-Berrien;LOCMARIA-BERRIEN;29690;29;FINISTERE;1
29130;;Locmaria-Plouzané;LOCMARIA-PLOUZANE;29280;29;FINISTERE;1
29131;;Locmélar;LOCMELAR;29400;29;FINISTERE;1
29132;;Locquénolé;LOCQUENOLE;29670;29;FINISTERE;1
29133;;Locquirec;LOCQUIREC;29241;29;FINISTERE;1
29134;;Locronan;LOCRONAN;29180;29;FINISTERE;1
29135;;Loctudy;LOCTUDY;29750;29;FINISTERE;1
29136;;Locunolé;LOCUNOLE;29310;29;FINISTERE;1
29137;;Logonna-Daoulas;LOGONNA-DAOULAS;29460;29;FINISTERE;1
29139;;Lopérec;LOPEREC;29590;29;FINISTERE;1
29140;;Loperhet;LOPERHET;29470;29;FINISTERE;1
29141;;Loqueffret;LOQUEFFRET;29530;29;FINISTERE;1
29142;;Lothey;LOTHEY;29190;29;FINISTERE;1
29143;;Mahalon;MAHALON;29790;29;FINISTERE;1
29144;La;Martyre;MARTYRE;29800;29;FINISTERE;1
29145;;Confort-Meilars;CONFORT-MEILARS;29790;29;FINISTERE;1
29146;;Melgven;MELGVEN;29140;29;FINISTERE;1
29147;;Mellac;MELLAC;29300;29;FINISTERE;1
29148;;Mespaul;MESPAUL;29420;29;FINISTERE;1
29149;;Milizac;MILIZAC;29290;29;FINISTERE;1
29150;;Moëlan-sur-Mer;MOELAN-SUR-MER;29350;29;FINISTERE;1
29151;;Morlaix;MORLAIX;29600;29;FINISTERE;1
29152;;Motreff;MOTREFF;29270;29;FINISTERE;1
29153;;Névez;NEVEZ;29920;29;FINISTERE;1
29155;;Ouessant;OUESSANT;29242;29;FINISTERE;1
29156;;Pencran;PENCRAN;29800;29;FINISTERE;1
29158;;Penmarch;PENMARCH;29760;29;FINISTERE;1
29159;;Peumérit;PEUMERIT;29710;29;FINISTERE;1
29160;;Plabennec;PLABENNEC;29860;29;FINISTERE;1
29161;;Pleuven;PLEUVEN;29170;29;FINISTERE;1
29162;;Pleyben;PLEYBEN;29190;29;FINISTERE;1
29163;;Pleyber-Christ;PLEYBER-CHRIST;29410;29;FINISTERE;1
29165;;Plobannalec-Lesconil;PLOBANNALEC-LESCONIL;29740;29;FINISTERE;1
29166;;Ploéven;PLOEVEN;29550;29;FINISTERE;1
29167;;Plogastel-Saint-Germain;PLOGASTEL-SAINT-GERMAIN;29710;29;FINISTERE;1
29168;;Plogoff;PLOGOFF;29770;29;FINISTERE;1
29169;;Plogonnec;PLOGONNEC;29180;29;FINISTERE;1
29170;;Plomelin;PLOMELIN;29700;29;FINISTERE;1
29171;;Plomeur;PLOMEUR;29120;29;FINISTERE;1
29172;;Plomodiern;PLOMODIERN;29550;29;FINISTERE;1
29173;;Plonéis;PLONEIS;29710;29;FINISTERE;1
29174;;Plonéour-Lanvern;PLONEOUR-LANVERN;29720;29;FINISTERE;1
29175;;Plonévez-du-Faou;PLONEVEZ-DU-FAOU;29530;29;FINISTERE;1
29176;;Plonévez-Porzay;PLONEVEZ-PORZAY;29550;29;FINISTERE;1
29177;;Plouarzel;PLOUARZEL;29810;29;FINISTERE;1
29178;;Ploudalmézeau;PLOUDALMEZEAU;29830;29;FINISTERE;1
29179;;Ploudaniel;PLOUDANIEL;29260;29;FINISTERE;1
29180;;Ploudiry;PLOUDIRY;29800;29;FINISTERE;1
29181;;Plouédern;PLOUEDERN;29800;29;FINISTERE;1
29182;;Plouégat-Guérand;PLOUEGAT-GUERAND;29620;29;FINISTERE;1
29183;;Plouégat-Moysan;PLOUEGAT-MOYSAN;29650;29;FINISTERE;1
29184;;Plouénan;PLOUENAN;29420;29;FINISTERE;1
29185;;Plouescat;PLOUESCAT;29430;29;FINISTERE;1
29186;;Plouezoc'h;PLOUEZOC'H;29252;29;FINISTERE;1
29187;;Plougar;PLOUGAR;29440;29;FINISTERE;1
29188;;Plougasnou;PLOUGASNOU;29630;29;FINISTERE;1
29189;;Plougastel-Daoulas;PLOUGASTEL-DAOULAS;29470;29;FINISTERE;1
29190;;Plougonvelin;PLOUGONVELIN;29217;29;FINISTERE;1
29191;;Plougonven;PLOUGONVEN;29640;29;FINISTERE;1
29192;;Plougoulm;PLOUGOULM;29250;29;FINISTERE;1
29193;;Plougourvest;PLOUGOURVEST;29400;29;FINISTERE;1
29195;;Plouguerneau;PLOUGUERNEAU;29880;29;FINISTERE;1
29196;;Plouguin;PLOUGUIN;29830;29;FINISTERE;1
29197;;Plouhinec;PLOUHINEC;29780;29;FINISTERE;1
29198;;Plouider;PLOUIDER;29260;29;FINISTERE;1
29199;;Plouigneau;PLOUIGNEAU;29610;29;FINISTERE;1
29201;;Ploumoguer;PLOUMOGUER;29810;29;FINISTERE;1
29202;;Plounéour-Ménez;PLOUNEOUR-MENEZ;29410;29;FINISTERE;1
29203;;Plounéour-Trez;PLOUNEOUR-TREZ;29890;29;FINISTERE;1
29204;;Plounéventer;PLOUNEVENTER;29400;29;FINISTERE;1
29205;;Plounévézel;PLOUNEVEZEL;29270;29;FINISTERE;1
29206;;Plounévez-Lochrist;PLOUNEVEZ-LOCHRIST;29430;29;FINISTERE;1
29207;;Plourin-lès-Morlaix;PLOURIN-LES-MORLAIX;29600;29;FINISTERE;1
29208;;Plourin;PLOURIN;29830;29;FINISTERE;1
29209;;Plouvien;PLOUVIEN;29860;29;FINISTERE;1
29210;;Plouvorn;PLOUVORN;29420;29;FINISTERE;1
29211;;Plouyé;PLOUYE;29690;29;FINISTERE;1
29212;;Plouzané;PLOUZANE;29280;29;FINISTERE;1
29213;;Plouzévédé;PLOUZEVEDE;29440;29;FINISTERE;1
29214;;Plovan;PLOVAN;29720;29;FINISTERE;1
29215;;Plozévet;PLOZEVET;29710;29;FINISTERE;1
29216;;Pluguffan;PLUGUFFAN;29700;29;FINISTERE;1
29217;;Pont-Aven;PONT-AVEN;29930;29;FINISTERE;1
29218;;Pont-Croix;PONT-CROIX;29790;29;FINISTERE;1
29219;Le;Ponthou;PONTHOU;29650;29;FINISTERE;1
29220;;Pont-l'Abbé;PONT-L'ABBE;29120;29;FINISTERE;1
29221;;Porspoder;PORSPODER;29840;29;FINISTERE;1
29222;;Port-Launay;PORT-LAUNAY;29150;29;FINISTERE;1
29224;;Pouldergat;POULDERGAT;29100;29;FINISTERE;1
29225;;Pouldreuzic;POULDREUZIC;29710;29;FINISTERE;1
29226;;Poullan-sur-Mer;POULLAN-SUR-MER;29100;29;FINISTERE;1
29227;;Poullaouen;POULLAOUEN;29246;29;FINISTERE;1
29228;;Primelin;PRIMELIN;29770;29;FINISTERE;1
29229;;Quéménéven;QUEMENEVEN;29180;29;FINISTERE;1
29230;;Querrien;QUERRIEN;29310;29;FINISTERE;1
29232;;Quimper;QUIMPER;29000;29;FINISTERE;1
29233;;Quimperlé;QUIMPERLE;29300;29;FINISTERE;1
29234;;Rédené;REDENE;29300;29;FINISTERE;1
29235;Le;Relecq-Kerhuon;RELECQ-KERHUON;29480;29;FINISTERE;1
29236;;Riec-sur-Belon;RIEC-SUR-BELON;29340;29;FINISTERE;1
29237;La;Roche-Maurice;ROCHE-MAURICE;29800;29;FINISTERE;1
29238;;Roscanvel;ROSCANVEL;29570;29;FINISTERE;1
29239;;Roscoff;ROSCOFF;29680;29;FINISTERE;1
29240;;Rosnoën;ROSNOEN;29590;29;FINISTERE;1
29241;;Rosporden;ROSPORDEN;29140;29;FINISTERE;1
29243;;Saint-Coulitz;SAINT-COULITZ;29150;29;FINISTERE;1
29244;;Saint-Derrien;SAINT-DERRIEN;29440;29;FINISTERE;1
29245;;Saint-Divy;SAINT-DIVY;29800;29;FINISTERE;1
29246;;Saint-Eloy;SAINT-ELOY;29460;29;FINISTERE;1
29247;;Saint-Évarzec;SAINT-EVARZEC;29170;29;FINISTERE;1
29248;;Saint-Frégant;SAINT-FREGANT;29260;29;FINISTERE;1
29249;;Saint-Goazec;SAINT-GOAZEC;29520;29;FINISTERE;1
29250;;Saint-Hernin;SAINT-HERNIN;29270;29;FINISTERE;1
29251;;Saint-Jean-du-Doigt;SAINT-JEAN-DU-DOIGT;29630;29;FINISTERE;1
29252;;Saint-Jean-Trolimon;SAINT-JEAN-TROLIMON;29120;29;FINISTERE;1
29254;;Saint-Martin-des-Champs;SAINT-MARTIN-DES-CHAMPS;29600;29;FINISTERE;1
29255;;Saint-Méen;SAINT-MEEN;29260;29;FINISTERE;1
29256;;Saint-Nic;SAINT-NIC;29550;29;FINISTERE;1
29257;;Saint-Pabu;SAINT-PABU;29830;29;FINISTERE;1
29259;;Saint-Pol-de-Léon;SAINT-POL-DE-LEON;29250;29;FINISTERE;1
29260;;Saint-Renan;SAINT-RENAN;29290;29;FINISTERE;1
29261;;Saint-Rivoal;SAINT-RIVOAL;29190;29;FINISTERE;1
29262;;Saint-Sauveur;SAINT-SAUVEUR;29400;29;FINISTERE;1
29263;;Saint-Ségal;SAINT-SEGAL;29590;29;FINISTERE;1
29264;;Saint-Servais;SAINT-SERVAIS;29400;29;FINISTERE;1
29265;;Sainte-Sève;SAINTE-SEVE;29600;29;FINISTERE;1
29266;;Saint-Thégonnec;SAINT-THEGONNEC;29410;29;FINISTERE;1
29267;;Saint-Thois;SAINT-THOIS;29520;29;FINISTERE;1
29268;;Saint-Thonan;SAINT-THONAN;29800;29;FINISTERE;1
29269;;Saint-Thurien;SAINT-THURIEN;29380;29;FINISTERE;1
29270;;Saint-Urbain;SAINT-URBAIN;29800;29;FINISTERE;1
29271;;Saint-Vougay;SAINT-VOUGAY;29440;29;FINISTERE;1
29272;;Saint-Yvi;SAINT-YVI;29140;29;FINISTERE;1
29273;;Santec;SANTEC;29250;29;FINISTERE;1
29274;;Scaër;SCAER;29390;29;FINISTERE;1
29275;;Scrignac;SCRIGNAC;29640;29;FINISTERE;1
29276;;Sibiril;SIBIRIL;29250;29;FINISTERE;1
29277;;Sizun;SIZUN;29450;29;FINISTERE;1
29278;;Spézet;SPEZET;29540;29;FINISTERE;1
29279;;Taulé;TAULE;29670;29;FINISTERE;1
29280;;Telgruc-sur-Mer;TELGRUC-SUR-MER;29560;29;FINISTERE;1
29281;;Tourch;TOURCH;29140;29;FINISTERE;1
29282;;Trébabu;TREBABU;29217;29;FINISTERE;1
29284;;Treffiagat;TREFFIAGAT;29730;29;FINISTERE;1
29285;;Tréflaouénan;TREFLAOUENAN;29440;29;FINISTERE;1
29286;;Tréflévénez;TREFLEVENEZ;29800;29;FINISTERE;1
29287;;Tréflez;TREFLEZ;29430;29;FINISTERE;1
29288;;Trégarantec;TREGARANTEC;29260;29;FINISTERE;1
29289;;Trégarvan;TREGARVAN;29560;29;FINISTERE;1
29290;;Tréglonou;TREGLONOU;29870;29;FINISTERE;1
29291;;Trégourez;TREGOUREZ;29970;29;FINISTERE;1
29292;;Tréguennec;TREGUENNEC;29720;29;FINISTERE;1
29293;;Trégunc;TREGUNC;29910;29;FINISTERE;1
29294;Le;Tréhou;TREHOU;29450;29;FINISTERE;1
29295;;Trémaouézan;TREMAOUEZAN;29800;29;FINISTERE;1
29296;;Tréméoc;TREMEOC;29120;29;FINISTERE;1
29297;;Tréméven;TREMEVEN;29300;29;FINISTERE;1
29298;;Tréogat;TREOGAT;29720;29;FINISTERE;1
29299;;Tréouergat;TREOUERGAT;29290;29;FINISTERE;1
29300;Le;Trévoux;TREVOUX;29380;29;FINISTERE;1
29301;;Trézilidé;TREZILIDE;29440;29;FINISTERE;1
29302;;Pont-de-Buis-lès-Quimerch;PONT-DE-BUIS-LES-QUIMERCH;29590;29;FINISTERE;1
30001;;Aigaliers;AIGALIERS;30700;30;GARD;1
30002;;Aigremont;AIGREMONT;30350;30;GARD;1
30003;;Aigues-Mortes;AIGUES-MORTES;30220;30;GARD;1
30004;;Aigues-Vives;AIGUES-VIVES;30670;30;GARD;1
30005;;Aiguèze;AIGUEZE;30760;30;GARD;1
30006;;Aimargues;AIMARGUES;30470;30;GARD;1
30007;;Alès;ALES;30100;30;GARD;1
30008;;Allègre-les-Fumades;ALLEGRE-LES-FUMADES;30500;30;GARD;1
30009;;Alzon;ALZON;30770;30;GARD;1
30010;;Anduze;ANDUZE;30140;30;GARD;1
30011;Les;Angles;ANGLES;30133;30;GARD;1
30012;;Aramon;ARAMON;30390;30;GARD;1
30013;;Argilliers;ARGILLIERS;30210;30;GARD;1
30014;;Arpaillargues-et-Aureillac;ARPAILLARGUES-ET-AUREILLAC;30700;30;GARD;1
30015;;Arphy;ARPHY;30120;30;GARD;1
30016;;Arre;ARRE;30120;30;GARD;1
30017;;Arrigas;ARRIGAS;30770;30;GARD;1
30018;;Aspères;ASPERES;30250;30;GARD;1
30019;;Aubais;AUBAIS;30250;30;GARD;1
30020;;Aubord;AUBORD;30620;30;GARD;1
30021;;Aubussargues;AUBUSSARGUES;30190;30;GARD;1
30022;;Aujac;AUJAC;30450;30;GARD;1
30023;;Aujargues;AUJARGUES;30250;30;GARD;1
30024;;Aulas;AULAS;30120;30;GARD;1
30025;;Aumessas;AUMESSAS;30770;30;GARD;1
30026;;Avèze;AVEZE;30120;30;GARD;1
30027;;Bagard;BAGARD;30140;30;GARD;1
30028;;Bagnols-sur-Cèze;BAGNOLS-SUR-CEZE;30200;30;GARD;1
30029;;Barjac;BARJAC;30430;30;GARD;1
30030;;Baron;BARON;30700;30;GARD;1
30031;La;Bastide-d'Engras;BASTIDE-D'ENGRAS;30330;30;GARD;1
30032;;Beaucaire;BEAUCAIRE;30300;30;GARD;1
30033;;Beauvoisin;BEAUVOISIN;30640;30;GARD;1
30034;;Bellegarde;BELLEGARDE;30127;30;GARD;1
30035;;Belvézet;BELVEZET;30580;30;GARD;1
30036;;Bernis;BERNIS;30620;30;GARD;1
30037;;Bessèges;BESSEGES;30160;30;GARD;1
30038;;Bez-et-Esparon;BEZ-ET-ESPARON;30120;30;GARD;1
30039;;Bezouce;BEZOUCE;30320;30;GARD;1
30040;;Blandas;BLANDAS;30770;30;GARD;1
30041;;Blauzac;BLAUZAC;30700;30;GARD;1
30042;;Boisset-et-Gaujac;BOISSET-ET-GAUJAC;30140;30;GARD;1
30043;;Boissières;BOISSIERES;30114;30;GARD;1
30044;;Bonnevaux;BONNEVAUX;30450;30;GARD;1
30045;;Bordezac;BORDEZAC;30160;30;GARD;1
30046;;Boucoiran-et-Nozières;BOUCOIRAN-ET-NOZIERES;30190;30;GARD;1
30047;;Bouillargues;BOUILLARGUES;30230;30;GARD;1
30048;;Bouquet;BOUQUET;30580;30;GARD;1
30049;;Bourdic;BOURDIC;30190;30;GARD;1
30050;;Bragassargues;BRAGASSARGUES;30260;30;GARD;1
30051;;Branoux-les-Taillades;BRANOUX-LES-TAILLADES;30110;30;GARD;1
30052;;Bréau-et-Salagosse;BREAU-ET-SALAGOSSE;30120;30;GARD;1
30053;;Brignon;BRIGNON;30190;30;GARD;1
30054;;Brouzet-lès-Quissac;BROUZET-LES-QUISSAC;30260;30;GARD;1
30055;;Brouzet-lès-Alès;BROUZET-LES-ALES;30580;30;GARD;1
30056;La;Bruguière;BRUGUIERE;30580;30;GARD;1
30057;;Cabrières;CABRIERES;30210;30;GARD;1
30058;La;Cadière-et-Cambo;CADIERE-ET-CAMBO;30170;30;GARD;1
30059;Le;Cailar;CAILAR;30740;30;GARD;1
30060;;Caissargues;CAISSARGUES;30132;30;GARD;1
30061;La;Calmette;CALMETTE;30190;30;GARD;1
30062;;Calvisson;CALVISSON;30420;30;GARD;1
30064;;Campestre-et-Luc;CAMPESTRE-ET-LUC;30770;30;GARD;1
30065;;Canaules-et-Argentières;CANAULES-ET-ARGENTIERES;30350;30;GARD;1
30066;;Cannes-et-Clairan;CANNES-ET-CLAIRAN;30260;30;GARD;1
30067;La;Capelle-et-Masmolène;CAPELLE-ET-MASMOLENE;30700;30;GARD;1
30068;;Cardet;CARDET;30350;30;GARD;1
30069;;Carnas;CARNAS;30260;30;GARD;1
30070;;Carsan;CARSAN;30130;30;GARD;1
30071;;Cassagnoles;CASSAGNOLES;30350;30;GARD;1
30072;;Castelnau-Valence;CASTELNAU-VALENCE;30190;30;GARD;1
30073;;Castillon-du-Gard;CASTILLON-DU-GARD;30210;30;GARD;1
30074;;Causse-Bégon;CAUSSE-BEGON;30750;30;GARD;1
30075;;Caveirac;CAVEIRAC;30820;30;GARD;1
30076;;Cavillargues;CAVILLARGUES;30330;30;GARD;1
30077;;Cendras;CENDRAS;30480;30;GARD;1
30079;;Chambon;CHAMBON;30450;30;GARD;1
30080;;Chamborigaud;CHAMBORIGAUD;30530;30;GARD;1
30081;;Chusclan;CHUSCLAN;30200;30;GARD;1
30082;;Clarensac;CLARENSAC;30870;30;GARD;1
30083;;Codognan;CODOGNAN;30920;30;GARD;1
30084;;Codolet;CODOLET;30200;30;GARD;1
30085;;Collias;COLLIAS;30210;30;GARD;1
30086;;Collorgues;COLLORGUES;30190;30;GARD;1
30087;;Colognac;COLOGNAC;30460;30;GARD;1
30088;;Combas;COMBAS;30250;30;GARD;1
30089;;Comps;COMPS;30300;30;GARD;1
30090;;Concoules;CONCOULES;30450;30;GARD;1
30091;;Congénies;CONGENIES;30111;30;GARD;1
30092;;Connaux;CONNAUX;30330;30;GARD;1
30093;;Conqueyrac;CONQUEYRAC;30170;30;GARD;1
30094;;Corbès;CORBES;30140;30;GARD;1
30095;;Corconne;CORCONNE;30260;30;GARD;1
30096;;Cornillon;CORNILLON;30630;30;GARD;1
30097;;Courry;COURRY;30500;30;GARD;1
30098;;Crespian;CRESPIAN;30260;30;GARD;1
30099;;Cros;CROS;30170;30;GARD;1
30100;;Cruviers-Lascours;CRUVIERS-LASCOURS;30360;30;GARD;1
30101;;Deaux;DEAUX;30360;30;GARD;1
30102;;Dions;DIONS;30190;30;GARD;1
30103;;Domazan;DOMAZAN;30390;30;GARD;1
30104;;Domessargues;DOMESSARGUES;30350;30;GARD;1
30105;;Dourbies;DOURBIES;30750;30;GARD;1
30106;;Durfort-et-Saint-Martin-de-Sossenac;DURFORT-ET-SAINT-MARTIN-DE-SOSSENAC;30170;30;GARD;1
30107;;Estézargues;ESTEZARGUES;30390;30;GARD;1
30108;L';Estréchure;ESTRECHURE;30124;30;GARD;1
30109;;Euzet;EUZET;30360;30;GARD;1
30110;;Flaux;FLAUX;30700;30;GARD;1
30111;;Foissac;FOISSAC;30700;30;GARD;1
30112;;Fons;FONS;30730;30;GARD;1
30113;;Fons-sur-Lussan;FONS-SUR-LUSSAN;30580;30;GARD;1
30114;;Fontanès;FONTANES;30250;30;GARD;1
30115;;Fontarèches;FONTARECHES;30580;30;GARD;1
30116;;Fournès;FOURNES;30210;30;GARD;1
30117;;Fourques;FOURQUES;30300;30;GARD;1
30119;;Fressac;FRESSAC;30170;30;GARD;1
30120;;Gagnières;GAGNIERES;30160;30;GARD;1
30121;;Gailhan;GAILHAN;30260;30;GARD;1
30122;;Gajan;GAJAN;30730;30;GARD;1
30123;;Gallargues-le-Montueux;GALLARGUES-LE-MONTUEUX;30660;30;GARD;1
30124;Le;Garn;GARN;30760;30;GARD;1
30125;;Garons;GARONS;30128;30;GARD;1
30126;;Garrigues-Sainte-Eulalie;GARRIGUES-SAINTE-EULALIE;30190;30;GARD;1
30127;;Gaujac;GAUJAC;30330;30;GARD;1
30128;;Générac;GENERAC;30510;30;GARD;1
30129;;Générargues;GENERARGUES;30140;30;GARD;1
30130;;Génolhac;GENOLHAC;30450;30;GARD;1
30131;;Goudargues;GOUDARGUES;30630;30;GARD;1
30132;La;Grand-Combe;GRAND-COMBE;30110;30;GARD;1
30133;Le;Grau-du-Roi;GRAU-DU-ROI;30240;30;GARD;1
30134;;Issirac;ISSIRAC;30760;30;GARD;1
30135;;Jonquières-Saint-Vincent;JONQUIERES-SAINT-VINCENT;30300;30;GARD;1
30136;;Junas;JUNAS;30250;30;GARD;1
30137;;Lamelouze;LAMELOUZE;30110;30;GARD;1
30138;;Langlade;LANGLADE;30980;30;GARD;1
30139;;Lanuéjols;LANUEJOLS;30750;30;GARD;1
30140;;Lasalle;LASALLE;30460;30;GARD;1
30141;;Laudun-l'Ardoise;LAUDUN-L'ARDOISE;30290;30;GARD;1
30142;;Laval-Pradel;LAVAL-PRADEL;30110;30;GARD;1
30143;;Laval-Saint-Roman;LAVAL-SAINT-ROMAN;30760;30;GARD;1
30144;;Lecques;LECQUES;30250;30;GARD;1
30145;;Lédenon;LEDENON;30210;30;GARD;1
30146;;Lédignan;LEDIGNAN;30350;30;GARD;1
30147;;Lézan;LEZAN;30350;30;GARD;1
30148;;Liouc;LIOUC;30260;30;GARD;1
30149;;Lirac;LIRAC;30126;30;GARD;1
30150;;Logrian-Florian;LOGRIAN-FLORIAN;30610;30;GARD;1
30151;;Lussan;LUSSAN;30580;30;GARD;1
30152;Les;Mages;MAGES;30960;30;GARD;1
30153;;Malons-et-Elze;MALONS-ET-ELZE;30450;30;GARD;1
30154;;Mandagout;MANDAGOUT;30120;30;GARD;1
30155;;Manduel;MANDUEL;30129;30;GARD;1
30156;;Marguerittes;MARGUERITTES;30320;30;GARD;1
30157;;Mars;MARS;30120;30;GARD;1
30158;;Martignargues;MARTIGNARGUES;30360;30;GARD;1
30159;Le;Martinet;MARTINET;30960;30;GARD;1
30160;;Maruéjols-lès-Gardon;MARUEJOLS-LES-GARDON;30350;30;GARD;1
30161;;Massanes;MASSANES;30350;30;GARD;1
30162;;Massillargues-Attuech;MASSILLARGUES-ATTUECH;30140;30;GARD;1
30163;;Mauressargues;MAURESSARGUES;30350;30;GARD;1
30164;;Méjannes-le-Clap;MEJANNES-LE-CLAP;30430;30;GARD;1
30165;;Méjannes-lès-Alès;MEJANNES-LES-ALES;30340;30;GARD;1
30166;;Meynes;MEYNES;30840;30;GARD;1
30167;;Meyrannes;MEYRANNES;30410;30;GARD;1
30168;;Mialet;MIALET;30140;30;GARD;1
30169;;Milhaud;MILHAUD;30540;30;GARD;1
30170;;Molières-Cavaillac;MOLIERES-CAVAILLAC;30120;30;GARD;1
30171;;Molières-sur-Cèze;MOLIERES-SUR-CEZE;30410;30;GARD;1
30172;;Monoblet;MONOBLET;30170;30;GARD;1
30173;;Mons;MONS;30340;30;GARD;1
30174;;Montaren-et-Saint-Médiers;MONTAREN-ET-SAINT-MEDIERS;30700;30;GARD;1
30175;;Montclus;MONTCLUS;30630;30;GARD;1
30176;;Montdardier;MONTDARDIER;30120;30;GARD;1
30177;;Monteils;MONTEILS;30360;30;GARD;1
30178;;Montfaucon;MONTFAUCON;30150;30;GARD;1
30179;;Montfrin;MONTFRIN;30490;30;GARD;1
30180;;Montignargues;MONTIGNARGUES;30190;30;GARD;1
30181;;Montmirat;MONTMIRAT;30260;30;GARD;1
30182;;Montpezat;MONTPEZAT;30730;30;GARD;1
30183;;Moulézan;MOULEZAN;30350;30;GARD;1
30184;;Moussac;MOUSSAC;30190;30;GARD;1
30185;;Mus;MUS;30121;30;GARD;1
30186;;Nages-et-Solorgues;NAGES-ET-SOLORGUES;30114;30;GARD;1
30187;;Navacelles;NAVACELLES;30580;30;GARD;1
30188;;Ners;NERS;30360;30;GARD;1
30189;;Nîmes;NIMES;30000;30;GARD;1
30190;;Notre-Dame-de-la-Rouvière;NOTRE-DAME-DE-LA-ROUVIERE;30570;30;GARD;1
30191;;Orsan;ORSAN;30200;30;GARD;1
30192;;Orthoux-Sérignac-Quilhan;ORTHOUX-SERIGNAC-QUILHAN;30260;30;GARD;1
30193;;Parignargues;PARIGNARGUES;30730;30;GARD;1
30194;;Peyremale;PEYREMALE;30160;30;GARD;1
30195;;Peyrolles;PEYROLLES;30124;30;GARD;1
30196;Le;Pin;PIN;30330;30;GARD;1
30197;Les;Plans;PLANS;30340;30;GARD;1
30198;Les;Plantiers;PLANTIERS;30122;30;GARD;1
30199;;Pommiers;POMMIERS;30120;30;GARD;1
30200;;Pompignan;POMPIGNAN;30170;30;GARD;1
30201;;Ponteils-et-Brésis;PONTEILS-ET-BRESIS;30450;30;GARD;1
30202;;Pont-Saint-Esprit;PONT-SAINT-ESPRIT;30130;30;GARD;1
30203;;Portes;PORTES;30530;30;GARD;1
30204;;Potelières;POTELIERES;30500;30;GARD;1
30205;;Pougnadoresse;POUGNADORESSE;30330;30;GARD;1
30206;;Poulx;POULX;30320;30;GARD;1
30207;;Pouzilhac;POUZILHAC;30210;30;GARD;1
30208;;Puechredon;PUECHREDON;30610;30;GARD;1
30209;;Pujaut;PUJAUT;30131;30;GARD;1
30210;;Quissac;QUISSAC;30260;30;GARD;1
30211;;Redessan;REDESSAN;30129;30;GARD;1
30212;;Remoulins;REMOULINS;30210;30;GARD;1
30213;;Revens;REVENS;30750;30;GARD;1
30214;;Ribaute-les-Tavernes;RIBAUTE-LES-TAVERNES;30720;30;GARD;1
30215;;Rivières;RIVIERES;30430;30;GARD;1
30216;;Robiac-Rochessadoule;ROBIAC-ROCHESSADOULE;30160;30;GARD;1
30217;;Rochefort-du-Gard;ROCHEFORT-DU-GARD;30650;30;GARD;1
30218;;Rochegude;ROCHEGUDE;30430;30;GARD;1
30219;;Rogues;ROGUES;30120;30;GARD;1
30220;;Roquedur;ROQUEDUR;30440;30;GARD;1
30221;;Roquemaure;ROQUEMAURE;30150;30;GARD;1
30222;La;Roque-sur-Cèze;ROQUE-SUR-CEZE;30200;30;GARD;1
30223;;Rousson;ROUSSON;30340;30;GARD;1
30224;La;Rouvière;ROUVIERE;30190;30;GARD;1
30225;;Sabran;SABRAN;30200;30;GARD;1
30226;;Saint-Alexandre;SAINT-ALEXANDRE;30130;30;GARD;1
30227;;Saint-Ambroix;SAINT-AMBROIX;30500;30;GARD;1
30228;;Sainte-Anastasie;SAINTE-ANASTASIE;30190;30;GARD;1
30229;;Saint-André-de-Majencoules;SAINT-ANDRE-DE-MAJENCOULES;30570;30;GARD;1
30230;;Saint-André-de-Roquepertuis;SAINT-ANDRE-DE-ROQUEPERTUIS;30630;30;GARD;1
30231;;Saint-André-de-Valborgne;SAINT-ANDRE-DE-VALBORGNE;30940;30;GARD;1
30232;;Saint-André-d'Olérargues;SAINT-ANDRE-D'OLERARGUES;30330;30;GARD;1
30233;;Saint-Bauzély;SAINT-BAUZELY;30730;30;GARD;1
30234;;Saint-Bénézet;SAINT-BENEZET;30350;30;GARD;1
30235;;Saint-Bonnet-du-Gard;SAINT-BONNET-DU-GARD;30210;30;GARD;1
30236;;Saint-Bonnet-de-Salendrinque;SAINT-BONNET-DE-SALENDRINQUE;30460;30;GARD;1
30237;;Saint-Brès;SAINT-BRES;30500;30;GARD;1
30238;;Saint-Bresson;SAINT-BRESSON;30440;30;GARD;1
30239;;Sainte-Cécile-d'Andorge;SAINTE-CECILE-D'ANDORGE;30110;30;GARD;1
30240;;Saint-Césaire-de-Gauzignan;SAINT-CESAIRE-DE-GAUZIGNAN;30360;30;GARD;1
30241;;Saint-Chaptes;SAINT-CHAPTES;30190;30;GARD;1
30242;;Saint-Christol-de-Rodières;SAINT-CHRISTOL-DE-RODIERES;30760;30;GARD;1
30243;;Saint-Christol-lès-Alès;SAINT-CHRISTOL-LES-ALES;30380;30;GARD;1
30244;;Saint-Clément;SAINT-CLEMENT;30260;30;GARD;1
30245;;Saint-Côme-et-Maruéjols;SAINT-COME-ET-MARUEJOLS;30870;30;GARD;1
30246;;Sainte-Croix-de-Caderle;SAINTE-CROIX-DE-CADERLE;30460;30;GARD;1
30247;;Saint-Denis;SAINT-DENIS;30500;30;GARD;1
30248;;Saint-Dézéry;SAINT-DEZERY;30190;30;GARD;1
30249;;Saint-Dionisy;SAINT-DIONISY;30980;30;GARD;1
30250;;Saint-Étienne-de-l'Olm;SAINT-ETIENNE-DE-L'OLM;30360;30;GARD;1
30251;;Saint-Étienne-des-Sorts;SAINT-ETIENNE-DES-SORTS;30200;30;GARD;1
30252;;Saint-Félix-de-Pallières;SAINT-FELIX-DE-PALLIERES;30140;30;GARD;1
30253;;Saint-Florent-sur-Auzonnet;SAINT-FLORENT-SUR-AUZONNET;30960;30;GARD;1
30254;;Saint-Geniès-de-Comolas;SAINT-GENIES-DE-COMOLAS;30150;30;GARD;1
30255;;Saint-Geniès-de-Malgoirès;SAINT-GENIES-DE-MALGOIRES;30190;30;GARD;1
30256;;Saint-Gervais;SAINT-GERVAIS;30200;30;GARD;1
30257;;Saint-Gervasy;SAINT-GERVASY;30320;30;GARD;1
30258;;Saint-Gilles;SAINT-GILLES;30800;30;GARD;1
30259;;Saint-Hilaire-de-Brethmas;SAINT-HILAIRE-DE-BRETHMAS;30560;30;GARD;1
30260;;Saint-Hilaire-d'Ozilhan;SAINT-HILAIRE-D'OZILHAN;30210;30;GARD;1
30261;;Saint-Hippolyte-de-Caton;SAINT-HIPPOLYTE-DE-CATON;30360;30;GARD;1
30262;;Saint-Hippolyte-de-Montaigu;SAINT-HIPPOLYTE-DE-MONTAIGU;30700;30;GARD;1
30263;;Saint-Hippolyte-du-Fort;SAINT-HIPPOLYTE-DU-FORT;30170;30;GARD;1
30264;;Saint-Jean-de-Ceyrargues;SAINT-JEAN-DE-CEYRARGUES;30360;30;GARD;1
30265;;Saint-Jean-de-Crieulon;SAINT-JEAN-DE-CRIEULON;30610;30;GARD;1
30266;;Saint-Jean-de-Maruéjols-et-Avéjan;SAINT-JEAN-DE-MARUEJOLS-ET-AVEJAN;30430;30;GARD;1
30267;;Saint-Jean-de-Serres;SAINT-JEAN-DE-SERRES;30350;30;GARD;1
30268;;Saint-Jean-de-Valériscle;SAINT-JEAN-DE-VALERISCLE;30960;30;GARD;1
30269;;Saint-Jean-du-Gard;SAINT-JEAN-DU-GARD;30270;30;GARD;1
30270;;Saint-Jean-du-Pin;SAINT-JEAN-DU-PIN;30140;30;GARD;1
30271;;Saint-Julien-de-Cassagnas;SAINT-JULIEN-DE-CASSAGNAS;30500;30;GARD;1
30272;;Saint-Julien-de-la-Nef;SAINT-JULIEN-DE-LA-NEF;30440;30;GARD;1
30273;;Saint-Julien-de-Peyrolas;SAINT-JULIEN-DE-PEYROLAS;30760;30;GARD;1
30274;;Saint-Julien-les-Rosiers;SAINT-JULIEN-LES-ROSIERS;30340;30;GARD;1
30275;;Saint-Just-et-Vacquières;SAINT-JUST-ET-VACQUIERES;30580;30;GARD;1
30276;;Saint-Laurent-d'Aigouze;SAINT-LAURENT-D'AIGOUZE;30220;30;GARD;1
30277;;Saint-Laurent-de-Carnols;SAINT-LAURENT-DE-CARNOLS;30200;30;GARD;1
30278;;Saint-Laurent-des-Arbres;SAINT-LAURENT-DES-ARBRES;30126;30;GARD;1
30279;;Saint-Laurent-la-Vernède;SAINT-LAURENT-LA-VERNEDE;30330;30;GARD;1
30280;;Saint-Laurent-le-Minier;SAINT-LAURENT-LE-MINIER;30440;30;GARD;1
30281;;Saint-Mamert-du-Gard;SAINT-MAMERT-DU-GARD;30730;30;GARD;1
30282;;Saint-Marcel-de-Careiret;SAINT-MARCEL-DE-CAREIRET;30330;30;GARD;1
30283;;Saint-Martial;SAINT-MARTIAL;30440;30;GARD;1
30284;;Saint-Martin-de-Valgalgues;SAINT-MARTIN-DE-VALGALGUES;30520;30;GARD;1
30285;;Saint-Maurice-de-Cazevieille;SAINT-MAURICE-DE-CAZEVIEILLE;30360;30;GARD;1
30286;;Saint-Maximin;SAINT-MAXIMIN;30700;30;GARD;1
30287;;Saint-Michel-d'Euzet;SAINT-MICHEL-D'EUZET;30200;30;GARD;1
30288;;Saint-Nazaire;SAINT-NAZAIRE;30200;30;GARD;1
30289;;Saint-Nazaire-des-Gardies;SAINT-NAZAIRE-DES-GARDIES;30610;30;GARD;1
30290;;Saint-Paulet-de-Caisson;SAINT-PAULET-DE-CAISSON;30130;30;GARD;1
30291;;Saint-Paul-la-Coste;SAINT-PAUL-LA-COSTE;30480;30;GARD;1
30292;;Saint-Pons-la-Calm;SAINT-PONS-LA-CALM;30330;30;GARD;1
30293;;Saint-Privat-de-Champclos;SAINT-PRIVAT-DE-CHAMPCLOS;30430;30;GARD;1
30294;;Saint-Privat-des-Vieux;SAINT-PRIVAT-DES-VIEUX;30340;30;GARD;1
30295;;Saint-Quentin-la-Poterie;SAINT-QUENTIN-LA-POTERIE;30700;30;GARD;1
30296;;Saint-Roman-de-Codières;SAINT-ROMAN-DE-CODIERES;30440;30;GARD;1
30297;;Saint-Sauveur-Camprieu;SAINT-SAUVEUR-CAMPRIEU;30750;30;GARD;1
30298;;Saint-Sébastien-d'Aigrefeuille;SAINT-SEBASTIEN-D'AIGREFEUILLE;30140;30;GARD;1
30299;;Saint-Siffret;SAINT-SIFFRET;30700;30;GARD;1
30300;;Saint-Théodorit;SAINT-THEODORIT;30260;30;GARD;1
30301;;Saint-Victor-des-Oules;SAINT-VICTOR-DES-OULES;30700;30;GARD;1
30302;;Saint-Victor-la-Coste;SAINT-VICTOR-LA-COSTE;30290;30;GARD;1
30303;;Saint-Victor-de-Malcap;SAINT-VICTOR-DE-MALCAP;30500;30;GARD;1
30304;;Salazac;SALAZAC;30760;30;GARD;1
30305;;Salindres;SALINDRES;30340;30;GARD;1
30306;;Salinelles;SALINELLES;30250;30;GARD;1
30307;Les;Salles-du-Gardon;SALLES-DU-GARDON;30110;30;GARD;1
30308;;Sanilhac-Sagriès;SANILHAC-SAGRIES;30700;30;GARD;1
30309;;Sardan;SARDAN;30260;30;GARD;1
30310;;Saumane;SAUMANE;30125;30;GARD;1
30311;;Sauve;SAUVE;30610;30;GARD;1
30312;;Sauveterre;SAUVETERRE;30150;30;GARD;1
30313;;Sauzet;SAUZET;30190;30;GARD;1
30314;;Savignargues;SAVIGNARGUES;30350;30;GARD;1
30315;;Saze;SAZE;30650;30;GARD;1
30316;;Sénéchas;SENECHAS;30450;30;GARD;1
30317;;Sernhac;SERNHAC;30210;30;GARD;1
30318;;Servas;SERVAS;30340;30;GARD;1
30319;;Serviers-et-Labaume;SERVIERS-ET-LABAUME;30700;30;GARD;1
30320;;Seynes;SEYNES;30580;30;GARD;1
30321;;Sommières;SOMMIERES;30250;30;GARD;1
30322;;Soudorgues;SOUDORGUES;30460;30;GARD;1
30323;;Soustelle;SOUSTELLE;30110;30;GARD;1
30324;;Souvignargues;SOUVIGNARGUES;30250;30;GARD;1
30325;;Sumène;SUMENE;30440;30;GARD;1
30326;;Tavel;TAVEL;30126;30;GARD;1
30327;;Tharaux;THARAUX;30430;30;GARD;1
30328;;Théziers;THEZIERS;30390;30;GARD;1
30329;;Thoiras;THOIRAS;30140;30;GARD;1
30330;;Tornac;TORNAC;30140;30;GARD;1
30331;;Tresques;TRESQUES;30330;30;GARD;1
30332;;Trèves;TREVES;30750;30;GARD;1
30333;;Uchaud;UCHAUD;30620;30;GARD;1
30334;;Uzès;UZES;30700;30;GARD;1
30335;;Vabres;VABRES;30460;30;GARD;1
30336;;Vallabrègues;VALLABREGUES;30300;30;GARD;1
30337;;Vallabrix;VALLABRIX;30700;30;GARD;1
30338;;Vallérargues;VALLERARGUES;30580;30;GARD;1
30339;;Valleraugue;VALLERAUGUE;30570;30;GARD;1
30340;;Valliguières;VALLIGUIERES;30210;30;GARD;1
30341;;Vauvert;VAUVERT;30600;30;GARD;1
30342;;Vénéjan;VENEJAN;30200;30;GARD;1
30343;;Verfeuil;VERFEUIL;30630;30;GARD;1
30344;;Vergèze;VERGEZE;30310;30;GARD;1
30345;La;Vernarède;VERNAREDE;30530;30;GARD;1
30346;;Vers-Pont-du-Gard;VERS-PONT-DU-GARD;30210;30;GARD;1
30347;;Vestric-et-Candiac;VESTRIC-ET-CANDIAC;30600;30;GARD;1
30348;;Vézénobres;VEZENOBRES;30360;30;GARD;1
30349;;Vic-le-Fesq;VIC-LE-FESQ;30260;30;GARD;1
30350;Le;Vigan;VIGAN;30120;30;GARD;1
30351;;Villeneuve-lès-Avignon;VILLENEUVE-LES-AVIGNON;30400;30;GARD;1
30352;;Villevieille;VILLEVIEILLE;30250;30;GARD;1
30353;;Vissec;VISSEC;30770;30;GARD;1
30354;;Montagnac;MONTAGNAC;30350;30;GARD;1
30355;;Saint-Paul-les-Fonts;SAINT-PAUL-LES-FONTS;30330;30;GARD;1
30356;;Rodilhan;RODILHAN;30230;30;GARD;1
31001;;Agassac;AGASSAC;31230;31;HAUTE GARONNE;1
31002;;Aignes;AIGNES;31550;31;HAUTE GARONNE;1
31003;;Aigrefeuille;AIGREFEUILLE;31280;31;HAUTE GARONNE;1
31004;;Ayguesvives;AYGUESVIVES;31450;31;HAUTE GARONNE;1
31005;;Alan;ALAN;31420;31;HAUTE GARONNE;1
31006;;Albiac;ALBIAC;31460;31;HAUTE GARONNE;1
31007;;Ambax;AMBAX;31230;31;HAUTE GARONNE;1
31008;;Anan;ANAN;31230;31;HAUTE GARONNE;1
31009;;Antichan-de-Frontignes;ANTICHAN-DE-FRONTIGNES;31510;31;HAUTE GARONNE;1
31010;;Antignac;ANTIGNAC;31110;31;HAUTE GARONNE;1
31011;;Arbas;ARBAS;31160;31;HAUTE GARONNE;1
31012;;Arbon;ARBON;31160;31;HAUTE GARONNE;1
31013;;Ardiège;ARDIEGE;31210;31;HAUTE GARONNE;1
31014;;Arguenos;ARGUENOS;31160;31;HAUTE GARONNE;1
31015;;Argut-Dessous;ARGUT-DESSOUS;31440;31;HAUTE GARONNE;1
31017;;Arlos;ARLOS;31440;31;HAUTE GARONNE;1
31018;;Arnaud-Guilhem;ARNAUD-GUILHEM;31360;31;HAUTE GARONNE;1
31019;;Artigue;ARTIGUE;31110;31;HAUTE GARONNE;1
31020;;Aspet;ASPET;31160;31;HAUTE GARONNE;1
31021;;Aspret-Sarrat;ASPRET-SARRAT;31800;31;HAUTE GARONNE;1
31022;;Aucamville;AUCAMVILLE;31140;31;HAUTE GARONNE;1
31023;;Aulon;AULON;31420;31;HAUTE GARONNE;1
31024;;Auragne;AURAGNE;31190;31;HAUTE GARONNE;1
31025;;Aureville;AUREVILLE;31320;31;HAUTE GARONNE;1
31026;;Auriac-sur-Vendinelle;AURIAC-SUR-VENDINELLE;31460;31;HAUTE GARONNE;1
31027;;Auribail;AURIBAIL;31190;31;HAUTE GARONNE;1
31028;;Aurignac;AURIGNAC;31420;31;HAUTE GARONNE;1
31029;;Aurin;AURIN;31570;31;HAUTE GARONNE;1
31030;;Ausseing;AUSSEING;31260;31;HAUTE GARONNE;1
31031;;Ausson;AUSSON;31210;31;HAUTE GARONNE;1
31032;;Aussonne;AUSSONNE;31840;31;HAUTE GARONNE;1
31033;;Auterive;AUTERIVE;31190;31;HAUTE GARONNE;1
31034;;Auzas;AUZAS;31360;31;HAUTE GARONNE;1
31035;;Auzeville-Tolosane;AUZEVILLE-TOLOSANE;31320;31;HAUTE GARONNE;1
31036;;Auzielle;AUZIELLE;31650;31;HAUTE GARONNE;1
31037;;Avignonet-Lauragais;AVIGNONET-LAURAGAIS;31290;31;HAUTE GARONNE;1
31038;;Azas;AZAS;31380;31;HAUTE GARONNE;1
31039;;Bachas;BACHAS;31420;31;HAUTE GARONNE;1
31040;;Bachos;BACHOS;31440;31;HAUTE GARONNE;1
31041;;Bagiry;BAGIRY;31510;31;HAUTE GARONNE;1
31042;;Bagnères-de-Luchon;BAGNERES-DE-LUCHON;31110;31;HAUTE GARONNE;1
31043;;Balesta;BALESTA;31580;31;HAUTE GARONNE;1
31044;;Balma;BALMA;31130;31;HAUTE GARONNE;1
31045;;Barbazan;BARBAZAN;31510;31;HAUTE GARONNE;1
31046;;Baren;BAREN;31440;31;HAUTE GARONNE;1
31047;;Bax;BAX;31310;31;HAUTE GARONNE;1
31048;;Baziège;BAZIEGE;31450;31;HAUTE GARONNE;1
31049;;Bazus;BAZUS;31380;31;HAUTE GARONNE;1
31050;;Beauchalot;BEAUCHALOT;31360;31;HAUTE GARONNE;1
31051;;Beaufort;BEAUFORT;31370;31;HAUTE GARONNE;1
31052;;Beaumont-sur-Lèze;BEAUMONT-SUR-LEZE;31870;31;HAUTE GARONNE;1
31053;;Beaupuy;BEAUPUY;31850;31;HAUTE GARONNE;1
31054;;Beauteville;BEAUTEVILLE;31290;31;HAUTE GARONNE;1
31055;;Beauville;BEAUVILLE;31460;31;HAUTE GARONNE;1
31056;;Beauzelle;BEAUZELLE;31700;31;HAUTE GARONNE;1
31057;;Belberaud;BELBERAUD;31450;31;HAUTE GARONNE;1
31058;;Belbèze-de-Lauragais;BELBEZE-DE-LAURAGAIS;31450;31;HAUTE GARONNE;1
31059;;Belbèze-en-Comminges;BELBEZE-EN-COMMINGES;31260;31;HAUTE GARONNE;1
31060;;Bélesta-en-Lauragais;BELESTA-EN-LAURAGAIS;31540;31;HAUTE GARONNE;1
31061;;Bellegarde-Sainte-Marie;BELLEGARDE-SAINTE-MARIE;31530;31;HAUTE GARONNE;1
31062;;Bellesserre;BELLESSERRE;31480;31;HAUTE GARONNE;1
31063;;Benque;BENQUE;31420;31;HAUTE GARONNE;1
31064;;Benque-Dessous-et-Dessus;BENQUE-DESSOUS-ET-DESSUS;31110;31;HAUTE GARONNE;1
31065;;Bérat;BERAT;31370;31;HAUTE GARONNE;1
31066;;Bessières;BESSIERES;31660;31;HAUTE GARONNE;1
31067;;Bezins-Garraux;BEZINS-GARRAUX;31440;31;HAUTE GARONNE;1
31068;;Billière;BILLIERE;31110;31;HAUTE GARONNE;1
31069;;Blagnac;BLAGNAC;31700;31;HAUTE GARONNE;1
31070;;Blajan;BLAJAN;31350;31;HAUTE GARONNE;1
31071;;Bois-de-la-Pierre;BOIS-DE-LA-PIERRE;31390;31;HAUTE GARONNE;1
31072;;Boissède;BOISSEDE;31230;31;HAUTE GARONNE;1
31073;;Bondigoux;BONDIGOUX;31340;31;HAUTE GARONNE;1
31074;;Bonrepos-Riquet;BONREPOS-RIQUET;31590;31;HAUTE GARONNE;1
31075;;Bonrepos-sur-Aussonnelle;BONREPOS-SUR-AUSSONNELLE;31470;31;HAUTE GARONNE;1
31076;;Bordes-de-Rivière;BORDES-DE-RIVIERE;31210;31;HAUTE GARONNE;1
31077;Le;Born;BORN;31340;31;HAUTE GARONNE;1
31078;;Boudrac;BOUDRAC;31580;31;HAUTE GARONNE;1
31079;;Bouloc;BOULOC;31620;31;HAUTE GARONNE;1
31080;;Boulogne-sur-Gesse;BOULOGNE-SUR-GESSE;31350;31;HAUTE GARONNE;1
31081;;Bourg-d'Oueil;BOURG-D'OUEIL;31110;31;HAUTE GARONNE;1
31082;;Bourg-Saint-Bernard;BOURG-SAINT-BERNARD;31570;31;HAUTE GARONNE;1
31083;;Boussan;BOUSSAN;31420;31;HAUTE GARONNE;1
31084;;Boussens;BOUSSENS;31360;31;HAUTE GARONNE;1
31085;;Boutx;BOUTX;31440;31;HAUTE GARONNE;1
31086;;Bouzin;BOUZIN;31420;31;HAUTE GARONNE;1
31087;;Bragayrac;BRAGAYRAC;31470;31;HAUTE GARONNE;1
31088;;Brax;BRAX;31490;31;HAUTE GARONNE;1
31089;;Bretx;BRETX;31530;31;HAUTE GARONNE;1
31090;;Brignemont;BRIGNEMONT;31480;31;HAUTE GARONNE;1
31091;;Bruguières;BRUGUIERES;31150;31;HAUTE GARONNE;1
31092;;Burgalays;BURGALAYS;31440;31;HAUTE GARONNE;1
31093;Le;Burgaud;BURGAUD;31330;31;HAUTE GARONNE;1
31094;;Buzet-sur-Tarn;BUZET-SUR-TARN;31660;31;HAUTE GARONNE;1
31095;;Cabanac-Cazaux;CABANAC-CAZAUX;31160;31;HAUTE GARONNE;1
31096;;Cabanac-Séguenville;CABANAC-SEGUENVILLE;31480;31;HAUTE GARONNE;1
31097;Le;Cabanial;CABANIAL;31460;31;HAUTE GARONNE;1
31098;;Cadours;CADOURS;31480;31;HAUTE GARONNE;1
31099;;Caignac;CAIGNAC;31560;31;HAUTE GARONNE;1
31100;;Calmont;CALMONT;31560;31;HAUTE GARONNE;1
31101;;Cambernard;CAMBERNARD;31470;31;HAUTE GARONNE;1
31102;;Cambiac;CAMBIAC;31460;31;HAUTE GARONNE;1
31103;;Canens;CANENS;31310;31;HAUTE GARONNE;1
31104;;Capens;CAPENS;31410;31;HAUTE GARONNE;1
31105;;Caragoudes;CARAGOUDES;31460;31;HAUTE GARONNE;1
31106;;Caraman;CARAMAN;31460;31;HAUTE GARONNE;1
31107;;Carbonne;CARBONNE;31390;31;HAUTE GARONNE;1
31108;;Cardeilhac;CARDEILHAC;31350;31;HAUTE GARONNE;1
31109;;Cassagnabère-Tournas;CASSAGNABERE-TOURNAS;31420;31;HAUTE GARONNE;1
31110;;Cassagne;CASSAGNE;31260;31;HAUTE GARONNE;1
31111;;Castagnac;CASTAGNAC;31310;31;HAUTE GARONNE;1
31112;;Castagnède;CASTAGNEDE;31260;31;HAUTE GARONNE;1
31113;;Castanet-Tolosan;CASTANET-TOLOSAN;31320;31;HAUTE GARONNE;1
31114;;Castelbiague;CASTELBIAGUE;31160;31;HAUTE GARONNE;1
31115;;Castelgaillard;CASTELGAILLARD;31230;31;HAUTE GARONNE;1
31116;;Castelginest;CASTELGINEST;31780;31;HAUTE GARONNE;1
31117;;Castelmaurou;CASTELMAUROU;31180;31;HAUTE GARONNE;1
31118;;Castelnau-d'Estrétefonds;CASTELNAU-D'ESTRETEFONDS;31620;31;HAUTE GARONNE;1
31119;;Castelnau-Picampeau;CASTELNAU-PICAMPEAU;31430;31;HAUTE GARONNE;1
31120;Le;Castéra;CASTERA;31530;31;HAUTE GARONNE;1
31121;;Castéra-Vignoles;CASTERA-VIGNOLES;31350;31;HAUTE GARONNE;1
31122;;Casties-Labrande;CASTIES-LABRANDE;31430;31;HAUTE GARONNE;1
31123;;Castillon-de-Larboust;CASTILLON-DE-LARBOUST;31110;31;HAUTE GARONNE;1
31124;;Castillon-de-Saint-Martory;CASTILLON-DE-SAINT-MARTORY;31360;31;HAUTE GARONNE;1
31125;;Cathervielle;CATHERVIELLE;31110;31;HAUTE GARONNE;1
31126;;Caubiac;CAUBIAC;31480;31;HAUTE GARONNE;1
31127;;Caubous;CAUBOUS;31110;31;HAUTE GARONNE;1
31128;;Caujac;CAUJAC;31190;31;HAUTE GARONNE;1
31129;;Cazaril-Laspènes;CAZARIL-LASPENES;31110;31;HAUTE GARONNE;1
31130;;Cazaril-Tambourès;CAZARIL-TAMBOURES;31580;31;HAUTE GARONNE;1
31131;;Cazaunous;CAZAUNOUS;31160;31;HAUTE GARONNE;1
31132;;Cazaux-Layrisse;CAZAUX-LAYRISSE;31440;31;HAUTE GARONNE;1
31133;;Cazeaux-de-Larboust;CAZEAUX-DE-LARBOUST;31110;31;HAUTE GARONNE;1
31134;;Cazeneuve-Montaut;CAZENEUVE-MONTAUT;31420;31;HAUTE GARONNE;1
31135;;Cazères;CAZERES;31220;31;HAUTE GARONNE;1
31136;;Cépet;CEPET;31620;31;HAUTE GARONNE;1
31137;;Cessales;CESSALES;31290;31;HAUTE GARONNE;1
31138;;Charlas;CHARLAS;31350;31;HAUTE GARONNE;1
31139;;Chaum;CHAUM;31440;31;HAUTE GARONNE;1
31140;;Chein-Dessus;CHEIN-DESSUS;31160;31;HAUTE GARONNE;1
31141;;Ciadoux;CIADOUX;31350;31;HAUTE GARONNE;1
31142;;Cier-de-Luchon;CIER-DE-LUCHON;31110;31;HAUTE GARONNE;1
31143;;Cier-de-Rivière;CIER-DE-RIVIERE;31510;31;HAUTE GARONNE;1
31144;;Cierp-Gaud;CIERP-GAUD;31440;31;HAUTE GARONNE;1
31145;;Cintegabelle;CINTEGABELLE;31550;31;HAUTE GARONNE;1
31146;;Cirès;CIRES;31110;31;HAUTE GARONNE;1
31147;;Clarac;CLARAC;31210;31;HAUTE GARONNE;1
31148;;Clermont-le-Fort;CLERMONT-LE-FORT;31810;31;HAUTE GARONNE;1
31149;;Colomiers;COLOMIERS;31770;31;HAUTE GARONNE;1
31150;;Cornebarrieu;CORNEBARRIEU;31700;31;HAUTE GARONNE;1
31151;;Corronsac;CORRONSAC;31450;31;HAUTE GARONNE;1
31152;;Coueilles;COUEILLES;31230;31;HAUTE GARONNE;1
31153;;Couladère;COULADERE;31220;31;HAUTE GARONNE;1
31155;;Couret;COURET;31160;31;HAUTE GARONNE;1
31156;;Cox;COX;31480;31;HAUTE GARONNE;1
31157;;Cugnaux;CUGNAUX;31270;31;HAUTE GARONNE;1
31158;;Cuguron;CUGURON;31210;31;HAUTE GARONNE;1
31159;Le;Cuing;CUING;31210;31;HAUTE GARONNE;1
31160;;Daux;DAUX;31700;31;HAUTE GARONNE;1
31161;;Deyme;DEYME;31450;31;HAUTE GARONNE;1
31162;;Donneville;DONNEVILLE;31450;31;HAUTE GARONNE;1
31163;;Drémil-Lafage;DREMIL-LAFAGE;31280;31;HAUTE GARONNE;1
31164;;Drudas;DRUDAS;31480;31;HAUTE GARONNE;1
31165;;Eaunes;EAUNES;31600;31;HAUTE GARONNE;1
31166;;Empeaux;EMPEAUX;31470;31;HAUTE GARONNE;1
31167;;Encausse-les-Thermes;ENCAUSSE-LES-THERMES;31160;31;HAUTE GARONNE;1
31168;;Eoux;EOUX;31420;31;HAUTE GARONNE;1
31169;;Escalquens;ESCALQUENS;31750;31;HAUTE GARONNE;1
31170;;Escanecrabe;ESCANECRABE;31350;31;HAUTE GARONNE;1
31171;;Espanès;ESPANES;31450;31;HAUTE GARONNE;1
31172;;Esparron;ESPARRON;31420;31;HAUTE GARONNE;1
31173;;Esperce;ESPERCE;31190;31;HAUTE GARONNE;1
31174;;Estadens;ESTADENS;31160;31;HAUTE GARONNE;1
31175;;Estancarbon;ESTANCARBON;31800;31;HAUTE GARONNE;1
31176;;Esténos;ESTENOS;31440;31;HAUTE GARONNE;1
31177;;Eup;EUP;31440;31;HAUTE GARONNE;1
31178;;Fabas;FABAS;31230;31;HAUTE GARONNE;1
31179;Le;Faget;FAGET;31460;31;HAUTE GARONNE;1
31180;;Falga;FALGA;31540;31;HAUTE GARONNE;1
31181;Le;Fauga;FAUGA;31410;31;HAUTE GARONNE;1
31182;;Fenouillet;FENOUILLET;31150;31;HAUTE GARONNE;1
31183;;Figarol;FIGAROL;31260;31;HAUTE GARONNE;1
31184;;Flourens;FLOURENS;31130;31;HAUTE GARONNE;1
31185;;Folcarde;FOLCARDE;31290;31;HAUTE GARONNE;1
31186;;Fonbeauzard;FONBEAUZARD;31140;31;HAUTE GARONNE;1
31187;;Fonsorbes;FONSORBES;31470;31;HAUTE GARONNE;1
31188;;Fontenilles;FONTENILLES;31470;31;HAUTE GARONNE;1
31189;;Forgues;FORGUES;31370;31;HAUTE GARONNE;1
31190;;Fos;FOS;31440;31;HAUTE GARONNE;1
31191;;Fougaron;FOUGARON;31160;31;HAUTE GARONNE;1
31192;;Fourquevaux;FOURQUEVAUX;31450;31;HAUTE GARONNE;1
31193;Le;Fousseret;FOUSSERET;31430;31;HAUTE GARONNE;1
31194;;Francarville;FRANCARVILLE;31460;31;HAUTE GARONNE;1
31195;;Francazal;FRANCAZAL;31260;31;HAUTE GARONNE;1
31196;;Francon;FRANCON;31420;31;HAUTE GARONNE;1
31197;;Franquevielle;FRANQUEVIELLE;31210;31;HAUTE GARONNE;1
31198;Le;Fréchet;FRECHET;31360;31;HAUTE GARONNE;1
31199;;Fronsac;FRONSAC;31440;31;HAUTE GARONNE;1
31200;;Frontignan-de-Comminges;FRONTIGNAN-DE-COMMINGES;31510;31;HAUTE GARONNE;1
31201;;Frontignan-Savès;FRONTIGNAN-SAVES;31230;31;HAUTE GARONNE;1
31202;;Fronton;FRONTON;31620;31;HAUTE GARONNE;1
31203;;Frouzins;FROUZINS;31270;31;HAUTE GARONNE;1
31204;;Fustignac;FUSTIGNAC;31430;31;HAUTE GARONNE;1
31205;;Gagnac-sur-Garonne;GAGNAC-SUR-GARONNE;31150;31;HAUTE GARONNE;1
31206;;Gaillac-Toulza;GAILLAC-TOULZA;31550;31;HAUTE GARONNE;1
31207;;Galié;GALIE;31510;31;HAUTE GARONNE;1
31208;;Ganties;GANTIES;31160;31;HAUTE GARONNE;1
31209;;Garac;GARAC;31480;31;HAUTE GARONNE;1
31210;;Gardouch;GARDOUCH;31290;31;HAUTE GARONNE;1
31211;;Gargas;GARGAS;31620;31;HAUTE GARONNE;1
31212;;Garidech;GARIDECH;31380;31;HAUTE GARONNE;1
31213;;Garin;GARIN;31110;31;HAUTE GARONNE;1
31215;;Gauré;GAURE;31590;31;HAUTE GARONNE;1
31216;;Gémil;GEMIL;31380;31;HAUTE GARONNE;1
31217;;Génos;GENOS;31510;31;HAUTE GARONNE;1
31218;;Gensac-de-Boulogne;GENSAC-DE-BOULOGNE;31350;31;HAUTE GARONNE;1
31219;;Gensac-sur-Garonne;GENSAC-SUR-GARONNE;31310;31;HAUTE GARONNE;1
31220;;Gibel;GIBEL;31560;31;HAUTE GARONNE;1
31221;;Gouaux-de-Larboust;GOUAUX-DE-LARBOUST;31110;31;HAUTE GARONNE;1
31222;;Gouaux-de-Luchon;GOUAUX-DE-LUCHON;31110;31;HAUTE GARONNE;1
31223;;Goudex;GOUDEX;31230;31;HAUTE GARONNE;1
31224;;Gourdan-Polignan;GOURDAN-POLIGNAN;31210;31;HAUTE GARONNE;1
31225;;Goutevernisse;GOUTEVERNISSE;31310;31;HAUTE GARONNE;1
31226;;Gouzens;GOUZENS;31310;31;HAUTE GARONNE;1
31227;;Goyrans;GOYRANS;31120;31;HAUTE GARONNE;1
31228;;Gragnague;GRAGNAGUE;31380;31;HAUTE GARONNE;1
31229;;Gratens;GRATENS;31430;31;HAUTE GARONNE;1
31230;;Gratentour;GRATENTOUR;31150;31;HAUTE GARONNE;1
31231;;Grazac;GRAZAC;31190;31;HAUTE GARONNE;1
31232;;Grenade;GRENADE;31330;31;HAUTE GARONNE;1
31233;;Grépiac;GREPIAC;31190;31;HAUTE GARONNE;1
31234;Le;Grès;GRES;31480;31;HAUTE GARONNE;1
31235;;Guran;GURAN;31440;31;HAUTE GARONNE;1
31236;;Herran;HERRAN;31160;31;HAUTE GARONNE;1
31237;;His;HIS;31260;31;HAUTE GARONNE;1
31238;;Huos;HUOS;31210;31;HAUTE GARONNE;1
31239;L';Isle-en-Dodon;ISLE-EN-DODON;31230;31;HAUTE GARONNE;1
31240;;Issus;ISSUS;31450;31;HAUTE GARONNE;1
31241;;Izaut-de-l'Hôtel;IZAUT-DE-L'HOTEL;31160;31;HAUTE GARONNE;1
31242;;Jurvielle;JURVIELLE;31110;31;HAUTE GARONNE;1
31243;;Juzes;JUZES;31540;31;HAUTE GARONNE;1
31244;;Juzet-de-Luchon;JUZET-DE-LUCHON;31110;31;HAUTE GARONNE;1
31245;;Juzet-d'Izaut;JUZET-D'IZAUT;31160;31;HAUTE GARONNE;1
31246;;Labarthe-Inard;LABARTHE-INARD;31800;31;HAUTE GARONNE;1
31247;;Labarthe-Rivière;LABARTHE-RIVIERE;31800;31;HAUTE GARONNE;1
31248;;Labarthe-sur-Lèze;LABARTHE-SUR-LEZE;31860;31;HAUTE GARONNE;1
31249;;Labastide-Beauvoir;LABASTIDE-BEAUVOIR;31450;31;HAUTE GARONNE;1
31250;;Labastide-Clermont;LABASTIDE-CLERMONT;31370;31;HAUTE GARONNE;1
31251;;Labastide-Paumès;LABASTIDE-PAUMES;31230;31;HAUTE GARONNE;1
31252;;Labastide-Saint-Sernin;LABASTIDE-SAINT-SERNIN;31620;31;HAUTE GARONNE;1
31253;;Labastidette;LABASTIDETTE;31600;31;HAUTE GARONNE;1
31254;;Labège;LABEGE;31670;31;HAUTE GARONNE;1
31255;;Labroquère;LABROQUERE;31510;31;HAUTE GARONNE;1
31256;;Labruyère-Dorsa;LABRUYERE-DORSA;31190;31;HAUTE GARONNE;1
31258;;Lacaugne;LACAUGNE;31390;31;HAUTE GARONNE;1
31259;;Lacroix-Falgarde;LACROIX-FALGARDE;31120;31;HAUTE GARONNE;1
31260;;Laffite-Toupière;LAFFITE-TOUPIERE;31360;31;HAUTE GARONNE;1
31261;;Lafitte-Vigordane;LAFITTE-VIGORDANE;31390;31;HAUTE GARONNE;1
31262;;Lagarde;LAGARDE;31290;31;HAUTE GARONNE;1
31263;;Lagardelle-sur-Lèze;LAGARDELLE-SUR-LEZE;31870;31;HAUTE GARONNE;1
31264;;Lagrâce-Dieu;LAGRACE-DIEU;31190;31;HAUTE GARONNE;1
31265;;Lagraulet-Saint-Nicolas;LAGRAULET-SAINT-NICOLAS;31480;31;HAUTE GARONNE;1
31266;;Lahage;LAHAGE;31370;31;HAUTE GARONNE;1
31267;;Lahitère;LAHITERE;31310;31;HAUTE GARONNE;1
31268;;Lalouret-Laffiteau;LALOURET-LAFFITEAU;31800;31;HAUTE GARONNE;1
31269;;Lamasquère;LAMASQUERE;31600;31;HAUTE GARONNE;1
31270;;Landorthe;LANDORTHE;31800;31;HAUTE GARONNE;1
31271;;Lanta;LANTA;31570;31;HAUTE GARONNE;1
31272;;Lapeyrère;LAPEYRERE;31310;31;HAUTE GARONNE;1
31273;;Lapeyrouse-Fossat;LAPEYROUSE-FOSSAT;31180;31;HAUTE GARONNE;1
31274;;Larcan;LARCAN;31800;31;HAUTE GARONNE;1
31275;;Laréole;LAREOLE;31480;31;HAUTE GARONNE;1
31276;;Larroque;LARROQUE;31580;31;HAUTE GARONNE;1
31277;;Lasserre;LASSERRE;31530;31;HAUTE GARONNE;1
31278;;Latoue;LATOUE;31800;31;HAUTE GARONNE;1
31279;;Latour;LATOUR;31310;31;HAUTE GARONNE;1
31280;;Latrape;LATRAPE;31310;31;HAUTE GARONNE;1
31281;;Launac;LAUNAC;31330;31;HAUTE GARONNE;1
31282;;Launaguet;LAUNAGUET;31140;31;HAUTE GARONNE;1
31283;;Lautignac;LAUTIGNAC;31370;31;HAUTE GARONNE;1
31284;;Lauzerville;LAUZERVILLE;31650;31;HAUTE GARONNE;1
31285;;Lavalette;LAVALETTE;31590;31;HAUTE GARONNE;1
31286;;Lavelanet-de-Comminges;LAVELANET-DE-COMMINGES;31220;31;HAUTE GARONNE;1
31287;;Lavernose-Lacasse;LAVERNOSE-LACASSE;31410;31;HAUTE GARONNE;1
31288;;Layrac-sur-Tarn;LAYRAC-SUR-TARN;31340;31;HAUTE GARONNE;1
31289;;Lécussan;LECUSSAN;31580;31;HAUTE GARONNE;1
31290;;Lège;LEGE;31440;31;HAUTE GARONNE;1
31291;;Léguevin;LEGUEVIN;31490;31;HAUTE GARONNE;1
31292;;Lescuns;LESCUNS;31220;31;HAUTE GARONNE;1
31293;;Lespinasse;LESPINASSE;31150;31;HAUTE GARONNE;1
31294;;Lespiteau;LESPITEAU;31160;31;HAUTE GARONNE;1
31295;;Lespugue;LESPUGUE;31350;31;HAUTE GARONNE;1
31296;;Lestelle-de-Saint-Martory;LESTELLE-DE-SAINT-MARTORY;31360;31;HAUTE GARONNE;1
31297;;Lévignac;LEVIGNAC;31530;31;HAUTE GARONNE;1
31298;;Lez;LEZ;31440;31;HAUTE GARONNE;1
31299;;Lherm;LHERM;31600;31;HAUTE GARONNE;1
31300;;Lieoux;LIEOUX;31800;31;HAUTE GARONNE;1
31301;;Lilhac;LILHAC;31230;31;HAUTE GARONNE;1
31302;;Lodes;LODES;31800;31;HAUTE GARONNE;1
31303;;Longages;LONGAGES;31410;31;HAUTE GARONNE;1
31304;;Loubens-Lauragais;LOUBENS-LAURAGAIS;31460;31;HAUTE GARONNE;1
31305;;Loudet;LOUDET;31580;31;HAUTE GARONNE;1
31306;;Lourde;LOURDE;31510;31;HAUTE GARONNE;1
31307;;Lunax;LUNAX;31350;31;HAUTE GARONNE;1
31308;;Luscan;LUSCAN;31510;31;HAUTE GARONNE;1
31309;;Lussan-Adeilhac;LUSSAN-ADEILHAC;31430;31;HAUTE GARONNE;1
31310;;Lux;LUX;31290;31;HAUTE GARONNE;1
31311;La;Magdelaine-sur-Tarn;MAGDELAINE-SUR-TARN;31340;31;HAUTE GARONNE;1
31312;;Mailholas;MAILHOLAS;31310;31;HAUTE GARONNE;1
31313;;Malvezie;MALVEZIE;31510;31;HAUTE GARONNE;1
31314;;Mancioux;MANCIOUX;31360;31;HAUTE GARONNE;1
31315;;Mane;MANE;31260;31;HAUTE GARONNE;1
31316;;Marignac;MARIGNAC;31440;31;HAUTE GARONNE;1
31317;;Marignac-Lasclares;MARIGNAC-LASCLARES;31430;31;HAUTE GARONNE;1
31318;;Marignac-Laspeyres;MARIGNAC-LASPEYRES;31220;31;HAUTE GARONNE;1
31319;;Marliac;MARLIAC;31550;31;HAUTE GARONNE;1
31320;;Marquefave;MARQUEFAVE;31390;31;HAUTE GARONNE;1
31321;;Marsoulas;MARSOULAS;31260;31;HAUTE GARONNE;1
31322;;Martisserre;MARTISSERRE;31230;31;HAUTE GARONNE;1
31323;;Martres-de-Rivière;MARTRES-DE-RIVIERE;31210;31;HAUTE GARONNE;1
31324;;Martres-Tolosane;MARTRES-TOLOSANE;31220;31;HAUTE GARONNE;1
31325;;Mascarville;MASCARVILLE;31460;31;HAUTE GARONNE;1
31326;;Massabrac;MASSABRAC;31310;31;HAUTE GARONNE;1
31327;;Mauran;MAURAN;31220;31;HAUTE GARONNE;1
31328;;Mauremont;MAUREMONT;31290;31;HAUTE GARONNE;1
31329;;Maurens;MAURENS;31540;31;HAUTE GARONNE;1
31330;;Mauressac;MAURESSAC;31190;31;HAUTE GARONNE;1
31331;;Maureville;MAUREVILLE;31460;31;HAUTE GARONNE;1
31332;;Mauvaisin;MAUVAISIN;31190;31;HAUTE GARONNE;1
31333;;Mauvezin;MAUVEZIN;31230;31;HAUTE GARONNE;1
31334;;Mauzac;MAUZAC;31410;31;HAUTE GARONNE;1
31335;;Mayrègne;MAYREGNE;31110;31;HAUTE GARONNE;1
31336;;Mazères-sur-Salat;MAZERES-SUR-SALAT;31260;31;HAUTE GARONNE;1
31337;;Melles;MELLES;31440;31;HAUTE GARONNE;1
31338;;Menville;MENVILLE;31530;31;HAUTE GARONNE;1
31339;;Mérenvielle;MERENVIELLE;31530;31;HAUTE GARONNE;1
31340;;Mervilla;MERVILLA;31320;31;HAUTE GARONNE;1
31341;;Merville;MERVILLE;31330;31;HAUTE GARONNE;1
31342;;Milhas;MILHAS;31160;31;HAUTE GARONNE;1
31343;;Mirambeau;MIRAMBEAU;31230;31;HAUTE GARONNE;1
31344;;Miramont-de-Comminges;MIRAMONT-DE-COMMINGES;31800;31;HAUTE GARONNE;1
31345;;Miremont;MIREMONT;31190;31;HAUTE GARONNE;1
31346;;Mirepoix-sur-Tarn;MIREPOIX-SUR-TARN;31340;31;HAUTE GARONNE;1
31347;;Molas;MOLAS;31230;31;HAUTE GARONNE;1
31348;;Moncaup;MONCAUP;31160;31;HAUTE GARONNE;1
31349;;Mondavezan;MONDAVEZAN;31220;31;HAUTE GARONNE;1
31350;;Mondilhan;MONDILHAN;31350;31;HAUTE GARONNE;1
31351;;Mondonville;MONDONVILLE;31700;31;HAUTE GARONNE;1
31352;;Mondouzil;MONDOUZIL;31850;31;HAUTE GARONNE;1
31353;;Monès;MONES;31370;31;HAUTE GARONNE;1
31354;;Monestrol;MONESTROL;31560;31;HAUTE GARONNE;1
31355;;Mons;MONS;31280;31;HAUTE GARONNE;1
31356;;Montaigut-sur-Save;MONTAIGUT-SUR-SAVE;31530;31;HAUTE GARONNE;1
31357;;Montastruc-de-Salies;MONTASTRUC-DE-SALIES;31160;31;HAUTE GARONNE;1
31358;;Montastruc-la-Conseillère;MONTASTRUC-LA-CONSEILLERE;31380;31;HAUTE GARONNE;1
31359;;Montastruc-Savès;MONTASTRUC-SAVES;31370;31;HAUTE GARONNE;1
31360;;Montauban-de-Luchon;MONTAUBAN-DE-LUCHON;31110;31;HAUTE GARONNE;1
31361;;Montaut;MONTAUT;31410;31;HAUTE GARONNE;1
31362;;Montberaud;MONTBERAUD;31220;31;HAUTE GARONNE;1
31363;;Montbernard;MONTBERNARD;31230;31;HAUTE GARONNE;1
31364;;Montberon;MONTBERON;31140;31;HAUTE GARONNE;1
31365;;Montbrun-Bocage;MONTBRUN-BOCAGE;31310;31;HAUTE GARONNE;1
31366;;Montbrun-Lauragais;MONTBRUN-LAURAGAIS;31450;31;HAUTE GARONNE;1
31367;;Montclar-de-Comminges;MONTCLAR-DE-COMMINGES;31220;31;HAUTE GARONNE;1
31368;;Montclar-Lauragais;MONTCLAR-LAURAGAIS;31290;31;HAUTE GARONNE;1
31369;;Mont-de-Galié;MONT-DE-GALIE;31510;31;HAUTE GARONNE;1
31370;;Montégut-Bourjac;MONTEGUT-BOURJAC;31430;31;HAUTE GARONNE;1
31371;;Montégut-Lauragais;MONTEGUT-LAURAGAIS;31540;31;HAUTE GARONNE;1
31372;;Montespan;MONTESPAN;31260;31;HAUTE GARONNE;1
31373;;Montesquieu-Guittaut;MONTESQUIEU-GUITTAUT;31230;31;HAUTE GARONNE;1
31374;;Montesquieu-Lauragais;MONTESQUIEU-LAURAGAIS;31450;31;HAUTE GARONNE;1
31375;;Montesquieu-Volvestre;MONTESQUIEU-VOLVESTRE;31310;31;HAUTE GARONNE;1
31376;;Montgaillard-de-Salies;MONTGAILLARD-DE-SALIES;31260;31;HAUTE GARONNE;1
31377;;Montgaillard-Lauragais;MONTGAILLARD-LAURAGAIS;31290;31;HAUTE GARONNE;1
31378;;Montgaillard-sur-Save;MONTGAILLARD-SUR-SAVE;31350;31;HAUTE GARONNE;1
31379;;Montgazin;MONTGAZIN;31410;31;HAUTE GARONNE;1
31380;;Montgeard;MONTGEARD;31560;31;HAUTE GARONNE;1
31381;;Montgiscard;MONTGISCARD;31450;31;HAUTE GARONNE;1
31382;;Montgras;MONTGRAS;31370;31;HAUTE GARONNE;1
31383;;Montjoire;MONTJOIRE;31380;31;HAUTE GARONNE;1
31384;;Montlaur;MONTLAUR;31450;31;HAUTE GARONNE;1
31385;;Montmaurin;MONTMAURIN;31350;31;HAUTE GARONNE;1
31386;;Montoulieu-Saint-Bernard;MONTOULIEU-SAINT-BERNARD;31420;31;HAUTE GARONNE;1
31387;;Montoussin;MONTOUSSIN;31430;31;HAUTE GARONNE;1
31388;;Montpitol;MONTPITOL;31380;31;HAUTE GARONNE;1
31389;;Montrabé;MONTRABE;31850;31;HAUTE GARONNE;1
31390;;Montréjeau;MONTREJEAU;31210;31;HAUTE GARONNE;1
31391;;Montsaunès;MONTSAUNES;31260;31;HAUTE GARONNE;1
31392;;Mourvilles-Basses;MOURVILLES-BASSES;31460;31;HAUTE GARONNE;1
31393;;Mourvilles-Hautes;MOURVILLES-HAUTES;31540;31;HAUTE GARONNE;1
31394;;Moustajon;MOUSTAJON;31110;31;HAUTE GARONNE;1
31395;;Muret;MURET;31600;31;HAUTE GARONNE;1
31396;;Nailloux;NAILLOUX;31560;31;HAUTE GARONNE;1
31397;;Nénigan;NENIGAN;31350;31;HAUTE GARONNE;1
31398;;Nizan-Gesse;NIZAN-GESSE;31350;31;HAUTE GARONNE;1
31399;;Noé;NOE;31410;31;HAUTE GARONNE;1
31400;;Nogaret;NOGARET;31540;31;HAUTE GARONNE;1
31401;;Noueilles;NOUEILLES;31450;31;HAUTE GARONNE;1
31402;;Odars;ODARS;31450;31;HAUTE GARONNE;1
31403;;Ondes;ONDES;31330;31;HAUTE GARONNE;1
31404;;Oô;OO;31110;31;HAUTE GARONNE;1
31405;;Ore;ORE;31510;31;HAUTE GARONNE;1
31406;;Palaminy;PALAMINY;31220;31;HAUTE GARONNE;1
31407;;Paulhac;PAULHAC;31380;31;HAUTE GARONNE;1
31408;;Payssous;PAYSSOUS;31510;31;HAUTE GARONNE;1
31409;;Péchabou;PECHABOU;31320;31;HAUTE GARONNE;1
31410;;Pechbonnieu;PECHBONNIEU;31140;31;HAUTE GARONNE;1
31411;;Pechbusque;PECHBUSQUE;31320;31;HAUTE GARONNE;1
31412;;Péguilhan;PEGUILHAN;31350;31;HAUTE GARONNE;1
31413;;Pelleport;PELLEPORT;31480;31;HAUTE GARONNE;1
31414;;Peyrissas;PEYRISSAS;31420;31;HAUTE GARONNE;1
31415;;Peyrouzet;PEYROUZET;31420;31;HAUTE GARONNE;1
31416;;Peyssies;PEYSSIES;31390;31;HAUTE GARONNE;1
31417;;Pibrac;PIBRAC;31820;31;HAUTE GARONNE;1
31418;;Pin-Balma;PIN-BALMA;31130;31;HAUTE GARONNE;1
31419;Le;Pin-Murelet;PIN-MURELET;31370;31;HAUTE GARONNE;1
31420;;Pinsaguel;PINSAGUEL;31120;31;HAUTE GARONNE;1
31421;;Pins-Justaret;PINS-JUSTARET;31860;31;HAUTE GARONNE;1
31422;;Plagne;PLAGNE;31220;31;HAUTE GARONNE;1
31423;;Plagnole;PLAGNOLE;31370;31;HAUTE GARONNE;1
31424;;Plaisance-du-Touch;PLAISANCE-DU-TOUCH;31830;31;HAUTE GARONNE;1
31425;Le;Plan;PLAN;31220;31;HAUTE GARONNE;1
31426;;Pointis-de-Rivière;POINTIS-DE-RIVIERE;31210;31;HAUTE GARONNE;1
31427;;Pointis-Inard;POINTIS-INARD;31800;31;HAUTE GARONNE;1
31428;;Polastron;POLASTRON;31430;31;HAUTE GARONNE;1
31429;;Pompertuzat;POMPERTUZAT;31450;31;HAUTE GARONNE;1
31430;;Ponlat-Taillebourg;PONLAT-TAILLEBOURG;31210;31;HAUTE GARONNE;1
31431;;Portet-d'Aspet;PORTET-D'ASPET;31160;31;HAUTE GARONNE;1
31432;;Portet-de-Luchon;PORTET-DE-LUCHON;31110;31;HAUTE GARONNE;1
31433;;Portet-sur-Garonne;PORTET-SUR-GARONNE;31120;31;HAUTE GARONNE;1
31434;;Poubeau;POUBEAU;31110;31;HAUTE GARONNE;1
31435;;Poucharramet;POUCHARRAMET;31370;31;HAUTE GARONNE;1
31436;;Pouy-de-Touges;POUY-DE-TOUGES;31430;31;HAUTE GARONNE;1
31437;;Pouze;POUZE;31450;31;HAUTE GARONNE;1
31438;;Pradère-les-Bourguets;PRADERE-LES-BOURGUETS;31530;31;HAUTE GARONNE;1
31439;;Préserville;PRESERVILLE;31570;31;HAUTE GARONNE;1
31440;;Proupiary;PROUPIARY;31360;31;HAUTE GARONNE;1
31441;;Prunet;PRUNET;31460;31;HAUTE GARONNE;1
31442;;Puydaniel;PUYDANIEL;31190;31;HAUTE GARONNE;1
31443;;Puymaurin;PUYMAURIN;31230;31;HAUTE GARONNE;1
31444;;Puysségur;PUYSSEGUR;31480;31;HAUTE GARONNE;1
31445;;Quint-Fonsegrives;QUINT-FONSEGRIVES;31130;31;HAUTE GARONNE;1
31446;;Ramonville-Saint-Agne;RAMONVILLE-SAINT-AGNE;31520;31;HAUTE GARONNE;1
31447;;Razecueillé;RAZECUEILLE;31160;31;HAUTE GARONNE;1
31448;;Rebigue;REBIGUE;31320;31;HAUTE GARONNE;1
31449;;Régades;REGADES;31800;31;HAUTE GARONNE;1
31450;;Renneville;RENNEVILLE;31290;31;HAUTE GARONNE;1
31451;;Revel;REVEL;31250;31;HAUTE GARONNE;1
31452;;Rieucazé;RIEUCAZE;31800;31;HAUTE GARONNE;1
31453;;Rieumajou;RIEUMAJOU;31290;31;HAUTE GARONNE;1
31454;;Rieumes;RIEUMES;31370;31;HAUTE GARONNE;1
31455;;Rieux-Volvestre;RIEUX-VOLVESTRE;31310;31;HAUTE GARONNE;1
31456;;Riolas;RIOLAS;31230;31;HAUTE GARONNE;1
31457;;Roquefort-sur-Garonne;ROQUEFORT-SUR-GARONNE;31360;31;HAUTE GARONNE;1
31458;;Roques;ROQUES;31120;31;HAUTE GARONNE;1
31459;;Roquesérière;ROQUESERIERE;31380;31;HAUTE GARONNE;1
31460;;Roquettes;ROQUETTES;31120;31;HAUTE GARONNE;1
31461;;Rouède;ROUEDE;31160;31;HAUTE GARONNE;1
31462;;Rouffiac-Tolosan;ROUFFIAC-TOLOSAN;31180;31;HAUTE GARONNE;1
31463;;Roumens;ROUMENS;31540;31;HAUTE GARONNE;1
31464;;Sabonnères;SABONNERES;31370;31;HAUTE GARONNE;1
31465;;Saccourvielle;SACCOURVIELLE;31110;31;HAUTE GARONNE;1
31466;;Saiguède;SAIGUEDE;31470;31;HAUTE GARONNE;1
31467;;Saint-Alban;SAINT-ALBAN;31140;31;HAUTE GARONNE;1
31468;;Saint-André;SAINT-ANDRE;31420;31;HAUTE GARONNE;1
31469;;Saint-Araille;SAINT-ARAILLE;31430;31;HAUTE GARONNE;1
31470;;Saint-Aventin;SAINT-AVENTIN;31110;31;HAUTE GARONNE;1
31471;;Saint-Béat;SAINT-BEAT;31440;31;HAUTE GARONNE;1
31472;;Saint-Bertrand-de-Comminges;SAINT-BERTRAND-DE-COMMINGES;31510;31;HAUTE GARONNE;1
31473;;Saint-Cézert;SAINT-CEZERT;31330;31;HAUTE GARONNE;1
31474;;Saint-Christaud;SAINT-CHRISTAUD;31310;31;HAUTE GARONNE;1
31475;;Saint-Clar-de-Rivière;SAINT-CLAR-DE-RIVIERE;31600;31;HAUTE GARONNE;1
31476;;Saint-Élix-le-Château;SAINT-ELIX-LE-CHATEAU;31430;31;HAUTE GARONNE;1
31477;;Saint-Élix-Séglan;SAINT-ELIX-SEGLAN;31420;31;HAUTE GARONNE;1
31478;;Saint-Félix-Lauragais;SAINT-FELIX-LAURAGAIS;31540;31;HAUTE GARONNE;1
31479;;Saint-Ferréol-de-Comminges;SAINT-FERREOL-DE-COMMINGES;31350;31;HAUTE GARONNE;1
31480;;Sainte-Foy-d'Aigrefeuille;SAINTE-FOY-D'AIGREFEUILLE;31570;31;HAUTE GARONNE;1
31481;;Sainte-Foy-de-Peyrolières;SAINTE-FOY-DE-PEYROLIERES;31470;31;HAUTE GARONNE;1
31482;;Saint-Frajou;SAINT-FRAJOU;31230;31;HAUTE GARONNE;1
31483;;Saint-Gaudens;SAINT-GAUDENS;31800;31;HAUTE GARONNE;1
31484;;Saint-Geniès-Bellevue;SAINT-GENIES-BELLEVUE;31180;31;HAUTE GARONNE;1
31485;;Saint-Germier;SAINT-GERMIER;31290;31;HAUTE GARONNE;1
31486;;Saint-Hilaire;SAINT-HILAIRE;31410;31;HAUTE GARONNE;1
31487;;Saint-Ignan;SAINT-IGNAN;31800;31;HAUTE GARONNE;1
31488;;Saint-Jean;SAINT-JEAN;31240;31;HAUTE GARONNE;1
31489;;Saint-Jean-Lherm;SAINT-JEAN-LHERM;31380;31;HAUTE GARONNE;1
31490;;Saint-Jory;SAINT-JORY;31790;31;HAUTE GARONNE;1
31491;;Saint-Julia;SAINT-JULIA;31540;31;HAUTE GARONNE;1
31492;;Saint-Julien-sur-Garonne;SAINT-JULIEN-SUR-GARONNE;31220;31;HAUTE GARONNE;1
31493;;Saint-Lary-Boujean;SAINT-LARY-BOUJEAN;31350;31;HAUTE GARONNE;1
31494;;Saint-Laurent;SAINT-LAURENT;31230;31;HAUTE GARONNE;1
31495;;Saint-Léon;SAINT-LEON;31560;31;HAUTE GARONNE;1
31496;;Sainte-Livrade;SAINTE-LIVRADE;31530;31;HAUTE GARONNE;1
31497;;Saint-Loup-Cammas;SAINT-LOUP-CAMMAS;31140;31;HAUTE GARONNE;1
31498;;Saint-Loup-en-Comminges;SAINT-LOUP-EN-COMMINGES;31350;31;HAUTE GARONNE;1
31499;;Saint-Lys;SAINT-LYS;31470;31;HAUTE GARONNE;1
31500;;Saint-Mamet;SAINT-MAMET;31110;31;HAUTE GARONNE;1
31501;;Saint-Marcel-Paulel;SAINT-MARCEL-PAULEL;31590;31;HAUTE GARONNE;1
31502;;Saint-Marcet;SAINT-MARCET;31800;31;HAUTE GARONNE;1
31503;;Saint-Martory;SAINT-MARTORY;31360;31;HAUTE GARONNE;1
31504;;Saint-Médard;SAINT-MEDARD;31360;31;HAUTE GARONNE;1
31505;;Saint-Michel;SAINT-MICHEL;31220;31;HAUTE GARONNE;1
31506;;Saint-Orens-de-Gameville;SAINT-ORENS-DE-GAMEVILLE;31650;31;HAUTE GARONNE;1
31507;;Saint-Paul-sur-Save;SAINT-PAUL-SUR-SAVE;31530;31;HAUTE GARONNE;1
31508;;Saint-Paul-d'Oueil;SAINT-PAUL-D'OUEIL;31110;31;HAUTE GARONNE;1
31509;;Saint-Pé-d'Ardet;SAINT-PE-D'ARDET;31510;31;HAUTE GARONNE;1
31510;;Saint-Pé-Delbosc;SAINT-PE-DELBOSC;31350;31;HAUTE GARONNE;1
31511;;Saint-Pierre;SAINT-PIERRE;31590;31;HAUTE GARONNE;1
31512;;Saint-Pierre-de-Lages;SAINT-PIERRE-DE-LAGES;31570;31;HAUTE GARONNE;1
31513;;Saint-Plancard;SAINT-PLANCARD;31580;31;HAUTE GARONNE;1
31514;;Saint-Rome;SAINT-ROME;31290;31;HAUTE GARONNE;1
31515;;Saint-Rustice;SAINT-RUSTICE;31620;31;HAUTE GARONNE;1
31516;;Saint-Sauveur;SAINT-SAUVEUR;31790;31;HAUTE GARONNE;1
31517;;Saint-Sulpice-sur-Lèze;SAINT-SULPICE-SUR-LEZE;31410;31;HAUTE GARONNE;1
31518;;Saint-Thomas;SAINT-THOMAS;31470;31;HAUTE GARONNE;1
31519;;Saint-Vincent;SAINT-VINCENT;31290;31;HAUTE GARONNE;1
31520;;Sajas;SAJAS;31370;31;HAUTE GARONNE;1
31521;;Saleich;SALEICH;31260;31;HAUTE GARONNE;1
31522;;Salerm;SALERM;31230;31;HAUTE GARONNE;1
31523;;Salies-du-Salat;SALIES-DU-SALAT;31260;31;HAUTE GARONNE;1
31524;;Salles-et-Pratviel;SALLES-ET-PRATVIEL;31110;31;HAUTE GARONNE;1
31525;;Salles-sur-Garonne;SALLES-SUR-GARONNE;31390;31;HAUTE GARONNE;1
31526;La;Salvetat-Saint-Gilles;SALVETAT-SAINT-GILLES;31880;31;HAUTE GARONNE;1
31527;La;Salvetat-Lauragais;SALVETAT-LAURAGAIS;31460;31;HAUTE GARONNE;1
31528;;Saman;SAMAN;31350;31;HAUTE GARONNE;1
31529;;Samouillan;SAMOUILLAN;31420;31;HAUTE GARONNE;1
31530;;Sana;SANA;31220;31;HAUTE GARONNE;1
31531;;Sarrecave;SARRECAVE;31350;31;HAUTE GARONNE;1
31532;;Sarremezan;SARREMEZAN;31350;31;HAUTE GARONNE;1
31533;;Saubens;SAUBENS;31600;31;HAUTE GARONNE;1
31534;;Saussens;SAUSSENS;31460;31;HAUTE GARONNE;1
31535;;Sauveterre-de-Comminges;SAUVETERRE-DE-COMMINGES;31510;31;HAUTE GARONNE;1
31536;;Saux-et-Pomarède;SAUX-ET-POMAREDE;31800;31;HAUTE GARONNE;1
31537;;Savarthès;SAVARTHES;31800;31;HAUTE GARONNE;1
31538;;Savères;SAVERES;31370;31;HAUTE GARONNE;1
31539;;Sédeilhac;SEDEILHAC;31580;31;HAUTE GARONNE;1
31540;;Ségreville;SEGREVILLE;31460;31;HAUTE GARONNE;1
31541;;Seilh;SEILH;31840;31;HAUTE GARONNE;1
31542;;Seilhan;SEILHAN;31510;31;HAUTE GARONNE;1
31543;;Sénarens;SENARENS;31430;31;HAUTE GARONNE;1
31544;;Sengouagnet;SENGOUAGNET;31160;31;HAUTE GARONNE;1
31545;;Sepx;SEPX;31360;31;HAUTE GARONNE;1
31546;;Seyre;SEYRE;31560;31;HAUTE GARONNE;1
31547;;Seysses;SEYSSES;31600;31;HAUTE GARONNE;1
31548;;Signac;SIGNAC;31440;31;HAUTE GARONNE;1
31549;;Sode;SODE;31110;31;HAUTE GARONNE;1
31550;;Soueich;SOUEICH;31160;31;HAUTE GARONNE;1
31551;;Tarabel;TARABEL;31570;31;HAUTE GARONNE;1
31552;;Terrebasse;TERREBASSE;31420;31;HAUTE GARONNE;1
31553;;Thil;THIL;31530;31;HAUTE GARONNE;1
31554;;Touille;TOUILLE;31260;31;HAUTE GARONNE;1
31555;;Toulouse;TOULOUSE;31000;31;HAUTE GARONNE;1
31556;Les;Tourreilles;TOURREILLES;31210;31;HAUTE GARONNE;1
31557;;Tournefeuille;TOURNEFEUILLE;31170;31;HAUTE GARONNE;1
31558;;Toutens;TOUTENS;31460;31;HAUTE GARONNE;1
31559;;Trébons-de-Luchon;TREBONS-DE-LUCHON;31110;31;HAUTE GARONNE;1
31560;;Trébons-sur-la-Grasse;TREBONS-SUR-LA-GRASSE;31290;31;HAUTE GARONNE;1
31561;L';Union;UNION;31240;31;HAUTE GARONNE;1
31562;;Urau;URAU;31260;31;HAUTE GARONNE;1
31563;;Vacquiers;VACQUIERS;31340;31;HAUTE GARONNE;1
31564;;Valcabrère;VALCABRERE;31510;31;HAUTE GARONNE;1
31565;;Valentine;VALENTINE;31800;31;HAUTE GARONNE;1
31566;;Vallègue;VALLEGUE;31290;31;HAUTE GARONNE;1
31567;;Vallesvilles;VALLESVILLES;31570;31;HAUTE GARONNE;1
31568;;Varennes;VARENNES;31450;31;HAUTE GARONNE;1
31569;;Vaudreuille;VAUDREUILLE;31250;31;HAUTE GARONNE;1
31570;;Vaux;VAUX;31540;31;HAUTE GARONNE;1
31571;;Vendine;VENDINE;31460;31;HAUTE GARONNE;1
31572;;Venerque;VENERQUE;31810;31;HAUTE GARONNE;1
31573;;Verfeil;VERFEIL;31590;31;HAUTE GARONNE;1
31574;;Vernet;VERNET;31810;31;HAUTE GARONNE;1
31575;;Vieille-Toulouse;VIEILLE-TOULOUSE;31320;31;HAUTE GARONNE;1
31576;;Vieillevigne;VIEILLEVIGNE;31290;31;HAUTE GARONNE;1
31577;;Vignaux;VIGNAUX;31480;31;HAUTE GARONNE;1
31578;;Vigoulet-Auzil;VIGOULET-AUZIL;31320;31;HAUTE GARONNE;1
31579;;Villariès;VILLARIES;31380;31;HAUTE GARONNE;1
31580;;Villate;VILLATE;31860;31;HAUTE GARONNE;1
31581;;Villaudric;VILLAUDRIC;31620;31;HAUTE GARONNE;1
31582;;Villefranche-de-Lauragais;VILLEFRANCHE-DE-LAURAGAIS;31290;31;HAUTE GARONNE;1
31583;;Villematier;VILLEMATIER;31340;31;HAUTE GARONNE;1
31584;;Villemur-sur-Tarn;VILLEMUR-SUR-TARN;31340;31;HAUTE GARONNE;1
31585;;Villeneuve-de-Rivière;VILLENEUVE-DE-RIVIERE;31800;31;HAUTE GARONNE;1
31586;;Villeneuve-Lécussan;VILLENEUVE-LECUSSAN;31580;31;HAUTE GARONNE;1
31587;;Villeneuve-lès-Bouloc;VILLENEUVE-LES-BOULOC;31620;31;HAUTE GARONNE;1
31588;;Villeneuve-Tolosane;VILLENEUVE-TOLOSANE;31270;31;HAUTE GARONNE;1
31589;;Villenouvelle;VILLENOUVELLE;31290;31;HAUTE GARONNE;1
31590;;Binos;BINOS;31440;31;HAUTE GARONNE;1
31591;;Escoulis;ESCOULIS;31260;31;HAUTE GARONNE;1
31592;;Larra;LARRA;31330;31;HAUTE GARONNE;1
31593;;Cazac;CAZAC;31230;31;HAUTE GARONNE;1
32001;;Aignan;AIGNAN;32290;32;GERS;1
32002;;Ansan;ANSAN;32270;32;GERS;1
32003;;Antras;ANTRAS;32360;32;GERS;1
32004;;Arblade-le-Bas;ARBLADE-LE-BAS;32720;32;GERS;1
32005;;Arblade-le-Haut;ARBLADE-LE-HAUT;32110;32;GERS;1
32007;;Ardizas;ARDIZAS;32430;32;GERS;1
32008;;Armentieux;ARMENTIEUX;32230;32;GERS;1
32009;;Armous-et-Cau;ARMOUS-ET-CAU;32230;32;GERS;1
32010;;Arrouède;ARROUEDE;32140;32;GERS;1
32012;;Aubiet;AUBIET;32270;32;GERS;1
32013;;Auch;AUCH;32000;32;GERS;1
32014;;Augnax;AUGNAX;32120;32;GERS;1
32015;;Aujan-Mournède;AUJAN-MOURNEDE;32300;32;GERS;1
32016;;Auradé;AURADE;32600;32;GERS;1
32017;;Aurensan;AURENSAN;32400;32;GERS;1
32018;;Aurimont;AURIMONT;32450;32;GERS;1
32019;;Auterive;AUTERIVE;32550;32;GERS;1
32020;;Aux-Aussat;AUX-AUSSAT;32170;32;GERS;1
32021;;Avensac;AVENSAC;32120;32;GERS;1
32022;;Avéron-Bergelle;AVERON-BERGELLE;32290;32;GERS;1
32023;;Avezan;AVEZAN;32380;32;GERS;1
32024;;Ayguetinte;AYGUETINTE;32410;32;GERS;1
32025;;Ayzieu;AYZIEU;32800;32;GERS;1
32026;;Bajonnette;BAJONNETTE;32120;32;GERS;1
32027;;Barcelonne-du-Gers;BARCELONNE-DU-GERS;32720;32;GERS;1
32028;;Barcugnan;BARCUGNAN;32170;32;GERS;1
32029;;Barran;BARRAN;32350;32;GERS;1
32030;;Bars;BARS;32300;32;GERS;1
32031;;Bascous;BASCOUS;32190;32;GERS;1
32032;;Bassoues;BASSOUES;32320;32;GERS;1
32033;;Bazian;BAZIAN;32320;32;GERS;1
32034;;Bazugues;BAZUGUES;32170;32;GERS;1
32035;;Beaucaire;BEAUCAIRE;32410;32;GERS;1
32036;;Beaumarchés;BEAUMARCHES;32160;32;GERS;1
32037;;Beaumont;BEAUMONT;32100;32;GERS;1
32038;;Beaupuy;BEAUPUY;32600;32;GERS;1
32039;;Beccas;BECCAS;32730;32;GERS;1
32040;;Bédéchan;BEDECHAN;32450;32;GERS;1
32041;;Bellegarde;BELLEGARDE;32140;32;GERS;1
32042;;Belloc-Saint-Clamens;BELLOC-SAINT-CLAMENS;32300;32;GERS;1
32043;;Belmont;BELMONT;32190;32;GERS;1
32044;;Béraut;BERAUT;32100;32;GERS;1
32045;;Berdoues;BERDOUES;32300;32;GERS;1
32046;;Bernède;BERNEDE;32400;32;GERS;1
32047;;Berrac;BERRAC;32480;32;GERS;1
32048;;Betcave-Aguin;BETCAVE-AGUIN;32420;32;GERS;1
32049;;Bétous;BETOUS;32110;32;GERS;1
32050;;Betplan;BETPLAN;32730;32;GERS;1
32051;;Bézéril;BEZERIL;32130;32;GERS;1
32052;;Bezolles;BEZOLLES;32310;32;GERS;1
32053;;Bézues-Bajon;BEZUES-BAJON;32140;32;GERS;1
32054;;Biran;BIRAN;32350;32;GERS;1
32055;;Bivès;BIVES;32380;32;GERS;1
32056;;Blanquefort;BLANQUEFORT;32270;32;GERS;1
32057;;Blaziert;BLAZIERT;32100;32;GERS;1
32058;;Blousson-Sérian;BLOUSSON-SERIAN;32230;32;GERS;1
32059;;Bonas;BONAS;32410;32;GERS;1
32060;;Boucagnères;BOUCAGNERES;32550;32;GERS;1
32061;;Boulaur;BOULAUR;32450;32;GERS;1
32062;;Bourrouillan;BOURROUILLAN;32370;32;GERS;1
32063;;Bouzon-Gellenave;BOUZON-GELLENAVE;32290;32;GERS;1
32064;;Bretagne-d'Armagnac;BRETAGNE-D'ARMAGNAC;32800;32;GERS;1
32065;Le;Brouilh-Monbert;BROUILH-MONBERT;32350;32;GERS;1
32066;;Brugnens;BRUGNENS;32500;32;GERS;1
32067;;Cabas-Loumassès;CABAS-LOUMASSES;32140;32;GERS;1
32068;;Cadeilhan;CADEILHAN;32380;32;GERS;1
32069;;Cadeillan;CADEILLAN;32220;32;GERS;1
32070;;Cahuzac-sur-Adour;CAHUZAC-SUR-ADOUR;32400;32;GERS;1
32071;;Caillavet;CAILLAVET;32190;32;GERS;1
32072;;Callian;CALLIAN;32190;32;GERS;1
32073;;Campagne-d'Armagnac;CAMPAGNE-D'ARMAGNAC;32800;32;GERS;1
32074;;Cannet;CANNET;32400;32;GERS;1
32075;;Cassaigne;CASSAIGNE;32100;32;GERS;1
32076;;Castelnau-Barbarens;CASTELNAU-BARBARENS;32450;32;GERS;1
32077;;Castelnau-d'Anglès;CASTELNAU-D'ANGLES;32320;32;GERS;1
32078;;Castelnau-d'Arbieu;CASTELNAU-D'ARBIEU;32500;32;GERS;1
32079;;Castelnau-d'Auzan;CASTELNAU-D'AUZAN;32440;32;GERS;1
32080;;Castelnau-sur-l'Auvignon;CASTELNAU-SUR-L'AUVIGNON;32100;32;GERS;1
32081;;Castelnavet;CASTELNAVET;32290;32;GERS;1
32082;;Castéra-Lectourois;CASTERA-LECTOUROIS;32700;32;GERS;1
32083;;Castéra-Verduzan;CASTERA-VERDUZAN;32410;32;GERS;1
32084;;Castéron;CASTERON;32380;32;GERS;1
32085;;Castet-Arrouy;CASTET-ARROUY;32340;32;GERS;1
32086;;Castex;CASTEX;32170;32;GERS;1
32087;;Castex-d'Armagnac;CASTEX-D'ARMAGNAC;32240;32;GERS;1
32088;;Castillon-Debats;CASTILLON-DEBATS;32190;32;GERS;1
32089;;Castillon-Massas;CASTILLON-MASSAS;32360;32;GERS;1
32090;;Castillon-Savès;CASTILLON-SAVES;32490;32;GERS;1
32091;;Castin;CASTIN;32810;32;GERS;1
32092;;Catonvielle;CATONVIELLE;32200;32;GERS;1
32093;;Caumont;CAUMONT;32400;32;GERS;1
32094;;Caupenne-d'Armagnac;CAUPENNE-D'ARMAGNAC;32110;32;GERS;1
32095;;Caussens;CAUSSENS;32100;32;GERS;1
32096;;Cazaubon;CAZAUBON;32150;32;GERS;1
32097;;Cazaux-d'Anglès;CAZAUX-D'ANGLES;32190;32;GERS;1
32098;;Cazaux-Savès;CAZAUX-SAVES;32130;32;GERS;1
32099;;Cazaux-Villecomtal;CAZAUX-VILLECOMTAL;32230;32;GERS;1
32100;;Cazeneuve;CAZENEUVE;32800;32;GERS;1
32101;;Céran;CERAN;32500;32;GERS;1
32102;;Cézan;CEZAN;32410;32;GERS;1
32103;;Chélan;CHELAN;32140;32;GERS;1
32104;;Clermont-Pouyguillès;CLERMONT-POUYGUILLES;32300;32;GERS;1
32105;;Clermont-Savès;CLERMONT-SAVES;32600;32;GERS;1
32106;;Cologne;COLOGNE;32430;32;GERS;1
32107;;Condom;CONDOM;32100;32;GERS;1
32108;;Corneillan;CORNEILLAN;32400;32;GERS;1
32109;;Couloumé-Mondebat;COULOUME-MONDEBAT;32160;32;GERS;1
32110;;Courrensan;COURRENSAN;32330;32;GERS;1
32111;;Courties;COURTIES;32230;32;GERS;1
32112;;Crastes;CRASTES;32270;32;GERS;1
32113;;Cravencères;CRAVENCERES;32110;32;GERS;1
32114;;Cuélas;CUELAS;32300;32;GERS;1
32115;;Dému;DEMU;32190;32;GERS;1
32116;;Duffort;DUFFORT;32170;32;GERS;1
32117;;Duran;DURAN;32810;32;GERS;1
32118;;Durban;DURBAN;32260;32;GERS;1
32119;;Eauze;EAUZE;32800;32;GERS;1
32120;;Encausse;ENCAUSSE;32430;32;GERS;1
32121;;Endoufielle;ENDOUFIELLE;32600;32;GERS;1
32122;;Esclassan-Labastide;ESCLASSAN-LABASTIDE;32140;32;GERS;1
32123;;Escornebœuf;ESCORNEBOEUF;32200;32;GERS;1
32124;;Espaon;ESPAON;32220;32;GERS;1
32125;;Espas;ESPAS;32370;32;GERS;1
32126;;Estampes;ESTAMPES;32170;32;GERS;1
32127;;Estang;ESTANG;32240;32;GERS;1
32128;;Estipouy;ESTIPOUY;32300;32;GERS;1
32129;;Estramiac;ESTRAMIAC;32380;32;GERS;1
32130;;Faget-Abbatial;FAGET-ABBATIAL;32450;32;GERS;1
32131;;Flamarens;FLAMARENS;32340;32;GERS;1
32132;;Fleurance;FLEURANCE;32500;32;GERS;1
32133;;Fourcès;FOURCES;32250;32;GERS;1
32134;;Frégouville;FREGOUVILLE;32490;32;GERS;1
32135;;Fustérouau;FUSTEROUAU;32400;32;GERS;1
32136;;Galiax;GALIAX;32160;32;GERS;1
32138;;Garravet;GARRAVET;32220;32;GERS;1
32139;;Gaudonville;GAUDONVILLE;32380;32;GERS;1
32140;;Gaujac;GAUJAC;32220;32;GERS;1
32141;;Gaujan;GAUJAN;32420;32;GERS;1
32142;;Gavarret-sur-Aulouste;GAVARRET-SUR-AULOUSTE;32390;32;GERS;1
32143;;Gazaupouy;GAZAUPOUY;32480;32;GERS;1
32144;;Gazax-et-Baccarisse;GAZAX-ET-BACCARISSE;32230;32;GERS;1
32145;;Gée-Rivière;GEE-RIVIERE;32720;32;GERS;1
32146;;Gimbrède;GIMBREDE;32340;32;GERS;1
32147;;Gimont;GIMONT;32200;32;GERS;1
32148;;Giscaro;GISCARO;32200;32;GERS;1
32149;;Gondrin;GONDRIN;32330;32;GERS;1
32150;;Goutz;GOUTZ;32500;32;GERS;1
32151;;Goux;GOUX;32400;32;GERS;1
32152;;Haget;HAGET;32730;32;GERS;1
32153;;Haulies;HAULIES;32550;32;GERS;1
32154;;Homps;HOMPS;32120;32;GERS;1
32155;Le;Houga;HOUGA;32460;32;GERS;1
32156;;Idrac-Respaillès;IDRAC-RESPAILLES;32300;32;GERS;1
32157;L';Isle-Arné;ISLE-ARNE;32270;32;GERS;1
32158;L';Isle-Bouzon;ISLE-BOUZON;32380;32;GERS;1
32159;L';Isle-de-Noé;ISLE-DE-NOE;32300;32;GERS;1
32160;L';Isle-Jourdain;ISLE-JOURDAIN;32600;32;GERS;1
32161;;Izotges;IZOTGES;32400;32;GERS;1
32162;;Jegun;JEGUN;32360;32;GERS;1
32163;;Jû-Belloc;JU-BELLOC;32160;32;GERS;1
32164;;Juillac;JUILLAC;32230;32;GERS;1
32165;;Juilles;JUILLES;32200;32;GERS;1
32166;;Justian;JUSTIAN;32190;32;GERS;1
32167;;Laas;LAAS;32170;32;GERS;1
32168;;Labarrère;LABARRERE;32250;32;GERS;1
32169;;Labarthe;LABARTHE;32260;32;GERS;1
32170;;Labarthète;LABARTHETE;32400;32;GERS;1
32171;;Labastide-Savès;LABASTIDE-SAVES;32130;32;GERS;1
32172;;Labéjan;LABEJAN;32300;32;GERS;1
32173;;Labrihe;LABRIHE;32120;32;GERS;1
32174;;Ladevèze-Rivière;LADEVEZE-RIVIERE;32230;32;GERS;1
32175;;Ladevèze-Ville;LADEVEZE-VILLE;32230;32;GERS;1
32176;;Lagarde;LAGARDE;32700;32;GERS;1
32177;;Lagarde-Hachan;LAGARDE-HACHAN;32300;32;GERS;1
32178;;Lagardère;LAGARDERE;32310;32;GERS;1
32180;;Lagraulet-du-Gers;LAGRAULET-DU-GERS;32330;32;GERS;1
32181;;Laguian-Mazous;LAGUIAN-MAZOUS;32170;32;GERS;1
32182;;Lahas;LAHAS;32130;32;GERS;1
32183;;Lahitte;LAHITTE;32810;32;GERS;1
32184;;Lalanne;LALANNE;32500;32;GERS;1
32185;;Lalanne-Arqué;LALANNE-ARQUE;32140;32;GERS;1
32186;;Lamaguère;LAMAGUERE;32260;32;GERS;1
32187;;Lamazère;LAMAZERE;32300;32;GERS;1
32188;;Lamothe-Goas;LAMOTHE-GOAS;32500;32;GERS;1
32189;;Lannemaignan;LANNEMAIGNAN;32240;32;GERS;1
32190;;Lannepax;LANNEPAX;32190;32;GERS;1
32191;;Lanne-Soubiran;LANNE-SOUBIRAN;32110;32;GERS;1
32192;;Lannux;LANNUX;32400;32;GERS;1
32193;;Larée;LAREE;32150;32;GERS;1
32194;;Larressingle;LARRESSINGLE;32100;32;GERS;1
32195;;Larroque-Engalin;LARROQUE-ENGALIN;32480;32;GERS;1
32196;;Larroque-Saint-Sernin;LARROQUE-SAINT-SERNIN;32410;32;GERS;1
32197;;Larroque-sur-l'Osse;LARROQUE-SUR-L'OSSE;32100;32;GERS;1
32198;;Lartigue;LARTIGUE;32450;32;GERS;1
32199;;Lasserade;LASSERADE;32160;32;GERS;1
32200;;Lasséran;LASSERAN;32550;32;GERS;1
32201;;Lasseube-Propre;LASSEUBE-PROPRE;32550;32;GERS;1
32202;;Laujuzan;LAUJUZAN;32110;32;GERS;1
32203;;Lauraët;LAURAET;32330;32;GERS;1
32204;;Lavardens;LAVARDENS;32360;32;GERS;1
32205;;Laveraët;LAVERAET;32230;32;GERS;1
32206;;Laymont;LAYMONT;32220;32;GERS;1
32207;;Leboulin;LEBOULIN;32810;32;GERS;1
32208;;Lectoure;LECTOURE;32700;32;GERS;1
32209;;Lelin-Lapujolle;LELIN-LAPUJOLLE;32400;32;GERS;1
32210;;Lias;LIAS;32600;32;GERS;1
32211;;Lias-d'Armagnac;LIAS-D'ARMAGNAC;32240;32;GERS;1
32212;;Ligardes;LIGARDES;32480;32;GERS;1
32213;;Lombez;LOMBEZ;32220;32;GERS;1
32214;;Loubédat;LOUBEDAT;32110;32;GERS;1
32215;;Loubersan;LOUBERSAN;32300;32;GERS;1
32216;;Lourties-Monbrun;LOURTIES-MONBRUN;32140;32;GERS;1
32217;;Louslitges;LOUSLITGES;32230;32;GERS;1
32218;;Loussous-Débat;LOUSSOUS-DEBAT;32290;32;GERS;1
32219;;Lupiac;LUPIAC;32290;32;GERS;1
32220;;Luppé-Violles;LUPPE-VIOLLES;32110;32;GERS;1
32221;;Lussan;LUSSAN;32270;32;GERS;1
32222;;Magnan;MAGNAN;32110;32;GERS;1
32223;;Magnas;MAGNAS;32380;32;GERS;1
32224;;Maignaut-Tauzia;MAIGNAUT-TAUZIA;32310;32;GERS;1
32225;;Malabat;MALABAT;32730;32;GERS;1
32226;;Manas-Bastanous;MANAS-BASTANOUS;32170;32;GERS;1
32227;;Manciet;MANCIET;32370;32;GERS;1
32228;;Manent-Montané;MANENT-MONTANE;32140;32;GERS;1
32229;;Mansempuy;MANSEMPUY;32120;32;GERS;1
32230;;Mansencôme;MANSENCOME;32310;32;GERS;1
32231;;Marambat;MARAMBAT;32190;32;GERS;1
32232;;Maravat;MARAVAT;32120;32;GERS;1
32233;;Marciac;MARCIAC;32230;32;GERS;1
32234;;Marestaing;MARESTAING;32490;32;GERS;1
32235;;Margouët-Meymes;MARGOUET-MEYMES;32290;32;GERS;1
32236;;Marguestau;MARGUESTAU;32150;32;GERS;1
32237;;Marsan;MARSAN;32270;32;GERS;1
32238;;Marseillan;MARSEILLAN;32170;32;GERS;1
32239;;Marsolan;MARSOLAN;32700;32;GERS;1
32240;;Mascaras;MASCARAS;32230;32;GERS;1
32241;;Mas-d'Auvignon;MAS-D'AUVIGNON;32700;32;GERS;1
32242;;Masseube;MASSEUBE;32140;32;GERS;1
32243;;Mauléon-d'Armagnac;MAULEON-D'ARMAGNAC;32240;32;GERS;1
32244;;Maulichères;MAULICHERES;32400;32;GERS;1
32245;;Maumusson-Laguian;MAUMUSSON-LAGUIAN;32400;32;GERS;1
32246;;Maupas;MAUPAS;32240;32;GERS;1
32247;;Maurens;MAURENS;32200;32;GERS;1
32248;;Mauroux;MAUROUX;32380;32;GERS;1
32249;;Mauvezin;MAUVEZIN;32120;32;GERS;1
32250;;Meilhan;MEILHAN;32420;32;GERS;1
32251;;Mérens;MERENS;32360;32;GERS;1
32252;;Miélan;MIELAN;32170;32;GERS;1
32253;;Miradoux;MIRADOUX;32340;32;GERS;1
32254;;Miramont-d'Astarac;MIRAMONT-D'ASTARAC;32300;32;GERS;1
32255;;Miramont-Latour;MIRAMONT-LATOUR;32390;32;GERS;1
32256;;Mirande;MIRANDE;32300;32;GERS;1
32257;;Mirannes;MIRANNES;32350;32;GERS;1
32258;;Mirepoix;MIREPOIX;32390;32;GERS;1
32260;;Monbardon;MONBARDON;32420;32;GERS;1
32261;;Monblanc;MONBLANC;32130;32;GERS;1
32262;;Monbrun;MONBRUN;32600;32;GERS;1
32263;;Moncassin;MONCASSIN;32300;32;GERS;1
32264;;Monclar;MONCLAR;32150;32;GERS;1
32265;;Monclar-sur-Losse;MONCLAR-SUR-LOSSE;32300;32;GERS;1
32266;;Moncorneil-Grazan;MONCORNEIL-GRAZAN;32260;32;GERS;1
32267;;Monferran-Plavès;MONFERRAN-PLAVES;32260;32;GERS;1
32268;;Monferran-Savès;MONFERRAN-SAVES;32490;32;GERS;1
32269;;Monfort;MONFORT;32120;32;GERS;1
32270;;Mongausy;MONGAUSY;32220;32;GERS;1
32271;;Monguilhem;MONGUILHEM;32240;32;GERS;1
32272;;Monlaur-Bernet;MONLAUR-BERNET;32140;32;GERS;1
32273;;Monlezun;MONLEZUN;32230;32;GERS;1
32274;;Monlezun-d'Armagnac;MONLEZUN-D'ARMAGNAC;32240;32;GERS;1
32275;;Monpardiac;MONPARDIAC;32170;32;GERS;1
32276;;Montadet;MONTADET;32220;32;GERS;1
32277;;Montamat;MONTAMAT;32220;32;GERS;1
32278;;Montaut;MONTAUT;32300;32;GERS;1
32279;;Montaut-les-Créneaux;MONTAUT-LES-CRENEAUX;32810;32;GERS;1
32280;;Mont-d'Astarac;MONT-D'ASTARAC;32140;32;GERS;1
32281;;Mont-de-Marrast;MONT-DE-MARRAST;32170;32;GERS;1
32282;;Montégut;MONTEGUT;32550;32;GERS;1
32283;;Montégut-Arros;MONTEGUT-ARROS;32730;32;GERS;1
32284;;Montégut-Savès;MONTEGUT-SAVES;32220;32;GERS;1
32285;;Montesquiou;MONTESQUIOU;32320;32;GERS;1
32286;;Montestruc-sur-Gers;MONTESTRUC-SUR-GERS;32390;32;GERS;1
32287;;Monties;MONTIES;32420;32;GERS;1
32288;;Montiron;MONTIRON;32200;32;GERS;1
32289;;Montpézat;MONTPEZAT;32220;32;GERS;1
32290;;Montréal;MONTREAL;32250;32;GERS;1
32291;;Mormès;MORMES;32240;32;GERS;1
32292;;Mouchan;MOUCHAN;32330;32;GERS;1
32293;;Mouchès;MOUCHES;32300;32;GERS;1
32294;;Mourède;MOUREDE;32190;32;GERS;1
32295;;Nizas;NIZAS;32130;32;GERS;1
32296;;Nogaro;NOGARO;32110;32;GERS;1
32297;;Noilhan;NOILHAN;32130;32;GERS;1
32298;;Nougaroulet;NOUGAROULET;32270;32;GERS;1
32299;;Noulens;NOULENS;32800;32;GERS;1
32300;;Orbessan;ORBESSAN;32260;32;GERS;1
32301;;Ordan-Larroque;ORDAN-LARROQUE;32350;32;GERS;1
32302;;Ornézan;ORNEZAN;32260;32;GERS;1
32303;;Pallanne;PALLANNE;32230;32;GERS;1
32304;;Panassac;PANASSAC;32140;32;GERS;1
32305;;Panjas;PANJAS;32110;32;GERS;1
32306;;Pauilhac;PAUILHAC;32500;32;GERS;1
32307;;Pavie;PAVIE;32550;32;GERS;1
32308;;Pébées;PEBEES;32130;32;GERS;1
32309;;Pellefigue;PELLEFIGUE;32420;32;GERS;1
32310;;Perchède;PERCHEDE;32460;32;GERS;1
32311;;Pergain-Taillac;PERGAIN-TAILLAC;32700;32;GERS;1
32312;;Pessan;PESSAN;32550;32;GERS;1
32313;;Pessoulens;PESSOULENS;32380;32;GERS;1
32314;;Peyrecave;PEYRECAVE;32340;32;GERS;1
32315;;Peyrusse-Grande;PEYRUSSE-GRANDE;32320;32;GERS;1
32316;;Peyrusse-Massas;PEYRUSSE-MASSAS;32360;32;GERS;1
32317;;Peyrusse-Vieille;PEYRUSSE-VIEILLE;32230;32;GERS;1
32318;;Pis;PIS;32500;32;GERS;1
32319;;Plaisance;PLAISANCE;32160;32;GERS;1
32320;;Plieux;PLIEUX;32340;32;GERS;1
32321;;Polastron;POLASTRON;32130;32;GERS;1
32322;;Pompiac;POMPIAC;32130;32;GERS;1
32323;;Ponsampère;PONSAMPERE;32300;32;GERS;1
32324;;Ponsan-Soubiran;PONSAN-SOUBIRAN;32300;32;GERS;1
32325;;Pouydraguin;POUYDRAGUIN;32290;32;GERS;1
32326;;Pouylebon;POUYLEBON;32320;32;GERS;1
32327;;Pouy-Loubrin;POUY-LOUBRIN;32260;32;GERS;1
32328;;Pouy-Roquelaure;POUY-ROQUELAURE;32480;32;GERS;1
32329;;Préchac;PRECHAC;32390;32;GERS;1
32330;;Préchac-sur-Adour;PRECHAC-SUR-ADOUR;32160;32;GERS;1
32331;;Preignan;PREIGNAN;32810;32;GERS;1
32332;;Préneron;PRENERON;32190;32;GERS;1
32333;;Projan;PROJAN;32400;32;GERS;1
32334;;Pujaudran;PUJAUDRAN;32600;32;GERS;1
32335;;Puycasquier;PUYCASQUIER;32120;32;GERS;1
32336;;Puylausic;PUYLAUSIC;32220;32;GERS;1
32337;;Puységur;PUYSEGUR;32390;32;GERS;1
32338;;Ramouzens;RAMOUZENS;32800;32;GERS;1
32339;;Razengues;RAZENGUES;32600;32;GERS;1
32340;;Réans;REANS;32800;32;GERS;1
32341;;Réjaumont;REJAUMONT;32390;32;GERS;1
32342;;Ricourt;RICOURT;32230;32;GERS;1
32343;;Riguepeu;RIGUEPEU;32320;32;GERS;1
32344;;Riscle;RISCLE;32400;32;GERS;1
32345;La;Romieu;ROMIEU;32480;32;GERS;1
32346;;Roquebrune;ROQUEBRUNE;32190;32;GERS;1
32347;;Roquefort;ROQUEFORT;32390;32;GERS;1
32348;;Roquelaure;ROQUELAURE;32810;32;GERS;1
32349;;Roquelaure-Saint-Aubin;ROQUELAURE-SAINT-AUBIN;32430;32;GERS;1
32350;;Roquepine;ROQUEPINE;32100;32;GERS;1
32351;;Roques;ROQUES;32310;32;GERS;1
32352;;Rozès;ROZES;32190;32;GERS;1
32353;;Sabaillan;SABAILLAN;32420;32;GERS;1
32354;;Sabazan;SABAZAN;32290;32;GERS;1
32355;;Sadeillan;SADEILLAN;32170;32;GERS;1
32356;;Saint-André;SAINT-ANDRE;32200;32;GERS;1
32357;;Sainte-Anne;SAINTE-ANNE;32430;32;GERS;1
32358;;Saint-Antoine;SAINT-ANTOINE;32340;32;GERS;1
32359;;Saint-Antonin;SAINT-ANTONIN;32120;32;GERS;1
32360;;Saint-Arailles;SAINT-ARAILLES;32350;32;GERS;1
32361;;Saint-Arroman;SAINT-ARROMAN;32300;32;GERS;1
32362;;Saint-Aunix-Lengros;SAINT-AUNIX-LENGROS;32160;32;GERS;1
32363;;Sainte-Aurence-Cazaux;SAINTE-AURENCE-CAZAUX;32300;32;GERS;1
32364;;Saint-Avit-Frandat;SAINT-AVIT-FRANDAT;32700;32;GERS;1
32365;;Saint-Blancard;SAINT-BLANCARD;32140;32;GERS;1
32366;;Saint-Brès;SAINT-BRES;32120;32;GERS;1
32367;;Saint-Christaud;SAINT-CHRISTAUD;32320;32;GERS;1
32368;;Sainte-Christie;SAINTE-CHRISTIE;32390;32;GERS;1
32369;;Sainte-Christie-d'Armagnac;SAINTE-CHRISTIE-D'ARMAGNAC;32370;32;GERS;1
32370;;Saint-Clar;SAINT-CLAR;32380;32;GERS;1
32371;;Saint-Créac;SAINT-CREAC;32380;32;GERS;1
32372;;Saint-Cricq;SAINT-CRICQ;32430;32;GERS;1
32373;;Sainte-Dode;SAINTE-DODE;32170;32;GERS;1
32374;;Saint-Élix;SAINT-ELIX;32450;32;GERS;1
32375;;Saint-Élix-Theux;SAINT-ELIX-THEUX;32300;32;GERS;1
32376;;Sainte-Gemme;SAINTE-GEMME;32120;32;GERS;1
32377;;Saint-Georges;SAINT-GEORGES;32430;32;GERS;1
32378;;Saint-Germé;SAINT-GERME;32400;32;GERS;1
32379;;Saint-Germier;SAINT-GERMIER;32200;32;GERS;1
32380;;Saint-Griède;SAINT-GRIEDE;32110;32;GERS;1
32381;;Saint-Jean-le-Comtal;SAINT-JEAN-LE-COMTAL;32550;32;GERS;1
32382;;Saint-Jean-Poutge;SAINT-JEAN-POUTGE;32190;32;GERS;1
32383;;Saint-Justin;SAINT-JUSTIN;32230;32;GERS;1
32384;;Saint-Lary;SAINT-LARY;32360;32;GERS;1
32385;;Saint-Léonard;SAINT-LEONARD;32380;32;GERS;1
32386;;Saint-Lizier-du-Planté;SAINT-LIZIER-DU-PLANTE;32220;32;GERS;1
32387;;Saint-Loube;SAINT-LOUBE;32220;32;GERS;1
32388;;Sainte-Marie;SAINTE-MARIE;32200;32;GERS;1
32389;;Saint-Martin;SAINT-MARTIN;32300;32;GERS;1
32390;;Saint-Martin-d'Armagnac;SAINT-MARTIN-D'ARMAGNAC;32110;32;GERS;1
32391;;Saint-Martin-de-Goyne;SAINT-MARTIN-DE-GOYNE;32480;32;GERS;1
32392;;Saint-Martin-Gimois;SAINT-MARTIN-GIMOIS;32450;32;GERS;1
32393;;Saint-Maur;SAINT-MAUR;32300;32;GERS;1
32394;;Saint-Médard;SAINT-MEDARD;32300;32;GERS;1
32395;;Sainte-Mère;SAINTE-MERE;32700;32;GERS;1
32396;;Saint-Mézard;SAINT-MEZARD;32700;32;GERS;1
32397;;Saint-Michel;SAINT-MICHEL;32300;32;GERS;1
32398;;Saint-Mont;SAINT-MONT;32400;32;GERS;1
32399;;Saint-Orens;SAINT-ORENS;32120;32;GERS;1
32400;;Saint-Orens-Pouy-Petit;SAINT-ORENS-POUY-PETIT;32100;32;GERS;1
32401;;Saint-Ost;SAINT-OST;32300;32;GERS;1
32402;;Saint-Paul-de-Baïse;SAINT-PAUL-DE-BAISE;32190;32;GERS;1
32403;;Saint-Pierre-d'Aubézies;SAINT-PIERRE-D'AUBEZIES;32290;32;GERS;1
32404;;Saint-Puy;SAINT-PUY;32310;32;GERS;1
32405;;Sainte-Radegonde;SAINTE-RADEGONDE;32500;32;GERS;1
32406;;Saint-Sauvy;SAINT-SAUVY;32270;32;GERS;1
32407;;Saint-Soulan;SAINT-SOULAN;32220;32;GERS;1
32408;;Salles-d'Armagnac;SALLES-D'ARMAGNAC;32370;32;GERS;1
32409;;Samaran;SAMARAN;32140;32;GERS;1
32410;;Samatan;SAMATAN;32130;32;GERS;1
32411;;Sansan;SANSAN;32260;32;GERS;1
32412;;Saramon;SARAMON;32450;32;GERS;1
32413;;Sarcos;SARCOS;32420;32;GERS;1
32414;;Sarragachies;SARRAGACHIES;32400;32;GERS;1
32415;;Sarraguzan;SARRAGUZAN;32170;32;GERS;1
32416;;Sarrant;SARRANT;32120;32;GERS;1
32417;La;Sauvetat;SAUVETAT;32500;32;GERS;1
32418;;Sauveterre;SAUVETERRE;32220;32;GERS;1
32419;;Sauviac;SAUVIAC;32300;32;GERS;1
32420;;Sauvimont;SAUVIMONT;32220;32;GERS;1
32421;;Savignac-Mona;SAVIGNAC-MONA;32130;32;GERS;1
32422;;Scieurac-et-Flourès;SCIEURAC-ET-FLOURES;32230;32;GERS;1
32423;;Séailles;SEAILLES;32190;32;GERS;1
32424;;Ségos;SEGOS;32400;32;GERS;1
32425;;Ségoufielle;SEGOUFIELLE;32600;32;GERS;1
32426;;Seissan;SEISSAN;32260;32;GERS;1
32427;;Sembouès;SEMBOUES;32230;32;GERS;1
32428;;Sémézies-Cachan;SEMEZIES-CACHAN;32450;32;GERS;1
32429;;Sempesserre;SEMPESSERRE;32700;32;GERS;1
32430;;Sère;SERE;32140;32;GERS;1
32431;;Sérempuy;SEREMPUY;32120;32;GERS;1
32432;;Seysses-Savès;SEYSSES-SAVES;32130;32;GERS;1
32433;;Simorre;SIMORRE;32420;32;GERS;1
32434;;Sion;SION;32110;32;GERS;1
32435;;Sirac;SIRAC;32430;32;GERS;1
32436;;Solomiac;SOLOMIAC;32120;32;GERS;1
32437;;Sorbets;SORBETS;32110;32;GERS;1
32438;;Tachoires;TACHOIRES;32260;32;GERS;1
32439;;Tarsac;TARSAC;32400;32;GERS;1
32440;;Tasque;TASQUE;32160;32;GERS;1
32441;;Taybosc;TAYBOSC;32120;32;GERS;1
32442;;Terraube;TERRAUBE;32700;32;GERS;1
32443;;Termes-d'Armagnac;TERMES-D'ARMAGNAC;32400;32;GERS;1
32444;;Thoux;THOUX;32430;32;GERS;1
32445;;Tieste-Uragnoux;TIESTE-URAGNOUX;32160;32;GERS;1
32446;;Tillac;TILLAC;32170;32;GERS;1
32447;;Tirent-Pontéjac;TIRENT-PONTEJAC;32450;32;GERS;1
32448;;Touget;TOUGET;32430;32;GERS;1
32449;;Toujouse;TOUJOUSE;32240;32;GERS;1
32450;;Tourdun;TOURDUN;32230;32;GERS;1
32451;;Tournan;TOURNAN;32420;32;GERS;1
32452;;Tournecoupe;TOURNECOUPE;32380;32;GERS;1
32453;;Tourrenquets;TOURRENQUETS;32390;32;GERS;1
32454;;Traversères;TRAVERSERES;32450;32;GERS;1
32455;;Troncens;TRONCENS;32230;32;GERS;1
32456;;Tudelle;TUDELLE;32190;32;GERS;1
32457;;Urdens;URDENS;32500;32;GERS;1
32458;;Urgosse;URGOSSE;32110;32;GERS;1
32459;;Valence-sur-Baïse;VALENCE-SUR-BAISE;32310;32;GERS;1
32460;;Vergoignan;VERGOIGNAN;32720;32;GERS;1
32461;;Verlus;VERLUS;32400;32;GERS;1
32462;;Vic-Fezensac;VIC-FEZENSAC;32190;32;GERS;1
32463;;Viella;VIELLA;32400;32;GERS;1
32464;;Villecomtal-sur-Arros;VILLECOMTAL-SUR-ARROS;32730;32;GERS;1
32465;;Villefranche;VILLEFRANCHE;32420;32;GERS;1
32466;;Viozan;VIOZAN;32300;32;GERS;1
32467;;Saint-Caprais;SAINT-CAPRAIS;32200;32;GERS;1
32468;;Aussos;AUSSOS;32140;32;GERS;1
33001;;Abzac;ABZAC;33230;33;GIRONDE;1
33002;;Aillas;AILLAS;33124;33;GIRONDE;1
33003;;Ambarès-et-Lagrave;AMBARES-ET-LAGRAVE;33440;33;GIRONDE;1
33004;;Ambès;AMBES;33810;33;GIRONDE;1
33005;;Andernos-les-Bains;ANDERNOS-LES-BAINS;33510;33;GIRONDE;1
33006;;Anglade;ANGLADE;33390;33;GIRONDE;1
33007;;Arbanats;ARBANATS;33640;33;GIRONDE;1
33008;;Arbis;ARBIS;33760;33;GIRONDE;1
33009;;Arcachon;ARCACHON;33120;33;GIRONDE;1
33010;;Arcins;ARCINS;33460;33;GIRONDE;1
33011;;Arès;ARES;33740;33;GIRONDE;1
33012;;Arsac;ARSAC;33460;33;GIRONDE;1
33013;;Artigues-près-Bordeaux;ARTIGUES-PRES-BORDEAUX;33370;33;GIRONDE;1
33014;Les;Artigues-de-Lussac;ARTIGUES-DE-LUSSAC;33570;33;GIRONDE;1
33015;;Arveyres;ARVEYRES;33500;33;GIRONDE;1
33016;;Asques;ASQUES;33240;33;GIRONDE;1
33017;;Aubiac;AUBIAC;33430;33;GIRONDE;1
33018;;Aubie-et-Espessas;AUBIE-ET-ESPESSAS;33240;33;GIRONDE;1
33019;;Audenge;AUDENGE;33980;33;GIRONDE;1
33020;;Auriolles;AURIOLLES;33790;33;GIRONDE;1
33021;;Auros;AUROS;33124;33;GIRONDE;1
33022;;Avensan;AVENSAN;33480;33;GIRONDE;1
33023;;Ayguemorte-les-Graves;AYGUEMORTE-LES-GRAVES;33640;33;GIRONDE;1
33024;;Bagas;BAGAS;33190;33;GIRONDE;1
33025;;Baigneaux;BAIGNEAUX;33760;33;GIRONDE;1
33026;;Balizac;BALIZAC;33730;33;GIRONDE;1
33027;;Barie;BARIE;33190;33;GIRONDE;1
33028;;Baron;BARON;33750;33;GIRONDE;1
33029;Le;Barp;BARP;33114;33;GIRONDE;1
33030;;Barsac;BARSAC;33720;33;GIRONDE;1
33031;;Bassanne;BASSANNE;33190;33;GIRONDE;1
33032;;Bassens;BASSENS;33530;33;GIRONDE;1
33033;;Baurech;BAURECH;33880;33;GIRONDE;1
33034;;Bayas;BAYAS;33230;33;GIRONDE;1
33035;;Bayon-sur-Gironde;BAYON-SUR-GIRONDE;33710;33;GIRONDE;1
33036;;Bazas;BAZAS;33430;33;GIRONDE;1
33037;;Beautiran;BEAUTIRAN;33640;33;GIRONDE;1
33038;;Bégadan;BEGADAN;33340;33;GIRONDE;1
33039;;Bègles;BEGLES;33130;33;GIRONDE;1
33040;;Béguey;BEGUEY;33410;33;GIRONDE;1
33042;;Belin-Béliet;BELIN-BELIET;33830;33;GIRONDE;1
33043;;Bellebat;BELLEBAT;33760;33;GIRONDE;1
33044;;Bellefond;BELLEFOND;33760;33;GIRONDE;1
33045;;Belvès-de-Castillon;BELVES-DE-CASTILLON;33350;33;GIRONDE;1
33046;;Bernos-Beaulac;BERNOS-BEAULAC;33430;33;GIRONDE;1
33047;;Berson;BERSON;33390;33;GIRONDE;1
33048;;Berthez;BERTHEZ;33124;33;GIRONDE;1
33049;;Beychac-et-Caillau;BEYCHAC-ET-CAILLAU;33750;33;GIRONDE;1
33050;;Bieujac;BIEUJAC;33210;33;GIRONDE;1
33051;;Biganos;BIGANOS;33380;33;GIRONDE;1
33052;Les;Billaux;BILLAUX;33500;33;GIRONDE;1
33053;;Birac;BIRAC;33430;33;GIRONDE;1
33054;;Blaignac;BLAIGNAC;33190;33;GIRONDE;1
33055;;Blaignan;BLAIGNAN;33340;33;GIRONDE;1
33056;;Blanquefort;BLANQUEFORT;33290;33;GIRONDE;1
33057;;Blasimon;BLASIMON;33540;33;GIRONDE;1
33058;;Blaye;BLAYE;33390;33;GIRONDE;1
33059;;Blésignac;BLESIGNAC;33670;33;GIRONDE;1
33060;;Bommes;BOMMES;33210;33;GIRONDE;1
33061;;Bonnetan;BONNETAN;33370;33;GIRONDE;1
33062;;Bonzac;BONZAC;33910;33;GIRONDE;1
33063;;Bordeaux;BORDEAUX;33000;33;GIRONDE;1
33064;;Bossugan;BOSSUGAN;33350;33;GIRONDE;1
33065;;Bouliac;BOULIAC;33270;33;GIRONDE;1
33066;;Bourdelles;BOURDELLES;33190;33;GIRONDE;1
33067;;Bourg;BOURG;33710;33;GIRONDE;1
33068;;Bourideys;BOURIDEYS;33113;33;GIRONDE;1
33069;Le;Bouscat;BOUSCAT;33110;33;GIRONDE;1
33070;;Brach;BRACH;33480;33;GIRONDE;1
33071;;Branne;BRANNE;33420;33;GIRONDE;1
33072;;Brannens;BRANNENS;33124;33;GIRONDE;1
33073;;Braud-et-Saint-Louis;BRAUD-ET-SAINT-LOUIS;33820;33;GIRONDE;1
33074;;Brouqueyran;BROUQUEYRAN;33124;33;GIRONDE;1
33075;;Bruges;BRUGES;33520;33;GIRONDE;1
33076;;Budos;BUDOS;33720;33;GIRONDE;1
33077;;Cabanac-et-Villagrains;CABANAC-ET-VILLAGRAINS;33650;33;GIRONDE;1
33078;;Cabara;CABARA;33420;33;GIRONDE;1
33079;;Cadarsac;CADARSAC;33750;33;GIRONDE;1
33080;;Cadaujac;CADAUJAC;33140;33;GIRONDE;1
33081;;Cadillac;CADILLAC;33410;33;GIRONDE;1
33082;;Cadillac-en-Fronsadais;CADILLAC-EN-FRONSADAIS;33240;33;GIRONDE;1
33083;;Camarsac;CAMARSAC;33750;33;GIRONDE;1
33084;;Cambes;CAMBES;33880;33;GIRONDE;1
33085;;Camblanes-et-Meynac;CAMBLANES-ET-MEYNAC;33360;33;GIRONDE;1
33086;;Camiac-et-Saint-Denis;CAMIAC-ET-SAINT-DENIS;33420;33;GIRONDE;1
33087;;Camiran;CAMIRAN;33190;33;GIRONDE;1
33088;;Camps-sur-l'Isle;CAMPS-SUR-L'ISLE;33660;33;GIRONDE;1
33089;;Campugnan;CAMPUGNAN;33390;33;GIRONDE;1
33090;;Canéjan;CANEJAN;33610;33;GIRONDE;1
33091;;Cantenac;CANTENAC;33460;33;GIRONDE;1
33092;;Cantois;CANTOIS;33760;33;GIRONDE;1
33093;;Capian;CAPIAN;33550;33;GIRONDE;1
33094;;Caplong;CAPLONG;33220;33;GIRONDE;1
33095;;Captieux;CAPTIEUX;33840;33;GIRONDE;1
33096;;Carbon-Blanc;CARBON-BLANC;33560;33;GIRONDE;1
33097;;Carcans;CARCANS;33121;33;GIRONDE;1
33098;;Cardan;CARDAN;33410;33;GIRONDE;1
33099;;Carignan-de-Bordeaux;CARIGNAN-DE-BORDEAUX;33360;33;GIRONDE;1
33100;;Cars;CARS;33390;33;GIRONDE;1
33101;;Cartelègue;CARTELEGUE;33390;33;GIRONDE;1
33102;;Casseuil;CASSEUIL;33190;33;GIRONDE;1
33103;;Castelmoron-d'Albret;CASTELMORON-D'ALBRET;33540;33;GIRONDE;1
33104;;Castelnau-de-Médoc;CASTELNAU-DE-MEDOC;33480;33;GIRONDE;1
33105;;Castelviel;CASTELVIEL;33540;33;GIRONDE;1
33106;;Castets-en-Dorthe;CASTETS-EN-DORTHE;33210;33;GIRONDE;1
33107;;Castillon-de-Castets;CASTILLON-DE-CASTETS;33210;33;GIRONDE;1
33108;;Castillon-la-Bataille;CASTILLON-LA-BATAILLE;33350;33;GIRONDE;1
33109;;Castres-Gironde;CASTRES-GIRONDE;33640;33;GIRONDE;1
33111;;Caudrot;CAUDROT;33490;33;GIRONDE;1
33112;;Caumont;CAUMONT;33540;33;GIRONDE;1
33113;;Cauvignac;CAUVIGNAC;33690;33;GIRONDE;1
33114;;Cavignac;CAVIGNAC;33620;33;GIRONDE;1
33115;;Cazalis;CAZALIS;33113;33;GIRONDE;1
33116;;Cazats;CAZATS;33430;33;GIRONDE;1
33117;;Cazaugitat;CAZAUGITAT;33790;33;GIRONDE;1
33118;;Cénac;CENAC;33360;33;GIRONDE;1
33119;;Cenon;CENON;33150;33;GIRONDE;1
33120;;Cérons;CERONS;33720;33;GIRONDE;1
33121;;Cessac;CESSAC;33760;33;GIRONDE;1
33122;;Cestas;CESTAS;33610;33;GIRONDE;1
33123;;Cézac;CEZAC;33620;33;GIRONDE;1
33124;;Chamadelle;CHAMADELLE;33230;33;GIRONDE;1
33125;;Cissac-Médoc;CISSAC-MEDOC;33250;33;GIRONDE;1
33126;;Civrac-de-Blaye;CIVRAC-DE-BLAYE;33920;33;GIRONDE;1
33127;;Civrac-sur-Dordogne;CIVRAC-SUR-DORDOGNE;33350;33;GIRONDE;1
33128;;Civrac-en-Médoc;CIVRAC-EN-MEDOC;33340;33;GIRONDE;1
33129;;Cleyrac;CLEYRAC;33540;33;GIRONDE;1
33130;;Coimères;COIMERES;33210;33;GIRONDE;1
33131;;Coirac;COIRAC;33540;33;GIRONDE;1
33132;;Comps;COMPS;33710;33;GIRONDE;1
33133;;Coubeyrac;COUBEYRAC;33890;33;GIRONDE;1
33134;;Couquèques;COUQUEQUES;33340;33;GIRONDE;1
33135;;Courpiac;COURPIAC;33760;33;GIRONDE;1
33136;;Cours-de-Monségur;COURS-DE-MONSEGUR;33580;33;GIRONDE;1
33137;;Cours-les-Bains;COURS-LES-BAINS;33690;33;GIRONDE;1
33138;;Coutras;COUTRAS;33230;33;GIRONDE;1
33139;;Coutures;COUTURES;33580;33;GIRONDE;1
33140;;Créon;CREON;33670;33;GIRONDE;1
33141;;Croignon;CROIGNON;33750;33;GIRONDE;1
33142;;Cubnezais;CUBNEZAIS;33620;33;GIRONDE;1
33143;;Cubzac-les-Ponts;CUBZAC-LES-PONTS;33240;33;GIRONDE;1
33144;;Cudos;CUDOS;33430;33;GIRONDE;1
33145;;Cursan;CURSAN;33670;33;GIRONDE;1
33146;;Cussac-Fort-Médoc;CUSSAC-FORT-MEDOC;33460;33;GIRONDE;1
33147;;Daignac;DAIGNAC;33420;33;GIRONDE;1
33148;;Dardenac;DARDENAC;33420;33;GIRONDE;1
33149;;Daubèze;DAUBEZE;33540;33;GIRONDE;1
33150;;Dieulivol;DIEULIVOL;33580;33;GIRONDE;1
33151;;Donnezac;DONNEZAC;33860;33;GIRONDE;1
33152;;Donzac;DONZAC;33410;33;GIRONDE;1
33153;;Doulezon;DOULEZON;33350;33;GIRONDE;1
33154;Les;Églisottes-et-Chalaures;EGLISOTTES-ET-CHALAURES;33230;33;GIRONDE;1
33155;;Escaudes;ESCAUDES;33840;33;GIRONDE;1
33156;;Escoussans;ESCOUSSANS;33760;33;GIRONDE;1
33157;;Espiet;ESPIET;33420;33;GIRONDE;1
33158;Les;Esseintes;ESSEINTES;33190;33;GIRONDE;1
33159;;Étauliers;ETAULIERS;33820;33;GIRONDE;1
33160;;Eynesse;EYNESSE;33220;33;GIRONDE;1
33161;;Eyrans;EYRANS;33390;33;GIRONDE;1
33162;;Eysines;EYSINES;33320;33;GIRONDE;1
33163;;Faleyras;FALEYRAS;33760;33;GIRONDE;1
33164;;Fargues;FARGUES;33210;33;GIRONDE;1
33165;;Fargues-Saint-Hilaire;FARGUES-SAINT-HILAIRE;33370;33;GIRONDE;1
33166;Le;Fieu;FIEU;33230;33;GIRONDE;1
33167;;Floirac;FLOIRAC;33270;33;GIRONDE;1
33168;;Flaujagues;FLAUJAGUES;33350;33;GIRONDE;1
33169;;Floudès;FLOUDES;33190;33;GIRONDE;1
33170;;Fontet;FONTET;33190;33;GIRONDE;1
33171;;Fossès-et-Baleyssac;FOSSES-ET-BALEYSSAC;33190;33;GIRONDE;1
33172;;Fours;FOURS;33390;33;GIRONDE;1
33173;;Francs;FRANCS;33570;33;GIRONDE;1
33174;;Fronsac;FRONSAC;33126;33;GIRONDE;1
33175;;Frontenac;FRONTENAC;33760;33;GIRONDE;1
33176;;Gabarnac;GABARNAC;33410;33;GIRONDE;1
33177;;Gaillan-en-Médoc;GAILLAN-EN-MEDOC;33340;33;GIRONDE;1
33178;;Gajac;GAJAC;33430;33;GIRONDE;1
33179;;Galgon;GALGON;33133;33;GIRONDE;1
33180;;Gans;GANS;33430;33;GIRONDE;1
33181;;Gardegan-et-Tourtirac;GARDEGAN-ET-TOURTIRAC;33350;33;GIRONDE;1
33182;;Gauriac;GAURIAC;33710;33;GIRONDE;1
33183;;Gauriaguet;GAURIAGUET;33240;33;GIRONDE;1
33184;;Générac;GENERAC;33920;33;GIRONDE;1
33185;;Génissac;GENISSAC;33420;33;GIRONDE;1
33186;;Gensac;GENSAC;33890;33;GIRONDE;1
33187;;Gironde-sur-Dropt;GIRONDE-SUR-DROPT;33190;33;GIRONDE;1
33188;;Giscos;GISCOS;33840;33;GIRONDE;1
33189;;Gornac;GORNAC;33540;33;GIRONDE;1
33190;;Goualade;GOUALADE;33840;33;GIRONDE;1
33191;;Gours;GOURS;33660;33;GIRONDE;1
33192;;Gradignan;GRADIGNAN;33170;33;GIRONDE;1
33193;;Grayan-et-l'Hôpital;GRAYAN-ET-L'HOPITAL;33590;33;GIRONDE;1
33194;;Grézillac;GREZILLAC;33420;33;GIRONDE;1
33195;;Grignols;GRIGNOLS;33690;33;GIRONDE;1
33196;;Guillac;GUILLAC;33420;33;GIRONDE;1
33197;;Guillos;GUILLOS;33720;33;GIRONDE;1
33198;;Guîtres;GUITRES;33230;33;GIRONDE;1
33199;;Gujan-Mestras;GUJAN-MESTRAS;33470;33;GIRONDE;1
33200;Le;Haillan;HAILLAN;33185;33;GIRONDE;1
33201;;Haux;HAUX;33550;33;GIRONDE;1
33202;;Hostens;HOSTENS;33125;33;GIRONDE;1
33203;;Hourtin;HOURTIN;33990;33;GIRONDE;1
33204;;Hure;HURE;33190;33;GIRONDE;1
33205;;Illats;ILLATS;33720;33;GIRONDE;1
33206;;Isle-Saint-Georges;ISLE-SAINT-GEORGES;33640;33;GIRONDE;1
33207;;Izon;IZON;33450;33;GIRONDE;1
33208;;Jau-Dignac-et-Loirac;JAU-DIGNAC-ET-LOIRAC;33590;33;GIRONDE;1
33209;;Jugazan;JUGAZAN;33420;33;GIRONDE;1
33210;;Juillac;JUILLAC;33890;33;GIRONDE;1
33211;;Labarde;LABARDE;33460;33;GIRONDE;1
33212;;Labescau;LABESCAU;33690;33;GIRONDE;1
33213;La;Brède;BREDE;33650;33;GIRONDE;1
33214;;Lacanau;LACANAU;33680;33;GIRONDE;1
33215;;Ladaux;LADAUX;33760;33;GIRONDE;1
33216;;Lados;LADOS;33124;33;GIRONDE;1
33218;;Lagorce;LAGORCE;33230;33;GIRONDE;1
33219;La;Lande-de-Fronsac;LANDE-DE-FRONSAC;33240;33;GIRONDE;1
33220;;Lamarque;LAMARQUE;33460;33;GIRONDE;1
33221;;Lamothe-Landerron;LAMOTHE-LANDERRON;33190;33;GIRONDE;1
33222;;Lalande-de-Pomerol;LALANDE-DE-POMEROL;33500;33;GIRONDE;1
33223;;Landerrouat;LANDERROUAT;33790;33;GIRONDE;1
33224;;Landerrouet-sur-Ségur;LANDERROUET-SUR-SEGUR;33540;33;GIRONDE;1
33225;;Landiras;LANDIRAS;33720;33;GIRONDE;1
33226;;Langoiran;LANGOIRAN;33550;33;GIRONDE;1
33227;;Langon;LANGON;33210;33;GIRONDE;1
33228;;Lansac;LANSAC;33710;33;GIRONDE;1
33229;;Lanton;LANTON;33138;33;GIRONDE;1
33230;;Lapouyade;LAPOUYADE;33620;33;GIRONDE;1
33231;;Laroque;LAROQUE;33410;33;GIRONDE;1
33232;;Lartigue;LARTIGUE;33840;33;GIRONDE;1
33233;;Laruscade;LARUSCADE;33620;33;GIRONDE;1
33234;;Latresne;LATRESNE;33360;33;GIRONDE;1
33235;;Lavazan;LAVAZAN;33690;33;GIRONDE;1
33236;;Lège-Cap-Ferret;LEGE-CAP-FERRET;33950;33;GIRONDE;1
33237;;Léogeats;LEOGEATS;33210;33;GIRONDE;1
33238;;Léognan;LEOGNAN;33850;33;GIRONDE;1
33239;;Lerm-et-Musset;LERM-ET-MUSSET;33840;33;GIRONDE;1
33240;;Lesparre-Médoc;LESPARRE-MEDOC;33340;33;GIRONDE;1
33241;;Lestiac-sur-Garonne;LESTIAC-SUR-GARONNE;33550;33;GIRONDE;1
33242;Les;Lèves-et-Thoumeyragues;LEVES-ET-THOUMEYRAGUES;33220;33;GIRONDE;1
33243;;Libourne;LIBOURNE;33500;33;GIRONDE;1
33244;;Lignan-de-Bazas;LIGNAN-DE-BAZAS;33430;33;GIRONDE;1
33245;;Lignan-de-Bordeaux;LIGNAN-DE-BORDEAUX;33360;33;GIRONDE;1
33246;;Ligueux;LIGUEUX;33220;33;GIRONDE;1
33247;;Listrac-de-Durèze;LISTRAC-DE-DUREZE;33790;33;GIRONDE;1
33248;;Listrac-Médoc;LISTRAC-MEDOC;33480;33;GIRONDE;1
33249;;Lormont;LORMONT;33310;33;GIRONDE;1
33250;;Loubens;LOUBENS;33190;33;GIRONDE;1
33251;;Louchats;LOUCHATS;33125;33;GIRONDE;1
33252;;Loupes;LOUPES;33370;33;GIRONDE;1
33253;;Loupiac;LOUPIAC;33410;33;GIRONDE;1
33254;;Loupiac-de-la-Réole;LOUPIAC-DE-LA-REOLE;33190;33;GIRONDE;1
33255;;Lucmau;LUCMAU;33840;33;GIRONDE;1
33256;;Ludon-Médoc;LUDON-MEDOC;33290;33;GIRONDE;1
33257;;Lugaignac;LUGAIGNAC;33420;33;GIRONDE;1
33258;;Lugasson;LUGASSON;33760;33;GIRONDE;1
33259;;Lugon-et-l'Île-du-Carnay;LUGON-ET-L'ILE-DU-CARNAY;33240;33;GIRONDE;1
33260;;Lugos;LUGOS;33830;33;GIRONDE;1
33261;;Lussac;LUSSAC;33570;33;GIRONDE;1
33262;;Macau;MACAU;33460;33;GIRONDE;1
33263;;Madirac;MADIRAC;33670;33;GIRONDE;1
33264;;Maransin;MARANSIN;33230;33;GIRONDE;1
33266;;Marcenais;MARCENAIS;33620;33;GIRONDE;1
33267;;Marcillac;MARCILLAC;33860;33;GIRONDE;1
33268;;Margaux;MARGAUX;33460;33;GIRONDE;1
33269;;Margueron;MARGUERON;33220;33;GIRONDE;1
33270;;Marimbault;MARIMBAULT;33430;33;GIRONDE;1
33271;;Marions;MARIONS;33690;33;GIRONDE;1
33272;;Marsas;MARSAS;33620;33;GIRONDE;1
33273;;Martignas-sur-Jalle;MARTIGNAS-SUR-JALLE;33127;33;GIRONDE;1
33274;;Martillac;MARTILLAC;33650;33;GIRONDE;1
33275;;Martres;MARTRES;33760;33;GIRONDE;1
33276;;Masseilles;MASSEILLES;33690;33;GIRONDE;1
33277;;Massugas;MASSUGAS;33790;33;GIRONDE;1
33278;;Mauriac;MAURIAC;33540;33;GIRONDE;1
33279;;Mazères;MAZERES;33210;33;GIRONDE;1
33280;;Mazion;MAZION;33390;33;GIRONDE;1
33281;;Mérignac;MERIGNAC;33700;33;GIRONDE;1
33282;;Mérignas;MERIGNAS;33350;33;GIRONDE;1
33283;;Mesterrieux;MESTERRIEUX;33540;33;GIRONDE;1
33284;;Mios;MIOS;33380;33;GIRONDE;1
33285;;Mombrier;MOMBRIER;33710;33;GIRONDE;1
33287;;Mongauzy;MONGAUZY;33190;33;GIRONDE;1
33288;;Monprimblanc;MONPRIMBLANC;33410;33;GIRONDE;1
33289;;Monségur;MONSEGUR;33580;33;GIRONDE;1
33290;;Montagne;MONTAGNE;33570;33;GIRONDE;1
33291;;Montagoudin;MONTAGOUDIN;33190;33;GIRONDE;1
33292;;Montignac;MONTIGNAC;33760;33;GIRONDE;1
33293;;Montussan;MONTUSSAN;33450;33;GIRONDE;1
33294;;Morizès;MORIZES;33190;33;GIRONDE;1
33295;;Mouillac;MOUILLAC;33240;33;GIRONDE;1
33296;;Mouliets-et-Villemartin;MOULIETS-ET-VILLEMARTIN;33350;33;GIRONDE;1
33297;;Moulis-en-Médoc;MOULIS-EN-MEDOC;33480;33;GIRONDE;1
33298;;Moulon;MOULON;33420;33;GIRONDE;1
33299;;Mourens;MOURENS;33410;33;GIRONDE;1
33300;;Naujac-sur-Mer;NAUJAC-SUR-MER;33990;33;GIRONDE;1
33301;;Naujan-et-Postiac;NAUJAN-ET-POSTIAC;33420;33;GIRONDE;1
33302;;Néac;NEAC;33500;33;GIRONDE;1
33303;;Nérigean;NERIGEAN;33750;33;GIRONDE;1
33304;;Neuffons;NEUFFONS;33580;33;GIRONDE;1
33305;Le;Nizan;NIZAN;33430;33;GIRONDE;1
33306;;Noaillac;NOAILLAC;33190;33;GIRONDE;1
33307;;Noaillan;NOAILLAN;33730;33;GIRONDE;1
33308;;Omet;OMET;33410;33;GIRONDE;1
33309;;Ordonnac;ORDONNAC;33340;33;GIRONDE;1
33310;;Origne;ORIGNE;33113;33;GIRONDE;1
33311;;Paillet;PAILLET;33550;33;GIRONDE;1
33312;;Parempuyre;PAREMPUYRE;33290;33;GIRONDE;1
33314;;Pauillac;PAUILLAC;33250;33;GIRONDE;1
33315;Les;Peintures;PEINTURES;33230;33;GIRONDE;1
33316;;Pellegrue;PELLEGRUE;33790;33;GIRONDE;1
33317;;Périssac;PERISSAC;33240;33;GIRONDE;1
33318;;Pessac;PESSAC;33600;33;GIRONDE;1
33319;;Pessac-sur-Dordogne;PESSAC-SUR-DORDOGNE;33890;33;GIRONDE;1
33320;;Petit-Palais-et-Cornemps;PETIT-PALAIS-ET-CORNEMPS;33570;33;GIRONDE;1
33321;;Peujard;PEUJARD;33240;33;GIRONDE;1
33322;Le;Pian-Médoc;PIAN-MEDOC;33290;33;GIRONDE;1
33323;Le;Pian-sur-Garonne;PIAN-SUR-GARONNE;33490;33;GIRONDE;1
33324;;Pineuilh;PINEUILH;33220;33;GIRONDE;1
33325;;Plassac;PLASSAC;33390;33;GIRONDE;1
33326;;Pleine-Selve;PLEINE-SELVE;33820;33;GIRONDE;1
33327;;Podensac;PODENSAC;33720;33;GIRONDE;1
33328;;Pomerol;POMEROL;33500;33;GIRONDE;1
33329;;Pompéjac;POMPEJAC;33730;33;GIRONDE;1
33330;;Pompignac;POMPIGNAC;33370;33;GIRONDE;1
33331;;Pondaurat;PONDAURAT;33190;33;GIRONDE;1
33332;;Porchères;PORCHERES;33660;33;GIRONDE;1
33333;Le;Porge;PORGE;33680;33;GIRONDE;1
33334;;Portets;PORTETS;33640;33;GIRONDE;1
33335;Le;Pout;POUT;33670;33;GIRONDE;1
33336;;Préchac;PRECHAC;33730;33;GIRONDE;1
33337;;Preignac;PREIGNAC;33210;33;GIRONDE;1
33338;;Prignac-en-Médoc;PRIGNAC-EN-MEDOC;33340;33;GIRONDE;1
33339;;Prignac-et-Marcamps;PRIGNAC-ET-MARCAMPS;33710;33;GIRONDE;1
33341;;Pugnac;PUGNAC;33710;33;GIRONDE;1
33342;;Puisseguin;PUISSEGUIN;33570;33;GIRONDE;1
33343;;Pujols-sur-Ciron;PUJOLS-SUR-CIRON;33210;33;GIRONDE;1
33344;;Pujols;PUJOLS;33350;33;GIRONDE;1
33345;Le;Puy;PUY;33580;33;GIRONDE;1
33346;;Puybarban;PUYBARBAN;33190;33;GIRONDE;1
33347;;Puynormand;PUYNORMAND;33660;33;GIRONDE;1
33348;;Queyrac;QUEYRAC;33340;33;GIRONDE;1
33349;;Quinsac;QUINSAC;33360;33;GIRONDE;1
33350;;Rauzan;RAUZAN;33420;33;GIRONDE;1
33351;;Reignac;REIGNAC;33860;33;GIRONDE;1
33352;La;Réole;REOLE;33190;33;GIRONDE;1
33353;;Rimons;RIMONS;33580;33;GIRONDE;1
33354;;Riocaud;RIOCAUD;33220;33;GIRONDE;1
33355;;Rions;RIONS;33410;33;GIRONDE;1
33356;La;Rivière;RIVIERE;33126;33;GIRONDE;1
33357;;Roaillan;ROAILLAN;33210;33;GIRONDE;1
33358;;Romagne;ROMAGNE;33760;33;GIRONDE;1
33359;;Roquebrune;ROQUEBRUNE;33580;33;GIRONDE;1
33360;La;Roquille;ROQUILLE;33220;33;GIRONDE;1
33361;;Ruch;RUCH;33350;33;GIRONDE;1
33362;;Sablons;SABLONS;33910;33;GIRONDE;1
33363;;Sadirac;SADIRAC;33670;33;GIRONDE;1
33364;;Saillans;SAILLANS;33141;33;GIRONDE;1
33365;;Saint-Aignan;SAINT-AIGNAN;33126;33;GIRONDE;1
33366;;Saint-André-de-Cubzac;SAINT-ANDRE-DE-CUBZAC;33240;33;GIRONDE;1
33367;;Saint-André-du-Bois;SAINT-ANDRE-DU-BOIS;33490;33;GIRONDE;1
33369;;Saint-André-et-Appelles;SAINT-ANDRE-ET-APPELLES;33220;33;GIRONDE;1
33370;;Saint-Androny;SAINT-ANDRONY;33390;33;GIRONDE;1
33371;;Saint-Antoine;SAINT-ANTOINE;33240;33;GIRONDE;1
33372;;Saint-Antoine-du-Queyret;SAINT-ANTOINE-DU-QUEYRET;33790;33;GIRONDE;1
33373;;Saint-Antoine-sur-l'Isle;SAINT-ANTOINE-SUR-L'ISLE;33660;33;GIRONDE;1
33374;;Saint-Aubin-de-Blaye;SAINT-AUBIN-DE-BLAYE;33820;33;GIRONDE;1
33375;;Saint-Aubin-de-Branne;SAINT-AUBIN-DE-BRANNE;33420;33;GIRONDE;1
33376;;Saint-Aubin-de-Médoc;SAINT-AUBIN-DE-MEDOC;33160;33;GIRONDE;1
33377;;Saint-Avit-de-Soulège;SAINT-AVIT-DE-SOULEGE;33220;33;GIRONDE;1
33378;;Saint-Avit-Saint-Nazaire;SAINT-AVIT-SAINT-NAZAIRE;33220;33;GIRONDE;1
33379;;Saint-Brice;SAINT-BRICE;33540;33;GIRONDE;1
33380;;Saint-Caprais-de-Blaye;SAINT-CAPRAIS-DE-BLAYE;33820;33;GIRONDE;1
33381;;Saint-Caprais-de-Bordeaux;SAINT-CAPRAIS-DE-BORDEAUX;33880;33;GIRONDE;1
33382;;Saint-Christoly-de-Blaye;SAINT-CHRISTOLY-DE-BLAYE;33920;33;GIRONDE;1
33383;;Saint-Christoly-Médoc;SAINT-CHRISTOLY-MEDOC;33340;33;GIRONDE;1
33384;;Saint-Christophe-des-Bardes;SAINT-CHRISTOPHE-DES-BARDES;33330;33;GIRONDE;1
33385;;Saint-Christophe-de-Double;SAINT-CHRISTOPHE-DE-DOUBLE;33230;33;GIRONDE;1
33386;;Saint-Cibard;SAINT-CIBARD;33570;33;GIRONDE;1
33387;;Saint-Ciers-d'Abzac;SAINT-CIERS-D'ABZAC;33910;33;GIRONDE;1
33388;;Saint-Ciers-de-Canesse;SAINT-CIERS-DE-CANESSE;33710;33;GIRONDE;1
33389;;Saint-Ciers-sur-Gironde;SAINT-CIERS-SUR-GIRONDE;33820;33;GIRONDE;1
33390;;Sainte-Colombe;SAINTE-COLOMBE;33350;33;GIRONDE;1
33391;;Saint-Côme;SAINT-COME;33430;33;GIRONDE;1
33392;;Sainte-Croix-du-Mont;SAINTE-CROIX-DU-MONT;33410;33;GIRONDE;1
33393;;Saint-Denis-de-Pile;SAINT-DENIS-DE-PILE;33910;33;GIRONDE;1
33394;;Saint-Émilion;SAINT-EMILION;33330;33;GIRONDE;1
33395;;Saint-Estèphe;SAINT-ESTEPHE;33180;33;GIRONDE;1
33396;;Saint-Étienne-de-Lisse;SAINT-ETIENNE-DE-LISSE;33330;33;GIRONDE;1
33397;;Sainte-Eulalie;SAINTE-EULALIE;33560;33;GIRONDE;1
33398;;Saint-Exupéry;SAINT-EXUPERY;33190;33;GIRONDE;1
33399;;Saint-Félix-de-Foncaude;SAINT-FELIX-DE-FONCAUDE;33540;33;GIRONDE;1
33400;;Saint-Ferme;SAINT-FERME;33580;33;GIRONDE;1
33401;;Sainte-Florence;SAINTE-FLORENCE;33350;33;GIRONDE;1
33402;;Sainte-Foy-la-Grande;SAINTE-FOY-LA-GRANDE;33220;33;GIRONDE;1
33403;;Sainte-Foy-la-Longue;SAINTE-FOY-LA-LONGUE;33490;33;GIRONDE;1
33404;;Sainte-Gemme;SAINTE-GEMME;33580;33;GIRONDE;1
33405;;Saint-Genès-de-Blaye;SAINT-GENES-DE-BLAYE;33390;33;GIRONDE;1
33406;;Saint-Genès-de-Castillon;SAINT-GENES-DE-CASTILLON;33350;33;GIRONDE;1
33407;;Saint-Genès-de-Fronsac;SAINT-GENES-DE-FRONSAC;33240;33;GIRONDE;1
33408;;Saint-Genès-de-Lombaud;SAINT-GENES-DE-LOMBAUD;33670;33;GIRONDE;1
33409;;Saint-Genis-du-Bois;SAINT-GENIS-DU-BOIS;33760;33;GIRONDE;1
33411;;Saint-Germain-de-Grave;SAINT-GERMAIN-DE-GRAVE;33490;33;GIRONDE;1
33412;;Saint-Germain-d'Esteuil;SAINT-GERMAIN-D'ESTEUIL;33340;33;GIRONDE;1
33413;;Saint-Germain-du-Puch;SAINT-GERMAIN-DU-PUCH;33750;33;GIRONDE;1
33414;;Saint-Germain-de-la-Rivière;SAINT-GERMAIN-DE-LA-RIVIERE;33240;33;GIRONDE;1
33415;;Saint-Gervais;SAINT-GERVAIS;33240;33;GIRONDE;1
33416;;Saint-Girons-d'Aiguevives;SAINT-GIRONS-D'AIGUEVIVES;33920;33;GIRONDE;1
33417;;Sainte-Hélène;SAINTE-HELENE;33480;33;GIRONDE;1
33418;;Saint-Hilaire-de-la-Noaille;SAINT-HILAIRE-DE-LA-NOAILLE;33190;33;GIRONDE;1
33419;;Saint-Hilaire-du-Bois;SAINT-HILAIRE-DU-BOIS;33540;33;GIRONDE;1
33420;;Saint-Hippolyte;SAINT-HIPPOLYTE;33330;33;GIRONDE;1
33421;;Saint-Jean-de-Blaignac;SAINT-JEAN-DE-BLAIGNAC;33420;33;GIRONDE;1
33422;;Saint-Jean-d'Illac;SAINT-JEAN-D'ILLAC;33127;33;GIRONDE;1
33423;;Saint-Julien-Beychevelle;SAINT-JULIEN-BEYCHEVELLE;33250;33;GIRONDE;1
33424;;Saint-Laurent-Médoc;SAINT-LAURENT-MEDOC;33112;33;GIRONDE;1
33425;;Saint-Laurent-d'Arce;SAINT-LAURENT-D'ARCE;33240;33;GIRONDE;1
33426;;Saint-Laurent-des-Combes;SAINT-LAURENT-DES-COMBES;33330;33;GIRONDE;1
33427;;Saint-Laurent-du-Bois;SAINT-LAURENT-DU-BOIS;33540;33;GIRONDE;1
33428;;Saint-Laurent-du-Plan;SAINT-LAURENT-DU-PLAN;33190;33;GIRONDE;1
33429;;Saint-Léger-de-Balson;SAINT-LEGER-DE-BALSON;33113;33;GIRONDE;1
33431;;Saint-Léon;SAINT-LEON;33670;33;GIRONDE;1
33432;;Saint-Loubert;SAINT-LOUBERT;33210;33;GIRONDE;1
33433;;Saint-Loubès;SAINT-LOUBES;33450;33;GIRONDE;1
33434;;Saint-Louis-de-Montferrand;SAINT-LOUIS-DE-MONTFERRAND;33440;33;GIRONDE;1
33435;;Saint-Macaire;SAINT-MACAIRE;33490;33;GIRONDE;1
33436;;Saint-Magne;SAINT-MAGNE;33125;33;GIRONDE;1
33437;;Saint-Magne-de-Castillon;SAINT-MAGNE-DE-CASTILLON;33350;33;GIRONDE;1
33438;;Saint-Maixant;SAINT-MAIXANT;33490;33;GIRONDE;1
33439;;Saint-Mariens;SAINT-MARIENS;33620;33;GIRONDE;1
33440;;Saint-Martial;SAINT-MARTIAL;33490;33;GIRONDE;1
33441;;Saint-Martin-Lacaussade;SAINT-MARTIN-LACAUSSADE;33390;33;GIRONDE;1
33442;;Saint-Martin-de-Laye;SAINT-MARTIN-DE-LAYE;33910;33;GIRONDE;1
33443;;Saint-Martin-de-Lerm;SAINT-MARTIN-DE-LERM;33540;33;GIRONDE;1
33444;;Saint-Martin-de-Sescas;SAINT-MARTIN-DE-SESCAS;33490;33;GIRONDE;1
33445;;Saint-Martin-du-Bois;SAINT-MARTIN-DU-BOIS;33910;33;GIRONDE;1
33446;;Saint-Martin-du-Puy;SAINT-MARTIN-DU-PUY;33540;33;GIRONDE;1
33447;;Saint-Médard-de-Guizières;SAINT-MEDARD-DE-GUIZIERES;33230;33;GIRONDE;1
33448;;Saint-Médard-d'Eyrans;SAINT-MEDARD-D'EYRANS;33650;33;GIRONDE;1
33449;;Saint-Médard-en-Jalles;SAINT-MEDARD-EN-JALLES;33160;33;GIRONDE;1
33450;;Saint-Michel-de-Castelnau;SAINT-MICHEL-DE-CASTELNAU;33840;33;GIRONDE;1
33451;;Saint-Michel-de-Fronsac;SAINT-MICHEL-DE-FRONSAC;33126;33;GIRONDE;1
33452;;Saint-Michel-de-Rieufret;SAINT-MICHEL-DE-RIEUFRET;33720;33;GIRONDE;1
33453;;Saint-Michel-de-Lapujade;SAINT-MICHEL-DE-LAPUJADE;33190;33;GIRONDE;1
33454;;Saint-Morillon;SAINT-MORILLON;33650;33;GIRONDE;1
33456;;Saint-Palais;SAINT-PALAIS;33820;33;GIRONDE;1
33457;;Saint-Pardon-de-Conques;SAINT-PARDON-DE-CONQUES;33210;33;GIRONDE;1
33458;;Saint-Paul;SAINT-PAUL;33390;33;GIRONDE;1
33459;;Saint-Pey-d'Armens;SAINT-PEY-D'ARMENS;33330;33;GIRONDE;1
33460;;Saint-Pey-de-Castets;SAINT-PEY-DE-CASTETS;33350;33;GIRONDE;1
33461;;Saint-Philippe-d'Aiguille;SAINT-PHILIPPE-D'AIGUILLE;33350;33;GIRONDE;1
33462;;Saint-Philippe-du-Seignal;SAINT-PHILIPPE-DU-SEIGNAL;33220;33;GIRONDE;1
33463;;Saint-Pierre-d'Aurillac;SAINT-PIERRE-D'AURILLAC;33490;33;GIRONDE;1
33464;;Saint-Pierre-de-Bat;SAINT-PIERRE-DE-BAT;33760;33;GIRONDE;1
33465;;Saint-Pierre-de-Mons;SAINT-PIERRE-DE-MONS;33210;33;GIRONDE;1
33466;;Saint-Quentin-de-Baron;SAINT-QUENTIN-DE-BARON;33750;33;GIRONDE;1
33467;;Saint-Quentin-de-Caplong;SAINT-QUENTIN-DE-CAPLONG;33220;33;GIRONDE;1
33468;;Sainte-Radegonde;SAINTE-RADEGONDE;33350;33;GIRONDE;1
33470;;Saint-Romain-la-Virvée;SAINT-ROMAIN-LA-VIRVEE;33240;33;GIRONDE;1
33471;;Saint-Sauveur;SAINT-SAUVEUR;33250;33;GIRONDE;1
33472;;Saint-Sauveur-de-Puynormand;SAINT-SAUVEUR-DE-PUYNORMAND;33660;33;GIRONDE;1
33473;;Saint-Savin;SAINT-SAVIN;33920;33;GIRONDE;1
33474;;Saint-Selve;SAINT-SELVE;33650;33;GIRONDE;1
33475;;Saint-Seurin-de-Bourg;SAINT-SEURIN-DE-BOURG;33710;33;GIRONDE;1
33476;;Saint-Seurin-de-Cadourne;SAINT-SEURIN-DE-CADOURNE;33180;33;GIRONDE;1
33477;;Saint-Seurin-de-Cursac;SAINT-SEURIN-DE-CURSAC;33390;33;GIRONDE;1
33478;;Saint-Seurin-sur-l'Isle;SAINT-SEURIN-SUR-L'ISLE;33660;33;GIRONDE;1
33479;;Saint-Sève;SAINT-SEVE;33190;33;GIRONDE;1
33480;;Saint-Sulpice-de-Faleyrens;SAINT-SULPICE-DE-FALEYRENS;33330;33;GIRONDE;1
33481;;Saint-Sulpice-de-Guilleragues;SAINT-SULPICE-DE-GUILLERAGUES;33580;33;GIRONDE;1
33482;;Saint-Sulpice-de-Pommiers;SAINT-SULPICE-DE-POMMIERS;33540;33;GIRONDE;1
33483;;Saint-Sulpice-et-Cameyrac;SAINT-SULPICE-ET-CAMEYRAC;33450;33;GIRONDE;1
33484;;Saint-Symphorien;SAINT-SYMPHORIEN;33113;33;GIRONDE;1
33485;;Sainte-Terre;SAINTE-TERRE;33350;33;GIRONDE;1
33486;;Saint-Trojan;SAINT-TROJAN;33710;33;GIRONDE;1
33487;;Saint-Vincent-de-Paul;SAINT-VINCENT-DE-PAUL;33440;33;GIRONDE;1
33488;;Saint-Vincent-de-Pertignas;SAINT-VINCENT-DE-PERTIGNAS;33420;33;GIRONDE;1
33489;;Saint-Vivien-de-Blaye;SAINT-VIVIEN-DE-BLAYE;33920;33;GIRONDE;1
33490;;Saint-Vivien-de-Médoc;SAINT-VIVIEN-DE-MEDOC;33590;33;GIRONDE;1
33491;;Saint-Vivien-de-Monségur;SAINT-VIVIEN-DE-MONSEGUR;33580;33;GIRONDE;1
33492;;Saint-Yzan-de-Soudiac;SAINT-YZAN-DE-SOUDIAC;33920;33;GIRONDE;1
33493;;Saint-Yzans-de-Médoc;SAINT-YZANS-DE-MEDOC;33340;33;GIRONDE;1
33494;;Salaunes;SALAUNES;33160;33;GIRONDE;1
33495;;Salignac;SALIGNAC;33240;33;GIRONDE;1
33496;;Sallebœuf;SALLEBOEUF;33370;33;GIRONDE;1
33498;;Salles;SALLES;33770;33;GIRONDE;1
33499;Les;Salles-de-Castillon;SALLES-DE-CASTILLON;33350;33;GIRONDE;1
33500;;Samonac;SAMONAC;33710;33;GIRONDE;1
33501;;Saucats;SAUCATS;33650;33;GIRONDE;1
33502;;Saugon;SAUGON;33920;33;GIRONDE;1
33503;;Saumos;SAUMOS;33680;33;GIRONDE;1
33504;;Sauternes;SAUTERNES;33210;33;GIRONDE;1
33505;La;Sauve;SAUVE;33670;33;GIRONDE;1
33506;;Sauveterre-de-Guyenne;SAUVETERRE-DE-GUYENNE;33540;33;GIRONDE;1
33507;;Sauviac;SAUVIAC;33430;33;GIRONDE;1
33508;;Savignac;SAVIGNAC;33124;33;GIRONDE;1
33509;;Savignac-de-l'Isle;SAVIGNAC-DE-L'ISLE;33910;33;GIRONDE;1
33510;;Semens;SEMENS;33490;33;GIRONDE;1
33511;;Sendets;SENDETS;33690;33;GIRONDE;1
33512;;Sigalens;SIGALENS;33690;33;GIRONDE;1
33513;;Sillas;SILLAS;33690;33;GIRONDE;1
33514;;Soulac-sur-Mer;SOULAC-SUR-MER;33780;33;GIRONDE;1
33515;;Soulignac;SOULIGNAC;33760;33;GIRONDE;1
33516;;Soussac;SOUSSAC;33790;33;GIRONDE;1
33517;;Soussans;SOUSSANS;33460;33;GIRONDE;1
33518;;Tabanac;TABANAC;33550;33;GIRONDE;1
33519;Le;Taillan-Médoc;TAILLAN-MEDOC;33320;33;GIRONDE;1
33520;;Taillecavat;TAILLECAVAT;33580;33;GIRONDE;1
33521;;Talais;TALAIS;33590;33;GIRONDE;1
33522;;Talence;TALENCE;33400;33;GIRONDE;1
33523;;Targon;TARGON;33760;33;GIRONDE;1
33524;;Tarnès;TARNES;33240;33;GIRONDE;1
33525;;Tauriac;TAURIAC;33710;33;GIRONDE;1
33526;;Tayac;TAYAC;33570;33;GIRONDE;1
33527;Le;Teich;TEICH;33470;33;GIRONDE;1
33528;Le;Temple;TEMPLE;33680;33;GIRONDE;1
33529;La;Teste-de-Buch;TESTE-DE-BUCH;33260;33;GIRONDE;1
33530;;Teuillac;TEUILLAC;33710;33;GIRONDE;1
33531;;Tizac-de-Curton;TIZAC-DE-CURTON;33420;33;GIRONDE;1
33532;;Tizac-de-Lapouyade;TIZAC-DE-LAPOUYADE;33620;33;GIRONDE;1
33533;;Toulenne;TOULENNE;33210;33;GIRONDE;1
33534;Le;Tourne;TOURNE;33550;33;GIRONDE;1
33535;;Tresses;TRESSES;33370;33;GIRONDE;1
33536;Le;Tuzan;TUZAN;33125;33;GIRONDE;1
33537;;Uzeste;UZESTE;33730;33;GIRONDE;1
33538;;Valeyrac;VALEYRAC;33340;33;GIRONDE;1
33539;;Vayres;VAYRES;33870;33;GIRONDE;1
33540;;Vendays-Montalivet;VENDAYS-MONTALIVET;33930;33;GIRONDE;1
33541;;Vensac;VENSAC;33590;33;GIRONDE;1
33542;;Vérac;VERAC;33240;33;GIRONDE;1
33543;;Verdelais;VERDELAIS;33490;33;GIRONDE;1
33544;Le;Verdon-sur-Mer;VERDON-SUR-MER;33123;33;GIRONDE;1
33545;;Vertheuil;VERTHEUIL;33180;33;GIRONDE;1
33546;;Vignonet;VIGNONET;33330;33;GIRONDE;1
33547;;Villandraut;VILLANDRAUT;33730;33;GIRONDE;1
33548;;Villegouge;VILLEGOUGE;33141;33;GIRONDE;1
33549;;Villenave-de-Rions;VILLENAVE-DE-RIONS;33550;33;GIRONDE;1
33550;;Villenave-d'Ornon;VILLENAVE-D'ORNON;33140;33;GIRONDE;1
33551;;Villeneuve;VILLENEUVE;33710;33;GIRONDE;1
33552;;Virelade;VIRELADE;33720;33;GIRONDE;1
33553;;Virsac;VIRSAC;33240;33;GIRONDE;1
33554;;Yvrac;YVRAC;33370;33;GIRONDE;1
33555;;Marcheprime;MARCHEPRIME;33380;33;GIRONDE;1
34001;;Abeilhan;ABEILHAN;34290;34;HERAULT;1
34002;;Adissan;ADISSAN;34230;34;HERAULT;1
34003;;Agde;AGDE;34300;34;HERAULT;1
34004;;Agel;AGEL;34210;34;HERAULT;1
34005;;Agonès;AGONES;34190;34;HERAULT;1
34006;;Aigne;AIGNE;34210;34;HERAULT;1
34007;;Aigues-Vives;AIGUES-VIVES;34210;34;HERAULT;1
34008;Les;Aires;AIRES;34600;34;HERAULT;1
34009;;Alignan-du-Vent;ALIGNAN-DU-VENT;34290;34;HERAULT;1
34010;;Aniane;ANIANE;34150;34;HERAULT;1
34011;;Arboras;ARBORAS;34150;34;HERAULT;1
34012;;Argelliers;ARGELLIERS;34380;34;HERAULT;1
34013;;Aspiran;ASPIRAN;34800;34;HERAULT;1
34014;;Assas;ASSAS;34820;34;HERAULT;1
34015;;Assignan;ASSIGNAN;34360;34;HERAULT;1
34016;;Aumelas;AUMELAS;34230;34;HERAULT;1
34017;;Aumes;AUMES;34530;34;HERAULT;1
34018;;Autignac;AUTIGNAC;34480;34;HERAULT;1
34019;;Avène;AVENE;34260;34;HERAULT;1
34020;;Azillanet;AZILLANET;34210;34;HERAULT;1
34021;;Babeau-Bouldoux;BABEAU-BOULDOUX;34360;34;HERAULT;1
34022;;Baillargues;BAILLARGUES;34670;34;HERAULT;1
34023;;Balaruc-les-Bains;BALARUC-LES-BAINS;34540;34;HERAULT;1
34024;;Balaruc-le-Vieux;BALARUC-LE-VIEUX;34540;34;HERAULT;1
34025;;Bassan;BASSAN;34290;34;HERAULT;1
34026;;Beaufort;BEAUFORT;34210;34;HERAULT;1
34027;;Beaulieu;BEAULIEU;34160;34;HERAULT;1
34028;;Bédarieux;BEDARIEUX;34600;34;HERAULT;1
34029;;Bélarga;BELARGA;34230;34;HERAULT;1
34030;;Berlou;BERLOU;34360;34;HERAULT;1
34031;;Bessan;BESSAN;34550;34;HERAULT;1
34032;;Béziers;BEZIERS;34500;34;HERAULT;1
34033;;Boisseron;BOISSERON;34160;34;HERAULT;1
34034;;Boisset;BOISSET;34220;34;HERAULT;1
34035;La;Boissière;BOISSIERE;34150;34;HERAULT;1
34036;Le;Bosc;BOSC;34700;34;HERAULT;1
34037;;Boujan-sur-Libron;BOUJAN-SUR-LIBRON;34760;34;HERAULT;1
34038;Le;Bousquet-d'Orb;BOUSQUET-D'ORB;34260;34;HERAULT;1
34039;;Bouzigues;BOUZIGUES;34140;34;HERAULT;1
34040;;Brenas;BRENAS;34650;34;HERAULT;1
34041;;Brignac;BRIGNAC;34800;34;HERAULT;1
34042;;Brissac;BRISSAC;34190;34;HERAULT;1
34043;;Buzignargues;BUZIGNARGUES;34160;34;HERAULT;1
34044;;Cabrerolles;CABREROLLES;34480;34;HERAULT;1
34045;;Cabrières;CABRIERES;34800;34;HERAULT;1
34046;;Cambon-et-Salvergues;CAMBON-ET-SALVERGUES;34330;34;HERAULT;1
34047;;Campagnan;CAMPAGNAN;34230;34;HERAULT;1
34048;;Campagne;CAMPAGNE;34160;34;HERAULT;1
34049;;Camplong;CAMPLONG;34260;34;HERAULT;1
34050;;Candillargues;CANDILLARGUES;34130;34;HERAULT;1
34051;;Canet;CANET;34800;34;HERAULT;1
34052;;Capestang;CAPESTANG;34310;34;HERAULT;1
34053;;Carlencas-et-Levas;CARLENCAS-ET-LEVAS;34600;34;HERAULT;1
34054;;Cassagnoles;CASSAGNOLES;34210;34;HERAULT;1
34055;;Castanet-le-Haut;CASTANET-LE-HAUT;34610;34;HERAULT;1
34056;;Castelnau-de-Guers;CASTELNAU-DE-GUERS;34120;34;HERAULT;1
34057;;Castelnau-le-Lez;CASTELNAU-LE-LEZ;34170;34;HERAULT;1
34058;;Castries;CASTRIES;34160;34;HERAULT;1
34059;La;Caunette;CAUNETTE;34210;34;HERAULT;1
34060;;Causse-de-la-Selle;CAUSSE-DE-LA-SELLE;34380;34;HERAULT;1
34061;;Causses-et-Veyran;CAUSSES-ET-VEYRAN;34490;34;HERAULT;1
34062;;Caussiniojouls;CAUSSINIOJOULS;34600;34;HERAULT;1
34063;;Caux;CAUX;34720;34;HERAULT;1
34064;Le;Caylar;CAYLAR;34520;34;HERAULT;1
34065;;Cazedarnes;CAZEDARNES;34460;34;HERAULT;1
34066;;Cazevieille;CAZEVIEILLE;34270;34;HERAULT;1
34067;;Cazilhac;CAZILHAC;34190;34;HERAULT;1
34068;;Cazouls-d'Hérault;CAZOULS-D'HERAULT;34120;34;HERAULT;1
34069;;Cazouls-lès-Béziers;CAZOULS-LES-BEZIERS;34370;34;HERAULT;1
34070;;Cébazan;CEBAZAN;34360;34;HERAULT;1
34071;;Ceilhes-et-Rocozels;CEILHES-ET-ROCOZELS;34260;34;HERAULT;1
34072;;Celles;CELLES;34800;34;HERAULT;1
34073;;Cers;CERS;34420;34;HERAULT;1
34074;;Cessenon-sur-Orb;CESSENON-SUR-ORB;34460;34;HERAULT;1
34075;;Cesseras;CESSERAS;34210;34;HERAULT;1
34076;;Ceyras;CEYRAS;34800;34;HERAULT;1
34077;;Clapiers;CLAPIERS;34830;34;HERAULT;1
34078;;Claret;CLARET;34270;34;HERAULT;1
34079;;Clermont-l'Hérault;CLERMONT-L'HERAULT;34800;34;HERAULT;1
34080;;Colombières-sur-Orb;COLOMBIERES-SUR-ORB;34390;34;HERAULT;1
34081;;Colombiers;COLOMBIERS;34440;34;HERAULT;1
34082;;Combaillaux;COMBAILLAUX;34980;34;HERAULT;1
34083;;Combes;COMBES;34240;34;HERAULT;1
34084;;Corneilhan;CORNEILHAN;34490;34;HERAULT;1
34085;;Coulobres;COULOBRES;34290;34;HERAULT;1
34086;;Courniou;COURNIOU;34220;34;HERAULT;1
34087;;Cournonsec;COURNONSEC;34660;34;HERAULT;1
34088;;Cournonterral;COURNONTERRAL;34660;34;HERAULT;1
34089;;Creissan;CREISSAN;34370;34;HERAULT;1
34090;Le;Crès;CRES;34920;34;HERAULT;1
34091;Le;Cros;CROS;34520;34;HERAULT;1
34092;;Cruzy;CRUZY;34310;34;HERAULT;1
34093;;Dio-et-Valquières;DIO-ET-VALQUIERES;34650;34;HERAULT;1
34094;;Espondeilhan;ESPONDEILHAN;34290;34;HERAULT;1
34095;;Fabrègues;FABREGUES;34690;34;HERAULT;1
34096;;Faugères;FAUGERES;34600;34;HERAULT;1
34097;;Félines-Minervois;FELINES-MINERVOIS;34210;34;HERAULT;1
34098;;Ferrals-les-Montagnes;FERRALS-LES-MONTAGNES;34210;34;HERAULT;1
34099;;Ferrières-les-Verreries;FERRIERES-LES-VERRERIES;34190;34;HERAULT;1
34100;;Ferrières-Poussarou;FERRIERES-POUSSAROU;34360;34;HERAULT;1
34101;;Florensac;FLORENSAC;34510;34;HERAULT;1
34102;;Fontanès;FONTANES;34270;34;HERAULT;1
34103;;Fontès;FONTES;34320;34;HERAULT;1
34104;;Fos;FOS;34320;34;HERAULT;1
34105;;Fouzilhon;FOUZILHON;34480;34;HERAULT;1
34106;;Fozières;FOZIERES;34700;34;HERAULT;1
34107;;Fraisse-sur-Agout;FRAISSE-SUR-AGOUT;34330;34;HERAULT;1
34108;;Frontignan;FRONTIGNAN;34110;34;HERAULT;1
34109;;Gabian;GABIAN;34320;34;HERAULT;1
34110;;Galargues;GALARGUES;34160;34;HERAULT;1
34111;;Ganges;GANGES;34190;34;HERAULT;1
34112;;Garrigues;GARRIGUES;34160;34;HERAULT;1
34113;;Gigean;GIGEAN;34770;34;HERAULT;1
34114;;Gignac;GIGNAC;34150;34;HERAULT;1
34115;;Gorniès;GORNIES;34190;34;HERAULT;1
34116;;Grabels;GRABELS;34790;34;HERAULT;1
34117;;Graissessac;GRAISSESSAC;34260;34;HERAULT;1
34118;;Guzargues;GUZARGUES;34820;34;HERAULT;1
34119;;Hérépian;HEREPIAN;34600;34;HERAULT;1
34120;;Jacou;JACOU;34830;34;HERAULT;1
34121;;Joncels;JONCELS;34650;34;HERAULT;1
34122;;Jonquières;JONQUIERES;34725;34;HERAULT;1
34123;;Juvignac;JUVIGNAC;34990;34;HERAULT;1
34124;;Lacoste;LACOSTE;34800;34;HERAULT;1
34125;;Lagamas;LAGAMAS;34150;34;HERAULT;1
34126;;Lamalou-les-Bains;LAMALOU-LES-BAINS;34240;34;HERAULT;1
34127;;Lansargues;LANSARGUES;34130;34;HERAULT;1
34128;;Laroque;LAROQUE;34190;34;HERAULT;1
34129;;Lattes;LATTES;34970;34;HERAULT;1
34130;;Laurens;LAURENS;34480;34;HERAULT;1
34131;;Lauret;LAURET;34270;34;HERAULT;1
34132;;Lauroux;LAUROUX;34700;34;HERAULT;1
34133;;Lavalette;LAVALETTE;34700;34;HERAULT;1
34134;;Lavérune;LAVERUNE;34880;34;HERAULT;1
34135;;Lespignan;LESPIGNAN;34710;34;HERAULT;1
34136;;Lézignan-la-Cèbe;LEZIGNAN-LA-CEBE;34120;34;HERAULT;1
34137;;Liausson;LIAUSSON;34800;34;HERAULT;1
34138;;Lieuran-Cabrières;LIEURAN-CABRIERES;34800;34;HERAULT;1
34139;;Lieuran-lès-Béziers;LIEURAN-LES-BEZIERS;34290;34;HERAULT;1
34140;;Lignan-sur-Orb;LIGNAN-SUR-ORB;34490;34;HERAULT;1
34141;La;Livinière;LIVINIERE;34210;34;HERAULT;1
34142;;Lodève;LODEVE;34700;34;HERAULT;1
34143;;Loupian;LOUPIAN;34140;34;HERAULT;1
34144;;Lunas;LUNAS;34650;34;HERAULT;1
34145;;Lunel;LUNEL;34400;34;HERAULT;1
34146;;Lunel-Viel;LUNEL-VIEL;34400;34;HERAULT;1
34147;;Magalas;MAGALAS;34480;34;HERAULT;1
34148;;Maraussan;MARAUSSAN;34370;34;HERAULT;1
34149;;Margon;MARGON;34320;34;HERAULT;1
34150;;Marseillan;MARSEILLAN;34340;34;HERAULT;1
34151;;Marsillargues;MARSILLARGUES;34590;34;HERAULT;1
34152;;Mas-de-Londres;MAS-DE-LONDRES;34380;34;HERAULT;1
34153;Les;Matelles;MATELLES;34270;34;HERAULT;1
34154;;Mauguio;MAUGUIO;34130;34;HERAULT;1
34155;;Maureilhan;MAUREILHAN;34370;34;HERAULT;1
34156;;Mérifons;MERIFONS;34800;34;HERAULT;1
34157;;Mèze;MEZE;34140;34;HERAULT;1
34158;;Minerve;MINERVE;34210;34;HERAULT;1
34159;;Mireval;MIREVAL;34110;34;HERAULT;1
34160;;Mons;MONS;34390;34;HERAULT;1
34161;;Montady;MONTADY;34310;34;HERAULT;1
34162;;Montagnac;MONTAGNAC;34530;34;HERAULT;1
34163;;Montarnaud;MONTARNAUD;34570;34;HERAULT;1
34164;;Montaud;MONTAUD;34160;34;HERAULT;1
34165;;Montbazin;MONTBAZIN;34560;34;HERAULT;1
34166;;Montblanc;MONTBLANC;34290;34;HERAULT;1
34167;;Montels;MONTELS;34310;34;HERAULT;1
34168;;Montesquieu;MONTESQUIEU;34320;34;HERAULT;1
34169;;Montferrier-sur-Lez;MONTFERRIER-SUR-LEZ;34980;34;HERAULT;1
34170;;Montouliers;MONTOULIERS;34310;34;HERAULT;1
34171;;Montoulieu;MONTOULIEU;34190;34;HERAULT;1
34172;;Montpellier;MONTPELLIER;34000;34;HERAULT;1
34173;;Montpeyroux;MONTPEYROUX;34150;34;HERAULT;1
34174;;Moulès-et-Baucels;MOULES-ET-BAUCELS;34190;34;HERAULT;1
34175;;Mourèze;MOUREZE;34800;34;HERAULT;1
34176;;Mudaison;MUDAISON;34130;34;HERAULT;1
34177;;Murles;MURLES;34980;34;HERAULT;1
34178;;Murviel-lès-Béziers;MURVIEL-LES-BEZIERS;34490;34;HERAULT;1
34179;;Murviel-lès-Montpellier;MURVIEL-LES-MONTPELLIER;34570;34;HERAULT;1
34180;;Nébian;NEBIAN;34800;34;HERAULT;1
34181;;Neffiès;NEFFIES;34320;34;HERAULT;1
34182;;Nézignan-l'Évêque;NEZIGNAN-L'EVEQUE;34120;34;HERAULT;1
34183;;Nissan-lez-Enserune;NISSAN-LEZ-ENSERUNE;34440;34;HERAULT;1
34184;;Nizas;NIZAS;34320;34;HERAULT;1
34185;;Notre-Dame-de-Londres;NOTRE-DAME-DE-LONDRES;34380;34;HERAULT;1
34186;;Octon;OCTON;34800;34;HERAULT;1
34187;;Olargues;OLARGUES;34390;34;HERAULT;1
34188;;Olmet-et-Villecun;OLMET-ET-VILLECUN;34700;34;HERAULT;1
34189;;Olonzac;OLONZAC;34210;34;HERAULT;1
34190;;Oupia;OUPIA;34210;34;HERAULT;1
34191;;Pailhès;PAILHES;34490;34;HERAULT;1
34192;;Palavas-les-Flots;PALAVAS-LES-FLOTS;34250;34;HERAULT;1
34193;;Pardailhan;PARDAILHAN;34360;34;HERAULT;1
34194;;Paulhan;PAULHAN;34230;34;HERAULT;1
34195;;Pégairolles-de-Buèges;PEGAIROLLES-DE-BUEGES;34380;34;HERAULT;1
34196;;Pégairolles-de-l'Escalette;PEGAIROLLES-DE-L'ESCALETTE;34700;34;HERAULT;1
34197;;Péret;PERET;34800;34;HERAULT;1
34198;;Pérols;PEROLS;34470;34;HERAULT;1
34199;;Pézenas;PEZENAS;34120;34;HERAULT;1
34200;;Pézènes-les-Mines;PEZENES-LES-MINES;34600;34;HERAULT;1
34201;;Pierrerue;PIERRERUE;34360;34;HERAULT;1
34202;;Pignan;PIGNAN;34570;34;HERAULT;1
34203;;Pinet;PINET;34850;34;HERAULT;1
34204;;Plaissan;PLAISSAN;34230;34;HERAULT;1
34205;Les;Plans;PLANS;34700;34;HERAULT;1
34206;;Poilhes;POILHES;34310;34;HERAULT;1
34207;;Pomérols;POMEROLS;34810;34;HERAULT;1
34208;;Popian;POPIAN;34230;34;HERAULT;1
34209;;Portiragnes;PORTIRAGNES;34420;34;HERAULT;1
34210;Le;Pouget;POUGET;34230;34;HERAULT;1
34211;Le;Poujol-sur-Orb;POUJOL-SUR-ORB;34600;34;HERAULT;1
34212;;Poujols;POUJOLS;34700;34;HERAULT;1
34213;;Poussan;POUSSAN;34560;34;HERAULT;1
34214;;Pouzolles;POUZOLLES;34480;34;HERAULT;1
34215;;Pouzols;POUZOLS;34230;34;HERAULT;1
34216;Le;Pradal;PRADAL;34600;34;HERAULT;1
34217;;Prades-le-Lez;PRADES-LE-LEZ;34730;34;HERAULT;1
34218;;Prades-sur-Vernazobre;PRADES-SUR-VERNAZOBRE;34360;34;HERAULT;1
34219;;Prémian;PREMIAN;34390;34;HERAULT;1
34220;Le;Puech;PUECH;34700;34;HERAULT;1
34221;;Puéchabon;PUECHABON;34150;34;HERAULT;1
34222;;Puilacher;PUILACHER;34230;34;HERAULT;1
34223;;Puimisson;PUIMISSON;34480;34;HERAULT;1
34224;;Puissalicon;PUISSALICON;34480;34;HERAULT;1
34225;;Puisserguier;PUISSERGUIER;34620;34;HERAULT;1
34226;;Quarante;QUARANTE;34310;34;HERAULT;1
34227;;Restinclières;RESTINCLIERES;34160;34;HERAULT;1
34228;;Rieussec;RIEUSSEC;34220;34;HERAULT;1
34229;;Riols;RIOLS;34220;34;HERAULT;1
34230;Les;Rives;RIVES;34520;34;HERAULT;1
34231;;Romiguières;ROMIGUIERES;34650;34;HERAULT;1
34232;;Roquebrun;ROQUEBRUN;34460;34;HERAULT;1
34233;;Roqueredonde;ROQUEREDONDE;34650;34;HERAULT;1
34234;;Roquessels;ROQUESSELS;34320;34;HERAULT;1
34235;;Rosis;ROSIS;34610;34;HERAULT;1
34236;;Rouet;ROUET;34380;34;HERAULT;1
34237;;Roujan;ROUJAN;34320;34;HERAULT;1
34238;;Saint-André-de-Buèges;SAINT-ANDRE-DE-BUEGES;34190;34;HERAULT;1
34239;;Saint-André-de-Sangonis;SAINT-ANDRE-DE-SANGONIS;34725;34;HERAULT;1
34240;;Saint-Aunès;SAINT-AUNES;34130;34;HERAULT;1
34241;;Saint-Bauzille-de-la-Sylve;SAINT-BAUZILLE-DE-LA-SYLVE;34230;34;HERAULT;1
34242;;Saint-Bauzille-de-Montmel;SAINT-BAUZILLE-DE-MONTMEL;34160;34;HERAULT;1
34243;;Saint-Bauzille-de-Putois;SAINT-BAUZILLE-DE-PUTOIS;34190;34;HERAULT;1
34244;;Saint-Brès;SAINT-BRES;34670;34;HERAULT;1
34245;;Saint-Chinian;SAINT-CHINIAN;34360;34;HERAULT;1
34246;;Saint-Christol;SAINT-CHRISTOL;34400;34;HERAULT;1
34247;;Saint-Clément-de-Rivière;SAINT-CLEMENT-DE-RIVIERE;34980;34;HERAULT;1
34248;;Sainte-Croix-de-Quintillargues;SAINTE-CROIX-DE-QUINTILLARGUES;34270;34;HERAULT;1
34249;;Saint-Drézéry;SAINT-DREZERY;34160;34;HERAULT;1
34250;;Saint-Étienne-d'Albagnan;SAINT-ETIENNE-D'ALBAGNAN;34390;34;HERAULT;1
34251;;Saint-Étienne-de-Gourgas;SAINT-ETIENNE-DE-GOURGAS;34700;34;HERAULT;1
34252;;Saint-Étienne-Estréchoux;SAINT-ETIENNE-ESTRECHOUX;34260;34;HERAULT;1
34253;;Saint-Félix-de-l'Héras;SAINT-FELIX-DE-L'HERAS;34520;34;HERAULT;1
34254;;Saint-Félix-de-Lodez;SAINT-FELIX-DE-LODEZ;34725;34;HERAULT;1
34255;;Saint-Gély-du-Fesc;SAINT-GELY-DU-FESC;34980;34;HERAULT;1
34256;;Saint-Geniès-des-Mourgues;SAINT-GENIES-DES-MOURGUES;34160;34;HERAULT;1
34257;;Saint-Geniès-de-Varensal;SAINT-GENIES-DE-VARENSAL;34610;34;HERAULT;1
34258;;Saint-Geniès-de-Fontedit;SAINT-GENIES-DE-FONTEDIT;34480;34;HERAULT;1
34259;;Saint-Georges-d'Orques;SAINT-GEORGES-D'ORQUES;34680;34;HERAULT;1
34260;;Saint-Gervais-sur-Mare;SAINT-GERVAIS-SUR-MARE;34610;34;HERAULT;1
34261;;Saint-Guilhem-le-Désert;SAINT-GUILHEM-LE-DESERT;34150;34;HERAULT;1
34262;;Saint-Guiraud;SAINT-GUIRAUD;34725;34;HERAULT;1
34263;;Saint-Hilaire-de-Beauvoir;SAINT-HILAIRE-DE-BEAUVOIR;34160;34;HERAULT;1
34264;;Saint-Jean-de-Buèges;SAINT-JEAN-DE-BUEGES;34380;34;HERAULT;1
34265;;Saint-Jean-de-Cornies;SAINT-JEAN-DE-CORNIES;34160;34;HERAULT;1
34266;;Saint-Jean-de-Cuculles;SAINT-JEAN-DE-CUCULLES;34270;34;HERAULT;1
34267;;Saint-Jean-de-Fos;SAINT-JEAN-DE-FOS;34150;34;HERAULT;1
34268;;Saint-Jean-de-la-Blaquière;SAINT-JEAN-DE-LA-BLAQUIERE;34700;34;HERAULT;1
34269;;Saint-Jean-de-Minervois;SAINT-JEAN-DE-MINERVOIS;34360;34;HERAULT;1
34270;;Saint-Jean-de-Védas;SAINT-JEAN-DE-VEDAS;34430;34;HERAULT;1
34271;;Saint-Julien;SAINT-JULIEN;34390;34;HERAULT;1
34272;;Saint-Just;SAINT-JUST;34400;34;HERAULT;1
34273;;Saint-Martin-de-l'Arçon;SAINT-MARTIN-DE-L'ARCON;34390;34;HERAULT;1
34274;;Saint-Martin-de-Londres;SAINT-MARTIN-DE-LONDRES;34380;34;HERAULT;1
34276;;Saint-Mathieu-de-Tréviers;SAINT-MATHIEU-DE-TREVIERS;34270;34;HERAULT;1
34277;;Saint-Maurice-Navacelles;SAINT-MAURICE-NAVACELLES;34520;34;HERAULT;1
34278;;Saint-Michel;SAINT-MICHEL;34520;34;HERAULT;1
34279;;Saint-Nazaire-de-Ladarez;SAINT-NAZAIRE-DE-LADAREZ;34490;34;HERAULT;1
34280;;Saint-Nazaire-de-Pézan;SAINT-NAZAIRE-DE-PEZAN;34400;34;HERAULT;1
34281;;Saint-Pargoire;SAINT-PARGOIRE;34230;34;HERAULT;1
34282;;Saint-Paul-et-Valmalle;SAINT-PAUL-ET-VALMALLE;34570;34;HERAULT;1
34283;;Saint-Pierre-de-la-Fage;SAINT-PIERRE-DE-LA-FAGE;34520;34;HERAULT;1
34284;;Saint-Pons-de-Thomières;SAINT-PONS-DE-THOMIERES;34220;34;HERAULT;1
34285;;Saint-Pons-de-Mauchiens;SAINT-PONS-DE-MAUCHIENS;34230;34;HERAULT;1
34286;;Saint-Privat;SAINT-PRIVAT;34700;34;HERAULT;1
34287;;Saint-Saturnin-de-Lucian;SAINT-SATURNIN-DE-LUCIAN;34725;34;HERAULT;1
34288;;Saint-Sériès;SAINT-SERIES;34400;34;HERAULT;1
34289;;Saint-Thibéry;SAINT-THIBERY;34630;34;HERAULT;1
34290;;Saint-Vincent-de-Barbeyrargues;SAINT-VINCENT-DE-BARBEYRARGUES;34730;34;HERAULT;1
34291;;Saint-Vincent-d'Olargues;SAINT-VINCENT-D'OLARGUES;34390;34;HERAULT;1
34292;;Salasc;SALASC;34800;34;HERAULT;1
34293;La;Salvetat-sur-Agout;SALVETAT-SUR-AGOUT;34330;34;HERAULT;1
34294;;Saturargues;SATURARGUES;34400;34;HERAULT;1
34295;;Saussan;SAUSSAN;34570;34;HERAULT;1
34296;;Saussines;SAUSSINES;34160;34;HERAULT;1
34297;;Sauteyrargues;SAUTEYRARGUES;34270;34;HERAULT;1
34298;;Sauvian;SAUVIAN;34410;34;HERAULT;1
34299;;Sérignan;SERIGNAN;34410;34;HERAULT;1
34300;;Servian;SERVIAN;34290;34;HERAULT;1
34301;;Sète;SETE;34200;34;HERAULT;1
34302;;Siran;SIRAN;34210;34;HERAULT;1
34303;;Sorbs;SORBS;34520;34;HERAULT;1
34304;;Soubès;SOUBES;34700;34;HERAULT;1
34305;Le;Soulié;SOULIE;34330;34;HERAULT;1
34306;;Soumont;SOUMONT;34700;34;HERAULT;1
34307;;Sussargues;SUSSARGUES;34160;34;HERAULT;1
34308;;Taussac-la-Billière;TAUSSAC-LA-BILLIERE;34600;34;HERAULT;1
34309;;Teyran;TEYRAN;34820;34;HERAULT;1
34310;;Thézan-lès-Béziers;THEZAN-LES-BEZIERS;34490;34;HERAULT;1
34311;;Tourbes;TOURBES;34120;34;HERAULT;1
34312;La;Tour-sur-Orb;TOUR-SUR-ORB;34260;34;HERAULT;1
34313;;Tressan;TRESSAN;34230;34;HERAULT;1
34314;Le;Triadou;TRIADOU;34270;34;HERAULT;1
34315;;Usclas-d'Hérault;USCLAS-D'HERAULT;34230;34;HERAULT;1
34316;;Usclas-du-Bosc;USCLAS-DU-BOSC;34700;34;HERAULT;1
34317;La;Vacquerie-et-Saint-Martin-de-Castries;VACQUERIE-ET-SAINT-MARTIN-DE-CASTRIES;34520;34;HERAULT;1
34318;;Vacquières;VACQUIERES;34270;34;HERAULT;1
34319;;Vailhan;VAILHAN;34320;34;HERAULT;1
34320;;Vailhauquès;VAILHAUQUES;34570;34;HERAULT;1
34321;;Valergues;VALERGUES;34130;34;HERAULT;1
34322;;Valflaunès;VALFLAUNES;34270;34;HERAULT;1
34323;;Valmascle;VALMASCLE;34800;34;HERAULT;1
34324;;Valras-Plage;VALRAS-PLAGE;34350;34;HERAULT;1
34325;;Valros;VALROS;34290;34;HERAULT;1
34326;;Vélieux;VELIEUX;34220;34;HERAULT;1
34327;;Vendargues;VENDARGUES;34740;34;HERAULT;1
34328;;Vendémian;VENDEMIAN;34230;34;HERAULT;1
34329;;Vendres;VENDRES;34350;34;HERAULT;1
34330;;Vérargues;VERARGUES;34400;34;HERAULT;1
34331;;Verreries-de-Moussans;VERRERIES-DE-MOUSSANS;34220;34;HERAULT;1
34332;;Vias;VIAS;34450;34;HERAULT;1
34333;;Vic-la-Gardiole;VIC-LA-GARDIOLE;34110;34;HERAULT;1
34334;;Vieussan;VIEUSSAN;34390;34;HERAULT;1
34335;;Villemagne-l'Argentière;VILLEMAGNE-L'ARGENTIERE;34600;34;HERAULT;1
34336;;Villeneuve-lès-Béziers;VILLENEUVE-LES-BEZIERS;34420;34;HERAULT;1
34337;;Villeneuve-lès-Maguelone;VILLENEUVE-LES-MAGUELONE;34750;34;HERAULT;1
34338;;Villeneuvette;VILLENEUVETTE;34800;34;HERAULT;1
34339;;Villespassans;VILLESPASSANS;34360;34;HERAULT;1
34340;;Villetelle;VILLETELLE;34400;34;HERAULT;1
34341;;Villeveyrac;VILLEVEYRAC;34560;34;HERAULT;1
34342;;Viols-en-Laval;VIOLS-EN-LAVAL;34380;34;HERAULT;1
34343;;Viols-le-Fort;VIOLS-LE-FORT;34380;34;HERAULT;1
34344;La;Grande-Motte;GRANDE-MOTTE;34280;34;HERAULT;1
35001;;Acigné;ACIGNE;35690;35;ILLE ET VILAINE;1
35002;;Amanlis;AMANLIS;35150;35;ILLE ET VILAINE;1
35003;;Andouillé-Neuville;ANDOUILLE-NEUVILLE;35250;35;ILLE ET VILAINE;1
35004;;Antrain;ANTRAIN;35560;35;ILLE ET VILAINE;1
35005;;Arbrissel;ARBRISSEL;35130;35;ILLE ET VILAINE;1
35006;;Argentré-du-Plessis;ARGENTRE-DU-PLESSIS;35370;35;ILLE ET VILAINE;1
35007;;Aubigné;AUBIGNE;35250;35;ILLE ET VILAINE;1
35008;;Availles-sur-Seiche;AVAILLES-SUR-SEICHE;35130;35;ILLE ET VILAINE;1
35009;;Baguer-Morvan;BAGUER-MORVAN;35120;35;ILLE ET VILAINE;1
35010;;Baguer-Pican;BAGUER-PICAN;35120;35;ILLE ET VILAINE;1
35011;;Baillé;BAILLE;35460;35;ILLE ET VILAINE;1
35012;;Bain-de-Bretagne;BAIN-DE-BRETAGNE;35470;35;ILLE ET VILAINE;1
35013;;Bains-sur-Oust;BAINS-SUR-OUST;35600;35;ILLE ET VILAINE;1
35014;;Bais;BAIS;35680;35;ILLE ET VILAINE;1
35015;;Balazé;BALAZE;35500;35;ILLE ET VILAINE;1
35016;;Baulon;BAULON;35580;35;ILLE ET VILAINE;1
35017;La;Baussaine;BAUSSAINE;35190;35;ILLE ET VILAINE;1
35018;La;Bazouge-du-Désert;BAZOUGE-DU-DESERT;35420;35;ILLE ET VILAINE;1
35019;;Bazouges-la-Pérouse;BAZOUGES-LA-PEROUSE;35560;35;ILLE ET VILAINE;1
35021;;Beaucé;BEAUCE;35133;35;ILLE ET VILAINE;1
35022;;Bécherel;BECHEREL;35190;35;ILLE ET VILAINE;1
35023;;Bédée;BEDEE;35137;35;ILLE ET VILAINE;1
35024;;Betton;BETTON;35830;35;ILLE ET VILAINE;1
35025;;Billé;BILLE;35133;35;ILLE ET VILAINE;1
35026;;Bléruais;BLERUAIS;35750;35;ILLE ET VILAINE;1
35027;;Boisgervilly;BOISGERVILLY;35360;35;ILLE ET VILAINE;1
35028;;Boistrudan;BOISTRUDAN;35150;35;ILLE ET VILAINE;1
35029;;Bonnemain;BONNEMAIN;35270;35;ILLE ET VILAINE;1
35030;La;Bosse-de-Bretagne;BOSSE-DE-BRETAGNE;35320;35;ILLE ET VILAINE;1
35031;La;Bouëxière;BOUEXIERE;35340;35;ILLE ET VILAINE;1
35032;;Bourgbarré;BOURGBARRE;35230;35;ILLE ET VILAINE;1
35033;;Bourg-des-Comptes;BOURG-DES-COMPTES;35890;35;ILLE ET VILAINE;1
35034;La;Boussac;BOUSSAC;35120;35;ILLE ET VILAINE;1
35035;;Bovel;BOVEL;35330;35;ILLE ET VILAINE;1
35037;;Bréal-sous-Montfort;BREAL-SOUS-MONTFORT;35310;35;ILLE ET VILAINE;1
35038;;Bréal-sous-Vitré;BREAL-SOUS-VITRE;35370;35;ILLE ET VILAINE;1
35039;;Brécé;BRECE;35530;35;ILLE ET VILAINE;1
35040;;Breteil;BRETEIL;35160;35;ILLE ET VILAINE;1
35041;;Brie;BRIE;35150;35;ILLE ET VILAINE;1
35042;;Brielles;BRIELLES;35370;35;ILLE ET VILAINE;1
35044;;Broualan;BROUALAN;35120;35;ILLE ET VILAINE;1
35045;;Bruc-sur-Aff;BRUC-SUR-AFF;35550;35;ILLE ET VILAINE;1
35046;Les;Brulais;BRULAIS;35330;35;ILLE ET VILAINE;1
35047;;Bruz;BRUZ;35170;35;ILLE ET VILAINE;1
35048;;Campel;CAMPEL;35330;35;ILLE ET VILAINE;1
35049;;Cancale;CANCALE;35260;35;ILLE ET VILAINE;1
35050;;Cardroc;CARDROC;35190;35;ILLE ET VILAINE;1
35051;;Cesson-Sévigné;CESSON-SEVIGNE;35510;35;ILLE ET VILAINE;1
35052;;Champeaux;CHAMPEAUX;35500;35;ILLE ET VILAINE;1
35053;;Chancé;CHANCE;35680;35;ILLE ET VILAINE;1
35054;;Chanteloup;CHANTELOUP;35150;35;ILLE ET VILAINE;1
35055;;Chantepie;CHANTEPIE;35135;35;ILLE ET VILAINE;1
35056;La;Chapelle-aux-Filtzméens;CHAPELLE-AUX-FILTZMEENS;35190;35;ILLE ET VILAINE;1
35057;La;Chapelle-Bouëxic;CHAPELLE-BOUEXIC;35330;35;ILLE ET VILAINE;1
35058;La;Chapelle-Chaussée;CHAPELLE-CHAUSSEE;35630;35;ILLE ET VILAINE;1
35059;La;Chapelle-des-Fougeretz;CHAPELLE-DES-FOUGERETZ;35520;35;ILLE ET VILAINE;1
35060;La;Chapelle-du-Lou;CHAPELLE-DU-LOU;35360;35;ILLE ET VILAINE;1
35061;La;Chapelle-Erbrée;CHAPELLE-ERBREE;35500;35;ILLE ET VILAINE;1
35062;La;Chapelle-Janson;CHAPELLE-JANSON;35133;35;ILLE ET VILAINE;1
35063;La;Chapelle-Saint-Aubert;CHAPELLE-SAINT-AUBERT;35140;35;ILLE ET VILAINE;1
35064;La;Chapelle-de-Brain;CHAPELLE-DE-BRAIN;35660;35;ILLE ET VILAINE;1
35065;La;Chapelle-Thouarault;CHAPELLE-THOUARAULT;35590;35;ILLE ET VILAINE;1
35066;;Chartres-de-Bretagne;CHARTRES-DE-BRETAGNE;35131;35;ILLE ET VILAINE;1
35067;;Chasné-sur-Illet;CHASNE-SUR-ILLET;35250;35;ILLE ET VILAINE;1
35068;;Châteaubourg;CHATEAUBOURG;35220;35;ILLE ET VILAINE;1
35069;;Châteaugiron;CHATEAUGIRON;35410;35;ILLE ET VILAINE;1
35070;;Châteauneuf-d'Ille-et-Vilaine;CHATEAUNEUF-D'ILLE-ET-VILAINE;35430;35;ILLE ET VILAINE;1
35071;Le;Châtellier;CHATELLIER;35133;35;ILLE ET VILAINE;1
35072;;Châtillon-en-Vendelais;CHATILLON-EN-VENDELAIS;35210;35;ILLE ET VILAINE;1
35075;;Chauvigné;CHAUVIGNE;35490;35;ILLE ET VILAINE;1
35076;;Chavagne;CHAVAGNE;35310;35;ILLE ET VILAINE;1
35077;;Chelun;CHELUN;35640;35;ILLE ET VILAINE;1
35078;;Cherrueix;CHERRUEIX;35120;35;ILLE ET VILAINE;1
35079;;Chevaigné;CHEVAIGNE;35250;35;ILLE ET VILAINE;1
35080;;Cintré;CINTRE;35310;35;ILLE ET VILAINE;1
35081;;Clayes;CLAYES;35590;35;ILLE ET VILAINE;1
35082;;Coësmes;COESMES;35134;35;ILLE ET VILAINE;1
35083;;Coglès;COGLES;35460;35;ILLE ET VILAINE;1
35084;;Comblessac;COMBLESSAC;35330;35;ILLE ET VILAINE;1
35085;;Combourg;COMBOURG;35270;35;ILLE ET VILAINE;1
35086;;Combourtillé;COMBOURTILLE;35210;35;ILLE ET VILAINE;1
35087;;Cornillé;CORNILLE;35500;35;ILLE ET VILAINE;1
35088;;Corps-Nuds;CORPS-NUDS;35150;35;ILLE ET VILAINE;1
35089;La;Couyère;COUYERE;35320;35;ILLE ET VILAINE;1
35090;;Crevin;CREVIN;35320;35;ILLE ET VILAINE;1
35091;Le;Crouais;CROUAIS;35290;35;ILLE ET VILAINE;1
35092;;Cuguen;CUGUEN;35270;35;ILLE ET VILAINE;1
35093;;Dinard;DINARD;35800;35;ILLE ET VILAINE;1
35094;;Dingé;DINGE;35440;35;ILLE ET VILAINE;1
35095;;Dol-de-Bretagne;DOL-DE-BRETAGNE;35120;35;ILLE ET VILAINE;1
35096;;Domagné;DOMAGNE;35113;35;ILLE ET VILAINE;1
35097;;Domalain;DOMALAIN;35680;35;ILLE ET VILAINE;1
35098;La;Dominelais;DOMINELAIS;35390;35;ILLE ET VILAINE;1
35099;;Domloup;DOMLOUP;35410;35;ILLE ET VILAINE;1
35100;;Dompierre-du-Chemin;DOMPIERRE-DU-CHEMIN;35210;35;ILLE ET VILAINE;1
35101;;Dourdain;DOURDAIN;35450;35;ILLE ET VILAINE;1
35102;;Drouges;DROUGES;35130;35;ILLE ET VILAINE;1
35103;;Eancé;EANCE;35640;35;ILLE ET VILAINE;1
35104;;Epiniac;EPINIAC;35120;35;ILLE ET VILAINE;1
35105;;Erbrée;ERBREE;35500;35;ILLE ET VILAINE;1
35106;;Ercé-en-Lamée;ERCE-EN-LAMEE;35620;35;ILLE ET VILAINE;1
35107;;Ercé-près-Liffré;ERCE-PRES-LIFFRE;35340;35;ILLE ET VILAINE;1
35108;;Essé;ESSE;35150;35;ILLE ET VILAINE;1
35109;;Étrelles;ETRELLES;35370;35;ILLE ET VILAINE;1
35110;;Feins;FEINS;35440;35;ILLE ET VILAINE;1
35111;Le;Ferré;FERRE;35420;35;ILLE ET VILAINE;1
35112;;Fleurigné;FLEURIGNE;35133;35;ILLE ET VILAINE;1
35113;La;Fontenelle;FONTENELLE;35560;35;ILLE ET VILAINE;1
35114;;Forges-la-Forêt;FORGES-LA-FORET;35640;35;ILLE ET VILAINE;1
35115;;Fougères;FOUGERES;35300;35;ILLE ET VILAINE;1
35116;La;Fresnais;FRESNAIS;35111;35;ILLE ET VILAINE;1
35117;;Gaël;GAEL;35290;35;ILLE ET VILAINE;1
35118;;Gahard;GAHARD;35490;35;ILLE ET VILAINE;1
35119;;Gennes-sur-Seiche;GENNES-SUR-SEICHE;35370;35;ILLE ET VILAINE;1
35120;;Gévezé;GEVEZE;35850;35;ILLE ET VILAINE;1
35121;;Gosné;GOSNE;35140;35;ILLE ET VILAINE;1
35122;La;Gouesnière;GOUESNIERE;35350;35;ILLE ET VILAINE;1
35123;;Goven;GOVEN;35580;35;ILLE ET VILAINE;1
35124;;Grand-Fougeray;GRAND-FOUGERAY;35390;35;ILLE ET VILAINE;1
35125;La;Guerche-de-Bretagne;GUERCHE-DE-BRETAGNE;35130;35;ILLE ET VILAINE;1
35126;;Guichen;GUICHEN;35580;35;ILLE ET VILAINE;1
35127;;Guignen;GUIGNEN;35580;35;ILLE ET VILAINE;1
35128;;Guipel;GUIPEL;35440;35;ILLE ET VILAINE;1
35129;;Guipry;GUIPRY;35480;35;ILLE ET VILAINE;1
35130;;Hédé-Bazouges;HEDE-BAZOUGES;35630;35;ILLE ET VILAINE;1
35131;L';Hermitage;HERMITAGE;35590;35;ILLE ET VILAINE;1
35132;;Hirel;HIREL;35120;35;ILLE ET VILAINE;1
35133;;Iffendic;IFFENDIC;35750;35;ILLE ET VILAINE;1
35134;Les;Iffs;IFFS;35630;35;ILLE ET VILAINE;1
35135;;Irodouër;IRODOUER;35850;35;ILLE ET VILAINE;1
35136;;Janzé;JANZE;35150;35;ILLE ET VILAINE;1
35137;;Javené;JAVENE;35133;35;ILLE ET VILAINE;1
35138;;Laignelet;LAIGNELET;35133;35;ILLE ET VILAINE;1
35139;;Laillé;LAILLE;35890;35;ILLE ET VILAINE;1
35140;;Lalleu;LALLEU;35320;35;ILLE ET VILAINE;1
35141;;Landavran;LANDAVRAN;35450;35;ILLE ET VILAINE;1
35142;;Landéan;LANDEAN;35133;35;ILLE ET VILAINE;1
35143;;Landujan;LANDUJAN;35360;35;ILLE ET VILAINE;1
35144;;Langan;LANGAN;35850;35;ILLE ET VILAINE;1
35145;;Langon;LANGON;35660;35;ILLE ET VILAINE;1
35146;;Langouet;LANGOUET;35630;35;ILLE ET VILAINE;1
35147;;Lanhélin;LANHELIN;35720;35;ILLE ET VILAINE;1
35148;;Lanrigan;LANRIGAN;35270;35;ILLE ET VILAINE;1
35149;;Lassy;LASSY;35580;35;ILLE ET VILAINE;1
35150;;Lécousse;LECOUSSE;35133;35;ILLE ET VILAINE;1
35151;;Lieuron;LIEURON;35550;35;ILLE ET VILAINE;1
35152;;Liffré;LIFFRE;35340;35;ILLE ET VILAINE;1
35153;;Lillemer;LILLEMER;35111;35;ILLE ET VILAINE;1
35154;;Livré-sur-Changeon;LIVRE-SUR-CHANGEON;35450;35;ILLE ET VILAINE;1
35155;;Lohéac;LOHEAC;35550;35;ILLE ET VILAINE;1
35156;;Longaulnay;LONGAULNAY;35190;35;ILLE ET VILAINE;1
35157;Le;Loroux;LOROUX;35133;35;ILLE ET VILAINE;1
35158;Le;Lou-du-Lac;LOU-DU-LAC;35360;35;ILLE ET VILAINE;1
35159;;Lourmais;LOURMAIS;35270;35;ILLE ET VILAINE;1
35160;;Loutehel;LOUTEHEL;35330;35;ILLE ET VILAINE;1
35161;;Louvigné-de-Bais;LOUVIGNE-DE-BAIS;35680;35;ILLE ET VILAINE;1
35162;;Louvigné-du-Désert;LOUVIGNE-DU-DESERT;35420;35;ILLE ET VILAINE;1
35163;;Luitré;LUITRE;35133;35;ILLE ET VILAINE;1
35164;;Marcillé-Raoul;MARCILLE-RAOUL;35560;35;ILLE ET VILAINE;1
35165;;Marcillé-Robert;MARCILLE-ROBERT;35240;35;ILLE ET VILAINE;1
35166;;Marpiré;MARPIRE;35220;35;ILLE ET VILAINE;1
35167;;Martigné-Ferchaud;MARTIGNE-FERCHAUD;35640;35;ILLE ET VILAINE;1
35168;;Maure-de-Bretagne;MAURE-DE-BRETAGNE;35330;35;ILLE ET VILAINE;1
35169;;Maxent;MAXENT;35380;35;ILLE ET VILAINE;1
35170;;Mecé;MECE;35450;35;ILLE ET VILAINE;1
35171;;Médréac;MEDREAC;35360;35;ILLE ET VILAINE;1
35172;;Meillac;MEILLAC;35270;35;ILLE ET VILAINE;1
35173;;Melesse;MELESSE;35520;35;ILLE ET VILAINE;1
35174;;Mellé;MELLE;35420;35;ILLE ET VILAINE;1
35175;;Mernel;MERNEL;35330;35;ILLE ET VILAINE;1
35176;;Messac;MESSAC;35480;35;ILLE ET VILAINE;1
35177;La;Mézière;MEZIERE;35520;35;ILLE ET VILAINE;1
35178;;Mézières-sur-Couesnon;MEZIERES-SUR-COUESNON;35140;35;ILLE ET VILAINE;1
35179;;Miniac-Morvan;MINIAC-MORVAN;35540;35;ILLE ET VILAINE;1
35180;;Miniac-sous-Bécherel;MINIAC-SOUS-BECHEREL;35190;35;ILLE ET VILAINE;1
35181;Le;Minihic-sur-Rance;MINIHIC-SUR-RANCE;35870;35;ILLE ET VILAINE;1
35183;;Mondevert;MONDEVERT;35370;35;ILLE ET VILAINE;1
35184;;Montauban-de-Bretagne;MONTAUBAN-DE-BRETAGNE;35360;35;ILLE ET VILAINE;1
35185;;Montautour;MONTAUTOUR;35210;35;ILLE ET VILAINE;1
35186;;Mont-Dol;MONT-DOL;35120;35;ILLE ET VILAINE;1
35187;;Monterfil;MONTERFIL;35160;35;ILLE ET VILAINE;1
35188;;Montfort-sur-Meu;MONTFORT-SUR-MEU;35160;35;ILLE ET VILAINE;1
35189;;Montgermont;MONTGERMONT;35760;35;ILLE ET VILAINE;1
35190;;Monthault;MONTHAULT;35420;35;ILLE ET VILAINE;1
35191;;Montours;MONTOURS;35460;35;ILLE ET VILAINE;1
35192;;Montreuil-des-Landes;MONTREUIL-DES-LANDES;35210;35;ILLE ET VILAINE;1
35193;;Montreuil-le-Gast;MONTREUIL-LE-GAST;35520;35;ILLE ET VILAINE;1
35194;;Montreuil-sous-Pérouse;MONTREUIL-SOUS-PEROUSE;35500;35;ILLE ET VILAINE;1
35195;;Montreuil-sur-Ille;MONTREUIL-SUR-ILLE;35440;35;ILLE ET VILAINE;1
35196;;Mordelles;MORDELLES;35310;35;ILLE ET VILAINE;1
35197;;Mouazé;MOUAZE;35250;35;ILLE ET VILAINE;1
35198;;Moulins;MOULINS;35680;35;ILLE ET VILAINE;1
35199;;Moussé;MOUSSE;35130;35;ILLE ET VILAINE;1
35200;;Moutiers;MOUTIERS;35130;35;ILLE ET VILAINE;1
35201;;Muel;MUEL;35290;35;ILLE ET VILAINE;1
35202;La;Noë-Blanche;NOE-BLANCHE;35470;35;ILLE ET VILAINE;1
35203;La;Nouaye;NOUAYE;35137;35;ILLE ET VILAINE;1
35204;;Nouvoitou;NOUVOITOU;35410;35;ILLE ET VILAINE;1
35205;;Noyal-sous-Bazouges;NOYAL-SOUS-BAZOUGES;35560;35;ILLE ET VILAINE;1
35206;;Noyal-Châtillon-sur-Seiche;NOYAL-CHATILLON-SUR-SEICHE;35230;35;ILLE ET VILAINE;1
35207;;Noyal-sur-Vilaine;NOYAL-SUR-VILAINE;35530;35;ILLE ET VILAINE;1
35208;;Orgères;ORGERES;35230;35;ILLE ET VILAINE;1
35209;;Ossé;OSSE;35410;35;ILLE ET VILAINE;1
35210;;Pacé;PACE;35740;35;ILLE ET VILAINE;1
35211;;Paimpont;PAIMPONT;35380;35;ILLE ET VILAINE;1
35212;;Pancé;PANCE;35320;35;ILLE ET VILAINE;1
35214;;Parcé;PARCE;35210;35;ILLE ET VILAINE;1
35215;;Parigné;PARIGNE;35133;35;ILLE ET VILAINE;1
35216;;Parthenay-de-Bretagne;PARTHENAY-DE-BRETAGNE;35850;35;ILLE ET VILAINE;1
35217;Le;Pertre;PERTRE;35370;35;ILLE ET VILAINE;1
35218;Le;Petit-Fougeray;PETIT-FOUGERAY;35320;35;ILLE ET VILAINE;1
35219;;Pipriac;PIPRIAC;35550;35;ILLE ET VILAINE;1
35220;;Piré-sur-Seiche;PIRE-SUR-SEICHE;35150;35;ILLE ET VILAINE;1
35221;;Pléchâtel;PLECHATEL;35470;35;ILLE ET VILAINE;1
35222;;Pleine-Fougères;PLEINE-FOUGERES;35610;35;ILLE ET VILAINE;1
35223;;Plélan-le-Grand;PLELAN-LE-GRAND;35380;35;ILLE ET VILAINE;1
35224;;Plerguer;PLERGUER;35540;35;ILLE ET VILAINE;1
35225;;Plesder;PLESDER;35720;35;ILLE ET VILAINE;1
35226;;Pleugueneuc;PLEUGUENEUC;35720;35;ILLE ET VILAINE;1
35227;;Pleumeleuc;PLEUMELEUC;35137;35;ILLE ET VILAINE;1
35228;;Pleurtuit;PLEURTUIT;35730;35;ILLE ET VILAINE;1
35229;;Pocé-les-Bois;POCE-LES-BOIS;35500;35;ILLE ET VILAINE;1
35230;;Poilley;POILLEY;35420;35;ILLE ET VILAINE;1
35231;;Poligné;POLIGNE;35320;35;ILLE ET VILAINE;1
35232;;Princé;PRINCE;35210;35;ILLE ET VILAINE;1
35233;;Québriac;QUEBRIAC;35190;35;ILLE ET VILAINE;1
35234;;Quédillac;QUEDILLAC;35290;35;ILLE ET VILAINE;1
35235;;Rannée;RANNEE;35130;35;ILLE ET VILAINE;1
35236;;Redon;REDON;35600;35;ILLE ET VILAINE;1
35237;;Renac;RENAC;35660;35;ILLE ET VILAINE;1
35238;;Rennes;RENNES;35000;35;ILLE ET VILAINE;1
35239;;Retiers;RETIERS;35240;35;ILLE ET VILAINE;1
35240;Le;Rheu;RHEU;35650;35;ILLE ET VILAINE;1
35241;La;Richardais;RICHARDAIS;35780;35;ILLE ET VILAINE;1
35242;;Rimou;RIMOU;35560;35;ILLE ET VILAINE;1
35243;;Romagné;ROMAGNE;35133;35;ILLE ET VILAINE;1
35244;;Romazy;ROMAZY;35490;35;ILLE ET VILAINE;1
35245;;Romillé;ROMILLE;35850;35;ILLE ET VILAINE;1
35246;;Roz-Landrieux;ROZ-LANDRIEUX;35120;35;ILLE ET VILAINE;1
35247;;Roz-sur-Couesnon;ROZ-SUR-COUESNON;35610;35;ILLE ET VILAINE;1
35248;;Sains;SAINS;35610;35;ILLE ET VILAINE;1
35249;;Sainte-Anne-sur-Vilaine;SAINTE-ANNE-SUR-VILAINE;35390;35;ILLE ET VILAINE;1
35250;;Saint-Armel;SAINT-ARMEL;35230;35;ILLE ET VILAINE;1
35251;;Saint-Aubin-d'Aubigné;SAINT-AUBIN-D'AUBIGNE;35250;35;ILLE ET VILAINE;1
35252;;Saint-Aubin-des-Landes;SAINT-AUBIN-DES-LANDES;35500;35;ILLE ET VILAINE;1
35253;;Saint-Aubin-du-Cormier;SAINT-AUBIN-DU-CORMIER;35140;35;ILLE ET VILAINE;1
35254;;Saint-Aubin-du-Pavail;SAINT-AUBIN-DU-PAVAIL;35410;35;ILLE ET VILAINE;1
35255;;Saint-Benoît-des-Ondes;SAINT-BENOIT-DES-ONDES;35114;35;ILLE ET VILAINE;1
35256;;Saint-Briac-sur-Mer;SAINT-BRIAC-SUR-MER;35800;35;ILLE ET VILAINE;1
35257;;Saint-Brice-en-Coglès;SAINT-BRICE-EN-COGLES;35460;35;ILLE ET VILAINE;1
35258;;Saint-Brieuc-des-Iffs;SAINT-BRIEUC-DES-IFFS;35630;35;ILLE ET VILAINE;1
35259;;Saint-Broladre;SAINT-BROLADRE;35120;35;ILLE ET VILAINE;1
35260;;Saint-Christophe-des-Bois;SAINT-CHRISTOPHE-DES-BOIS;35210;35;ILLE ET VILAINE;1
35261;;Saint-Christophe-de-Valains;SAINT-CHRISTOPHE-DE-VALAINS;35140;35;ILLE ET VILAINE;1
35262;;Sainte-Colombe;SAINTE-COLOMBE;35134;35;ILLE ET VILAINE;1
35263;;Saint-Coulomb;SAINT-COULOMB;35350;35;ILLE ET VILAINE;1
35264;;Saint-Didier;SAINT-DIDIER;35220;35;ILLE ET VILAINE;1
35265;;Saint-Domineuc;SAINT-DOMINEUC;35190;35;ILLE ET VILAINE;1
35266;;Saint-Erblon;SAINT-ERBLON;35230;35;ILLE ET VILAINE;1
35267;;Saint-Étienne-en-Coglès;SAINT-ETIENNE-EN-COGLES;35460;35;ILLE ET VILAINE;1
35268;;Saint-Ganton;SAINT-GANTON;35550;35;ILLE ET VILAINE;1
35269;;Saint-Georges-de-Chesné;SAINT-GEORGES-DE-CHESNE;35140;35;ILLE ET VILAINE;1
35270;;Saint-Georges-de-Gréhaigne;SAINT-GEORGES-DE-GREHAIGNE;35610;35;ILLE ET VILAINE;1
35271;;Saint-Georges-de-Reintembault;SAINT-GEORGES-DE-REINTEMBAULT;35420;35;ILLE ET VILAINE;1
35272;;Saint-Germain-du-Pinel;SAINT-GERMAIN-DU-PINEL;35370;35;ILLE ET VILAINE;1
35273;;Saint-Germain-en-Coglès;SAINT-GERMAIN-EN-COGLES;35133;35;ILLE ET VILAINE;1
35274;;Saint-Germain-sur-Ille;SAINT-GERMAIN-SUR-ILLE;35250;35;ILLE ET VILAINE;1
35275;;Saint-Gilles;SAINT-GILLES;35590;35;ILLE ET VILAINE;1
35276;;Saint-Gondran;SAINT-GONDRAN;35630;35;ILLE ET VILAINE;1
35277;;Saint-Gonlay;SAINT-GONLAY;35750;35;ILLE ET VILAINE;1
35278;;Saint-Grégoire;SAINT-GREGOIRE;35760;35;ILLE ET VILAINE;1
35279;;Saint-Guinoux;SAINT-GUINOUX;35430;35;ILLE ET VILAINE;1
35280;;Saint-Hilaire-des-Landes;SAINT-HILAIRE-DES-LANDES;35140;35;ILLE ET VILAINE;1
35281;;Saint-Jacques-de-la-Lande;SAINT-JACQUES-DE-LA-LANDE;35136;35;ILLE ET VILAINE;1
35282;;Saint-Jean-sur-Couesnon;SAINT-JEAN-SUR-COUESNON;35140;35;ILLE ET VILAINE;1
35283;;Saint-Jean-sur-Vilaine;SAINT-JEAN-SUR-VILAINE;35220;35;ILLE ET VILAINE;1
35284;;Saint-Jouan-des-Guérets;SAINT-JOUAN-DES-GUERETS;35430;35;ILLE ET VILAINE;1
35285;;Saint-Just;SAINT-JUST;35550;35;ILLE ET VILAINE;1
35286;;Saint-Léger-des-Prés;SAINT-LEGER-DES-PRES;35270;35;ILLE ET VILAINE;1
35287;;Saint-Lunaire;SAINT-LUNAIRE;35800;35;ILLE ET VILAINE;1
35288;;Saint-Malo;SAINT-MALO;35400;35;ILLE ET VILAINE;1
35289;;Saint-Malo-de-Phily;SAINT-MALO-DE-PHILY;35480;35;ILLE ET VILAINE;1
35290;;Saint-Malon-sur-Mel;SAINT-MALON-SUR-MEL;35750;35;ILLE ET VILAINE;1
35291;;Saint-Marcan;SAINT-MARCAN;35120;35;ILLE ET VILAINE;1
35292;;Saint-Marc-le-Blanc;SAINT-MARC-LE-BLANC;35460;35;ILLE ET VILAINE;1
35293;;Saint-Marc-sur-Couesnon;SAINT-MARC-SUR-COUESNON;35140;35;ILLE ET VILAINE;1
35294;;Sainte-Marie;SAINTE-MARIE;35600;35;ILLE ET VILAINE;1
35295;;Saint-Maugan;SAINT-MAUGAN;35750;35;ILLE ET VILAINE;1
35296;;Saint-Médard-sur-Ille;SAINT-MEDARD-SUR-ILLE;35250;35;ILLE ET VILAINE;1
35297;;Saint-Méen-le-Grand;SAINT-MEEN-LE-GRAND;35290;35;ILLE ET VILAINE;1
35299;;Saint-Méloir-des-Ondes;SAINT-MELOIR-DES-ONDES;35350;35;ILLE ET VILAINE;1
35300;;Saint-M'Hervé;SAINT-M'HERVE;35500;35;ILLE ET VILAINE;1
35301;;Saint-M'Hervon;SAINT-M'HERVON;35360;35;ILLE ET VILAINE;1
35302;;Saint-Onen-la-Chapelle;SAINT-ONEN-LA-CHAPELLE;35290;35;ILLE ET VILAINE;1
35303;;Saint-Ouen-la-Rouërie;SAINT-OUEN-LA-ROUERIE;35460;35;ILLE ET VILAINE;1
35304;;Saint-Ouen-des-Alleux;SAINT-OUEN-DES-ALLEUX;35140;35;ILLE ET VILAINE;1
35305;;Saint-Péran;SAINT-PERAN;35380;35;ILLE ET VILAINE;1
35306;;Saint-Père;SAINT-PERE;35430;35;ILLE ET VILAINE;1
35307;;Saint-Pern;SAINT-PERN;35190;35;ILLE ET VILAINE;1
35308;;Saint-Pierre-de-Plesguen;SAINT-PIERRE-DE-PLESGUEN;35720;35;ILLE ET VILAINE;1
35309;;Saint-Rémy-du-Plain;SAINT-REMY-DU-PLAIN;35560;35;ILLE ET VILAINE;1
35310;;Saint-Sauveur-des-Landes;SAINT-SAUVEUR-DES-LANDES;35133;35;ILLE ET VILAINE;1
35311;;Saint-Séglin;SAINT-SEGLIN;35330;35;ILLE ET VILAINE;1
35312;;Saint-Senoux;SAINT-SENOUX;35580;35;ILLE ET VILAINE;1
35314;;Saint-Suliac;SAINT-SULIAC;35430;35;ILLE ET VILAINE;1
35315;;Saint-Sulpice-la-Forêt;SAINT-SULPICE-LA-FORET;35250;35;ILLE ET VILAINE;1
35316;;Saint-Sulpice-des-Landes;SAINT-SULPICE-DES-LANDES;35390;35;ILLE ET VILAINE;1
35317;;Saint-Symphorien;SAINT-SYMPHORIEN;35630;35;ILLE ET VILAINE;1
35318;;Saint-Thual;SAINT-THUAL;35190;35;ILLE ET VILAINE;1
35319;;Saint-Thurial;SAINT-THURIAL;35310;35;ILLE ET VILAINE;1
35320;;Saint-Uniac;SAINT-UNIAC;35360;35;ILLE ET VILAINE;1
35321;;Saulnières;SAULNIERES;35320;35;ILLE ET VILAINE;1
35322;Le;Sel-de-Bretagne;SEL-DE-BRETAGNE;35320;35;ILLE ET VILAINE;1
35323;La;Selle-en-Coglès;SELLE-EN-COGLES;35460;35;ILLE ET VILAINE;1
35324;La;Selle-en-Luitré;SELLE-EN-LUITRE;35133;35;ILLE ET VILAINE;1
35325;La;Selle-Guerchaise;SELLE-GUERCHAISE;35130;35;ILLE ET VILAINE;1
35326;;Sens-de-Bretagne;SENS-DE-BRETAGNE;35490;35;ILLE ET VILAINE;1
35327;;Servon-sur-Vilaine;SERVON-SUR-VILAINE;35530;35;ILLE ET VILAINE;1
35328;;Sixt-sur-Aff;SIXT-SUR-AFF;35550;35;ILLE ET VILAINE;1
35329;;Sougéal;SOUGEAL;35610;35;ILLE ET VILAINE;1
35330;;Taillis;TAILLIS;35500;35;ILLE ET VILAINE;1
35331;;Talensac;TALENSAC;35160;35;ILLE ET VILAINE;1
35332;;Teillay;TEILLAY;35620;35;ILLE ET VILAINE;1
35333;Le;Theil-de-Bretagne;THEIL-DE-BRETAGNE;35240;35;ILLE ET VILAINE;1
35334;;Thorigné-Fouillard;THORIGNE-FOUILLARD;35235;35;ILLE ET VILAINE;1
35335;;Thourie;THOURIE;35134;35;ILLE ET VILAINE;1
35336;Le;Tiercent;TIERCENT;35460;35;ILLE ET VILAINE;1
35337;;Tinténiac;TINTENIAC;35190;35;ILLE ET VILAINE;1
35338;;Torcé;TORCE;35370;35;ILLE ET VILAINE;1
35339;;Trans-la-Forêt;TRANS-LA-FORET;35610;35;ILLE ET VILAINE;1
35340;;Treffendel;TREFFENDEL;35380;35;ILLE ET VILAINE;1
35341;;Tremblay;TREMBLAY;35460;35;ILLE ET VILAINE;1
35342;;Trémeheuc;TREMEHEUC;35270;35;ILLE ET VILAINE;1
35343;;Tresbœuf;TRESBOEUF;35320;35;ILLE ET VILAINE;1
35344;;Tressé;TRESSE;35720;35;ILLE ET VILAINE;1
35345;;Trévérien;TREVERIEN;35190;35;ILLE ET VILAINE;1
35346;;Trimer;TRIMER;35190;35;ILLE ET VILAINE;1
35347;;Val-d'Izé;VAL-D'IZE;35450;35;ILLE ET VILAINE;1
35348;;Vendel;VENDEL;35140;35;ILLE ET VILAINE;1
35350;;Vergéal;VERGEAL;35680;35;ILLE ET VILAINE;1
35351;Le;Verger;VERGER;35160;35;ILLE ET VILAINE;1
35352;;Vern-sur-Seiche;VERN-SUR-SEICHE;35770;35;ILLE ET VILAINE;1
35353;;Vezin-le-Coquet;VEZIN-LE-COQUET;35132;35;ILLE ET VILAINE;1
35354;;Vieux-Viel;VIEUX-VIEL;35610;35;ILLE ET VILAINE;1
35355;;Vieux-Vy-sur-Couesnon;VIEUX-VY-SUR-COUESNON;35490;35;ILLE ET VILAINE;1
35356;;Vignoc;VIGNOC;35630;35;ILLE ET VILAINE;1
35357;;Villamée;VILLAMEE;35420;35;ILLE ET VILAINE;1
35358;La;Ville-ès-Nonais;VILLE-ES-NONAIS;35430;35;ILLE ET VILAINE;1
35359;;Visseiche;VISSEICHE;35130;35;ILLE ET VILAINE;1
35360;;Vitré;VITRE;35500;35;ILLE ET VILAINE;1
35361;Le;Vivier-sur-Mer;VIVIER-SUR-MER;35960;35;ILLE ET VILAINE;1
35362;Le;Tronchet;TRONCHET;35540;35;ILLE ET VILAINE;1
35363;;Pont-Péan;PONT-PEAN;35131;35;ILLE ET VILAINE;1
36001;;Aigurande;AIGURANDE;36140;36;INDRE;1
36002;;Aize;AIZE;36150;36;INDRE;1
36003;;Ambrault;AMBRAULT;36120;36;INDRE;1
36004;;Anjouin;ANJOUIN;36210;36;INDRE;1
36005;;Ardentes;ARDENTES;36120;36;INDRE;1
36006;;Argenton-sur-Creuse;ARGENTON-SUR-CREUSE;36200;36;INDRE;1
36007;;Argy;ARGY;36500;36;INDRE;1
36008;;Arpheuilles;ARPHEUILLES;36700;36;INDRE;1
36009;;Arthon;ARTHON;36330;36;INDRE;1
36010;;Azay-le-Ferron;AZAY-LE-FERRON;36290;36;INDRE;1
36011;;Bagneux;BAGNEUX;36210;36;INDRE;1
36012;;Baraize;BARAIZE;36270;36;INDRE;1
36013;;Baudres;BAUDRES;36110;36;INDRE;1
36014;;Bazaiges;BAZAIGES;36270;36;INDRE;1
36015;;Beaulieu;BEAULIEU;36310;36;INDRE;1
36016;;Bélâbre;BELABRE;36370;36;INDRE;1
36017;La;Berthenoux;BERTHENOUX;36400;36;INDRE;1
36018;Le;Blanc;BLANC;36300;36;INDRE;1
36019;;Bommiers;BOMMIERS;36120;36;INDRE;1
36020;;Bonneuil;BONNEUIL;36310;36;INDRE;1
36021;Les;Bordes;BORDES;36100;36;INDRE;1
36022;;Bouesse;BOUESSE;36200;36;INDRE;1
36023;;Bouges-le-Château;BOUGES-LE-CHATEAU;36110;36;INDRE;1
36024;;Bretagne;BRETAGNE;36110;36;INDRE;1
36025;;Briantes;BRIANTES;36400;36;INDRE;1
36026;;Brion;BRION;36110;36;INDRE;1
36027;;Brives;BRIVES;36100;36;INDRE;1
36028;La;Buxerette;BUXERETTE;36140;36;INDRE;1
36029;;Buxeuil;BUXEUIL;36150;36;INDRE;1
36030;;Buxières-d'Aillac;BUXIERES-D'AILLAC;36230;36;INDRE;1
36031;;Buzançais;BUZANCAIS;36500;36;INDRE;1
36032;;Ceaulmont;CEAULMONT;36200;36;INDRE;1
36033;;Celon;CELON;36200;36;INDRE;1
36034;;Chabris;CHABRIS;36210;36;INDRE;1
36035;;Chaillac;CHAILLAC;36310;36;INDRE;1
36036;;Chalais;CHALAIS;36370;36;INDRE;1
36037;La;Champenoise;CHAMPENOISE;36100;36;INDRE;1
36038;;Champillet;CHAMPILLET;36160;36;INDRE;1
36040;La;Chapelle-Orthemale;CHAPELLE-ORTHEMALE;36500;36;INDRE;1
36041;La;Chapelle-Saint-Laurian;CHAPELLE-SAINT-LAURIAN;36150;36;INDRE;1
36042;;Chasseneuil;CHASSENEUIL;36800;36;INDRE;1
36043;;Chassignolles;CHASSIGNOLLES;36400;36;INDRE;1
36044;;Châteauroux;CHATEAUROUX;36000;36;INDRE;1
36045;;Châtillon-sur-Indre;CHATILLON-SUR-INDRE;36700;36;INDRE;1
36046;La;Châtre;CHATRE;36400;36;INDRE;1
36047;La;Châtre-Langlin;CHATRE-LANGLIN;36170;36;INDRE;1
36048;;Chavin;CHAVIN;36200;36;INDRE;1
36049;;Chazelet;CHAZELET;36170;36;INDRE;1
36050;;Chezelles;CHEZELLES;36500;36;INDRE;1
36051;;Chitray;CHITRAY;36800;36;INDRE;1
36052;;Chouday;CHOUDAY;36100;36;INDRE;1
36053;;Ciron;CIRON;36300;36;INDRE;1
36054;;Cléré-du-Bois;CLERE-DU-BOIS;36700;36;INDRE;1
36055;;Clion;CLION;36700;36;INDRE;1
36056;;Cluis;CLUIS;36340;36;INDRE;1
36057;;Coings;COINGS;36130;36;INDRE;1
36058;;Concremiers;CONCREMIERS;36300;36;INDRE;1
36059;;Condé;CONDE;36100;36;INDRE;1
36060;;Crevant;CREVANT;36140;36;INDRE;1
36061;;Crozon-sur-Vauvre;CROZON-SUR-VAUVRE;36140;36;INDRE;1
36062;;Cuzion;CUZION;36190;36;INDRE;1
36063;;Déols;DEOLS;36130;36;INDRE;1
36064;;Diors;DIORS;36130;36;INDRE;1
36065;;Diou;DIOU;36260;36;INDRE;1
36066;;Douadic;DOUADIC;36300;36;INDRE;1
36067;;Dunet;DUNET;36310;36;INDRE;1
36068;;Dun-le-Poëlier;DUN-LE-POELIER;36210;36;INDRE;1
36069;;Écueillé;ECUEILLE;36240;36;INDRE;1
36070;;Éguzon-Chantôme;EGUZON-CHANTOME;36270;36;INDRE;1
36071;;Étrechet;ETRECHET;36120;36;INDRE;1
36072;;Faverolles;FAVEROLLES;36360;36;INDRE;1
36073;;Feusines;FEUSINES;36160;36;INDRE;1
36074;;Fléré-la-Rivière;FLERE-LA-RIVIERE;36700;36;INDRE;1
36075;;Fontenay;FONTENAY;36150;36;INDRE;1
36076;;Fontgombault;FONTGOMBAULT;36220;36;INDRE;1
36077;;Fontguenand;FONTGUENAND;36600;36;INDRE;1
36078;;Fougerolles;FOUGEROLLES;36230;36;INDRE;1
36079;;Francillon;FRANCILLON;36110;36;INDRE;1
36080;;Frédille;FREDILLE;36180;36;INDRE;1
36081;;Gargilesse-Dampierre;GARGILESSE-DAMPIERRE;36190;36;INDRE;1
36082;;Gehée;GEHEE;36240;36;INDRE;1
36083;;Giroux;GIROUX;36150;36;INDRE;1
36084;;Gournay;GOURNAY;36230;36;INDRE;1
36085;;Guilly;GUILLY;36150;36;INDRE;1
36086;;Heugnes;HEUGNES;36180;36;INDRE;1
36087;;Ingrandes;INGRANDES;36300;36;INDRE;1
36088;;Issoudun;ISSOUDUN;36100;36;INDRE;1
36089;;Jeu-les-Bois;JEU-LES-BOIS;36120;36;INDRE;1
36090;;Jeu-Maloches;JEU-MALOCHES;36240;36;INDRE;1
36091;;Lacs;LACS;36400;36;INDRE;1
36092;;Langé;LANGE;36600;36;INDRE;1
36093;;Levroux;LEVROUX;36110;36;INDRE;1
36094;;Lignac;LIGNAC;36370;36;INDRE;1
36095;;Lignerolles;LIGNEROLLES;36160;36;INDRE;1
36096;;Lingé;LINGE;36220;36;INDRE;1
36097;;Liniez;LINIEZ;36150;36;INDRE;1
36098;;Lizeray;LIZERAY;36100;36;INDRE;1
36099;;Lourdoueix-Saint-Michel;LOURDOUEIX-SAINT-MICHEL;36140;36;INDRE;1
36100;;Lourouer-Saint-Laurent;LOUROUER-SAINT-LAURENT;36400;36;INDRE;1
36101;;Luant;LUANT;36350;36;INDRE;1
36102;;Luçay-le-Libre;LUCAY-LE-LIBRE;36150;36;INDRE;1
36103;;Luçay-le-Mâle;LUCAY-LE-MALE;36360;36;INDRE;1
36104;;Lurais;LURAIS;36220;36;INDRE;1
36105;;Lureuil;LUREUIL;36220;36;INDRE;1
36106;;Luzeret;LUZERET;36800;36;INDRE;1
36107;;Lye;LYE;36600;36;INDRE;1
36108;;Lys-Saint-Georges;LYS-SAINT-GEORGES;36230;36;INDRE;1
36109;Le;Magny;MAGNY;36400;36;INDRE;1
36110;;Maillet;MAILLET;36340;36;INDRE;1
36111;;Malicornay;MALICORNAY;36340;36;INDRE;1
36112;;Mâron;MARON;36120;36;INDRE;1
36113;;Martizay;MARTIZAY;36220;36;INDRE;1
36114;;Mauvières;MAUVIERES;36370;36;INDRE;1
36115;;Menetou-sur-Nahon;MENETOU-SUR-NAHON;36210;36;INDRE;1
36116;;Ménétréols-sous-Vatan;MENETREOLS-SOUS-VATAN;36150;36;INDRE;1
36117;Le;Menoux;MENOUX;36200;36;INDRE;1
36118;;Méobecq;MEOBECQ;36500;36;INDRE;1
36119;;Mérigny;MERIGNY;36220;36;INDRE;1
36120;;Mers-sur-Indre;MERS-SUR-INDRE;36230;36;INDRE;1
36121;;Meunet-Planches;MEUNET-PLANCHES;36100;36;INDRE;1
36122;;Meunet-sur-Vatan;MEUNET-SUR-VATAN;36150;36;INDRE;1
36123;;Mézières-en-Brenne;MEZIERES-EN-BRENNE;36290;36;INDRE;1
36124;;Migné;MIGNE;36800;36;INDRE;1
36125;;Migny;MIGNY;36260;36;INDRE;1
36126;;Montchevrier;MONTCHEVRIER;36140;36;INDRE;1
36127;;Montgivray;MONTGIVRAY;36400;36;INDRE;1
36128;;Montierchaume;MONTIERCHAUME;36130;36;INDRE;1
36129;;Montipouret;MONTIPOURET;36230;36;INDRE;1
36130;;Montlevicq;MONTLEVICQ;36400;36;INDRE;1
36131;;Mosnay;MOSNAY;36200;36;INDRE;1
36132;La;Motte-Feuilly;MOTTE-FEUILLY;36160;36;INDRE;1
36133;;Mouhers;MOUHERS;36340;36;INDRE;1
36134;;Mouhet;MOUHET;36170;36;INDRE;1
36135;;Moulins-sur-Céphons;MOULINS-SUR-CEPHONS;36110;36;INDRE;1
36136;;Murs;MURS;36700;36;INDRE;1
36137;;Néons-sur-Creuse;NEONS-SUR-CREUSE;36220;36;INDRE;1
36138;;Néret;NERET;36400;36;INDRE;1
36139;;Neuillay-les-Bois;NEUILLAY-LES-BOIS;36500;36;INDRE;1
36140;;Neuvy-Pailloux;NEUVY-PAILLOUX;36100;36;INDRE;1
36141;;Neuvy-Saint-Sépulchre;NEUVY-SAINT-SEPULCHRE;36230;36;INDRE;1
36142;;Niherne;NIHERNE;36250;36;INDRE;1
36143;;Nohant-Vic;NOHANT-VIC;36400;36;INDRE;1
36144;;Nuret-le-Ferron;NURET-LE-FERRON;36800;36;INDRE;1
36145;;Obterre;OBTERRE;36290;36;INDRE;1
36146;;Orsennes;ORSENNES;36190;36;INDRE;1
36147;;Orville;ORVILLE;36210;36;INDRE;1
36148;;Oulches;OULCHES;36800;36;INDRE;1
36149;;Palluau-sur-Indre;PALLUAU-SUR-INDRE;36500;36;INDRE;1
36150;;Parnac;PARNAC;36170;36;INDRE;1
36151;;Parpeçay;PARPECAY;36210;36;INDRE;1
36152;;Paudy;PAUDY;36260;36;INDRE;1
36153;;Paulnay;PAULNAY;36290;36;INDRE;1
36154;Le;Pêchereau;PECHEREAU;36200;36;INDRE;1
36155;;Pellevoisin;PELLEVOISIN;36180;36;INDRE;1
36156;;Pérassay;PERASSAY;36160;36;INDRE;1
36157;La;Pérouille;PEROUILLE;36350;36;INDRE;1
36158;;Badecon-le-Pin;BADECON-LE-PIN;36200;36;INDRE;1
36159;Le;Poinçonnet;POINCONNET;36330;36;INDRE;1
36160;;Pommiers;POMMIERS;36190;36;INDRE;1
36161;Le;Pont-Chrétien-Chabenet;PONT-CHRETIEN-CHABENET;36800;36;INDRE;1
36162;;Poulaines;POULAINES;36210;36;INDRE;1
36163;;Pouligny-Notre-Dame;POULIGNY-NOTRE-DAME;36160;36;INDRE;1
36164;;Pouligny-Saint-Martin;POULIGNY-SAINT-MARTIN;36160;36;INDRE;1
36165;;Pouligny-Saint-Pierre;POULIGNY-SAINT-PIERRE;36300;36;INDRE;1
36166;;Préaux;PREAUX;36240;36;INDRE;1
36167;;Preuilly-la-Ville;PREUILLY-LA-VILLE;36220;36;INDRE;1
36168;;Prissac;PRISSAC;36370;36;INDRE;1
36169;;Pruniers;PRUNIERS;36120;36;INDRE;1
36170;;Reboursin;REBOURSIN;36150;36;INDRE;1
36171;;Reuilly;REUILLY;36260;36;INDRE;1
36172;;Rivarennes;RIVARENNES;36800;36;INDRE;1
36173;;Rosnay;ROSNAY;36300;36;INDRE;1
36174;;Roussines;ROUSSINES;36170;36;INDRE;1
36175;;Rouvres-les-Bois;ROUVRES-LES-BOIS;36110;36;INDRE;1
36176;;Ruffec;RUFFEC;36300;36;INDRE;1
36177;;Sacierges-Saint-Martin;SACIERGES-SAINT-MARTIN;36170;36;INDRE;1
36178;;Saint-Aigny;SAINT-AIGNY;36300;36;INDRE;1
36179;;Saint-Aoustrille;SAINT-AOUSTRILLE;36100;36;INDRE;1
36180;;Saint-Août;SAINT-AOUT;36120;36;INDRE;1
36181;;Saint-Aubin;SAINT-AUBIN;36100;36;INDRE;1
36182;;Saint-Benoît-du-Sault;SAINT-BENOIT-DU-SAULT;36170;36;INDRE;1
36183;;Sainte-Cécile;SAINTE-CECILE;36210;36;INDRE;1
36184;;Saint-Chartier;SAINT-CHARTIER;36400;36;INDRE;1
36185;;Saint-Christophe-en-Bazelle;SAINT-CHRISTOPHE-EN-BAZELLE;36210;36;INDRE;1
36186;;Saint-Christophe-en-Boucherie;SAINT-CHRISTOPHE-EN-BOUCHERIE;36400;36;INDRE;1
36187;;Saint-Civran;SAINT-CIVRAN;36170;36;INDRE;1
36188;;Saint-Cyran-du-Jambot;SAINT-CYRAN-DU-JAMBOT;36700;36;INDRE;1
36189;;Saint-Denis-de-Jouhet;SAINT-DENIS-DE-JOUHET;36230;36;INDRE;1
36190;;Sainte-Fauste;SAINTE-FAUSTE;36100;36;INDRE;1
36191;;Saint-Florentin;SAINT-FLORENTIN;36150;36;INDRE;1
36192;;Saint-Gaultier;SAINT-GAULTIER;36800;36;INDRE;1
36193;;Sainte-Gemme;SAINTE-GEMME;36500;36;INDRE;1
36194;;Saint-Genou;SAINT-GENOU;36500;36;INDRE;1
36195;;Saint-Georges-sur-Arnon;SAINT-GEORGES-SUR-ARNON;36100;36;INDRE;1
36196;;Saint-Gilles;SAINT-GILLES;36170;36;INDRE;1
36197;;Saint-Hilaire-sur-Benaize;SAINT-HILAIRE-SUR-BENAIZE;36370;36;INDRE;1
36198;;Saint-Lactencin;SAINT-LACTENCIN;36500;36;INDRE;1
36199;;Sainte-Lizaigne;SAINTE-LIZAIGNE;36260;36;INDRE;1
36200;;Saint-Marcel;SAINT-MARCEL;36200;36;INDRE;1
36201;;Saint-Martin-de-Lamps;SAINT-MARTIN-DE-LAMPS;36110;36;INDRE;1
36202;;Saint-Maur;SAINT-MAUR;36250;36;INDRE;1
36203;;Saint-Médard;SAINT-MEDARD;36700;36;INDRE;1
36204;;Saint-Michel-en-Brenne;SAINT-MICHEL-EN-BRENNE;36290;36;INDRE;1
36205;;Saint-Pierre-de-Jards;SAINT-PIERRE-DE-JARDS;36260;36;INDRE;1
36206;;Saint-Pierre-de-Lamps;SAINT-PIERRE-DE-LAMPS;36110;36;INDRE;1
36207;;Saint-Plantaire;SAINT-PLANTAIRE;36190;36;INDRE;1
36208;;Sainte-Sévère-sur-Indre;SAINTE-SEVERE-SUR-INDRE;36160;36;INDRE;1
36209;;Saint-Valentin;SAINT-VALENTIN;36100;36;INDRE;1
36210;;Sarzay;SARZAY;36230;36;INDRE;1
36211;;Sassierges-Saint-Germain;SASSIERGES-SAINT-GERMAIN;36120;36;INDRE;1
36212;;Saulnay;SAULNAY;36290;36;INDRE;1
36213;;Sauzelles;SAUZELLES;36220;36;INDRE;1
36214;;Sazeray;SAZERAY;36160;36;INDRE;1
36215;;Ségry;SEGRY;36100;36;INDRE;1
36216;;Selles-sur-Nahon;SELLES-SUR-NAHON;36180;36;INDRE;1
36217;;Sembleçay;SEMBLECAY;36210;36;INDRE;1
36218;;Sougé;SOUGE;36500;36;INDRE;1
36219;;Tendu;TENDU;36200;36;INDRE;1
36220;;Thenay;THENAY;36800;36;INDRE;1
36221;;Thevet-Saint-Julien;THEVET-SAINT-JULIEN;36400;36;INDRE;1
36222;;Thizay;THIZAY;36100;36;INDRE;1
36223;;Tilly;TILLY;36310;36;INDRE;1
36224;;Tournon-Saint-Martin;TOURNON-SAINT-MARTIN;36220;36;INDRE;1
36225;Le;Tranger;TRANGER;36700;36;INDRE;1
36226;;Tranzault;TRANZAULT;36230;36;INDRE;1
36227;;Urciers;URCIERS;36160;36;INDRE;1
36228;;Valençay;VALENCAY;36600;36;INDRE;1
36229;;Varennes-sur-Fouzon;VARENNES-SUR-FOUZON;36210;36;INDRE;1
36230;;Vatan;VATAN;36150;36;INDRE;1
36231;;Velles;VELLES;36330;36;INDRE;1
36232;;Vendœuvres;VENDOEUVRES;36500;36;INDRE;1
36233;La;Vernelle;VERNELLE;36600;36;INDRE;1
36234;;Verneuil-sur-Igneraie;VERNEUIL-SUR-IGNERAIE;36400;36;INDRE;1
36235;;Veuil;VEUIL;36600;36;INDRE;1
36236;;Vicq-Exemplet;VICQ-EXEMPLET;36400;36;INDRE;1
36237;;Vicq-sur-Nahon;VICQ-SUR-NAHON;36600;36;INDRE;1
36238;;Vigoulant;VIGOULANT;36160;36;INDRE;1
36239;;Vigoux;VIGOUX;36170;36;INDRE;1
36240;;Vijon;VIJON;36160;36;INDRE;1
36241;;Villedieu-sur-Indre;VILLEDIEU-SUR-INDRE;36320;36;INDRE;1
36242;;Villegongis;VILLEGONGIS;36110;36;INDRE;1
36243;;Villegouin;VILLEGOUIN;36500;36;INDRE;1
36244;;Villentrois;VILLENTROIS;36600;36;INDRE;1
36245;;Villers-les-Ormes;VILLERS-LES-ORMES;36250;36;INDRE;1
36246;;Villiers;VILLIERS;36290;36;INDRE;1
36247;;Vineuil;VINEUIL;36110;36;INDRE;1
36248;;Vouillon;VOUILLON;36100;36;INDRE;1
37001;;Abilly;ABILLY;37160;37;INDRE ET LOIRE;1
37002;;Ambillou;AMBILLOU;37340;37;INDRE ET LOIRE;1
37003;;Amboise;AMBOISE;37400;37;INDRE ET LOIRE;1
37004;;Anché;ANCHE;37500;37;INDRE ET LOIRE;1
37005;;Antogny-le-Tillac;ANTOGNY-LE-TILLAC;37800;37;INDRE ET LOIRE;1
37006;;Artannes-sur-Indre;ARTANNES-SUR-INDRE;37260;37;INDRE ET LOIRE;1
37007;;Assay;ASSAY;37120;37;INDRE ET LOIRE;1
37008;;Athée-sur-Cher;ATHEE-SUR-CHER;37270;37;INDRE ET LOIRE;1
37009;;Autrèche;AUTRECHE;37110;37;INDRE ET LOIRE;1
37010;;Auzouer-en-Touraine;AUZOUER-EN-TOURAINE;37110;37;INDRE ET LOIRE;1
37011;;Avoine;AVOINE;37420;37;INDRE ET LOIRE;1
37012;;Avon-les-Roches;AVON-LES-ROCHES;37220;37;INDRE ET LOIRE;1
37013;;Avrillé-les-Ponceaux;AVRILLE-LES-PONCEAUX;37340;37;INDRE ET LOIRE;1
37014;;Azay-le-Rideau;AZAY-LE-RIDEAU;37190;37;INDRE ET LOIRE;1
37015;;Azay-sur-Cher;AZAY-SUR-CHER;37270;37;INDRE ET LOIRE;1
37016;;Azay-sur-Indre;AZAY-SUR-INDRE;37310;37;INDRE ET LOIRE;1
37018;;Ballan-Miré;BALLAN-MIRE;37510;37;INDRE ET LOIRE;1
37019;;Barrou;BARROU;37350;37;INDRE ET LOIRE;1
37020;;Beaulieu-lès-Loches;BEAULIEU-LES-LOCHES;37600;37;INDRE ET LOIRE;1
37021;;Beaumont-la-Ronce;BEAUMONT-LA-RONCE;37360;37;INDRE ET LOIRE;1
37022;;Beaumont-en-Véron;BEAUMONT-EN-VERON;37420;37;INDRE ET LOIRE;1
37023;;Beaumont-Village;BEAUMONT-VILLAGE;37460;37;INDRE ET LOIRE;1
37024;;Benais;BENAIS;37140;37;INDRE ET LOIRE;1
37025;;Berthenay;BERTHENAY;37510;37;INDRE ET LOIRE;1
37026;;Betz-le-Château;BETZ-LE-CHATEAU;37600;37;INDRE ET LOIRE;1
37027;;Bléré;BLERE;37150;37;INDRE ET LOIRE;1
37028;;Bossay-sur-Claise;BOSSAY-SUR-CLAISE;37290;37;INDRE ET LOIRE;1
37029;;Bossée;BOSSEE;37240;37;INDRE ET LOIRE;1
37030;Le;Boulay;BOULAY;37110;37;INDRE ET LOIRE;1
37031;;Bourgueil;BOURGUEIL;37140;37;INDRE ET LOIRE;1
37032;;Bournan;BOURNAN;37240;37;INDRE ET LOIRE;1
37033;;Boussay;BOUSSAY;37290;37;INDRE ET LOIRE;1
37034;;Braslou;BRASLOU;37120;37;INDRE ET LOIRE;1
37035;;Braye-sous-Faye;BRAYE-SOUS-FAYE;37120;37;INDRE ET LOIRE;1
37036;;Braye-sur-Maulne;BRAYE-SUR-MAULNE;37330;37;INDRE ET LOIRE;1
37037;;Brèches;BRECHES;37330;37;INDRE ET LOIRE;1
37038;;Bréhémont;BREHEMONT;37130;37;INDRE ET LOIRE;1
37039;;Bridoré;BRIDORE;37600;37;INDRE ET LOIRE;1
37040;;Brizay;BRIZAY;37220;37;INDRE ET LOIRE;1
37041;;Bueil-en-Touraine;BUEIL-EN-TOURAINE;37370;37;INDRE ET LOIRE;1
37042;;Candes-Saint-Martin;CANDES-SAINT-MARTIN;37500;37;INDRE ET LOIRE;1
37043;;Cangey;CANGEY;37530;37;INDRE ET LOIRE;1
37044;La;Celle-Guenand;CELLE-GUENAND;37350;37;INDRE ET LOIRE;1
37045;La;Celle-Saint-Avant;CELLE-SAINT-AVANT;37160;37;INDRE ET LOIRE;1
37046;;Céré-la-Ronde;CERE-LA-RONDE;37460;37;INDRE ET LOIRE;1
37047;;Cerelles;CERELLES;37390;37;INDRE ET LOIRE;1
37048;;Chambon;CHAMBON;37290;37;INDRE ET LOIRE;1
37049;;Chambourg-sur-Indre;CHAMBOURG-SUR-INDRE;37310;37;INDRE ET LOIRE;1
37050;;Chambray-lès-Tours;CHAMBRAY-LES-TOURS;37170;37;INDRE ET LOIRE;1
37051;;Champigny-sur-Veude;CHAMPIGNY-SUR-VEUDE;37120;37;INDRE ET LOIRE;1
37052;;Chançay;CHANCAY;37210;37;INDRE ET LOIRE;1
37053;;Chanceaux-près-Loches;CHANCEAUX-PRES-LOCHES;37600;37;INDRE ET LOIRE;1
37054;;Chanceaux-sur-Choisille;CHANCEAUX-SUR-CHOISILLE;37390;37;INDRE ET LOIRE;1
37055;;Channay-sur-Lathan;CHANNAY-SUR-LATHAN;37330;37;INDRE ET LOIRE;1
37056;La;Chapelle-aux-Naux;CHAPELLE-AUX-NAUX;37130;37;INDRE ET LOIRE;1
37057;La;Chapelle-Blanche-Saint-Martin;CHAPELLE-BLANCHE-SAINT-MARTIN;37240;37;INDRE ET LOIRE;1
37058;La;Chapelle-sur-Loire;CHAPELLE-SUR-LOIRE;37140;37;INDRE ET LOIRE;1
37059;;Charentilly;CHARENTILLY;37390;37;INDRE ET LOIRE;1
37060;;Chargé;CHARGE;37530;37;INDRE ET LOIRE;1
37061;;Charnizay;CHARNIZAY;37290;37;INDRE ET LOIRE;1
37062;;Château-la-Vallière;CHATEAU-LA-VALLIERE;37330;37;INDRE ET LOIRE;1
37063;;Château-Renault;CHATEAU-RENAULT;37110;37;INDRE ET LOIRE;1
37064;;Chaumussay;CHAUMUSSAY;37350;37;INDRE ET LOIRE;1
37065;;Chaveignes;CHAVEIGNES;37120;37;INDRE ET LOIRE;1
37066;;Chédigny;CHEDIGNY;37310;37;INDRE ET LOIRE;1
37067;;Cheillé;CHEILLE;37190;37;INDRE ET LOIRE;1
37068;;Chemillé-sur-Dême;CHEMILLE-SUR-DEME;37370;37;INDRE ET LOIRE;1
37069;;Chemillé-sur-Indrois;CHEMILLE-SUR-INDROIS;37460;37;INDRE ET LOIRE;1
37070;;Chenonceaux;CHENONCEAUX;37150;37;INDRE ET LOIRE;1
37071;;Chezelles;CHEZELLES;37220;37;INDRE ET LOIRE;1
37072;;Chinon;CHINON;37500;37;INDRE ET LOIRE;1
37073;;Chisseaux;CHISSEAUX;37150;37;INDRE ET LOIRE;1
37074;;Chouzé-sur-Loire;CHOUZE-SUR-LOIRE;37140;37;INDRE ET LOIRE;1
37075;;Cigogné;CIGOGNE;37310;37;INDRE ET LOIRE;1
37076;;Cinais;CINAIS;37500;37;INDRE ET LOIRE;1
37077;;Cinq-Mars-la-Pile;CINQ-MARS-LA-PILE;37130;37;INDRE ET LOIRE;1
37078;;Ciran;CIRAN;37240;37;INDRE ET LOIRE;1
37079;;Civray-de-Touraine;CIVRAY-DE-TOURAINE;37150;37;INDRE ET LOIRE;1
37080;;Civray-sur-Esves;CIVRAY-SUR-ESVES;37160;37;INDRE ET LOIRE;1
37081;;Cléré-les-Pins;CLERE-LES-PINS;37340;37;INDRE ET LOIRE;1
37082;;Continvoir;CONTINVOIR;37340;37;INDRE ET LOIRE;1
37083;;Cormery;CORMERY;37320;37;INDRE ET LOIRE;1
37084;;Couesmes;COUESMES;37330;37;INDRE ET LOIRE;1
37085;;Courçay;COURCAY;37310;37;INDRE ET LOIRE;1
37086;;Courcelles-de-Touraine;COURCELLES-DE-TOURAINE;37330;37;INDRE ET LOIRE;1
37087;;Courcoué;COURCOUE;37120;37;INDRE ET LOIRE;1
37088;;Couziers;COUZIERS;37500;37;INDRE ET LOIRE;1
37089;;Cravant-les-Côteaux;CRAVANT-LES-COTEAUX;37500;37;INDRE ET LOIRE;1
37090;;Crissay-sur-Manse;CRISSAY-SUR-MANSE;37220;37;INDRE ET LOIRE;1
37091;La;Croix-en-Touraine;CROIX-EN-TOURAINE;37150;37;INDRE ET LOIRE;1
37092;;Crotelles;CROTELLES;37380;37;INDRE ET LOIRE;1
37093;;Crouzilles;CROUZILLES;37220;37;INDRE ET LOIRE;1
37094;;Cussay;CUSSAY;37240;37;INDRE ET LOIRE;1
37095;;Dame-Marie-les-Bois;DAME-MARIE-LES-BOIS;37110;37;INDRE ET LOIRE;1
37096;;Dierre;DIERRE;37150;37;INDRE ET LOIRE;1
37097;;Dolus-le-Sec;DOLUS-LE-SEC;37310;37;INDRE ET LOIRE;1
37098;;Draché;DRACHE;37800;37;INDRE ET LOIRE;1
37099;;Druye;DRUYE;37190;37;INDRE ET LOIRE;1
37100;;Épeigné-les-Bois;EPEIGNE-LES-BOIS;37150;37;INDRE ET LOIRE;1
37101;;Épeigné-sur-Dême;EPEIGNE-SUR-DEME;37370;37;INDRE ET LOIRE;1
37102;Les;Essards;ESSARDS;37130;37;INDRE ET LOIRE;1
37103;;Esves-le-Moutier;ESVES-LE-MOUTIER;37240;37;INDRE ET LOIRE;1
37104;;Esvres;ESVRES;37320;37;INDRE ET LOIRE;1
37105;;Faye-la-Vineuse;FAYE-LA-VINEUSE;37120;37;INDRE ET LOIRE;1
37106;La;Ferrière;FERRIERE;37110;37;INDRE ET LOIRE;1
37107;;Ferrière-Larçon;FERRIERE-LARCON;37350;37;INDRE ET LOIRE;1
37108;;Ferrière-sur-Beaulieu;FERRIERE-SUR-BEAULIEU;37600;37;INDRE ET LOIRE;1
37109;;Fondettes;FONDETTES;37230;37;INDRE ET LOIRE;1
37110;;Francueil;FRANCUEIL;37150;37;INDRE ET LOIRE;1
37111;;Genillé;GENILLE;37460;37;INDRE ET LOIRE;1
37112;;Gizeux;GIZEUX;37340;37;INDRE ET LOIRE;1
37113;Le;Grand-Pressigny;GRAND-PRESSIGNY;37350;37;INDRE ET LOIRE;1
37114;La;Guerche;GUERCHE;37350;37;INDRE ET LOIRE;1
37115;;Descartes;DESCARTES;37160;37;INDRE ET LOIRE;1
37116;Les;Hermites;HERMITES;37110;37;INDRE ET LOIRE;1
37117;;Hommes;HOMMES;37340;37;INDRE ET LOIRE;1
37118;;Huismes;HUISMES;37420;37;INDRE ET LOIRE;1
37119;L';Île-Bouchard;ILE-BOUCHARD;37220;37;INDRE ET LOIRE;1
37120;;Ingrandes-de-Touraine;INGRANDES-DE-TOURAINE;37140;37;INDRE ET LOIRE;1
37121;;Jaulnay;JAULNAY;37120;37;INDRE ET LOIRE;1
37122;;Joué-lès-Tours;JOUE-LES-TOURS;37300;37;INDRE ET LOIRE;1
37123;;Langeais;LANGEAIS;37130;37;INDRE ET LOIRE;1
37124;;Larçay;LARCAY;37270;37;INDRE ET LOIRE;1
37125;;Lémeré;LEMERE;37120;37;INDRE ET LOIRE;1
37126;;Lerné;LERNE;37500;37;INDRE ET LOIRE;1
37127;Le;Liège;LIEGE;37460;37;INDRE ET LOIRE;1
37128;;Lignières-de-Touraine;LIGNIERES-DE-TOURAINE;37130;37;INDRE ET LOIRE;1
37129;;Ligré;LIGRE;37500;37;INDRE ET LOIRE;1
37130;;Ligueil;LIGUEIL;37240;37;INDRE ET LOIRE;1
37131;;Limeray;LIMERAY;37530;37;INDRE ET LOIRE;1
37132;;Loches;LOCHES;37600;37;INDRE ET LOIRE;1
37133;;Loché-sur-Indrois;LOCHE-SUR-INDROIS;37460;37;INDRE ET LOIRE;1
37134;;Louans;LOUANS;37320;37;INDRE ET LOIRE;1
37135;;Louestault;LOUESTAULT;37370;37;INDRE ET LOIRE;1
37136;Le;Louroux;LOUROUX;37240;37;INDRE ET LOIRE;1
37137;;Lublé;LUBLE;37330;37;INDRE ET LOIRE;1
37138;;Lussault-sur-Loire;LUSSAULT-SUR-LOIRE;37400;37;INDRE ET LOIRE;1
37139;;Luynes;LUYNES;37230;37;INDRE ET LOIRE;1
37140;;Luzé;LUZE;37120;37;INDRE ET LOIRE;1
37141;;Luzillé;LUZILLE;37150;37;INDRE ET LOIRE;1
37142;;Maillé;MAILLE;37800;37;INDRE ET LOIRE;1
37143;;Manthelan;MANTHELAN;37240;37;INDRE ET LOIRE;1
37144;;Marçay;MARCAY;37500;37;INDRE ET LOIRE;1
37145;;Marcé-sur-Esves;MARCE-SUR-ESVES;37160;37;INDRE ET LOIRE;1
37146;;Marcilly-sur-Maulne;MARCILLY-SUR-MAULNE;37330;37;INDRE ET LOIRE;1
37147;;Marcilly-sur-Vienne;MARCILLY-SUR-VIENNE;37800;37;INDRE ET LOIRE;1
37148;;Marigny-Marmande;MARIGNY-MARMANDE;37120;37;INDRE ET LOIRE;1
37149;;Marray;MARRAY;37370;37;INDRE ET LOIRE;1
37150;;Mazières-de-Touraine;MAZIERES-DE-TOURAINE;37130;37;INDRE ET LOIRE;1
37151;La;Membrolle-sur-Choisille;MEMBROLLE-SUR-CHOISILLE;37390;37;INDRE ET LOIRE;1
37152;;Mettray;METTRAY;37390;37;INDRE ET LOIRE;1
37153;;Monnaie;MONNAIE;37380;37;INDRE ET LOIRE;1
37154;;Montbazon;MONTBAZON;37250;37;INDRE ET LOIRE;1
37155;;Monthodon;MONTHODON;37110;37;INDRE ET LOIRE;1
37156;;Montlouis-sur-Loire;MONTLOUIS-SUR-LOIRE;37270;37;INDRE ET LOIRE;1
37157;;Montrésor;MONTRESOR;37460;37;INDRE ET LOIRE;1
37158;;Montreuil-en-Touraine;MONTREUIL-EN-TOURAINE;37530;37;INDRE ET LOIRE;1
37159;;Monts;MONTS;37260;37;INDRE ET LOIRE;1
37160;;Morand;MORAND;37110;37;INDRE ET LOIRE;1
37161;;Mosnes;MOSNES;37530;37;INDRE ET LOIRE;1
37162;;Mouzay;MOUZAY;37600;37;INDRE ET LOIRE;1
37163;;Nazelles-Négron;NAZELLES-NEGRON;37530;37;INDRE ET LOIRE;1
37165;;Neuil;NEUIL;37190;37;INDRE ET LOIRE;1
37166;;Neuillé-le-Lierre;NEUILLE-LE-LIERRE;37380;37;INDRE ET LOIRE;1
37167;;Neuillé-Pont-Pierre;NEUILLE-PONT-PIERRE;37360;37;INDRE ET LOIRE;1
37168;;Neuilly-le-Brignon;NEUILLY-LE-BRIGNON;37160;37;INDRE ET LOIRE;1
37169;;Neuville-sur-Brenne;NEUVILLE-SUR-BRENNE;37110;37;INDRE ET LOIRE;1
37170;;Neuvy-le-Roi;NEUVY-LE-ROI;37370;37;INDRE ET LOIRE;1
37171;;Noizay;NOIZAY;37210;37;INDRE ET LOIRE;1
37172;;Notre-Dame-d'Oé;NOTRE-DAME-D'OE;37390;37;INDRE ET LOIRE;1
37173;;Nouans-les-Fontaines;NOUANS-LES-FONTAINES;37460;37;INDRE ET LOIRE;1
37174;;Nouâtre;NOUATRE;37800;37;INDRE ET LOIRE;1
37175;;Nouzilly;NOUZILLY;37380;37;INDRE ET LOIRE;1
37176;;Noyant-de-Touraine;NOYANT-DE-TOURAINE;37800;37;INDRE ET LOIRE;1
37177;;Orbigny;ORBIGNY;37460;37;INDRE ET LOIRE;1
37178;;Panzoult;PANZOULT;37220;37;INDRE ET LOIRE;1
37179;;Parçay-Meslay;PARCAY-MESLAY;37210;37;INDRE ET LOIRE;1
37180;;Parçay-sur-Vienne;PARCAY-SUR-VIENNE;37220;37;INDRE ET LOIRE;1
37181;;Paulmy;PAULMY;37350;37;INDRE ET LOIRE;1
37182;;Pernay;PERNAY;37230;37;INDRE ET LOIRE;1
37183;;Perrusson;PERRUSSON;37600;37;INDRE ET LOIRE;1
37184;Le;Petit-Pressigny;PETIT-PRESSIGNY;37350;37;INDRE ET LOIRE;1
37185;;Pocé-sur-Cisse;POCE-SUR-CISSE;37530;37;INDRE ET LOIRE;1
37186;;Pont-de-Ruan;PONT-DE-RUAN;37260;37;INDRE ET LOIRE;1
37187;;Ports;PORTS;37800;37;INDRE ET LOIRE;1
37188;;Pouzay;POUZAY;37800;37;INDRE ET LOIRE;1
37189;;Preuilly-sur-Claise;PREUILLY-SUR-CLAISE;37290;37;INDRE ET LOIRE;1
37190;;Pussigny;PUSSIGNY;37800;37;INDRE ET LOIRE;1
37191;;Razines;RAZINES;37120;37;INDRE ET LOIRE;1
37192;;Reignac-sur-Indre;REIGNAC-SUR-INDRE;37310;37;INDRE ET LOIRE;1
37193;;Restigné;RESTIGNE;37140;37;INDRE ET LOIRE;1
37194;;Reugny;REUGNY;37380;37;INDRE ET LOIRE;1
37195;La;Riche;RICHE;37520;37;INDRE ET LOIRE;1
37196;;Richelieu;RICHELIEU;37120;37;INDRE ET LOIRE;1
37197;;Rigny-Ussé;RIGNY-USSE;37420;37;INDRE ET LOIRE;1
37198;;Rillé;RILLE;37340;37;INDRE ET LOIRE;1
37199;;Rilly-sur-Vienne;RILLY-SUR-VIENNE;37220;37;INDRE ET LOIRE;1
37200;;Rivarennes;RIVARENNES;37190;37;INDRE ET LOIRE;1
37201;;Rivière;RIVIERE;37500;37;INDRE ET LOIRE;1
37202;La;Roche-Clermault;ROCHE-CLERMAULT;37500;37;INDRE ET LOIRE;1
37203;;Rochecorbon;ROCHECORBON;37210;37;INDRE ET LOIRE;1
37204;;Rouziers-de-Touraine;ROUZIERS-DE-TOURAINE;37360;37;INDRE ET LOIRE;1
37205;;Saché;SACHE;37190;37;INDRE ET LOIRE;1
37206;;Saint-Antoine-du-Rocher;SAINT-ANTOINE-DU-ROCHER;37360;37;INDRE ET LOIRE;1
37207;;Saint-Aubin-le-Dépeint;SAINT-AUBIN-LE-DEPEINT;37370;37;INDRE ET LOIRE;1
37208;;Saint-Avertin;SAINT-AVERTIN;37550;37;INDRE ET LOIRE;1
37209;;Saint-Bauld;SAINT-BAULD;37310;37;INDRE ET LOIRE;1
37210;;Saint-Benoît-la-Forêt;SAINT-BENOIT-LA-FORET;37500;37;INDRE ET LOIRE;1
37211;;Saint-Branchs;SAINT-BRANCHS;37320;37;INDRE ET LOIRE;1
37212;;Sainte-Catherine-de-Fierbois;SAINTE-CATHERINE-DE-FIERBOIS;37800;37;INDRE ET LOIRE;1
37213;;Saint-Christophe-sur-le-Nais;SAINT-CHRISTOPHE-SUR-LE-NAIS;37370;37;INDRE ET LOIRE;1
37214;;Saint-Cyr-sur-Loire;SAINT-CYR-SUR-LOIRE;37540;37;INDRE ET LOIRE;1
37216;;Saint-Épain;SAINT-EPAIN;37800;37;INDRE ET LOIRE;1
37217;;Saint-Étienne-de-Chigny;SAINT-ETIENNE-DE-CHIGNY;37230;37;INDRE ET LOIRE;1
37218;;Saint-Flovier;SAINT-FLOVIER;37600;37;INDRE ET LOIRE;1
37219;;Saint-Genouph;SAINT-GENOUPH;37510;37;INDRE ET LOIRE;1
37220;;Saint-Germain-sur-Vienne;SAINT-GERMAIN-SUR-VIENNE;37500;37;INDRE ET LOIRE;1
37221;;Saint-Hippolyte;SAINT-HIPPOLYTE;37600;37;INDRE ET LOIRE;1
37222;;Saint-Jean-Saint-Germain;SAINT-JEAN-SAINT-GERMAIN;37600;37;INDRE ET LOIRE;1
37223;;Saint-Laurent-de-Lin;SAINT-LAURENT-DE-LIN;37330;37;INDRE ET LOIRE;1
37224;;Saint-Laurent-en-Gâtines;SAINT-LAURENT-EN-GATINES;37380;37;INDRE ET LOIRE;1
37225;;Saint-Martin-le-Beau;SAINT-MARTIN-LE-BEAU;37270;37;INDRE ET LOIRE;1
37226;;Sainte-Maure-de-Touraine;SAINTE-MAURE-DE-TOURAINE;37800;37;INDRE ET LOIRE;1
37227;;Saint-Michel-sur-Loire;SAINT-MICHEL-SUR-LOIRE;37130;37;INDRE ET LOIRE;1
37228;;Saint-Nicolas-de-Bourgueil;SAINT-NICOLAS-DE-BOURGUEIL;37140;37;INDRE ET LOIRE;1
37229;;Saint-Nicolas-des-Motets;SAINT-NICOLAS-DES-MOTETS;37110;37;INDRE ET LOIRE;1
37230;;Saint-Ouen-les-Vignes;SAINT-OUEN-LES-VIGNES;37530;37;INDRE ET LOIRE;1
37231;;Saint-Paterne-Racan;SAINT-PATERNE-RACAN;37370;37;INDRE ET LOIRE;1
37232;;Saint-Patrice;SAINT-PATRICE;37130;37;INDRE ET LOIRE;1
37233;;Saint-Pierre-des-Corps;SAINT-PIERRE-DES-CORPS;37700;37;INDRE ET LOIRE;1
37234;;Saint-Quentin-sur-Indrois;SAINT-QUENTIN-SUR-INDROIS;37310;37;INDRE ET LOIRE;1
37236;;Saint-Règle;SAINT-REGLE;37530;37;INDRE ET LOIRE;1
37237;;Saint-Roch;SAINT-ROCH;37390;37;INDRE ET LOIRE;1
37238;;Saint-Senoch;SAINT-SENOCH;37600;37;INDRE ET LOIRE;1
37240;;Saunay;SAUNAY;37110;37;INDRE ET LOIRE;1
37241;;Savigné-sur-Lathan;SAVIGNE-SUR-LATHAN;37340;37;INDRE ET LOIRE;1
37242;;Savigny-en-Véron;SAVIGNY-EN-VERON;37420;37;INDRE ET LOIRE;1
37243;;Savonnières;SAVONNIERES;37510;37;INDRE ET LOIRE;1
37244;;Sazilly;SAZILLY;37220;37;INDRE ET LOIRE;1
37245;;Semblançay;SEMBLANCAY;37360;37;INDRE ET LOIRE;1
37246;;Sennevières;SENNEVIERES;37600;37;INDRE ET LOIRE;1
37247;;Sepmes;SEPMES;37800;37;INDRE ET LOIRE;1
37248;;Seuilly;SEUILLY;37500;37;INDRE ET LOIRE;1
37249;;Sonzay;SONZAY;37360;37;INDRE ET LOIRE;1
37250;;Sorigny;SORIGNY;37250;37;INDRE ET LOIRE;1
37251;;Souvigné;SOUVIGNE;37330;37;INDRE ET LOIRE;1
37252;;Souvigny-de-Touraine;SOUVIGNY-DE-TOURAINE;37530;37;INDRE ET LOIRE;1
37253;;Sublaines;SUBLAINES;37310;37;INDRE ET LOIRE;1
37254;;Tauxigny;TAUXIGNY;37310;37;INDRE ET LOIRE;1
37255;;Tavant;TAVANT;37220;37;INDRE ET LOIRE;1
37256;;Theneuil;THENEUIL;37220;37;INDRE ET LOIRE;1
37257;;Thilouze;THILOUZE;37260;37;INDRE ET LOIRE;1
37258;;Thizay;THIZAY;37500;37;INDRE ET LOIRE;1
37259;;Tournon-Saint-Pierre;TOURNON-SAINT-PIERRE;37290;37;INDRE ET LOIRE;1
37260;La;Tour-Saint-Gelin;TOUR-SAINT-GELIN;37120;37;INDRE ET LOIRE;1
37261;;Tours;TOURS;37000;37;INDRE ET LOIRE;1
37262;;Trogues;TROGUES;37220;37;INDRE ET LOIRE;1
37263;;Truyes;TRUYES;37320;37;INDRE ET LOIRE;1
37264;;Vallères;VALLERES;37190;37;INDRE ET LOIRE;1
37265;;Varennes;VARENNES;37600;37;INDRE ET LOIRE;1
37266;;Veigné;VEIGNE;37250;37;INDRE ET LOIRE;1
37267;;Véretz;VERETZ;37270;37;INDRE ET LOIRE;1
37268;;Verneuil-le-Château;VERNEUIL-LE-CHATEAU;37120;37;INDRE ET LOIRE;1
37269;;Verneuil-sur-Indre;VERNEUIL-SUR-INDRE;37600;37;INDRE ET LOIRE;1
37270;;Vernou-sur-Brenne;VERNOU-SUR-BRENNE;37210;37;INDRE ET LOIRE;1
37271;;Villaines-les-Rochers;VILLAINES-LES-ROCHERS;37190;37;INDRE ET LOIRE;1
37272;;Villandry;VILLANDRY;37510;37;INDRE ET LOIRE;1
37273;La;Ville-aux-Dames;VILLE-AUX-DAMES;37700;37;INDRE ET LOIRE;1
37274;;Villebourg;VILLEBOURG;37370;37;INDRE ET LOIRE;1
37275;;Villedômain;VILLEDOMAIN;37460;37;INDRE ET LOIRE;1
37276;;Villedômer;VILLEDOMER;37110;37;INDRE ET LOIRE;1
37277;;Villeloin-Coulangé;VILLELOIN-COULANGE;37460;37;INDRE ET LOIRE;1
37278;;Villeperdue;VILLEPERDUE;37260;37;INDRE ET LOIRE;1
37279;;Villiers-au-Bouin;VILLIERS-AU-BOUIN;37330;37;INDRE ET LOIRE;1
37280;;Vou;VOU;37240;37;INDRE ET LOIRE;1
37281;;Vouvray;VOUVRAY;37210;37;INDRE ET LOIRE;1
37282;;Yzeures-sur-Creuse;YZEURES-SUR-CREUSE;37290;37;INDRE ET LOIRE;1
38001;Les;Abrets;ABRETS;38490;38;ISERE;1
38002;Les;Adrets;ADRETS;38190;38;ISERE;1
38003;;Agnin;AGNIN;38150;38;ISERE;1
38004;L';Albenc;ALBENC;38470;38;ISERE;1
38005;;Allemond;ALLEMOND;38114;38;ISERE;1
38006;;Allevard;ALLEVARD;38580;38;ISERE;1
38008;;Ambel;AMBEL;38970;38;ISERE;1
38009;;Anjou;ANJOU;38150;38;ISERE;1
38010;;Annoisin-Chatelans;ANNOISIN-CHATELANS;38460;38;ISERE;1
38011;;Anthon;ANTHON;38280;38;ISERE;1
38012;;Aoste;AOSTE;38490;38;ISERE;1
38013;;Apprieu;APPRIEU;38140;38;ISERE;1
38014;;Arandon;ARANDON;38510;38;ISERE;1
38015;;Artas;ARTAS;38440;38;ISERE;1
38016;;Arzay;ARZAY;38260;38;ISERE;1
38017;;Assieu;ASSIEU;38150;38;ISERE;1
38018;;Auberives-en-Royans;AUBERIVES-EN-ROYANS;38680;38;ISERE;1
38019;;Auberives-sur-Varèze;AUBERIVES-SUR-VAREZE;38550;38;ISERE;1
38020;;Auris;AURIS;38142;38;ISERE;1
38021;;Autrans;AUTRANS;38880;38;ISERE;1
38022;Les;Avenières;AVENIERES;38630;38;ISERE;1
38023;;Avignonet;AVIGNONET;38650;38;ISERE;1
38024;;Badinières;BADINIERES;38300;38;ISERE;1
38025;;Balbins;BALBINS;38260;38;ISERE;1
38026;La;Balme-les-Grottes;BALME-LES-GROTTES;38390;38;ISERE;1
38027;;Barraux;BARRAUX;38530;38;ISERE;1
38028;La;Bâtie-Divisin;BATIE-DIVISIN;38490;38;ISERE;1
38029;La;Bâtie-Montgascon;BATIE-MONTGASCON;38110;38;ISERE;1
38030;;Beaucroissant;BEAUCROISSANT;38140;38;ISERE;1
38031;;Beaufin;BEAUFIN;38970;38;ISERE;1
38032;;Beaufort;BEAUFORT;38270;38;ISERE;1
38033;;Beaulieu;BEAULIEU;38470;38;ISERE;1
38034;;Beaurepaire;BEAUREPAIRE;38270;38;ISERE;1
38035;;Beauvoir-de-Marc;BEAUVOIR-DE-MARC;38440;38;ISERE;1
38036;;Beauvoir-en-Royans;BEAUVOIR-EN-ROYANS;38160;38;ISERE;1
38037;;Bellegarde-Poussieu;BELLEGARDE-POUSSIEU;38270;38;ISERE;1
38038;;Belmont;BELMONT;38690;38;ISERE;1
38039;;Bernin;BERNIN;38190;38;ISERE;1
38040;;Besse;BESSE;38142;38;ISERE;1
38041;;Bessins;BESSINS;38160;38;ISERE;1
38042;;Bévenais;BEVENAIS;38690;38;ISERE;1
38043;;Bilieu;BILIEU;38850;38;ISERE;1
38044;;Biol;BIOL;38690;38;ISERE;1
38045;;Biviers;BIVIERS;38330;38;ISERE;1
38046;;Bizonnes;BIZONNES;38690;38;ISERE;1
38047;;Blandin;BLANDIN;38730;38;ISERE;1
38048;;Bonnefamille;BONNEFAMILLE;38090;38;ISERE;1
38049;;Bossieu;BOSSIEU;38260;38;ISERE;1
38050;Le;Bouchage;BOUCHAGE;38510;38;ISERE;1
38051;;Bougé-Chambalud;BOUGE-CHAMBALUD;38150;38;ISERE;1
38052;Le;Bourg-d'Oisans;BOURG-D'OISANS;38520;38;ISERE;1
38053;;Bourgoin-Jallieu;BOURGOIN-JALLIEU;38300;38;ISERE;1
38054;;Bouvesse-Quirieu;BOUVESSE-QUIRIEU;38390;38;ISERE;1
38055;;Brangues;BRANGUES;38510;38;ISERE;1
38056;;Bressieux;BRESSIEUX;38870;38;ISERE;1
38057;;Bresson;BRESSON;38320;38;ISERE;1
38058;;Brézins;BREZINS;38590;38;ISERE;1
38059;;Brié-et-Angonnes;BRIE-ET-ANGONNES;38320;38;ISERE;1
38060;;Brion;BRION;38590;38;ISERE;1
38061;La;Buisse;BUISSE;38500;38;ISERE;1
38062;La;Buissière;BUISSIERE;38530;38;ISERE;1
38063;;Burcin;BURCIN;38690;38;ISERE;1
38064;;Cessieu;CESSIEU;38110;38;ISERE;1
38065;;Châbons;CHABONS;38690;38;ISERE;1
38066;;Châlons;CHALONS;38122;38;ISERE;1
38067;;Chamagnieu;CHAMAGNIEU;38460;38;ISERE;1
38068;;Champagnier;CHAMPAGNIER;38800;38;ISERE;1
38069;;Champier;CHAMPIER;38260;38;ISERE;1
38070;Le;Champ-près-Froges;CHAMP-PRES-FROGES;38190;38;ISERE;1
38071;;Champ-sur-Drac;CHAMP-SUR-DRAC;38560;38;ISERE;1
38072;;Chanas;CHANAS;38150;38;ISERE;1
38073;;Chantelouve;CHANTELOUVE;38740;38;ISERE;1
38074;;Chantesse;CHANTESSE;38470;38;ISERE;1
38075;;Chapareillan;CHAPAREILLAN;38530;38;ISERE;1
38076;La;Chapelle-de-la-Tour;CHAPELLE-DE-LA-TOUR;38110;38;ISERE;1
38077;La;Chapelle-de-Surieu;CHAPELLE-DE-SURIEU;38150;38;ISERE;1
38078;La;Chapelle-du-Bard;CHAPELLE-DU-BARD;38580;38;ISERE;1
38080;;Charancieu;CHARANCIEU;38490;38;ISERE;1
38081;;Charantonnay;CHARANTONNAY;38790;38;ISERE;1
38082;;Charavines;CHARAVINES;38850;38;ISERE;1
38083;;Charette;CHARETTE;38390;38;ISERE;1
38084;;Charnècles;CHARNECLES;38140;38;ISERE;1
38085;;Charvieu-Chavagneux;CHARVIEU-CHAVAGNEUX;38230;38;ISERE;1
38086;;Chasselay;CHASSELAY;38470;38;ISERE;1
38087;;Chasse-sur-Rhône;CHASSE-SUR-RHONE;38670;38;ISERE;1
38089;;Chassignieu;CHASSIGNIEU;38730;38;ISERE;1
38090;;Château-Bernard;CHATEAU-BERNARD;38650;38;ISERE;1
38091;;Châteauvilain;CHATEAUVILAIN;38300;38;ISERE;1
38092;;Châtelus;CHATELUS;38680;38;ISERE;1
38093;;Châtenay;CHATENAY;38980;38;ISERE;1
38094;;Châtonnay;CHATONNAY;38440;38;ISERE;1
38095;;Chatte;CHATTE;38160;38;ISERE;1
38097;;Chavanoz;CHAVANOZ;38230;38;ISERE;1
38098;;Chélieu;CHELIEU;38730;38;ISERE;1
38099;;Chevrières;CHEVRIERES;38160;38;ISERE;1
38100;Le;Cheylas;CHEYLAS;38570;38;ISERE;1
38101;;Cheyssieu;CHEYSSIEU;38550;38;ISERE;1
38102;;Chèzeneuve;CHEZENEUVE;38300;38;ISERE;1
38103;;Chichilianne;CHICHILIANNE;38930;38;ISERE;1
38104;;Chimilin;CHIMILIN;38490;38;ISERE;1
38105;;Chirens;CHIRENS;38850;38;ISERE;1
38106;;Cholonge;CHOLONGE;38220;38;ISERE;1
38107;;Chonas-l'Amballan;CHONAS-L'AMBALLAN;38121;38;ISERE;1
38108;;Choranche;CHORANCHE;38680;38;ISERE;1
38109;;Chozeau;CHOZEAU;38460;38;ISERE;1
38110;;Chuzelles;CHUZELLES;38200;38;ISERE;1
38111;;Claix;CLAIX;38640;38;ISERE;1
38112;;Clavans-en-Haut-Oisans;CLAVANS-EN-HAUT-OISANS;38142;38;ISERE;1
38113;;Clelles;CLELLES;38930;38;ISERE;1
38114;;Clonas-sur-Varèze;CLONAS-SUR-VAREZE;38550;38;ISERE;1
38115;;Saint-Martin-de-la-Cluze;SAINT-MARTIN-DE-LA-CLUZE;38650;38;ISERE;1
38116;;Cognet;COGNET;38350;38;ISERE;1
38117;;Cognin-les-Gorges;COGNIN-LES-GORGES;38470;38;ISERE;1
38118;;Colombe;COLOMBE;38690;38;ISERE;1
38120;La;Combe-de-Lancey;COMBE-DE-LANCEY;38190;38;ISERE;1
38121;;Commelle;COMMELLE;38260;38;ISERE;1
38124;;Corbelin;CORBELIN;38630;38;ISERE;1
38125;;Cordéac;CORDEAC;38710;38;ISERE;1
38126;;Corenc;CORENC;38700;38;ISERE;1
38127;;Cornillon-en-Trièves;CORNILLON-EN-TRIEVES;38710;38;ISERE;1
38128;;Corps;CORPS;38970;38;ISERE;1
38129;;Corrençon-en-Vercors;CORRENCON-EN-VERCORS;38250;38;ISERE;1
38130;La;Côte-Saint-André;COTE-SAINT-ANDRE;38260;38;ISERE;1
38131;Les;Côtes-d'Arey;COTES-D'AREY;38138;38;ISERE;1
38132;Les;Côtes-de-Corps;COTES-DE-CORPS;38970;38;ISERE;1
38133;;Coublevie;COUBLEVIE;38500;38;ISERE;1
38134;;Cour-et-Buis;COUR-ET-BUIS;38122;38;ISERE;1
38135;;Courtenay;COURTENAY;38510;38;ISERE;1
38136;;Crachier;CRACHIER;38300;38;ISERE;1
38137;;Cras;CRAS;38210;38;ISERE;1
38138;;Crémieu;CREMIEU;38460;38;ISERE;1
38139;;Creys-Mépieu;CREYS-MEPIEU;38510;38;ISERE;1
38140;;Crolles;CROLLES;38190;38;ISERE;1
38141;;Culin;CULIN;38300;38;ISERE;1
38144;;Diémoz;DIEMOZ;38790;38;ISERE;1
38145;;Dionay;DIONAY;38160;38;ISERE;1
38146;;Dizimieu;DIZIMIEU;38460;38;ISERE;1
38147;;Doissin;DOISSIN;38730;38;ISERE;1
38148;;Dolomieu;DOLOMIEU;38110;38;ISERE;1
38149;;Domarin;DOMARIN;38300;38;ISERE;1
38150;;Domène;DOMENE;38420;38;ISERE;1
38151;;Échirolles;ECHIROLLES;38130;38;ISERE;1
38152;;Eclose;ECLOSE;38300;38;ISERE;1
38153;;Engins;ENGINS;38360;38;ISERE;1
38154;;Entraigues;ENTRAIGUES;38740;38;ISERE;1
38155;;Entre-deux-Guiers;ENTRE-DEUX-GUIERS;38380;38;ISERE;1
38156;Les;Éparres;EPARRES;38300;38;ISERE;1
38157;;Estrablin;ESTRABLIN;38780;38;ISERE;1
38158;;Eybens;EYBENS;38320;38;ISERE;1
38159;;Eydoche;EYDOCHE;38690;38;ISERE;1
38160;;Eyzin-Pinet;EYZIN-PINET;38780;38;ISERE;1
38161;;Faramans;FARAMANS;38260;38;ISERE;1
38162;;Faverges-de-la-Tour;FAVERGES-DE-LA-TOUR;38110;38;ISERE;1
38163;La;Ferrière;FERRIERE;38580;38;ISERE;1
38165;;Fitilieu;FITILIEU;38490;38;ISERE;1
38166;La;Flachère;FLACHERE;38530;38;ISERE;1
38167;;Flachères;FLACHERES;38690;38;ISERE;1
38169;;Fontaine;FONTAINE;38600;38;ISERE;1
38170;;Fontanil-Cornillon;FONTANIL-CORNILLON;38120;38;ISERE;1
38171;La;Forteresse;FORTERESSE;38590;38;ISERE;1
38172;;Four;FOUR;38080;38;ISERE;1
38173;Le;Freney-d'Oisans;FRENEY-D'OISANS;38142;38;ISERE;1
38174;La;Frette;FRETTE;38260;38;ISERE;1
38175;;Froges;FROGES;38190;38;ISERE;1
38176;;Frontonas;FRONTONAS;38290;38;ISERE;1
38177;La;Garde;GARDE;38520;38;ISERE;1
38179;;Gières;GIERES;38610;38;ISERE;1
38180;;Gillonnay;GILLONNAY;38260;38;ISERE;1
38181;;Goncelin;GONCELIN;38570;38;ISERE;1
38182;Le;Grand-Lemps;GRAND-LEMPS;38690;38;ISERE;1
38183;;Granieu;GRANIEU;38490;38;ISERE;1
38184;;Grenay;GRENAY;38540;38;ISERE;1
38185;;Grenoble;GRENOBLE;38000;38;ISERE;1
38186;;Gresse-en-Vercors;GRESSE-EN-VERCORS;38650;38;ISERE;1
38187;Le;Gua;GUA;38450;38;ISERE;1
38188;;Herbeys;HERBEYS;38320;38;ISERE;1
38189;;Heyrieux;HEYRIEUX;38540;38;ISERE;1
38190;;Hières-sur-Amby;HIERES-SUR-AMBY;38118;38;ISERE;1
38191;;Huez;HUEZ;38750;38;ISERE;1
38192;;Hurtières;HURTIERES;38570;38;ISERE;1
38193;L';Isle-d'Abeau;ISLE-D'ABEAU;38080;38;ISERE;1
38194;;Izeaux;IZEAUX;38140;38;ISERE;1
38195;;Izeron;IZERON;38160;38;ISERE;1
38197;;Janneyrias;JANNEYRIAS;38280;38;ISERE;1
38198;;Jarcieu;JARCIEU;38270;38;ISERE;1
38199;;Jardin;JARDIN;38200;38;ISERE;1
38200;;Jarrie;JARRIE;38560;38;ISERE;1
38203;;Laffrey;LAFFREY;38220;38;ISERE;1
38204;;Lalley;LALLEY;38930;38;ISERE;1
38205;;Lans-en-Vercors;LANS-EN-VERCORS;38250;38;ISERE;1
38206;;Laval;LAVAL;38190;38;ISERE;1
38207;;Lavaldens;LAVALDENS;38350;38;ISERE;1
38208;;Lavars;LAVARS;38710;38;ISERE;1
38209;;Lentiol;LENTIOL;38270;38;ISERE;1
38210;;Leyrieu;LEYRIEU;38460;38;ISERE;1
38211;;Lieudieu;LIEUDIEU;38440;38;ISERE;1
38212;;Livet-et-Gavet;LIVET-ET-GAVET;38220;38;ISERE;1
38213;;Longechenal;LONGECHENAL;38690;38;ISERE;1
38214;;Lumbin;LUMBIN;38660;38;ISERE;1
38215;;Luzinay;LUZINAY;38200;38;ISERE;1
38216;;Malleval-en-Vercors;MALLEVAL-EN-VERCORS;38470;38;ISERE;1
38217;;Marcieu;MARCIEU;38350;38;ISERE;1
38218;;Marcilloles;MARCILLOLES;38260;38;ISERE;1
38219;;Marcollin;MARCOLLIN;38270;38;ISERE;1
38221;;Marnans;MARNANS;38980;38;ISERE;1
38222;;Massieu;MASSIEU;38620;38;ISERE;1
38223;;Maubec;MAUBEC;38300;38;ISERE;1
38224;;Mayres-Savel;MAYRES-SAVEL;38350;38;ISERE;1
38225;;Méaudre;MEAUDRE;38112;38;ISERE;1
38226;;Mens;MENS;38710;38;ISERE;1
38228;;Merlas;MERLAS;38620;38;ISERE;1
38229;;Meylan;MEYLAN;38240;38;ISERE;1
38230;;Meyrié;MEYRIE;38300;38;ISERE;1
38231;;Meyrieu-les-Étangs;MEYRIEU-LES-ETANGS;38440;38;ISERE;1
38232;;Meyssiès;MEYSSIES;38440;38;ISERE;1
38235;;Miribel-Lanchâtre;MIRIBEL-LANCHATRE;38450;38;ISERE;1
38236;;Miribel-les-Échelles;MIRIBEL-LES-ECHELLES;38380;38;ISERE;1
38237;;Mizoën;MIZOEN;38142;38;ISERE;1
38238;;Moidieu-Détourbe;MOIDIEU-DETOURBE;38440;38;ISERE;1
38239;;Moirans;MOIRANS;38430;38;ISERE;1
38240;;Moissieu-sur-Dolon;MOISSIEU-SUR-DOLON;38270;38;ISERE;1
38241;;Monestier-d'Ambel;MONESTIER-D'AMBEL;38970;38;ISERE;1
38242;;Monestier-de-Clermont;MONESTIER-DE-CLERMONT;38650;38;ISERE;1
38243;Le;Monestier-du-Percy;MONESTIER-DU-PERCY;38930;38;ISERE;1
38244;;Monsteroux-Milieu;MONSTEROUX-MILIEU;38122;38;ISERE;1
38245;;Montagne;MONTAGNE;38160;38;ISERE;1
38246;;Montagnieu;MONTAGNIEU;38110;38;ISERE;1
38247;;Montalieu-Vercieu;MONTALIEU-VERCIEU;38390;38;ISERE;1
38248;;Montaud;MONTAUD;38210;38;ISERE;1
38249;;Montbonnot-Saint-Martin;MONTBONNOT-SAINT-MARTIN;38330;38;ISERE;1
38250;;Montcarra;MONTCARRA;38890;38;ISERE;1
38252;;Montchaboud;MONTCHABOUD;38220;38;ISERE;1
38253;;Mont-de-Lans;MONT-DE-LANS;38860;38;ISERE;1
38254;;Monteynard;MONTEYNARD;38770;38;ISERE;1
38255;;Montfalcon;MONTFALCON;38940;38;ISERE;1
38256;;Montferrat;MONTFERRAT;38620;38;ISERE;1
38257;;Montrevel;MONTREVEL;38690;38;ISERE;1
38258;;Mont-Saint-Martin;MONT-SAINT-MARTIN;38120;38;ISERE;1
38259;;Montseveroux;MONTSEVEROUX;38122;38;ISERE;1
38260;;Moras;MORAS;38460;38;ISERE;1
38261;;Morestel;MORESTEL;38510;38;ISERE;1
38262;;Morêtel-de-Mailles;MORETEL-DE-MAILLES;38570;38;ISERE;1
38263;;Morette;MORETTE;38210;38;ISERE;1
38264;La;Morte;MORTE;38350;38;ISERE;1
38265;La;Motte-d'Aveillans;MOTTE-D'AVEILLANS;38770;38;ISERE;1
38266;La;Motte-Saint-Martin;MOTTE-SAINT-MARTIN;38770;38;ISERE;1
38267;;Mottier;MOTTIER;38260;38;ISERE;1
38268;Le;Moutaret;MOUTARET;38580;38;ISERE;1
38269;La;Mure;MURE;38350;38;ISERE;1
38270;La;Murette;MURETTE;38140;38;ISERE;1
38271;;Murianette;MURIANETTE;38420;38;ISERE;1
38272;;Murinais;MURINAIS;38160;38;ISERE;1
38273;;Nantes-en-Ratier;NANTES-EN-RATIER;38350;38;ISERE;1
38274;;Nantoin;NANTOIN;38260;38;ISERE;1
38275;;Serre-Nerpol;SERRE-NERPOL;38470;38;ISERE;1
38276;;Nivolas-Vermelle;NIVOLAS-VERMELLE;38300;38;ISERE;1
38277;;Notre-Dame-de-Commiers;NOTRE-DAME-DE-COMMIERS;38450;38;ISERE;1
38278;;Notre-Dame-de-l'Osier;NOTRE-DAME-DE-L'OSIER;38470;38;ISERE;1
38279;;Notre-Dame-de-Mésage;NOTRE-DAME-DE-MESAGE;38220;38;ISERE;1
38280;;Notre-Dame-de-Vaulx;NOTRE-DAME-DE-VAULX;38144;38;ISERE;1
38281;;Noyarey;NOYAREY;38360;38;ISERE;1
38282;;Optevoz;OPTEVOZ;38460;38;ISERE;1
38283;;Oris-en-Rattier;ORIS-EN-RATTIER;38350;38;ISERE;1
38284;;Ornacieux;ORNACIEUX;38260;38;ISERE;1
38285;;Ornon;ORNON;38520;38;ISERE;1
38286;;Oulles;OULLES;38520;38;ISERE;1
38287;;Oyeu;OYEU;38690;38;ISERE;1
38288;;Oytier-Saint-Oblas;OYTIER-SAINT-OBLAS;38780;38;ISERE;1
38289;;Oz;OZ;38114;38;ISERE;1
38290;;Pact;PACT;38270;38;ISERE;1
38291;;Pajay;PAJAY;38260;38;ISERE;1
38292;;Paladru;PALADRU;38137;38;ISERE;1
38293;;Panissage;PANISSAGE;38730;38;ISERE;1
38294;;Panossas;PANOSSAS;38460;38;ISERE;1
38295;;Parmilieu;PARMILIEU;38390;38;ISERE;1
38296;Le;Passage;PASSAGE;38490;38;ISERE;1
38297;;Passins;PASSINS;38510;38;ISERE;1
38298;Le;Péage-de-Roussillon;PEAGE-DE-ROUSSILLON;38550;38;ISERE;1
38299;;Pellafol;PELLAFOL;38970;38;ISERE;1
38300;;Penol;PENOL;38260;38;ISERE;1
38301;;Percy;PERCY;38930;38;ISERE;1
38302;Le;Périer;PERIER;38740;38;ISERE;1
38303;La;Pierre;PIERRE;38570;38;ISERE;1
38304;;Pierre-Châtel;PIERRE-CHATEL;38119;38;ISERE;1
38305;Le;Pin;PIN;38730;38;ISERE;1
38306;;Pinsot;PINSOT;38580;38;ISERE;1
38307;;Pisieu;PISIEU;38270;38;ISERE;1
38308;;Plan;PLAN;38590;38;ISERE;1
38309;;Poisat;POISAT;38320;38;ISERE;1
38310;;Poliénas;POLIENAS;38210;38;ISERE;1
38311;;Pommier-de-Beaurepaire;POMMIER-DE-BEAUREPAIRE;38260;38;ISERE;1
38312;;Pommiers-la-Placette;POMMIERS-LA-PLACETTE;38340;38;ISERE;1
38313;;Ponsonnas;PONSONNAS;38350;38;ISERE;1
38314;;Pontcharra;PONTCHARRA;38530;38;ISERE;1
38315;Le;Pont-de-Beauvoisin;PONT-DE-BEAUVOISIN;38480;38;ISERE;1
38316;;Pont-de-Chéruy;PONT-DE-CHERUY;38230;38;ISERE;1
38317;Le;Pont-de-Claix;PONT-DE-CLAIX;38800;38;ISERE;1
38318;;Pont-Évêque;PONT-EVEQUE;38780;38;ISERE;1
38319;;Pont-en-Royans;PONT-EN-ROYANS;38680;38;ISERE;1
38320;;Porcieu-Amblagnieu;PORCIEU-AMBLAGNIEU;38390;38;ISERE;1
38321;;Prébois;PREBOIS;38710;38;ISERE;1
38322;;Presles;PRESLES;38680;38;ISERE;1
38323;;Pressins;PRESSINS;38480;38;ISERE;1
38324;;Primarette;PRIMARETTE;38270;38;ISERE;1
38325;;Proveysieux;PROVEYSIEUX;38120;38;ISERE;1
38326;;Prunières;PRUNIERES;38350;38;ISERE;1
38328;;Quaix-en-Chartreuse;QUAIX-EN-CHARTREUSE;38950;38;ISERE;1
38329;;Quet-en-Beaumont;QUET-EN-BEAUMONT;38970;38;ISERE;1
38330;;Quincieu;QUINCIEU;38470;38;ISERE;1
38331;;Réaumont;REAUMONT;38140;38;ISERE;1
38332;;Renage;RENAGE;38140;38;ISERE;1
38333;;Rencurel;RENCUREL;38680;38;ISERE;1
38334;;Revel;REVEL;38420;38;ISERE;1
38335;;Revel-Tourdan;REVEL-TOURDAN;38270;38;ISERE;1
38336;;Reventin-Vaugris;REVENTIN-VAUGRIS;38121;38;ISERE;1
38337;;Rives;RIVES;38140;38;ISERE;1
38338;La;Rivière;RIVIERE;38210;38;ISERE;1
38339;;Roche;ROCHE;38090;38;ISERE;1
38340;Les;Roches-de-Condrieu;ROCHES-DE-CONDRIEU;38370;38;ISERE;1
38341;;Rochetoirin;ROCHETOIRIN;38110;38;ISERE;1
38342;;Roissard;ROISSARD;38650;38;ISERE;1
38343;;Romagnieu;ROMAGNIEU;38480;38;ISERE;1
38344;;Roussillon;ROUSSILLON;38150;38;ISERE;1
38345;;Rovon;ROVON;38470;38;ISERE;1
38346;;Royas;ROYAS;38440;38;ISERE;1
38347;;Roybon;ROYBON;38940;38;ISERE;1
38348;;Ruy;RUY;38300;38;ISERE;1
38349;;Sablons;SABLONS;38550;38;ISERE;1
38350;;Sainte-Agnès;SAINTE-AGNES;38190;38;ISERE;1
38351;;Saint-Agnin-sur-Bion;SAINT-AGNIN-SUR-BION;38300;38;ISERE;1
38352;;Saint-Alban-de-Roche;SAINT-ALBAN-DE-ROCHE;38300;38;ISERE;1
38353;;Saint-Alban-du-Rhône;SAINT-ALBAN-DU-RHONE;38370;38;ISERE;1
38354;;Saint-Albin-de-Vaulserre;SAINT-ALBIN-DE-VAULSERRE;38480;38;ISERE;1
38355;;Saint-Andéol;SAINT-ANDEOL;38650;38;ISERE;1
38356;;Saint-André-en-Royans;SAINT-ANDRE-EN-ROYANS;38680;38;ISERE;1
38357;;Saint-André-le-Gaz;SAINT-ANDRE-LE-GAZ;38490;38;ISERE;1
38358;;Sainte-Anne-sur-Gervonde;SAINTE-ANNE-SUR-GERVONDE;38440;38;ISERE;1
38359;;Saint-Antoine-l'Abbaye;SAINT-ANTOINE-L'ABBAYE;38160;38;ISERE;1
38360;;Saint-Appolinard;SAINT-APPOLINARD;38160;38;ISERE;1
38361;;Saint-Arey;SAINT-AREY;38350;38;ISERE;1
38362;;Saint-Aupre;SAINT-AUPRE;38960;38;ISERE;1
38363;;Saint-Barthélemy;SAINT-BARTHELEMY;38270;38;ISERE;1
38364;;Saint-Barthélemy-de-Séchilienne;SAINT-BARTHELEMY-DE-SECHILIENNE;38220;38;ISERE;1
38365;;Saint-Baudille-de-la-Tour;SAINT-BAUDILLE-DE-LA-TOUR;38118;38;ISERE;1
38366;;Saint-Baudille-et-Pipet;SAINT-BAUDILLE-ET-PIPET;38710;38;ISERE;1
38367;;Saint-Bernard;SAINT-BERNARD;38660;38;ISERE;1
38368;;Saint-Blaise-du-Buis;SAINT-BLAISE-DU-BUIS;38140;38;ISERE;1
38369;;Sainte-Blandine;SAINTE-BLANDINE;38110;38;ISERE;1
38370;;Saint-Bonnet-de-Chavagne;SAINT-BONNET-DE-CHAVAGNE;38840;38;ISERE;1
38372;;Saint-Bueil;SAINT-BUEIL;38620;38;ISERE;1
38373;;Saint-Cassien;SAINT-CASSIEN;38500;38;ISERE;1
38374;;Saint-Chef;SAINT-CHEF;38890;38;ISERE;1
38375;;Saint-Christophe-en-Oisans;SAINT-CHRISTOPHE-EN-OISANS;38520;38;ISERE;1
38376;;Saint-Christophe-sur-Guiers;SAINT-CHRISTOPHE-SUR-GUIERS;38380;38;ISERE;1
38377;;Saint-Clair-de-la-Tour;SAINT-CLAIR-DE-LA-TOUR;38110;38;ISERE;1
38378;;Saint-Clair-du-Rhône;SAINT-CLAIR-DU-RHONE;38370;38;ISERE;1
38379;;Saint-Clair-sur-Galaure;SAINT-CLAIR-SUR-GALAURE;38940;38;ISERE;1
38380;;Saint-Didier-de-Bizonnes;SAINT-DIDIER-DE-BIZONNES;38690;38;ISERE;1
38381;;Saint-Didier-de-la-Tour;SAINT-DIDIER-DE-LA-TOUR;38110;38;ISERE;1
38382;;Saint-Égrève;SAINT-EGREVE;38120;38;ISERE;1
38383;;Saint-Étienne-de-Crossey;SAINT-ETIENNE-DE-CROSSEY;38960;38;ISERE;1
38384;;Saint-Étienne-de-Saint-Geoirs;SAINT-ETIENNE-DE-SAINT-GEOIRS;38590;38;ISERE;1
38386;;Saint-Geoire-en-Valdaine;SAINT-GEOIRE-EN-VALDAINE;38620;38;ISERE;1
38387;;Saint-Geoirs;SAINT-GEOIRS;38590;38;ISERE;1
38388;;Saint-Georges-de-Commiers;SAINT-GEORGES-DE-COMMIERS;38450;38;ISERE;1
38389;;Saint-Georges-d'Espéranche;SAINT-GEORGES-D'ESPERANCHE;38790;38;ISERE;1
38390;;Saint-Gervais;SAINT-GERVAIS;38470;38;ISERE;1
38391;;Saint-Guillaume;SAINT-GUILLAUME;38650;38;ISERE;1
38392;;Saint-Hilaire-de-Brens;SAINT-HILAIRE-DE-BRENS;38460;38;ISERE;1
38393;;Saint-Hilaire-de-la-Côte;SAINT-HILAIRE-DE-LA-COTE;38260;38;ISERE;1
38394;;Saint-Hilaire-du-Rosier;SAINT-HILAIRE-DU-ROSIER;38840;38;ISERE;1
38395;;Saint-Hilaire;SAINT-HILAIRE;38660;38;ISERE;1
38396;;Saint-Honoré;SAINT-HONORE;38350;38;ISERE;1
38397;;Saint-Ismier;SAINT-ISMIER;38330;38;ISERE;1
38398;;Saint-Jean-d'Avelanne;SAINT-JEAN-D'AVELANNE;38480;38;ISERE;1
38399;;Saint-Jean-de-Bournay;SAINT-JEAN-DE-BOURNAY;38440;38;ISERE;1
38400;;Saint-Jean-de-Moirans;SAINT-JEAN-DE-MOIRANS;38430;38;ISERE;1
38401;;Saint-Jean-de-Soudain;SAINT-JEAN-DE-SOUDAIN;38110;38;ISERE;1
38402;;Saint-Jean-de-Vaulx;SAINT-JEAN-DE-VAULX;38220;38;ISERE;1
38403;;Saint-Jean-d'Hérans;SAINT-JEAN-D'HERANS;38710;38;ISERE;1
38404;;Saint-Jean-le-Vieux;SAINT-JEAN-LE-VIEUX;38420;38;ISERE;1
38405;;Saint-Joseph-de-Rivière;SAINT-JOSEPH-DE-RIVIERE;38134;38;ISERE;1
38406;;Saint-Julien-de-l'Herms;SAINT-JULIEN-DE-L'HERMS;38122;38;ISERE;1
38407;;Saint-Julien-de-Raz;SAINT-JULIEN-DE-RAZ;38134;38;ISERE;1
38408;;Saint-Just-Chaleyssin;SAINT-JUST-CHALEYSSIN;38540;38;ISERE;1
38409;;Saint-Just-de-Claix;SAINT-JUST-DE-CLAIX;38680;38;ISERE;1
38410;;Saint-Lattier;SAINT-LATTIER;38840;38;ISERE;1
38412;;Saint-Laurent-du-Pont;SAINT-LAURENT-DU-PONT;38380;38;ISERE;1
38413;;Saint-Laurent-en-Beaumont;SAINT-LAURENT-EN-BEAUMONT;38350;38;ISERE;1
38414;;Sainte-Luce;SAINTE-LUCE;38970;38;ISERE;1
38415;;Saint-Marcel-Bel-Accueil;SAINT-MARCEL-BEL-ACCUEIL;38080;38;ISERE;1
38416;;Saint-Marcellin;SAINT-MARCELLIN;38160;38;ISERE;1
38417;;Sainte-Marie-d'Alloix;SAINTE-MARIE-D'ALLOIX;38660;38;ISERE;1
38418;;Sainte-Marie-du-Mont;SAINTE-MARIE-DU-MONT;38660;38;ISERE;1
38419;;Saint-Martin-de-Clelles;SAINT-MARTIN-DE-CLELLES;38930;38;ISERE;1
38420;;Saint-Martin-de-Vaulserre;SAINT-MARTIN-DE-VAULSERRE;38480;38;ISERE;1
38421;;Saint-Martin-d'Hères;SAINT-MARTIN-D'HERES;38400;38;ISERE;1
38422;;Saint-Martin-d'Uriage;SAINT-MARTIN-D'URIAGE;38410;38;ISERE;1
38423;;Saint-Martin-le-Vinoux;SAINT-MARTIN-LE-VINOUX;38950;38;ISERE;1
38424;;Saint-Maurice-en-Trièves;SAINT-MAURICE-EN-TRIEVES;38930;38;ISERE;1
38425;;Saint-Maurice-l'Exil;SAINT-MAURICE-L'EXIL;38550;38;ISERE;1
38426;;Saint-Maximin;SAINT-MAXIMIN;38530;38;ISERE;1
38427;;Saint-Michel-de-Saint-Geoirs;SAINT-MICHEL-DE-SAINT-GEOIRS;38590;38;ISERE;1
38428;;Saint-Michel-en-Beaumont;SAINT-MICHEL-EN-BEAUMONT;38350;38;ISERE;1
38429;;Saint-Michel-les-Portes;SAINT-MICHEL-LES-PORTES;38650;38;ISERE;1
38430;;Saint-Mury-Monteymond;SAINT-MURY-MONTEYMOND;38190;38;ISERE;1
38431;;Saint-Nazaire-les-Eymes;SAINT-NAZAIRE-LES-EYMES;38330;38;ISERE;1
38432;;Saint-Nicolas-de-Macherin;SAINT-NICOLAS-DE-MACHERIN;38500;38;ISERE;1
38433;;Saint-Nizier-du-Moucherotte;SAINT-NIZIER-DU-MOUCHEROTTE;38250;38;ISERE;1
38434;;Saint-Ondras;SAINT-ONDRAS;38490;38;ISERE;1
38435;;Saint-Pancrasse;SAINT-PANCRASSE;38660;38;ISERE;1
38436;;Saint-Paul-de-Varces;SAINT-PAUL-DE-VARCES;38760;38;ISERE;1
38437;;Saint-Paul-d'Izeaux;SAINT-PAUL-D'IZEAUX;38140;38;ISERE;1
38438;;Saint-Paul-lès-Monestier;SAINT-PAUL-LES-MONESTIER;38650;38;ISERE;1
38439;;Saint-Pierre-d'Allevard;SAINT-PIERRE-D'ALLEVARD;38830;38;ISERE;1
38440;;Saint-Pierre-de-Bressieux;SAINT-PIERRE-DE-BRESSIEUX;38870;38;ISERE;1
38442;;Saint-Pierre-de-Chartreuse;SAINT-PIERRE-DE-CHARTREUSE;38380;38;ISERE;1
38443;;Saint-Pierre-de-Chérennes;SAINT-PIERRE-DE-CHERENNES;38160;38;ISERE;1
38444;;Saint-Pierre-de-Méaroz;SAINT-PIERRE-DE-MEAROZ;38350;38;ISERE;1
38445;;Saint-Pierre-de-Mésage;SAINT-PIERRE-DE-MESAGE;38220;38;ISERE;1
38446;;Saint-Pierre-d'Entremont;SAINT-PIERRE-D'ENTREMONT;73670;38;SAVOIE;1
38448;;Saint-Prim;SAINT-PRIM;38370;38;ISERE;1
38449;;Saint-Quentin-Fallavier;SAINT-QUENTIN-FALLAVIER;38070;38;ISERE;1
38450;;Saint-Quentin-sur-Isère;SAINT-QUENTIN-SUR-ISERE;38210;38;ISERE;1
38451;;Saint-Romain-de-Jalionas;SAINT-ROMAIN-DE-JALIONAS;38460;38;ISERE;1
38452;;Saint-Romain-de-Surieu;SAINT-ROMAIN-DE-SURIEU;38150;38;ISERE;1
38453;;Saint-Romans;SAINT-ROMANS;38160;38;ISERE;1
38454;;Saint-Sauveur;SAINT-SAUVEUR;38160;38;ISERE;1
38455;;Saint-Savin;SAINT-SAVIN;38300;38;ISERE;1
38456;;Saint-Sébastien;SAINT-SEBASTIEN;38710;38;ISERE;1
38457;;Saint-Siméon-de-Bressieux;SAINT-SIMEON-DE-BRESSIEUX;38870;38;ISERE;1
38458;;Saint-Sorlin-de-Morestel;SAINT-SORLIN-DE-MORESTEL;38510;38;ISERE;1
38459;;Saint-Sorlin-de-Vienne;SAINT-SORLIN-DE-VIENNE;38200;38;ISERE;1
38460;;Saint-Sulpice-des-Rivoires;SAINT-SULPICE-DES-RIVOIRES;38620;38;ISERE;1
38462;;Saint-Théoffrey;SAINT-THEOFFREY;38119;38;ISERE;1
38463;;Saint-Vérand;SAINT-VERAND;38160;38;ISERE;1
38464;;Saint-Victor-de-Cessieu;SAINT-VICTOR-DE-CESSIEU;38110;38;ISERE;1
38465;;Saint-Victor-de-Morestel;SAINT-VICTOR-DE-MORESTEL;38510;38;ISERE;1
38466;;Saint-Vincent-de-Mercuze;SAINT-VINCENT-DE-MERCUZE;38660;38;ISERE;1
38467;;Salagnon;SALAGNON;38890;38;ISERE;1
38468;;Salaise-sur-Sanne;SALAISE-SUR-SANNE;38150;38;ISERE;1
38469;La;Salette-Fallavaux;SALETTE-FALLAVAUX;38970;38;ISERE;1
38470;La;Salle-en-Beaumont;SALLE-EN-BEAUMONT;38350;38;ISERE;1
38471;Le;Sappey-en-Chartreuse;SAPPEY-EN-CHARTREUSE;38700;38;ISERE;1
38472;;Sarcenas;SARCENAS;38700;38;ISERE;1
38473;;Sardieu;SARDIEU;38260;38;ISERE;1
38474;;Sassenage;SASSENAGE;38360;38;ISERE;1
38475;;Satolas-et-Bonce;SATOLAS-ET-BONCE;38290;38;ISERE;1
38476;;Savas-Mépin;SAVAS-MEPIN;38440;38;ISERE;1
38478;;Séchilienne;SECHILIENNE;38220;38;ISERE;1
38479;;Semons;SEMONS;38260;38;ISERE;1
38480;;Septème;SEPTEME;38780;38;ISERE;1
38481;;Sérézin-de-la-Tour;SEREZIN-DE-LA-TOUR;38300;38;ISERE;1
38483;;Sermérieu;SERMERIEU;38510;38;ISERE;1
38484;;Serpaize;SERPAIZE;38200;38;ISERE;1
38485;;Seyssinet-Pariset;SEYSSINET-PARISET;38170;38;ISERE;1
38486;;Seyssins;SEYSSINS;38180;38;ISERE;1
38487;;Seyssuel;SEYSSUEL;38200;38;ISERE;1
38488;;Siccieu-Saint-Julien-et-Carisieu;SICCIEU-SAINT-JULIEN-ET-CARISIEU;38460;38;ISERE;1
38489;;Siévoz;SIEVOZ;38350;38;ISERE;1
38490;;Sillans;SILLANS;38590;38;ISERE;1
38492;;Sinard;SINARD;38650;38;ISERE;1
38494;;Soleymieu;SOLEYMIEU;38460;38;ISERE;1
38495;La;Sône;SONE;38840;38;ISERE;1
38496;;Sonnay;SONNAY;38150;38;ISERE;1
38497;;Sousville;SOUSVILLE;38350;38;ISERE;1
38498;;Succieu;SUCCIEU;38300;38;ISERE;1
38499;;Susville;SUSVILLE;38350;38;ISERE;1
38500;;Têche;TECHE;38470;38;ISERE;1
38501;;Tencin;TENCIN;38570;38;ISERE;1
38503;La;Terrasse;TERRASSE;38660;38;ISERE;1
38504;;Theys;THEYS;38570;38;ISERE;1
38505;;Thodure;THODURE;38260;38;ISERE;1
38507;;Tignieu-Jameyzieu;TIGNIEU-JAMEYZIEU;38230;38;ISERE;1
38508;;Torchefelon;TORCHEFELON;38690;38;ISERE;1
38509;La;Tour-du-Pin;TOUR-DU-PIN;38110;38;ISERE;1
38511;Le;Touvet;TOUVET;38660;38;ISERE;1
38512;;Tramolé;TRAMOLE;38300;38;ISERE;1
38513;;Treffort;TREFFORT;38650;38;ISERE;1
38514;;Tréminis;TREMINIS;38710;38;ISERE;1
38515;;Trept;TREPT;38460;38;ISERE;1
38516;La;Tronche;TRONCHE;38700;38;ISERE;1
38517;;Tullins;TULLINS;38210;38;ISERE;1
38518;;Valbonnais;VALBONNAIS;38740;38;ISERE;1
38519;;Valencin;VALENCIN;38540;38;ISERE;1
38520;;Valencogne;VALENCOGNE;38730;38;ISERE;1
38521;La;Valette;VALETTE;38350;38;ISERE;1
38522;;Valjouffrey;VALJOUFFREY;38740;38;ISERE;1
38523;;Varacieux;VARACIEUX;38470;38;ISERE;1
38524;;Varces-Allières-et-Risset;VARCES-ALLIERES-ET-RISSET;38760;38;ISERE;1
38525;;Vasselin;VASSELIN;38890;38;ISERE;1
38526;;Vatilieu;VATILIEU;38470;38;ISERE;1
38527;;Vaujany;VAUJANY;38114;38;ISERE;1
38528;;Vaulnaveys-le-Bas;VAULNAVEYS-LE-BAS;38410;38;ISERE;1
38529;;Vaulnaveys-le-Haut;VAULNAVEYS-LE-HAUT;38410;38;ISERE;1
38530;;Vaulx-Milieu;VAULX-MILIEU;38090;38;ISERE;1
38531;;Velanne;VELANNE;38620;38;ISERE;1
38532;;Vénérieu;VENERIEU;38460;38;ISERE;1
38533;;Venon;VENON;38610;38;ISERE;1
38534;;Vénosc;VENOSC;38520;38;ISERE;1
38535;;Vernas;VERNAS;38460;38;ISERE;1
38536;;Vernioz;VERNIOZ;38150;38;ISERE;1
38537;La;Verpillière;VERPILLIERE;38290;38;ISERE;1
38538;Le;Versoud;VERSOUD;38420;38;ISERE;1
38539;;Vertrieu;VERTRIEU;38390;38;ISERE;1
38540;;Veurey-Voroize;VEUREY-VOROIZE;38113;38;ISERE;1
38541;;Veyrins-Thuellin;VEYRINS-THUELLIN;38630;38;ISERE;1
38542;;Veyssilieu;VEYSSILIEU;38460;38;ISERE;1
38543;;Vézeronce-Curtin;VEZERONCE-CURTIN;38510;38;ISERE;1
38544;;Vienne;VIENNE;38200;38;ISERE;1
38545;;Vif;VIF;38450;38;ISERE;1
38546;;Vignieu;VIGNIEU;38890;38;ISERE;1
38547;;Villard-Bonnot;VILLARD-BONNOT;38190;38;ISERE;1
38548;;Villard-de-Lans;VILLARD-DE-LANS;38250;38;ISERE;1
38549;;Villard-Notre-Dame;VILLARD-NOTRE-DAME;38520;38;ISERE;1
38550;;Villard-Reculas;VILLARD-RECULAS;38114;38;ISERE;1
38551;;Villard-Reymond;VILLARD-REYMOND;38520;38;ISERE;1
38552;;Villard-Saint-Christophe;VILLARD-SAINT-CHRISTOPHE;38119;38;ISERE;1
38553;;Villefontaine;VILLEFONTAINE;38090;38;ISERE;1
38554;;Villemoirieu;VILLEMOIRIEU;38460;38;ISERE;1
38555;;Villeneuve-de-Marc;VILLENEUVE-DE-MARC;38440;38;ISERE;1
38556;;Ville-sous-Anjou;VILLE-SOUS-ANJOU;38150;38;ISERE;1
38557;;Villette-d'Anthon;VILLETTE-D'ANTHON;38280;38;ISERE;1
38558;;Villette-de-Vienne;VILLETTE-DE-VIENNE;38200;38;ISERE;1
38559;;Vinay;VINAY;38470;38;ISERE;1
38560;;Virieu;VIRIEU;38730;38;ISERE;1
38561;;Viriville;VIRIVILLE;38980;38;ISERE;1
38562;;Vizille;VIZILLE;38220;38;ISERE;1
38563;;Voiron;VOIRON;38500;38;ISERE;1
38564;;Voissant;VOISSANT;38620;38;ISERE;1
38565;;Voreppe;VOREPPE;38340;38;ISERE;1
38566;;Vourey;VOUREY;38210;38;ISERE;1
38567;;Chamrousse;CHAMROUSSE;38410;38;ISERE;1
39001;;Abergement-la-Ronce;ABERGEMENT-LA-RONCE;39500;39;JURA;1
39002;;Abergement-le-Grand;ABERGEMENT-LE-GRAND;39600;39;JURA;1
39003;;Abergement-le-Petit;ABERGEMENT-LE-PETIT;39800;39;JURA;1
39004;;Abergement-lès-Thésy;ABERGEMENT-LES-THESY;39110;39;JURA;1
39006;;Aiglepierre;AIGLEPIERRE;39110;39;JURA;1
39007;;Alièze;ALIEZE;39270;39;JURA;1
39008;;Amange;AMANGE;39700;39;JURA;1
39009;;Andelot-en-Montagne;ANDELOT-EN-MONTAGNE;39110;39;JURA;1
39010;;Andelot-Morval;ANDELOT-MORVAL;39320;39;JURA;1
39011;;Annoire;ANNOIRE;39120;39;JURA;1
39013;;Arbois;ARBOIS;39600;39;JURA;1
39014;;Archelange;ARCHELANGE;39290;39;JURA;1
39015;;Ardon;ARDON;39300;39;JURA;1
39016;;Arinthod;ARINTHOD;39240;39;JURA;1
39017;;Arlay;ARLAY;39140;39;JURA;1
39018;;Aromas;AROMAS;39240;39;JURA;1
39019;Les;Arsures;ARSURES;39600;39;JURA;1
39020;;Arsure-Arsurette;ARSURE-ARSURETTE;39250;39;JURA;1
39021;;Arthenas;ARTHENAS;39270;39;JURA;1
39022;;Asnans-Beauvoisin;ASNANS-BEAUVOISIN;39120;39;JURA;1
39023;L';Aubépin;AUBEPIN;39160;39;JURA;1
39024;;Audelange;AUDELANGE;39700;39;JURA;1
39025;;Augea;AUGEA;39190;39;JURA;1
39026;;Augerans;AUGERANS;39380;39;JURA;1
39027;;Augisey;AUGISEY;39270;39;JURA;1
39028;;Aumont;AUMONT;39800;39;JURA;1
39029;;Aumur;AUMUR;39410;39;JURA;1
39030;;Authume;AUTHUME;39100;39;JURA;1
39031;;Auxange;AUXANGE;39700;39;JURA;1
39032;;Avignon-lès-Saint-Claude;AVIGNON-LES-SAINT-CLAUDE;39200;39;JURA;1
39034;;Balaiseaux;BALAISEAUX;39120;39;JURA;1
39035;;Balanod;BALANOD;39160;39;JURA;1
39036;La;Balme-d'Épy;BALME-D'EPY;39320;39;JURA;1
39037;;Bans;BANS;39380;39;JURA;1
39038;;Barésia-sur-l'Ain;BARESIA-SUR-L'AIN;39130;39;JURA;1
39039;La;Barre;BARRE;39700;39;JURA;1
39040;;Barretaine;BARRETAINE;39800;39;JURA;1
39041;;Baume-les-Messieurs;BAUME-LES-MESSIEURS;39210;39;JURA;1
39042;;Baverans;BAVERANS;39100;39;JURA;1
39043;;Beaufort;BEAUFORT;39190;39;JURA;1
39045;;Beffia;BEFFIA;39270;39;JURA;1
39046;;Bellecombe;BELLECOMBE;39310;39;JURA;1
39047;;Bellefontaine;BELLEFONTAINE;39400;39;JURA;1
39048;;Belmont;BELMONT;39380;39;JURA;1
39049;;Bersaillin;BERSAILLIN;39800;39;JURA;1
39050;;Besain;BESAIN;39800;39;JURA;1
39051;;Biarne;BIARNE;39290;39;JURA;1
39052;;Bief-des-Maisons;BIEF-DES-MAISONS;39150;39;JURA;1
39053;;Bief-du-Fourg;BIEF-DU-FOURG;39250;39;JURA;1
39054;;Biefmorin;BIEFMORIN;39800;39;JURA;1
39055;;Billecul;BILLECUL;39250;39;JURA;1
39056;;Bletterans;BLETTERANS;39140;39;JURA;1
39057;;Blois-sur-Seille;BLOIS-SUR-SEILLE;39210;39;JURA;1
39058;;Blye;BLYE;39130;39;JURA;1
39059;;Bois-d'Amont;BOIS-D'AMONT;39220;39;JURA;1
39060;;Bois-de-Gand;BOIS-DE-GAND;39230;39;JURA;1
39061;;Boissia;BOISSIA;39130;39;JURA;1
39062;La;Boissière;BOISSIERE;39240;39;JURA;1
39063;;Bonlieu;BONLIEU;39130;39;JURA;1
39064;;Bonnaud;BONNAUD;39190;39;JURA;1
39065;;Bonnefontaine;BONNEFONTAINE;39800;39;JURA;1
39066;;Bornay;BORNAY;39570;39;JURA;1
39068;Les;Bouchoux;BOUCHOUX;39370;39;JURA;1
39069;;Bourcia;BOURCIA;39320;39;JURA;1
39070;;Bourg-de-Sirod;BOURG-DE-SIROD;39300;39;JURA;1
39072;;Bracon;BRACON;39110;39;JURA;1
39073;;Brainans;BRAINANS;39800;39;JURA;1
39074;;Brans;BRANS;39290;39;JURA;1
39075;;Bréry;BRERY;39230;39;JURA;1
39076;La;Bretenière;BRETENIERE;39700;39;JURA;1
39077;;Bretenières;BRETENIERES;39120;39;JURA;1
39078;;Brevans;BREVANS;39100;39;JURA;1
39079;;Briod;BRIOD;39570;39;JURA;1
39080;;Broissia;BROISSIA;39320;39;JURA;1
39081;;Buvilly;BUVILLY;39800;39;JURA;1
39083;;Censeau;CENSEAU;39250;39;JURA;1
39084;;Cernans;CERNANS;39110;39;JURA;1
39085;;Cerniébaud;CERNIEBAUD;39250;39;JURA;1
39086;;Cernon;CERNON;39240;39;JURA;1
39088;;Cesancey;CESANCEY;39570;39;JURA;1
39089;;Cézia;CEZIA;39240;39;JURA;1
39090;;Chaînée-des-Coupis;CHAINEE-DES-COUPIS;39120;39;JURA;1
39091;Les;Chalesmes;CHALESMES;39150;39;JURA;1
39092;;Chambéria;CHAMBERIA;39270;39;JURA;1
39093;;Chamblay;CHAMBLAY;39380;39;JURA;1
39094;;Chamole;CHAMOLE;39800;39;JURA;1
39095;;Champagne-sur-Loue;CHAMPAGNE-SUR-LOUE;39600;39;JURA;1
39096;;Champagney;CHAMPAGNEY;39290;39;JURA;1
39097;;Champagnole;CHAMPAGNOLE;39300;39;JURA;1
39099;;Champdivers;CHAMPDIVERS;39500;39;JURA;1
39100;;Champrougier;CHAMPROUGIER;39230;39;JURA;1
39101;;Champvans;CHAMPVANS;39100;39;JURA;1
39102;;Chancia;CHANCIA;01590;39;AIN;1
39103;La;Chapelle-sur-Furieuse;CHAPELLE-SUR-FURIEUSE;39110;39;JURA;1
39104;;Chapelle-Voland;CHAPELLE-VOLAND;39140;39;JURA;1
39105;;Chapois;CHAPOIS;39300;39;JURA;1
39106;;Charchilla;CHARCHILLA;39260;39;JURA;1
39107;;Charcier;CHARCIER;39130;39;JURA;1
39108;;Charency;CHARENCY;39250;39;JURA;1
39109;;Charézier;CHAREZIER;39130;39;JURA;1
39110;La;Charme;CHARME;39230;39;JURA;1
39111;;Charnod;CHARNOD;39240;39;JURA;1
39112;La;Chassagne;CHASSAGNE;39230;39;JURA;1
39113;;Chassal;CHASSAL;39360;39;JURA;1
39114;;Château-Chalon;CHATEAU-CHALON;39210;39;JURA;1
39115;;Château-des-Prés;CHATEAU-DES-PRES;39150;39;JURA;1
39116;La;Châtelaine;CHATELAINE;39600;39;JURA;1
39117;;Chatelay;CHATELAY;39380;39;JURA;1
39118;;Châtel-de-Joux;CHATEL-DE-JOUX;39130;39;JURA;1
39119;Le;Chateley;CHATELEY;39230;39;JURA;1
39120;;Châtelneuf;CHATELNEUF;39300;39;JURA;1
39121;;Châtenois;CHATENOIS;39700;39;JURA;1
39122;;Châtillon;CHATILLON;39130;39;JURA;1
39123;;Chatonnay;CHATONNAY;39240;39;JURA;1
39124;;Chaumergy;CHAUMERGY;39230;39;JURA;1
39126;La;Chaumusse;CHAUMUSSE;39150;39;JURA;1
39127;;Chaussenans;CHAUSSENANS;39800;39;JURA;1
39128;;Chaussin;CHAUSSIN;39120;39;JURA;1
39129;;Chaux-des-Crotenay;CHAUX-DES-CROTENAY;39150;39;JURA;1
39130;;Chaux-des-Prés;CHAUX-DES-PRES;39150;39;JURA;1
39131;La;Chaux-du-Dombief;CHAUX-DU-DOMBIEF;39150;39;JURA;1
39132;La;Chaux-en-Bresse;CHAUX-EN-BRESSE;39230;39;JURA;1
39133;;Chaux-Champagny;CHAUX-CHAMPAGNY;39110;39;JURA;1
39134;;Chavéria;CHAVERIA;39270;39;JURA;1
39135;;Chazelles;CHAZELLES;39160;39;JURA;1
39136;;Chemenot;CHEMENOT;39230;39;JURA;1
39137;;Chemilla;CHEMILLA;39240;39;JURA;1
39138;;Chemin;CHEMIN;39120;39;JURA;1
39139;;Chêne-Bernard;CHENE-BERNARD;39120;39;JURA;1
39140;;Chêne-Sec;CHENE-SEC;39230;39;JURA;1
39141;;Chevigny;CHEVIGNY;39290;39;JURA;1
39142;;Chevreaux;CHEVREAUX;39190;39;JURA;1
39143;;Chevrotaine;CHEVROTAINE;39130;39;JURA;1
39145;;Chille;CHILLE;39570;39;JURA;1
39146;;Chilly-le-Vignoble;CHILLY-LE-VIGNOBLE;39570;39;JURA;1
39147;;Chilly-sur-Salins;CHILLY-SUR-SALINS;39110;39;JURA;1
39148;;Chisséria;CHISSERIA;39240;39;JURA;1
39149;;Chissey-sur-Loue;CHISSEY-SUR-LOUE;39380;39;JURA;1
39150;;Choisey;CHOISEY;39100;39;JURA;1
39151;;Choux;CHOUX;39370;39;JURA;1
39153;;Cize;CIZE;39300;39;JURA;1
39154;;Clairvaux-les-Lacs;CLAIRVAUX-LES-LACS;39130;39;JURA;1
39155;;Clucy;CLUCY;39110;39;JURA;1
39156;;Cogna;COGNA;39130;39;JURA;1
39157;;Coiserette;COISERETTE;39200;39;JURA;1
39158;;Coisia;COISIA;39240;39;JURA;1
39159;;Colonne;COLONNE;39800;39;JURA;1
39160;;Commenailles;COMMENAILLES;39140;39;JURA;1
39161;;Communailles-en-Montagne;COMMUNAILLES-EN-MONTAGNE;39250;39;JURA;1
39162;;Condamine;CONDAMINE;39570;39;JURA;1
39163;;Condes;CONDES;39240;39;JURA;1
39164;;Conliège;CONLIEGE;39570;39;JURA;1
39165;;Conte;CONTE;39300;39;JURA;1
39166;;Cornod;CORNOD;39240;39;JURA;1
39167;;Cosges;COSGES;39140;39;JURA;1
39168;;Courbette;COURBETTE;39570;39;JURA;1
39169;;Courbouzon;COURBOUZON;39570;39;JURA;1
39170;;Courlans;COURLANS;39570;39;JURA;1
39171;;Courlaoux;COURLAOUX;39570;39;JURA;1
39172;;Courtefontaine;COURTEFONTAINE;39700;39;JURA;1
39173;;Cousance;COUSANCE;39190;39;JURA;1
39174;;Coyrière;COYRIERE;39200;39;JURA;1
39175;;Coyron;COYRON;39260;39;JURA;1
39176;;Cramans;CRAMANS;39600;39;JURA;1
39177;;Crançot;CRANCOT;39570;39;JURA;1
39178;;Crans;CRANS;39300;39;JURA;1
39179;;Crenans;CRENANS;39260;39;JURA;1
39180;;Cressia;CRESSIA;39270;39;JURA;1
39182;;Crissey;CRISSEY;39100;39;JURA;1
39183;;Crotenay;CROTENAY;39300;39;JURA;1
39184;Les;Crozets;CROZETS;39260;39;JURA;1
39185;;Cuisia;CUISIA;39190;39;JURA;1
39186;;Cuttura;CUTTURA;39170;39;JURA;1
39187;;Cuvier;CUVIER;39250;39;JURA;1
39188;;Dammartin-Marpain;DAMMARTIN-MARPAIN;39290;39;JURA;1
39189;;Damparis;DAMPARIS;39500;39;JURA;1
39190;;Dampierre;DAMPIERRE;39700;39;JURA;1
39191;;Darbonnay;DARBONNAY;39230;39;JURA;1
39192;;Denezières;DENEZIERES;39130;39;JURA;1
39193;Le;Deschaux;DESCHAUX;39120;39;JURA;1
39194;;Desnes;DESNES;39140;39;JURA;1
39195;;Dessia;DESSIA;39320;39;JURA;1
39196;Les;Deux-Fays;DEUX-FAYS;39230;39;JURA;1
39197;;Digna;DIGNA;39190;39;JURA;1
39198;;Dole;DOLE;39100;39;JURA;1
39199;;Domblans;DOMBLANS;39210;39;JURA;1
39200;;Dompierre-sur-Mont;DOMPIERRE-SUR-MONT;39270;39;JURA;1
39201;;Doucier;DOUCIER;39130;39;JURA;1
39202;;Dournon;DOURNON;39110;39;JURA;1
39203;;Doye;DOYE;39250;39;JURA;1
39204;;Dramelay;DRAMELAY;39240;39;JURA;1
39205;;Éclans-Nenon;ECLANS-NENON;39700;39;JURA;1
39206;;Écleux;ECLEUX;39600;39;JURA;1
39207;;Écrille;ECRILLE;39270;39;JURA;1
39208;;Entre-deux-Monts;ENTRE-DEUX-MONTS;39150;39;JURA;1
39209;;Val-d'Épy;VAL-D'EPY;39160;39;JURA;1
39210;;Équevillon;EQUEVILLON;39300;39;JURA;1
39211;Les;Essards-Taignevaux;ESSARDS-TAIGNEVAUX;39120;39;JURA;1
39213;;Esserval-Combe;ESSERVAL-COMBE;39250;39;JURA;1
39214;;Esserval-Tartre;ESSERVAL-TARTRE;39250;39;JURA;1
39215;;Essia;ESSIA;39270;39;JURA;1
39216;;Étival;ETIVAL;39130;39;JURA;1
39217;L';Étoile;ETOILE;39570;39;JURA;1
39218;;Étrepigney;ETREPIGNEY;39700;39;JURA;1
39219;;Évans;EVANS;39700;39;JURA;1
39220;;Falletans;FALLETANS;39700;39;JURA;1
39221;La;Favière;FAVIERE;39250;39;JURA;1
39222;;Fay-en-Montagne;FAY-EN-MONTAGNE;39800;39;JURA;1
39223;La;Ferté;FERTE;39600;39;JURA;1
39224;;Fétigny;FETIGNY;39240;39;JURA;1
39225;Le;Fied;FIED;39800;39;JURA;1
39226;;Florentia;FLORENTIA;39320;39;JURA;1
39227;;Foncine-le-Bas;FONCINE-LE-BAS;39520;39;JURA;1
39228;;Foncine-le-Haut;FONCINE-LE-HAUT;39460;39;JURA;1
39229;;Fontainebrux;FONTAINEBRUX;39140;39;JURA;1
39230;;Fontenu;FONTENU;39130;39;JURA;1
39232;;Fort-du-Plasne;FORT-DU-PLASNE;39150;39;JURA;1
39233;;Foucherans;FOUCHERANS;39100;39;JURA;1
39234;;Foulenay;FOULENAY;39230;39;JURA;1
39235;;Fraisans;FRAISANS;39700;39;JURA;1
39236;;Francheville;FRANCHEVILLE;39230;39;JURA;1
39237;;Fraroz;FRAROZ;39250;39;JURA;1
39238;;Frasne-les-Meulières;FRASNE-LES-MEULIERES;39290;39;JURA;1
39239;La;Frasnée;FRASNEE;39130;39;JURA;1
39240;Le;Frasnois;FRASNOIS;39130;39;JURA;1
39241;;Frébuans;FREBUANS;39570;39;JURA;1
39243;;Froideville;FROIDEVILLE;39230;39;JURA;1
39244;;Frontenay;FRONTENAY;39210;39;JURA;1
39245;;Gatey;GATEY;39120;39;JURA;1
39246;;Gendrey;GENDREY;39350;39;JURA;1
39247;;Genod;GENOD;39240;39;JURA;1
39248;;Geraise;GERAISE;39110;39;JURA;1
39249;;Germigney;GERMIGNEY;39380;39;JURA;1
39250;;Geruge;GERUGE;39570;39;JURA;1
39251;;Gevingey;GEVINGEY;39570;39;JURA;1
39252;;Gevry;GEVRY;39100;39;JURA;1
39253;;Gigny;GIGNY;39320;39;JURA;1
39254;;Gillois;GILLOIS;39250;39;JURA;1
39255;;Gizia;GIZIA;39190;39;JURA;1
39258;;Grande-Rivière;GRANDE-RIVIERE;39150;39;JURA;1
39259;;Grange-de-Vaivre;GRANGE-DE-VAIVRE;39600;39;JURA;1
39260;;Granges-sur-Baume;GRANGES-SUR-BAUME;39210;39;JURA;1
39261;;Graye-et-Charnay;GRAYE-ET-CHARNAY;39320;39;JURA;1
39262;;Gredisans;GREDISANS;39290;39;JURA;1
39263;;Grozon;GROZON;39800;39;JURA;1
39264;;Grusse;GRUSSE;39190;39;JURA;1
39265;;Hautecour;HAUTECOUR;39130;39;JURA;1
39266;Les;Hays;HAYS;39120;39;JURA;1
39267;;Ivory;IVORY;39110;39;JURA;1
39268;;Ivrey;IVREY;39110;39;JURA;1
39269;;Jeurre;JEURRE;39360;39;JURA;1
39270;;Jouhe;JOUHE;39100;39;JURA;1
39271;;Lac-des-Rouges-Truites;LAC-DES-ROUGES-TRUITES;39150;39;JURA;1
39272;;Ladoye-sur-Seille;LADOYE-SUR-SEILLE;39210;39;JURA;1
39273;;Lains;LAINS;39320;39;JURA;1
39274;;Lajoux;LAJOUX;;39;JURA;1
39275;;Lamoura;LAMOURA;39310;39;JURA;1
39277;Le;Larderet;LARDERET;39300;39;JURA;1
39278;;Largillay-Marsonnay;LARGILLAY-MARSONNAY;39130;39;JURA;1
39279;;Larnaud;LARNAUD;39140;39;JURA;1
39280;;Larrivoire;LARRIVOIRE;39360;39;JURA;1
39281;Le;Latet;LATET;39300;39;JURA;1
39282;La;Latette;LATETTE;39250;39;JURA;1
39283;;Lavancia-Epercy;LAVANCIA-EPERCY;01590;39;AIN;1
39284;;Lavangeot;LAVANGEOT;39700;39;JURA;1
39285;;Lavans-lès-Dole;LAVANS-LES-DOLE;39700;39;JURA;1
39286;;Lavans-lès-Saint-Claude;LAVANS-LES-SAINT-CLAUDE;39170;39;JURA;1
39287;;Lavans-sur-Valouse;LAVANS-SUR-VALOUSE;39240;39;JURA;1
39288;;Lavigny;LAVIGNY;39210;39;JURA;1
39289;;Lect;LECT;39260;39;JURA;1
39290;;Légna;LEGNA;39240;39;JURA;1
39291;;Lemuy;LEMUY;39110;39;JURA;1
39292;;Lent;LENT;39300;39;JURA;1
39293;;Leschères;LESCHERES;39170;39;JURA;1
39294;;Lézat;LEZAT;39400;39;JURA;1
39295;;Loisia;LOISIA;39320;39;JURA;1
39296;;Lombard;LOMBARD;39230;39;JURA;1
39297;;Longchaumois;LONGCHAUMOIS;39400;39;JURA;1
39298;;Longcochon;LONGCOCHON;39250;39;JURA;1
39299;;Longwy-sur-le-Doubs;LONGWY-SUR-LE-DOUBS;39120;39;JURA;1
39300;;Lons-le-Saunier;LONS-LE-SAUNIER;39000;39;JURA;1
39301;;Loulle;LOULLE;39300;39;JURA;1
39302;;Louvatange;LOUVATANGE;39350;39;JURA;1
39303;;Louvenne;LOUVENNE;39320;39;JURA;1
39304;Le;Louverot;LOUVEROT;39210;39;JURA;1
39305;La;Loye;LOYE;39380;39;JURA;1
39306;;Macornay;MACORNAY;39570;39;JURA;1
39307;;Maisod;MAISOD;39260;39;JURA;1
39308;;Malange;MALANGE;39700;39;JURA;1
39309;;Mallerey;MALLEREY;39190;39;JURA;1
39310;;Mantry;MANTRY;39230;39;JURA;1
39312;;Marigna-sur-Valouse;MARIGNA-SUR-VALOUSE;39240;39;JURA;1
39313;;Marigny;MARIGNY;39130;39;JURA;1
39314;;Marnézia;MARNEZIA;39270;39;JURA;1
39315;;Marnoz;MARNOZ;39110;39;JURA;1
39317;La;Marre;MARRE;39210;39;JURA;1
39318;;Martigna;MARTIGNA;39260;39;JURA;1
39319;;Mathenay;MATHENAY;39600;39;JURA;1
39320;;Maynal;MAYNAL;39190;39;JURA;1
39321;;Menétru-le-Vignoble;MENETRU-LE-VIGNOBLE;39210;39;JURA;1
39322;;Menétrux-en-Joux;MENETRUX-EN-JOUX;39130;39;JURA;1
39323;;Menotey;MENOTEY;39290;39;JURA;1
39324;;Mérona;MERONA;39270;39;JURA;1
39325;;Mesnay;MESNAY;39600;39;JURA;1
39326;;Mesnois;MESNOIS;39130;39;JURA;1
39327;;Messia-sur-Sorne;MESSIA-SUR-SORNE;39570;39;JURA;1
39328;;Meussia;MEUSSIA;39260;39;JURA;1
39329;;Mièges;MIEGES;39250;39;JURA;1
39330;;Miéry;MIERY;39800;39;JURA;1
39331;;Mignovillard;MIGNOVILLARD;39250;39;JURA;1
39332;;Mirebel;MIREBEL;39570;39;JURA;1
39333;;Moirans-en-Montagne;MOIRANS-EN-MONTAGNE;39260;39;JURA;1
39334;;Moiron;MOIRON;39570;39;JURA;1
39335;;Moissey;MOISSEY;39290;39;JURA;1
39336;;Molain;MOLAIN;39800;39;JURA;1
39337;;Molamboz;MOLAMBOZ;39600;39;JURA;1
39338;;Molay;MOLAY;39500;39;JURA;1
39339;;Molinges;MOLINGES;39360;39;JURA;1
39340;;Molpré;MOLPRE;39250;39;JURA;1
39341;Les;Molunes;MOLUNES;39310;39;JURA;1
39342;;Monay;MONAY;39230;39;JURA;1
39343;;Monnetay;MONNETAY;39320;39;JURA;1
39344;;Monnet-la-Ville;MONNET-LA-VILLE;39300;39;JURA;1
39345;;Monnières;MONNIERES;39100;39;JURA;1
39346;;Montagna-le-Reconduit;MONTAGNA-LE-RECONDUIT;39160;39;JURA;1
39347;;Montagna-le-Templier;MONTAGNA-LE-TEMPLIER;39320;39;JURA;1
39348;;Montaigu;MONTAIGU;39570;39;JURA;1
39349;;Montain;MONTAIN;39210;39;JURA;1
39350;;Montbarrey;MONTBARREY;39380;39;JURA;1
39351;;Montcusel;MONTCUSEL;39260;39;JURA;1
39352;;Monteplain;MONTEPLAIN;39700;39;JURA;1
39353;;Montfleur;MONTFLEUR;39320;39;JURA;1
39354;;Montholier;MONTHOLIER;39800;39;JURA;1
39355;;Montigny-lès-Arsures;MONTIGNY-LES-ARSURES;39600;39;JURA;1
39356;;Montigny-sur-l'Ain;MONTIGNY-SUR-L'AIN;39300;39;JURA;1
39359;;Montmarlon;MONTMARLON;39110;39;JURA;1
39360;;Montmirey-la-Ville;MONTMIREY-LA-VILLE;39290;39;JURA;1
39361;;Montmirey-le-Château;MONTMIREY-LE-CHATEAU;39290;39;JURA;1
39362;;Montmorot;MONTMOROT;39570;39;JURA;1
39363;;Montrevel;MONTREVEL;39320;39;JURA;1
39364;;Montrond;MONTROND;39300;39;JURA;1
39365;;Mont-sous-Vaudrey;MONT-SOUS-VAUDREY;39380;39;JURA;1
39366;;Mont-sur-Monnet;MONT-SUR-MONNET;39300;39;JURA;1
39367;;Morbier;MORBIER;39400;39;JURA;1
39368;;Morez;MOREZ;39400;39;JURA;1
39370;;Mouchard;MOUCHARD;39330;39;JURA;1
39371;La;Mouille;MOUILLE;39400;39;JURA;1
39372;;Mournans-Charbonny;MOURNANS-CHARBONNY;39250;39;JURA;1
39373;Les;Moussières;MOUSSIERES;39310;39;JURA;1
39375;;Moutonne;MOUTONNE;39270;39;JURA;1
39376;;Moutoux;MOUTOUX;39300;39;JURA;1
39377;;Mutigney;MUTIGNEY;39290;39;JURA;1
39378;;Nanc-lès-Saint-Amour;NANC-LES-SAINT-AMOUR;39160;39;JURA;1
39379;;Nance;NANCE;39140;39;JURA;1
39380;;Nancuise;NANCUISE;39270;39;JURA;1
39381;Les;Nans;NANS;39300;39;JURA;1
39382;;Nantey;NANTEY;39160;39;JURA;1
39385;;Neublans-Abergement;NEUBLANS-ABERGEMENT;39120;39;JURA;1
39386;;Neuvilley;NEUVILLEY;39800;39;JURA;1
39387;;Nevy-lès-Dole;NEVY-LES-DOLE;39380;39;JURA;1
39388;;Nevy-sur-Seille;NEVY-SUR-SEILLE;39210;39;JURA;1
39389;;Ney;NEY;39300;39;JURA;1
39390;;Nogna;NOGNA;39570;39;JURA;1
39391;;Nozeroy;NOZEROY;39250;39;JURA;1
39392;;Offlanges;OFFLANGES;39290;39;JURA;1
39393;;Onglières;ONGLIERES;39250;39;JURA;1
39394;;Onoz;ONOZ;39270;39;JURA;1
39395;;Orbagna;ORBAGNA;39190;39;JURA;1
39396;;Orchamps;ORCHAMPS;39700;39;JURA;1
39397;;Orgelet;ORGELET;39270;39;JURA;1
39398;;Ougney;OUGNEY;39350;39;JURA;1
39399;;Ounans;OUNANS;39380;39;JURA;1
39400;;Our;OUR;39700;39;JURA;1
39401;;Oussières;OUSSIERES;39800;39;JURA;1
39402;;Pagney;PAGNEY;39350;39;JURA;1
39403;;Pagnoz;PAGNOZ;39330;39;JURA;1
39404;;Pannessières;PANNESSIERES;39570;39;JURA;1
39405;;Parcey;PARCEY;39100;39;JURA;1
39406;Le;Pasquier;PASQUIER;39300;39;JURA;1
39407;;Passenans;PASSENANS;39230;39;JURA;1
39408;;Patornay;PATORNAY;39130;39;JURA;1
39409;;Peintre;PEINTRE;39290;39;JURA;1
39411;;Perrigny;PERRIGNY;39570;39;JURA;1
39412;;Peseux;PESEUX;39120;39;JURA;1
39413;La;Pesse;PESSE;39370;39;JURA;1
39414;Le;Petit-Mercey;PETIT-MERCEY;39350;39;JURA;1
39415;;Petit-Noir;PETIT-NOIR;39120;39;JURA;1
39417;Les;Piards;PIARDS;39150;39;JURA;1
39418;;Picarreau;PICARREAU;39800;39;JURA;1
39419;;Pillemoine;PILLEMOINE;39300;39;JURA;1
39420;;Pimorin;PIMORIN;39270;39;JURA;1
39421;Le;Pin;PIN;39210;39;JURA;1
39422;;Plainoiseau;PLAINOISEAU;39210;39;JURA;1
39423;;Plaisia;PLAISIA;39270;39;JURA;1
39424;Les;Planches-en-Montagne;PLANCHES-EN-MONTAGNE;39150;39;JURA;1
39425;Les;Planches-près-Arbois;PLANCHES-PRES-ARBOIS;39600;39;JURA;1
39426;;Plasne;PLASNE;39210;39;JURA;1
39427;;Plénise;PLENISE;39250;39;JURA;1
39428;;Plénisette;PLENISETTE;39250;39;JURA;1
39429;;Pleure;PLEURE;39120;39;JURA;1
39430;;Plumont;PLUMONT;39700;39;JURA;1
39431;;Poids-de-Fiole;POIDS-DE-FIOLE;39570;39;JURA;1
39432;;Pointre;POINTRE;39290;39;JURA;1
39434;;Poligny;POLIGNY;39800;39;JURA;1
39435;;Pont-de-Poitte;PONT-DE-POITTE;39130;39;JURA;1
39436;;Pont-d'Héry;PONT-D'HERY;39110;39;JURA;1
39437;;Pont-du-Navoy;PONT-DU-NAVOY;39300;39;JURA;1
39438;;Ponthoux;PONTHOUX;39170;39;JURA;1
39439;;Port-Lesney;PORT-LESNEY;39330;39;JURA;1
39440;;Pratz;PRATZ;39170;39;JURA;1
39441;;Prémanon;PREMANON;39220;39;JURA;1
39442;;Prénovel;PRENOVEL;39150;39;JURA;1
39443;;Présilly;PRESILLY;39270;39;JURA;1
39444;;Pretin;PRETIN;39110;39;JURA;1
39445;;Publy;PUBLY;39570;39;JURA;1
39446;;Pupillin;PUPILLIN;39600;39;JURA;1
39447;;Quintigny;QUINTIGNY;39570;39;JURA;1
39448;;Rahon;RAHON;39120;39;JURA;1
39449;;Rainans;RAINANS;39290;39;JURA;1
39451;;Ranchot;RANCHOT;39700;39;JURA;1
39452;;Rans;RANS;39700;39;JURA;1
39453;;Ravilloles;RAVILLOLES;39170;39;JURA;1
39454;;Recanoz;RECANOZ;39230;39;JURA;1
39455;;Reithouse;REITHOUSE;39270;39;JURA;1
39456;;Relans;RELANS;39140;39;JURA;1
39457;Les;Repôts;REPOTS;39140;39;JURA;1
39458;;Revigny;REVIGNY;39570;39;JURA;1
39460;La;Rixouse;RIXOUSE;39200;39;JURA;1
39461;;Rix;RIX;39250;39;JURA;1
39462;;Rochefort-sur-Nenon;ROCHEFORT-SUR-NENON;39700;39;JURA;1
39463;;Rogna;ROGNA;39360;39;JURA;1
39464;;Romain;ROMAIN;39350;39;JURA;1
39465;;Romange;ROMANGE;39700;39;JURA;1
39466;;Rosay;ROSAY;39190;39;JURA;1
39467;;Rotalier;ROTALIER;39190;39;JURA;1
39468;;Rothonay;ROTHONAY;39270;39;JURA;1
39469;;Rouffange;ROUFFANGE;39350;39;JURA;1
39470;Les;Rousses;ROUSSES;39220;39;JURA;1
39471;;Ruffey-sur-Seille;RUFFEY-SUR-SEILLE;39140;39;JURA;1
39472;;Rye;RYE;39230;39;JURA;1
39473;;Saffloz;SAFFLOZ;39130;39;JURA;1
39474;;Sainte-Agnès;SAINTE-AGNES;39190;39;JURA;1
39475;;Saint-Amour;SAINT-AMOUR;39160;39;JURA;1
39476;;Saint-Aubin;SAINT-AUBIN;39410;39;JURA;1
39477;;Saint-Baraing;SAINT-BARAING;39120;39;JURA;1
39478;;Saint-Claude;SAINT-CLAUDE;39200;39;JURA;1
39479;;Saint-Cyr-Montmalin;SAINT-CYR-MONTMALIN;39600;39;JURA;1
39480;;Saint-Didier;SAINT-DIDIER;39570;39;JURA;1
39481;;Saint-Germain-en-Montagne;SAINT-GERMAIN-EN-MONTAGNE;39300;39;JURA;1
39482;;Saint-Germain-lès-Arlay;SAINT-GERMAIN-LES-ARLAY;39210;39;JURA;1
39483;;Saint-Hymetière;SAINT-HYMETIERE;39240;39;JURA;1
39484;;Saint-Jean-d'Étreux;SAINT-JEAN-D'ETREUX;39160;39;JURA;1
39485;;Saint-Julien;SAINT-JULIEN;39320;39;JURA;1
39486;;Saint-Lamain;SAINT-LAMAIN;39230;39;JURA;1
39487;;Saint-Laurent-en-Grandvaux;SAINT-LAURENT-EN-GRANDVAUX;39150;39;JURA;1
39488;;Saint-Laurent-la-Roche;SAINT-LAURENT-LA-ROCHE;39570;39;JURA;1
39489;;Saint-Lothain;SAINT-LOTHAIN;39230;39;JURA;1
39490;;Saint-Loup;SAINT-LOUP;39120;39;JURA;1
39491;;Saint-Lupicin;SAINT-LUPICIN;39170;39;JURA;1
39492;;Saint-Maur;SAINT-MAUR;39570;39;JURA;1
39493;;Saint-Maurice-Crillat;SAINT-MAURICE-CRILLAT;39130;39;JURA;1
39494;;Saint-Pierre;SAINT-PIERRE;39150;39;JURA;1
39495;;Saint-Thiébaud;SAINT-THIEBAUD;39110;39;JURA;1
39497;;Saizenay;SAIZENAY;39110;39;JURA;1
39498;;Salans;SALANS;39700;39;JURA;1
39499;;Saligney;SALIGNEY;39350;39;JURA;1
39500;;Salins-les-Bains;SALINS-LES-BAINS;39110;39;JURA;1
39501;;Sampans;SAMPANS;39100;39;JURA;1
39502;;Santans;SANTANS;39380;39;JURA;1
39503;;Sapois;SAPOIS;39300;39;JURA;1
39504;;Sarrogna;SARROGNA;39270;39;JURA;1
39505;;Saugeot;SAUGEOT;39130;39;JURA;1
39506;;Savigna;SAVIGNA;39240;39;JURA;1
39507;;Séligney;SELIGNEY;39120;39;JURA;1
39508;;Sellières;SELLIERES;39230;39;JURA;1
39509;;Senaud;SENAUD;39160;39;JURA;1
39510;;Septmoncel;SEPTMONCEL;39310;39;JURA;1
39511;;Sergenaux;SERGENAUX;39230;39;JURA;1
39512;;Sergenon;SERGENON;39120;39;JURA;1
39513;;Sermange;SERMANGE;39700;39;JURA;1
39514;;Serre-les-Moulières;SERRE-LES-MOULIERES;39700;39;JURA;1
39517;;Sirod;SIROD;39300;39;JURA;1
39518;;Songeson;SONGESON;39130;39;JURA;1
39519;;Soucia;SOUCIA;39130;39;JURA;1
39520;;Souvans;SOUVANS;39380;39;JURA;1
39522;;Supt;SUPT;39300;39;JURA;1
39523;;Syam;SYAM;39300;39;JURA;1
39525;;Tassenières;TASSENIERES;39120;39;JURA;1
39526;;Tavaux;TAVAUX;39500;39;JURA;1
39527;;Taxenne;TAXENNE;39350;39;JURA;1
39528;;Thervay;THERVAY;39290;39;JURA;1
39529;;Thésy;THESY;39110;39;JURA;1
39530;;Thoirette;THOIRETTE;39240;39;JURA;1
39531;;Thoiria;THOIRIA;39130;39;JURA;1
39532;;Thoissia;THOISSIA;39160;39;JURA;1
39533;;Toulouse-le-Château;TOULOUSE-LE-CHATEAU;39230;39;JURA;1
39534;La;Tour-du-Meix;TOUR-DU-MEIX;39270;39;JURA;1
39535;;Tourmont;TOURMONT;39800;39;JURA;1
39537;;Trenal;TRENAL;39570;39;JURA;1
39538;;Uxelles;UXELLES;39130;39;JURA;1
39539;;Vadans;VADANS;39600;39;JURA;1
39540;;Valempoulières;VALEMPOULIERES;39300;39;JURA;1
39542;;Valfin-sur-Valouse;VALFIN-SUR-VALOUSE;39240;39;JURA;1
39543;;Vannoz;VANNOZ;39300;39;JURA;1
39544;;Varessia;VARESSIA;39270;39;JURA;1
39545;Le;Vaudioux;VAUDIOUX;39300;39;JURA;1
39546;;Vaudrey;VAUDREY;39380;39;JURA;1
39547;;Vaux-lès-Saint-Claude;VAUX-LES-SAINT-CLAUDE;39360;39;JURA;1
39548;;Vaux-sur-Poligny;VAUX-SUR-POLIGNY;39800;39;JURA;1
39549;;Vercia;VERCIA;39190;39;JURA;1
39550;;Verges;VERGES;39570;39;JURA;1
39551;;Véria;VERIA;39160;39;JURA;1
39552;;Vernantois;VERNANTOIS;39570;39;JURA;1
39553;Le;Vernois;VERNOIS;39210;39;JURA;1
39554;;Vers-en-Montagne;VERS-EN-MONTAGNE;39300;39;JURA;1
39555;;Vers-sous-Sellières;VERS-SOUS-SELLIERES;39230;39;JURA;1
39556;;Vertamboz;VERTAMBOZ;39130;39;JURA;1
39557;;Vescles;VESCLES;39240;39;JURA;1
39558;;Vevy;VEVY;39570;39;JURA;1
39559;La;Vieille-Loye;VIEILLE-LOYE;39380;39;JURA;1
39560;;Villard-Saint-Sauveur;VILLARD-SAINT-SAUVEUR;39200;39;JURA;1
39561;;Villards-d'Héria;VILLARDS-D'HERIA;39260;39;JURA;1
39562;;Villard-sur-Bienne;VILLARD-SUR-BIENNE;39200;39;JURA;1
39564;;Villechantria;VILLECHANTRIA;39320;39;JURA;1
39565;;Villeneuve-d'Aval;VILLENEUVE-D'AVAL;39600;39;JURA;1
39566;;Villeneuve-lès-Charnod;VILLENEUVE-LES-CHARNOD;39240;39;JURA;1
39567;;Villeneuve-sous-Pymont;VILLENEUVE-SOUS-PYMONT;39570;39;JURA;1
39568;;Villerserine;VILLERSERINE;39800;39;JURA;1
39569;;Villers-Farlay;VILLERS-FARLAY;39600;39;JURA;1
39570;;Villers-les-Bois;VILLERS-LES-BOIS;39120;39;JURA;1
39571;;Villers-Robert;VILLERS-ROBERT;39120;39;JURA;1
39572;;Villette-lès-Arbois;VILLETTE-LES-ARBOIS;39600;39;JURA;1
39573;;Villette-lès-Dole;VILLETTE-LES-DOLE;39100;39;JURA;1
39574;;Villevieux;VILLEVIEUX;39140;39;JURA;1
39575;Le;Villey;VILLEY;39230;39;JURA;1
39576;;Vincelles;VINCELLES;39190;39;JURA;1
39577;;Vincent;VINCENT;39230;39;JURA;1
39579;;Viry;VIRY;39360;39;JURA;1
39581;;Vitreux;VITREUX;39350;39;JURA;1
39582;;Voiteur;VOITEUR;39210;39;JURA;1
39583;;Vosbles;VOSBLES;39240;39;JURA;1
39584;;Vriange;VRIANGE;39700;39;JURA;1
39585;;Vulvoz;VULVOZ;39360;39;JURA;1
39586;;Aresches;ARESCHES;39110;39;JURA;1
40001;;Aire-sur-l'Adour;AIRE-SUR-L'ADOUR;40800;40;LANDES;1
40002;;Amou;AMOU;40330;40;LANDES;1
40003;;Angoumé;ANGOUME;40990;40;LANDES;1
40004;;Angresse;ANGRESSE;40150;40;LANDES;1
40005;;Arboucave;ARBOUCAVE;40320;40;LANDES;1
40006;;Arengosse;ARENGOSSE;40110;40;LANDES;1
40007;;Argelos;ARGELOS;40700;40;LANDES;1
40008;;Argelouse;ARGELOUSE;40430;40;LANDES;1
40009;;Arjuzanx;ARJUZANX;40110;40;LANDES;1
40011;;Arsague;ARSAGUE;40330;40;LANDES;1
40012;;Artassenx;ARTASSENX;40090;40;LANDES;1
40013;;Arthez-d'Armagnac;ARTHEZ-D'ARMAGNAC;40190;40;LANDES;1
40014;;Arue;ARUE;40120;40;LANDES;1
40015;;Arx;ARX;40310;40;LANDES;1
40016;;Aubagnan;AUBAGNAN;40700;40;LANDES;1
40017;;Audignon;AUDIGNON;40500;40;LANDES;1
40018;;Audon;AUDON;40400;40;LANDES;1
40019;;Aureilhan;AUREILHAN;40200;40;LANDES;1
40020;;Aurice;AURICE;40500;40;LANDES;1
40021;;Azur;AZUR;40140;40;LANDES;1
40022;;Bahus-Soubiran;BAHUS-SOUBIRAN;40320;40;LANDES;1
40023;;Baigts;BAIGTS;40380;40;LANDES;1
40024;;Banos;BANOS;40500;40;LANDES;1
40025;;Bascons;BASCONS;40090;40;LANDES;1
40026;;Bas-Mauco;BAS-MAUCO;40500;40;LANDES;1
40027;;Bassercles;BASSERCLES;40700;40;LANDES;1
40028;;Bastennes;BASTENNES;40360;40;LANDES;1
40029;;Bats;BATS;40320;40;LANDES;1
40030;;Baudignan;BAUDIGNAN;40310;40;LANDES;1
40031;;Bégaar;BEGAAR;40400;40;LANDES;1
40032;;Belhade;BELHADE;40410;40;LANDES;1
40033;;Bélis;BELIS;40120;40;LANDES;1
40034;;Bélus;BELUS;40300;40;LANDES;1
40035;;Bénesse-lès-Dax;BENESSE-LES-DAX;40180;40;LANDES;1
40036;;Bénesse-Maremne;BENESSE-MAREMNE;40230;40;LANDES;1
40037;;Benquet;BENQUET;40280;40;LANDES;1
40038;;Bergouey;BERGOUEY;40250;40;LANDES;1
40039;;Betbezer-d'Armagnac;BETBEZER-D'ARMAGNAC;40240;40;LANDES;1
40040;;Beylongue;BEYLONGUE;40370;40;LANDES;1
40041;;Beyries;BEYRIES;40700;40;LANDES;1
40042;;Biarrotte;BIARROTTE;40390;40;LANDES;1
40043;;Bias;BIAS;40170;40;LANDES;1
40044;;Biaudos;BIAUDOS;40390;40;LANDES;1
40046;;Biscarrosse;BISCARROSSE;40600;40;LANDES;1
40047;;Bonnegarde;BONNEGARDE;40330;40;LANDES;1
40048;;Boos;BOOS;40370;40;LANDES;1
40049;;Bordères-et-Lamensans;BORDERES-ET-LAMENSANS;40270;40;LANDES;1
40050;;Bostens;BOSTENS;40090;40;LANDES;1
40051;;Bougue;BOUGUE;40090;40;LANDES;1
40052;;Bourdalat;BOURDALAT;40190;40;LANDES;1
40053;;Bourriot-Bergonce;BOURRIOT-BERGONCE;40120;40;LANDES;1
40054;;Brassempouy;BRASSEMPOUY;40330;40;LANDES;1
40055;;Bretagne-de-Marsan;BRETAGNE-DE-MARSAN;40280;40;LANDES;1
40056;;Brocas;BROCAS;40420;40;LANDES;1
40057;;Buanes;BUANES;40320;40;LANDES;1
40058;;Cachen;CACHEN;40120;40;LANDES;1
40059;;Cagnotte;CAGNOTTE;40300;40;LANDES;1
40060;;Callen;CALLEN;40430;40;LANDES;1
40061;;Campagne;CAMPAGNE;40090;40;LANDES;1
40062;;Campet-et-Lamolère;CAMPET-ET-LAMOLERE;40090;40;LANDES;1
40063;;Candresse;CANDRESSE;40180;40;LANDES;1
40064;;Canenx-et-Réaut;CANENX-ET-REAUT;40090;40;LANDES;1
40065;;Capbreton;CAPBRETON;40130;40;LANDES;1
40066;;Carcarès-Sainte-Croix;CARCARES-SAINTE-CROIX;40400;40;LANDES;1
40067;;Carcen-Ponson;CARCEN-PONSON;40400;40;LANDES;1
40068;;Cassen;CASSEN;40380;40;LANDES;1
40069;;Castaignos-Souslens;CASTAIGNOS-SOUSLENS;40700;40;LANDES;1
40070;;Castandet;CASTANDET;40270;40;LANDES;1
40071;;Castelnau-Chalosse;CASTELNAU-CHALOSSE;40360;40;LANDES;1
40072;;Castelnau-Tursan;CASTELNAU-TURSAN;40320;40;LANDES;1
40073;;Castelner;CASTELNER;40700;40;LANDES;1
40074;;Castel-Sarrazin;CASTEL-SARRAZIN;40330;40;LANDES;1
40075;;Castets;CASTETS;40260;40;LANDES;1
40076;;Cauna;CAUNA;40500;40;LANDES;1
40077;;Cauneille;CAUNEILLE;40300;40;LANDES;1
40078;;Caupenne;CAUPENNE;40250;40;LANDES;1
40079;;Cazalis;CAZALIS;40700;40;LANDES;1
40080;;Cazères-sur-l'Adour;CAZERES-SUR-L'ADOUR;40270;40;LANDES;1
40081;;Cère;CERE;40090;40;LANDES;1
40082;;Classun;CLASSUN;40320;40;LANDES;1
40083;;Clèdes;CLEDES;40320;40;LANDES;1
40084;;Clermont;CLERMONT;40180;40;LANDES;1
40085;;Commensacq;COMMENSACQ;40210;40;LANDES;1
40086;;Coudures;COUDURES;40500;40;LANDES;1
40087;;Créon-d'Armagnac;CREON-D'ARMAGNAC;40240;40;LANDES;1
40088;;Dax;DAX;40100;40;LANDES;1
40089;;Doazit;DOAZIT;40700;40;LANDES;1
40090;;Donzacq;DONZACQ;40360;40;LANDES;1
40091;;Duhort-Bachen;DUHORT-BACHEN;40800;40;LANDES;1
40092;;Dumes;DUMES;40500;40;LANDES;1
40093;;Escalans;ESCALANS;40310;40;LANDES;1
40094;;Escource;ESCOURCE;40210;40;LANDES;1
40095;;Estibeaux;ESTIBEAUX;40290;40;LANDES;1
40096;;Estigarde;ESTIGARDE;40240;40;LANDES;1
40097;;Eugénie-les-Bains;EUGENIE-LES-BAINS;40320;40;LANDES;1
40098;;Eyres-Moncube;EYRES-MONCUBE;40500;40;LANDES;1
40099;;Fargues;FARGUES;40500;40;LANDES;1
40100;Le;Frêche;FRECHE;40190;40;LANDES;1
40101;;Gaas;GAAS;40350;40;LANDES;1
40102;;Gabarret;GABARRET;40310;40;LANDES;1
40103;;Gaillères;GAILLERES;40090;40;LANDES;1
40104;;Gamarde-les-Bains;GAMARDE-LES-BAINS;40380;40;LANDES;1
40105;;Garein;GAREIN;40420;40;LANDES;1
40106;;Garrey;GARREY;40180;40;LANDES;1
40107;;Garrosse;GARROSSE;40110;40;LANDES;1
40108;;Gastes;GASTES;40160;40;LANDES;1
40109;;Gaujacq;GAUJACQ;40330;40;LANDES;1
40110;;Geaune;GEAUNE;40320;40;LANDES;1
40111;;Geloux;GELOUX;40090;40;LANDES;1
40112;;Gibret;GIBRET;40380;40;LANDES;1
40113;;Goos;GOOS;40180;40;LANDES;1
40114;;Gourbera;GOURBERA;40990;40;LANDES;1
40115;;Gousse;GOUSSE;40465;40;LANDES;1
40116;;Gouts;GOUTS;40400;40;LANDES;1
40117;;Grenade-sur-l'Adour;GRENADE-SUR-L'ADOUR;40270;40;LANDES;1
40118;;Habas;HABAS;40290;40;LANDES;1
40119;;Hagetmau;HAGETMAU;40700;40;LANDES;1
40120;;Hastingues;HASTINGUES;40300;40;LANDES;1
40121;;Hauriet;HAURIET;40250;40;LANDES;1
40122;;Haut-Mauco;HAUT-MAUCO;40280;40;LANDES;1
40123;;Herm;HERM;40990;40;LANDES;1
40124;;Herré;HERRE;40310;40;LANDES;1
40125;;Heugas;HEUGAS;40180;40;LANDES;1
40126;;Hinx;HINX;40180;40;LANDES;1
40127;;Hontanx;HONTANX;40190;40;LANDES;1
40128;;Horsarrieu;HORSARRIEU;40700;40;LANDES;1
40129;;Josse;JOSSE;40230;40;LANDES;1
40130;;Labastide-Chalosse;LABASTIDE-CHALOSSE;40700;40;LANDES;1
40131;;Labastide-d'Armagnac;LABASTIDE-D'ARMAGNAC;40240;40;LANDES;1
40132;;Labatut;LABATUT;40300;40;LANDES;1
40133;;Labenne;LABENNE;40530;40;LANDES;1
40134;;Labouheyre;LABOUHEYRE;40210;40;LANDES;1
40135;;Labrit;LABRIT;40420;40;LANDES;1
40136;;Lacajunte;LACAJUNTE;40320;40;LANDES;1
40137;;Lacquy;LACQUY;40120;40;LANDES;1
40138;;Lacrabe;LACRABE;40700;40;LANDES;1
40139;;Laglorieuse;LAGLORIEUSE;40090;40;LANDES;1
40140;;Lagrange;LAGRANGE;40240;40;LANDES;1
40141;;Lahosse;LAHOSSE;40250;40;LANDES;1
40142;;Laluque;LALUQUE;40465;40;LANDES;1
40143;;Lamothe;LAMOTHE;40250;40;LANDES;1
40144;;Larbey;LARBEY;40250;40;LANDES;1
40145;;Larrivière-Saint-Savin;LARRIVIERE-SAINT-SAVIN;40270;40;LANDES;1
40146;;Latrille;LATRILLE;40800;40;LANDES;1
40147;;Laurède;LAUREDE;40250;40;LANDES;1
40148;;Lauret;LAURET;40320;40;LANDES;1
40149;;Lencouacq;LENCOUACQ;40120;40;LANDES;1
40150;;Léon;LEON;40550;40;LANDES;1
40151;;Lesgor;LESGOR;40400;40;LANDES;1
40152;;Lesperon;LESPERON;40260;40;LANDES;1
40153;Le;Leuy;LEUY;40250;40;LANDES;1
40154;;Lévignacq;LEVIGNACQ;40170;40;LANDES;1
40155;;Linxe;LINXE;40260;40;LANDES;1
40156;;Liposthey;LIPOSTHEY;40410;40;LANDES;1
40157;;Lit-et-Mixe;LIT-ET-MIXE;40170;40;LANDES;1
40158;;Losse;LOSSE;40240;40;LANDES;1
40159;;Louer;LOUER;40380;40;LANDES;1
40160;;Lourquen;LOURQUEN;40250;40;LANDES;1
40161;;Lubbon;LUBBON;40240;40;LANDES;1
40162;;Lucbardez-et-Bargues;LUCBARDEZ-ET-BARGUES;40090;40;LANDES;1
40163;;Lüe;LUE;40210;40;LANDES;1
40164;;Retjons;RETJONS;40120;40;LANDES;1
40165;;Luglon;LUGLON;40630;40;LANDES;1
40166;;Lussagnet;LUSSAGNET;40270;40;LANDES;1
40167;;Luxey;LUXEY;40430;40;LANDES;1
40168;;Magescq;MAGESCQ;40140;40;LANDES;1
40169;;Maillas;MAILLAS;40120;40;LANDES;1
40170;;Maillères;MAILLERES;40120;40;LANDES;1
40171;;Mano;MANO;40410;40;LANDES;1
40172;;Mant;MANT;40700;40;LANDES;1
40173;;Marpaps;MARPAPS;40330;40;LANDES;1
40174;;Mauries;MAURIES;40320;40;LANDES;1
40175;;Maurrin;MAURRIN;40270;40;LANDES;1
40176;;Mauvezin-d'Armagnac;MAUVEZIN-D'ARMAGNAC;40240;40;LANDES;1
40177;;Maylis;MAYLIS;40250;40;LANDES;1
40178;;Mazerolles;MAZEROLLES;40090;40;LANDES;1
40179;;Mées;MEES;40990;40;LANDES;1
40180;;Meilhan;MEILHAN;40400;40;LANDES;1
40181;;Messanges;MESSANGES;40660;40;LANDES;1
40182;;Mézos;MEZOS;40170;40;LANDES;1
40183;;Mimbaste;MIMBASTE;40350;40;LANDES;1
40184;;Mimizan;MIMIZAN;40200;40;LANDES;1
40185;;Miramont-Sensacq;MIRAMONT-SENSACQ;40320;40;LANDES;1
40186;;Misson;MISSON;40290;40;LANDES;1
40187;;Moliets-et-Maa;MOLIETS-ET-MAA;40660;40;LANDES;1
40188;;Momuy;MOMUY;40700;40;LANDES;1
40189;;Monget;MONGET;40700;40;LANDES;1
40190;;Monségur;MONSEGUR;40700;40;LANDES;1
40191;;Montaut;MONTAUT;40500;40;LANDES;1
40192;;Mont-de-Marsan;MONT-DE-MARSAN;40000;40;LANDES;1
40193;;Montégut;MONTEGUT;40190;40;LANDES;1
40194;;Montfort-en-Chalosse;MONTFORT-EN-CHALOSSE;40380;40;LANDES;1
40195;;Montgaillard;MONTGAILLARD;40500;40;LANDES;1
40196;;Montsoué;MONTSOUE;40500;40;LANDES;1
40197;;Morcenx;MORCENX;40110;40;LANDES;1
40198;;Morganx;MORGANX;40700;40;LANDES;1
40199;;Mouscardès;MOUSCARDES;40290;40;LANDES;1
40200;;Moustey;MOUSTEY;40410;40;LANDES;1
40201;;Mugron;MUGRON;40250;40;LANDES;1
40202;;Narrosse;NARROSSE;40180;40;LANDES;1
40203;;Nassiet;NASSIET;40330;40;LANDES;1
40204;;Nerbis;NERBIS;40250;40;LANDES;1
40205;;Nousse;NOUSSE;40380;40;LANDES;1
40206;;Oeyregave;OEYREGAVE;40300;40;LANDES;1
40207;;Oeyreluy;OEYRELUY;40180;40;LANDES;1
40208;;Onard;ONARD;40380;40;LANDES;1
40209;;Ondres;ONDRES;40440;40;LANDES;1
40210;;Onesse-et-Laharie;ONESSE-ET-LAHARIE;40110;40;LANDES;1
40211;;Orist;ORIST;40300;40;LANDES;1
40212;;Orthevielle;ORTHEVIELLE;40300;40;LANDES;1
40213;;Orx;ORX;40230;40;LANDES;1
40214;;Ossages;OSSAGES;40290;40;LANDES;1
40215;;Ousse-Suzan;OUSSE-SUZAN;40110;40;LANDES;1
40216;;Ozourt;OZOURT;40380;40;LANDES;1
40217;;Parentis-en-Born;PARENTIS-EN-BORN;40160;40;LANDES;1
40218;;Parleboscq;PARLEBOSCQ;40310;40;LANDES;1
40219;;Payros-Cazautets;PAYROS-CAZAUTETS;40320;40;LANDES;1
40220;;Pécorade;PECORADE;40320;40;LANDES;1
40221;;Perquie;PERQUIE;40190;40;LANDES;1
40222;;Pey;PEY;40300;40;LANDES;1
40223;;Peyre;PEYRE;40700;40;LANDES;1
40224;;Peyrehorade;PEYREHORADE;40300;40;LANDES;1
40225;;Philondenx;PHILONDENX;40320;40;LANDES;1
40226;;Pimbo;PIMBO;40320;40;LANDES;1
40227;;Pissos;PISSOS;40410;40;LANDES;1
40228;;Pomarez;POMAREZ;40360;40;LANDES;1
40229;;Pontenx-les-Forges;PONTENX-LES-FORGES;40200;40;LANDES;1
40230;;Pontonx-sur-l'Adour;PONTONX-SUR-L'ADOUR;40465;40;LANDES;1
40231;;Port-de-Lanne;PORT-DE-LANNE;40300;40;LANDES;1
40232;;Poudenx;POUDENX;40700;40;LANDES;1
40233;;Pouillon;POUILLON;40350;40;LANDES;1
40234;;Pouydesseaux;POUYDESSEAUX;40120;40;LANDES;1
40235;;Poyanne;POYANNE;40380;40;LANDES;1
40236;;Poyartin;POYARTIN;40380;40;LANDES;1
40237;;Préchacq-les-Bains;PRECHACQ-LES-BAINS;40465;40;LANDES;1
40238;;Pujo-le-Plan;PUJO-LE-PLAN;40190;40;LANDES;1
40239;;Puyol-Cazalet;PUYOL-CAZALET;40320;40;LANDES;1
40240;;Renung;RENUNG;40270;40;LANDES;1
40242;;Rimbez-et-Baudiets;RIMBEZ-ET-BAUDIETS;40310;40;LANDES;1
40243;;Rion-des-Landes;RION-DES-LANDES;40370;40;LANDES;1
40244;;Rivière-Saas-et-Gourby;RIVIERE-SAAS-ET-GOURBY;40180;40;LANDES;1
40245;;Roquefort;ROQUEFORT;40120;40;LANDES;1
40246;;Sabres;SABRES;40630;40;LANDES;1
40247;;Saint-Agnet;SAINT-AGNET;40800;40;LANDES;1
40248;;Saint-André-de-Seignanx;SAINT-ANDRE-DE-SEIGNANX;40390;40;LANDES;1
40249;;Saint-Aubin;SAINT-AUBIN;40250;40;LANDES;1
40250;;Saint-Avit;SAINT-AVIT;40090;40;LANDES;1
40251;;Saint-Barthélemy;SAINT-BARTHELEMY;40390;40;LANDES;1
40252;;Sainte-Colombe;SAINTE-COLOMBE;40700;40;LANDES;1
40253;;Saint-Cricq-Chalosse;SAINT-CRICQ-CHALOSSE;40700;40;LANDES;1
40254;;Saint-Cricq-du-Gave;SAINT-CRICQ-DU-GAVE;40300;40;LANDES;1
40255;;Saint-Cricq-Villeneuve;SAINT-CRICQ-VILLENEUVE;40190;40;LANDES;1
40256;;Saint-Étienne-d'Orthe;SAINT-ETIENNE-D'ORTHE;40300;40;LANDES;1
40257;;Sainte-Eulalie-en-Born;SAINTE-EULALIE-EN-BORN;40200;40;LANDES;1
40258;;Sainte-Foy;SAINTE-FOY;40190;40;LANDES;1
40259;;Saint-Gein;SAINT-GEIN;40190;40;LANDES;1
40260;;Saint-Geours-d'Auribat;SAINT-GEOURS-D'AURIBAT;40380;40;LANDES;1
40261;;Saint-Geours-de-Maremne;SAINT-GEOURS-DE-MAREMNE;40230;40;LANDES;1
40262;;Saint-Gor;SAINT-GOR;40120;40;LANDES;1
40263;;Saint-Jean-de-Lier;SAINT-JEAN-DE-LIER;40380;40;LANDES;1
40264;;Saint-Jean-de-Marsacq;SAINT-JEAN-DE-MARSACQ;40230;40;LANDES;1
40265;;Saint-Julien-d'Armagnac;SAINT-JULIEN-D'ARMAGNAC;40240;40;LANDES;1
40266;;Saint-Julien-en-Born;SAINT-JULIEN-EN-BORN;40170;40;LANDES;1
40267;;Saint-Justin;SAINT-JUSTIN;40240;40;LANDES;1
40268;;Saint-Laurent-de-Gosse;SAINT-LAURENT-DE-GOSSE;40390;40;LANDES;1
40269;;Saint-Lon-les-Mines;SAINT-LON-LES-MINES;40300;40;LANDES;1
40270;;Saint-Loubouer;SAINT-LOUBOUER;40320;40;LANDES;1
40271;;Sainte-Marie-de-Gosse;SAINTE-MARIE-DE-GOSSE;40390;40;LANDES;1
40272;;Saint-Martin-de-Hinx;SAINT-MARTIN-DE-HINX;40390;40;LANDES;1
40273;;Saint-Martin-de-Seignanx;SAINT-MARTIN-DE-SEIGNANX;40390;40;LANDES;1
40274;;Saint-Martin-d'Oney;SAINT-MARTIN-D'ONEY;40090;40;LANDES;1
40275;;Saint-Maurice-sur-Adour;SAINT-MAURICE-SUR-ADOUR;40270;40;LANDES;1
40276;;Saint-Michel-Escalus;SAINT-MICHEL-ESCALUS;40550;40;LANDES;1
40277;;Saint-Pandelon;SAINT-PANDELON;40180;40;LANDES;1
40278;;Saint-Paul-en-Born;SAINT-PAUL-EN-BORN;40200;40;LANDES;1
40279;;Saint-Paul-lès-Dax;SAINT-PAUL-LES-DAX;40990;40;LANDES;1
40280;;Saint-Perdon;SAINT-PERDON;40090;40;LANDES;1
40281;;Saint-Pierre-du-Mont;SAINT-PIERRE-DU-MONT;40280;40;LANDES;1
40282;;Saint-Sever;SAINT-SEVER;40500;40;LANDES;1
40283;;Saint-Vincent-de-Paul;SAINT-VINCENT-DE-PAUL;40990;40;LANDES;1
40284;;Saint-Vincent-de-Tyrosse;SAINT-VINCENT-DE-TYROSSE;40230;40;LANDES;1
40285;;Saint-Yaguen;SAINT-YAGUEN;40400;40;LANDES;1
40286;;Samadet;SAMADET;40320;40;LANDES;1
40287;;Sanguinet;SANGUINET;40460;40;LANDES;1
40288;;Sarbazan;SARBAZAN;40120;40;LANDES;1
40289;;Sarraziet;SARRAZIET;40500;40;LANDES;1
40290;;Sarron;SARRON;40800;40;LANDES;1
40291;;Saubion;SAUBION;40230;40;LANDES;1
40292;;Saubrigues;SAUBRIGUES;40230;40;LANDES;1
40293;;Saubusse;SAUBUSSE;40180;40;LANDES;1
40294;;Saugnac-et-Cambran;SAUGNAC-ET-CAMBRAN;40180;40;LANDES;1
40295;;Saugnacq-et-Muret;SAUGNACQ-ET-MURET;40410;40;LANDES;1
40296;;Seignosse;SEIGNOSSE;40510;40;LANDES;1
40297;Le;Sen;SEN;40420;40;LANDES;1
40298;;Serres-Gaston;SERRES-GASTON;40700;40;LANDES;1
40299;;Serreslous-et-Arribans;SERRESLOUS-ET-ARRIBANS;40700;40;LANDES;1
40300;;Seyresse;SEYRESSE;40180;40;LANDES;1
40301;;Siest;SIEST;40180;40;LANDES;1
40302;;Sindères;SINDERES;40110;40;LANDES;1
40303;;Solférino;SOLFERINO;40210;40;LANDES;1
40304;;Soorts-Hossegor;SOORTS-HOSSEGOR;40150;40;LANDES;1
40305;;Sorbets;SORBETS;40320;40;LANDES;1
40306;;Sorde-l'Abbaye;SORDE-L'ABBAYE;40300;40;LANDES;1
40307;;Sore;SORE;40430;40;LANDES;1
40308;;Sort-en-Chalosse;SORT-EN-CHALOSSE;40180;40;LANDES;1
40309;;Souprosse;SOUPROSSE;40250;40;LANDES;1
40310;;Soustons;SOUSTONS;40140;40;LANDES;1
40311;;Taller;TALLER;40260;40;LANDES;1
40312;;Tarnos;TARNOS;40220;40;LANDES;1
40313;;Tartas;TARTAS;40400;40;LANDES;1
40314;;Tercis-les-Bains;TERCIS-LES-BAINS;40180;40;LANDES;1
40315;;Téthieu;TETHIEU;40990;40;LANDES;1
40316;;Tilh;TILH;40360;40;LANDES;1
40317;;Tosse;TOSSE;40230;40;LANDES;1
40318;;Toulouzette;TOULOUZETTE;40250;40;LANDES;1
40319;;Trensacq;TRENSACQ;40630;40;LANDES;1
40320;;Uchacq-et-Parentis;UCHACQ-ET-PARENTIS;40090;40;LANDES;1
40321;;Urgons;URGONS;40320;40;LANDES;1
40322;;Uza;UZA;40170;40;LANDES;1
40323;;Vert;VERT;40420;40;LANDES;1
40324;;Vicq-d'Auribat;VICQ-D'AURIBAT;40380;40;LANDES;1
40325;;Vielle-Tursan;VIELLE-TURSAN;40320;40;LANDES;1
40326;;Vielle-Saint-Girons;VIELLE-SAINT-GIRONS;40560;40;LANDES;1
40327;;Vielle-Soubiran;VIELLE-SOUBIRAN;40240;40;LANDES;1
40328;;Vieux-Boucau-les-Bains;VIEUX-BOUCAU-LES-BAINS;40480;40;LANDES;1
40329;Le;Vignau;VIGNAU;40270;40;LANDES;1
40330;;Villenave;VILLENAVE;40110;40;LANDES;1
40331;;Villeneuve-de-Marsan;VILLENEUVE-DE-MARSAN;40190;40;LANDES;1
40332;;Ychoux;YCHOUX;40160;40;LANDES;1
40333;;Ygos-Saint-Saturnin;YGOS-SAINT-SATURNIN;40110;40;LANDES;1
40334;;Yzosse;YZOSSE;40180;40;LANDES;1
41001;;Ambloy;AMBLOY;41310;41;LOIR ET CHER;1
41002;;Angé;ANGE;41400;41;LOIR ET CHER;1
41003;;Areines;AREINES;41100;41;LOIR ET CHER;1
41004;;Artins;ARTINS;41800;41;LOIR ET CHER;1
41005;;Arville;ARVILLE;41170;41;LOIR ET CHER;1
41006;;Autainville;AUTAINVILLE;41240;41;LOIR ET CHER;1
41007;;Authon;AUTHON;41310;41;LOIR ET CHER;1
41008;;Avaray;AVARAY;41500;41;LOIR ET CHER;1
41009;;Averdon;AVERDON;41330;41;LOIR ET CHER;1
41010;;Azé;AZE;41100;41;LOIR ET CHER;1
41011;;Baigneaux;BAIGNEAUX;41290;41;LOIR ET CHER;1
41012;;Baillou;BAILLOU;41170;41;LOIR ET CHER;1
41013;;Bauzy;BAUZY;41250;41;LOIR ET CHER;1
41014;;Beauchêne;BEAUCHENE;41170;41;LOIR ET CHER;1
41015;;Beauvilliers;BEAUVILLIERS;41290;41;LOIR ET CHER;1
41016;;Billy;BILLY;41130;41;LOIR ET CHER;1
41017;;Binas;BINAS;41240;41;LOIR ET CHER;1
41018;;Blois;BLOIS;41000;41;LOIR ET CHER;1
41019;;Boisseau;BOISSEAU;41290;41;LOIR ET CHER;1
41020;;Bonneveau;BONNEVEAU;41800;41;LOIR ET CHER;1
41022;;Bouffry;BOUFFRY;41270;41;LOIR ET CHER;1
41023;;Bourré;BOURRE;41400;41;LOIR ET CHER;1
41024;;Boursay;BOURSAY;41270;41;LOIR ET CHER;1
41025;;Bracieux;BRACIEUX;41250;41;LOIR ET CHER;1
41026;;Brévainville;BREVAINVILLE;41160;41;LOIR ET CHER;1
41027;;Briou;BRIOU;41370;41;LOIR ET CHER;1
41028;;Busloup;BUSLOUP;41160;41;LOIR ET CHER;1
41029;;Candé-sur-Beuvron;CANDE-SUR-BEUVRON;41120;41;LOIR ET CHER;1
41030;;Cellé;CELLE;41360;41;LOIR ET CHER;1
41031;;Cellettes;CELLETTES;41120;41;LOIR ET CHER;1
41032;;Chailles;CHAILLES;41120;41;LOIR ET CHER;1
41033;;Chambon-sur-Cisse;CHAMBON-SUR-CISSE;41190;41;LOIR ET CHER;1
41034;;Chambord;CHAMBORD;41250;41;LOIR ET CHER;1
41035;;Champigny-en-Beauce;CHAMPIGNY-EN-BEAUCE;41330;41;LOIR ET CHER;1
41036;;Chaon;CHAON;41600;41;LOIR ET CHER;1
41037;La;Chapelle-Enchérie;CHAPELLE-ENCHERIE;41290;41;LOIR ET CHER;1
41038;La;Chapelle-Montmartin;CHAPELLE-MONTMARTIN;41320;41;LOIR ET CHER;1
41039;La;Chapelle-Saint-Martin-en-Plaine;CHAPELLE-SAINT-MARTIN-EN-PLAINE;41500;41;LOIR ET CHER;1
41040;La;Chapelle-Vendômoise;CHAPELLE-VENDOMOISE;41330;41;LOIR ET CHER;1
41041;La;Chapelle-Vicomtesse;CHAPELLE-VICOMTESSE;41270;41;LOIR ET CHER;1
41042;;Châteauvieux;CHATEAUVIEUX;41110;41;LOIR ET CHER;1
41043;;Châtillon-sur-Cher;CHATILLON-SUR-CHER;41130;41;LOIR ET CHER;1
41044;;Châtres-sur-Cher;CHATRES-SUR-CHER;41320;41;LOIR ET CHER;1
41045;;Chaumont-sur-Loire;CHAUMONT-SUR-LOIRE;41150;41;LOIR ET CHER;1
41046;;Chaumont-sur-Tharonne;CHAUMONT-SUR-THARONNE;41600;41;LOIR ET CHER;1
41047;La;Chaussée-Saint-Victor;CHAUSSEE-SAINT-VICTOR;41260;41;LOIR ET CHER;1
41048;;Chauvigny-du-Perche;CHAUVIGNY-DU-PERCHE;41270;41;LOIR ET CHER;1
41049;;Chémery;CHEMERY;41700;41;LOIR ET CHER;1
41050;;Cheverny;CHEVERNY;41700;41;LOIR ET CHER;1
41051;;Chissay-en-Touraine;CHISSAY-EN-TOURAINE;41400;41;LOIR ET CHER;1
41052;;Chitenay;CHITENAY;41120;41;LOIR ET CHER;1
41053;;Choue;CHOUE;41170;41;LOIR ET CHER;1
41054;;Choussy;CHOUSSY;41700;41;LOIR ET CHER;1
41055;;Chouzy-sur-Cisse;CHOUZY-SUR-CISSE;41150;41;LOIR ET CHER;1
41056;La;Colombe;COLOMBE;41160;41;LOIR ET CHER;1
41057;;Conan;CONAN;41290;41;LOIR ET CHER;1
41058;;Concriers;CONCRIERS;41370;41;LOIR ET CHER;1
41059;;Contres;CONTRES;41700;41;LOIR ET CHER;1
41060;;Cormenon;CORMENON;41170;41;LOIR ET CHER;1
41061;;Cormeray;CORMERAY;41120;41;LOIR ET CHER;1
41062;;Couddes;COUDDES;41700;41;LOIR ET CHER;1
41063;;Couffy;COUFFY;41110;41;LOIR ET CHER;1
41064;;Coulanges;COULANGES;41150;41;LOIR ET CHER;1
41065;;Coulommiers-la-Tour;COULOMMIERS-LA-TOUR;41100;41;LOIR ET CHER;1
41066;;Courbouzon;COURBOUZON;41500;41;LOIR ET CHER;1
41067;;Cour-Cheverny;COUR-CHEVERNY;41700;41;LOIR ET CHER;1
41068;;Courmemin;COURMEMIN;41230;41;LOIR ET CHER;1
41069;;Cour-sur-Loire;COUR-SUR-LOIRE;41500;41;LOIR ET CHER;1
41070;;Couture-sur-Loir;COUTURE-SUR-LOIR;41800;41;LOIR ET CHER;1
41071;;Crouy-sur-Cosson;CROUY-SUR-COSSON;41220;41;LOIR ET CHER;1
41072;;Crucheray;CRUCHERAY;41100;41;LOIR ET CHER;1
41073;;Danzé;DANZE;41160;41;LOIR ET CHER;1
41074;;Dhuizon;DHUIZON;41220;41;LOIR ET CHER;1
41075;;Droué;DROUE;41270;41;LOIR ET CHER;1
41077;;Épiais;EPIAIS;41290;41;LOIR ET CHER;1
41078;;Épuisay;EPUISAY;41360;41;LOIR ET CHER;1
41079;Les;Essarts;ESSARTS;41800;41;LOIR ET CHER;1
41080;;Faverolles-sur-Cher;FAVEROLLES-SUR-CHER;41400;41;LOIR ET CHER;1
41081;;Faye;FAYE;41100;41;LOIR ET CHER;1
41082;;Feings;FEINGS;41120;41;LOIR ET CHER;1
41083;La;Ferté-Beauharnais;FERTE-BEAUHARNAIS;41210;41;LOIR ET CHER;1
41084;La;Ferté-Imbault;FERTE-IMBAULT;41300;41;LOIR ET CHER;1
41085;La;Ferté-Saint-Cyr;FERTE-SAINT-CYR;41220;41;LOIR ET CHER;1
41086;;Fontaines-en-Sologne;FONTAINES-EN-SOLOGNE;41250;41;LOIR ET CHER;1
41087;;Fontaine-les-Coteaux;FONTAINE-LES-COTEAUX;41800;41;LOIR ET CHER;1
41088;;Fontaine-Raoul;FONTAINE-RAOUL;41270;41;LOIR ET CHER;1
41089;La;Fontenelle;FONTENELLE;41270;41;LOIR ET CHER;1
41090;;Fortan;FORTAN;41360;41;LOIR ET CHER;1
41091;;Fossé;FOSSE;41330;41;LOIR ET CHER;1
41092;;Fougères-sur-Bièvre;FOUGERES-SUR-BIEVRE;41120;41;LOIR ET CHER;1
41093;;Françay;FRANCAY;41190;41;LOIR ET CHER;1
41094;;Fresnes;FRESNES;41700;41;LOIR ET CHER;1
41095;;Fréteval;FRETEVAL;41160;41;LOIR ET CHER;1
41096;Le;Gault-Perche;GAULT-PERCHE;41270;41;LOIR ET CHER;1
41097;;Gièvres;GIEVRES;41130;41;LOIR ET CHER;1
41098;;Gombergean;GOMBERGEAN;41310;41;LOIR ET CHER;1
41099;;Gy-en-Sologne;GY-EN-SOLOGNE;41230;41;LOIR ET CHER;1
41100;Les;Hayes;HAYES;41800;41;LOIR ET CHER;1
41101;;Herbault;HERBAULT;41190;41;LOIR ET CHER;1
41102;;Houssay;HOUSSAY;41800;41;LOIR ET CHER;1
41103;;Huisseau-en-Beauce;HUISSEAU-EN-BEAUCE;41310;41;LOIR ET CHER;1
41104;;Huisseau-sur-Cosson;HUISSEAU-SUR-COSSON;41350;41;LOIR ET CHER;1
41105;;Josnes;JOSNES;41370;41;LOIR ET CHER;1
41106;;Lamotte-Beuvron;LAMOTTE-BEUVRON;41600;41;LOIR ET CHER;1
41107;;Lancé;LANCE;41310;41;LOIR ET CHER;1
41108;;Lancôme;LANCOME;41190;41;LOIR ET CHER;1
41109;;Landes-le-Gaulois;LANDES-LE-GAULOIS;41190;41;LOIR ET CHER;1
41110;;Langon;LANGON;41320;41;LOIR ET CHER;1
41112;;Lassay-sur-Croisne;LASSAY-SUR-CROISNE;41230;41;LOIR ET CHER;1
41113;;Lavardin;LAVARDIN;41800;41;LOIR ET CHER;1
41114;;Lestiou;LESTIOU;41500;41;LOIR ET CHER;1
41115;;Lignières;LIGNIERES;41160;41;LOIR ET CHER;1
41116;;Lisle;LISLE;41100;41;LOIR ET CHER;1
41118;;Loreux;LOREUX;41200;41;LOIR ET CHER;1
41119;;Lorges;LORGES;41370;41;LOIR ET CHER;1
41120;;Lunay;LUNAY;41360;41;LOIR ET CHER;1
41121;La;Madeleine-Villefrouin;MADELEINE-VILLEFROUIN;41370;41;LOIR ET CHER;1
41122;;Maray;MARAY;41320;41;LOIR ET CHER;1
41123;;Marchenoir;MARCHENOIR;41370;41;LOIR ET CHER;1
41124;;Marcilly-en-Beauce;MARCILLY-EN-BEAUCE;41100;41;LOIR ET CHER;1
41125;;Marcilly-en-Gault;MARCILLY-EN-GAULT;41210;41;LOIR ET CHER;1
41126;;Mareuil-sur-Cher;MAREUIL-SUR-CHER;41110;41;LOIR ET CHER;1
41127;La;Marolle-en-Sologne;MAROLLE-EN-SOLOGNE;41210;41;LOIR ET CHER;1
41128;;Marolles;MAROLLES;41330;41;LOIR ET CHER;1
41129;;Maslives;MASLIVES;41250;41;LOIR ET CHER;1
41130;;Maves;MAVES;41500;41;LOIR ET CHER;1
41131;;Mazangé;MAZANGE;41100;41;LOIR ET CHER;1
41132;;Méhers;MEHERS;41140;41;LOIR ET CHER;1
41133;;Membrolles;MEMBROLLES;41240;41;LOIR ET CHER;1
41134;;Menars;MENARS;41500;41;LOIR ET CHER;1
41135;;Mennetou-sur-Cher;MENNETOU-SUR-CHER;41320;41;LOIR ET CHER;1
41136;;Mer;MER;41500;41;LOIR ET CHER;1
41137;;Mesland;MESLAND;41150;41;LOIR ET CHER;1
41138;;Meslay;MESLAY;41100;41;LOIR ET CHER;1
41139;;Meusnes;MEUSNES;41130;41;LOIR ET CHER;1
41140;;Millançay;MILLANCAY;41200;41;LOIR ET CHER;1
41141;;Moisy;MOISY;41160;41;LOIR ET CHER;1
41142;;Molineuf;MOLINEUF;41190;41;LOIR ET CHER;1
41143;;Mondoubleau;MONDOUBLEAU;41170;41;LOIR ET CHER;1
41144;;Monteaux;MONTEAUX;41150;41;LOIR ET CHER;1
41145;;Monthou-sur-Bièvre;MONTHOU-SUR-BIEVRE;41120;41;LOIR ET CHER;1
41146;;Monthou-sur-Cher;MONTHOU-SUR-CHER;41400;41;LOIR ET CHER;1
41147;Les;Montils;MONTILS;41120;41;LOIR ET CHER;1
41148;;Montlivault;MONTLIVAULT;41350;41;LOIR ET CHER;1
41149;;Montoire-sur-le-Loir;MONTOIRE-SUR-LE-LOIR;41800;41;LOIR ET CHER;1
41150;;Mont-près-Chambord;MONT-PRES-CHAMBORD;41250;41;LOIR ET CHER;1
41151;;Montrichard;MONTRICHARD;41400;41;LOIR ET CHER;1
41152;;Montrieux-en-Sologne;MONTRIEUX-EN-SOLOGNE;41210;41;LOIR ET CHER;1
41153;;Montrouveau;MONTROUVEAU;41800;41;LOIR ET CHER;1
41154;;Morée;MOREE;41160;41;LOIR ET CHER;1
41155;;Muides-sur-Loire;MUIDES-SUR-LOIRE;41500;41;LOIR ET CHER;1
41156;;Mulsans;MULSANS;41500;41;LOIR ET CHER;1
41157;;Mur-de-Sologne;MUR-DE-SOLOGNE;41230;41;LOIR ET CHER;1
41158;;Naveil;NAVEIL;41100;41;LOIR ET CHER;1
41159;;Neung-sur-Beuvron;NEUNG-SUR-BEUVRON;41210;41;LOIR ET CHER;1
41160;;Neuvy;NEUVY;41250;41;LOIR ET CHER;1
41161;;Nouan-le-Fuzelier;NOUAN-LE-FUZELIER;41600;41;LOIR ET CHER;1
41163;;Nourray;NOURRAY;41310;41;LOIR ET CHER;1
41164;;Noyers-sur-Cher;NOYERS-SUR-CHER;41140;41;LOIR ET CHER;1
41165;;Oigny;OIGNY;41170;41;LOIR ET CHER;1
41166;;Oisly;OISLY;41700;41;LOIR ET CHER;1
41167;;Onzain;ONZAIN;41150;41;LOIR ET CHER;1
41168;;Orçay;ORCAY;41300;41;LOIR ET CHER;1
41169;;Orchaise;ORCHAISE;41190;41;LOIR ET CHER;1
41170;;Ouchamps;OUCHAMPS;41120;41;LOIR ET CHER;1
41171;;Oucques;OUCQUES;41290;41;LOIR ET CHER;1
41172;;Ouzouer-le-Doyen;OUZOUER-LE-DOYEN;41160;41;LOIR ET CHER;1
41173;;Ouzouer-le-Marché;OUZOUER-LE-MARCHE;41240;41;LOIR ET CHER;1
41174;;Périgny;PERIGNY;41100;41;LOIR ET CHER;1
41175;;Pezou;PEZOU;41100;41;LOIR ET CHER;1
41176;;Pierrefitte-sur-Sauldre;PIERREFITTE-SUR-SAULDRE;41300;41;LOIR ET CHER;1
41177;Le;Plessis-Dorin;PLESSIS-DORIN;41170;41;LOIR ET CHER;1
41178;Le;Plessis-l'Échelle;PLESSIS-L'ECHELLE;41370;41;LOIR ET CHER;1
41179;Le;Poislay;POISLAY;41270;41;LOIR ET CHER;1
41180;;Pontlevoy;PONTLEVOY;41400;41;LOIR ET CHER;1
41181;;Pouillé;POUILLE;41110;41;LOIR ET CHER;1
41182;;Pray;PRAY;41190;41;LOIR ET CHER;1
41183;;Prénouvellon;PRENOUVELLON;41240;41;LOIR ET CHER;1
41184;;Prunay-Cassereau;PRUNAY-CASSEREAU;41310;41;LOIR ET CHER;1
41185;;Pruniers-en-Sologne;PRUNIERS-EN-SOLOGNE;41200;41;LOIR ET CHER;1
41186;;Rahart;RAHART;41160;41;LOIR ET CHER;1
41187;;Renay;RENAY;41100;41;LOIR ET CHER;1
41188;;Rhodon;RHODON;41290;41;LOIR ET CHER;1
41189;;Rilly-sur-Loire;RILLY-SUR-LOIRE;41150;41;LOIR ET CHER;1
41190;;Rocé;ROCE;41100;41;LOIR ET CHER;1
41191;;Roches;ROCHES;41370;41;LOIR ET CHER;1
41192;Les;Roches-l'Évêque;ROCHES-L'EVEQUE;41800;41;LOIR ET CHER;1
41193;;Romilly;ROMILLY;41270;41;LOIR ET CHER;1
41194;;Romorantin-Lanthenay;ROMORANTIN-LANTHENAY;41200;41;LOIR ET CHER;1
41195;;Rougeou;ROUGEOU;41230;41;LOIR ET CHER;1
41196;;Ruan-sur-Egvonne;RUAN-SUR-EGVONNE;41270;41;LOIR ET CHER;1
41197;;Saint-Agil;SAINT-AGIL;41170;41;LOIR ET CHER;1
41198;;Saint-Aignan;SAINT-AIGNAN;41110;41;LOIR ET CHER;1
41199;;Saint-Amand-Longpré;SAINT-AMAND-LONGPRE;41310;41;LOIR ET CHER;1
41200;;Sainte-Anne;SAINTE-ANNE;41100;41;LOIR ET CHER;1
41201;;Saint-Arnoult;SAINT-ARNOULT;41800;41;LOIR ET CHER;1
41202;;Saint-Avit;SAINT-AVIT;41170;41;LOIR ET CHER;1
41203;;Saint-Bohaire;SAINT-BOHAIRE;41330;41;LOIR ET CHER;1
41204;;Saint-Claude-de-Diray;SAINT-CLAUDE-DE-DIRAY;41350;41;LOIR ET CHER;1
41205;;Saint-Cyr-du-Gault;SAINT-CYR-DU-GAULT;41190;41;LOIR ET CHER;1
41206;;Saint-Denis-sur-Loire;SAINT-DENIS-SUR-LOIRE;41000;41;LOIR ET CHER;1
41207;;Saint-Dyé-sur-Loire;SAINT-DYE-SUR-LOIRE;41500;41;LOIR ET CHER;1
41208;;Saint-Étienne-des-Guérets;SAINT-ETIENNE-DES-GUERETS;41190;41;LOIR ET CHER;1
41209;;Saint-Firmin-des-Prés;SAINT-FIRMIN-DES-PRES;41100;41;LOIR ET CHER;1
41210;;Sainte-Gemmes;SAINTE-GEMMES;41290;41;LOIR ET CHER;1
41211;;Saint-Georges-sur-Cher;SAINT-GEORGES-SUR-CHER;41400;41;LOIR ET CHER;1
41212;;Saint-Gervais-la-Forêt;SAINT-GERVAIS-LA-FORET;41350;41;LOIR ET CHER;1
41213;;Saint-Gourgon;SAINT-GOURGON;41310;41;LOIR ET CHER;1
41214;;Saint-Hilaire-la-Gravelle;SAINT-HILAIRE-LA-GRAVELLE;41160;41;LOIR ET CHER;1
41215;;Saint-Jacques-des-Guérets;SAINT-JACQUES-DES-GUERETS;41800;41;LOIR ET CHER;1
41216;;Saint-Jean-Froidmentel;SAINT-JEAN-FROIDMENTEL;41160;41;LOIR ET CHER;1
41217;;Saint-Julien-de-Chédon;SAINT-JULIEN-DE-CHEDON;41400;41;LOIR ET CHER;1
41218;;Saint-Julien-sur-Cher;SAINT-JULIEN-SUR-CHER;41320;41;LOIR ET CHER;1
41219;;Saint-Laurent-des-Bois;SAINT-LAURENT-DES-BOIS;41240;41;LOIR ET CHER;1
41220;;Saint-Laurent-Nouan;SAINT-LAURENT-NOUAN;41220;41;LOIR ET CHER;1
41221;;Saint-Léonard-en-Beauce;SAINT-LEONARD-EN-BEAUCE;41370;41;LOIR ET CHER;1
41222;;Saint-Loup;SAINT-LOUP;41320;41;LOIR ET CHER;1
41223;;Saint-Lubin-en-Vergonnois;SAINT-LUBIN-EN-VERGONNOIS;41190;41;LOIR ET CHER;1
41224;;Saint-Marc-du-Cor;SAINT-MARC-DU-COR;41170;41;LOIR ET CHER;1
41225;;Saint-Martin-des-Bois;SAINT-MARTIN-DES-BOIS;41800;41;LOIR ET CHER;1
41226;;Saint-Ouen;SAINT-OUEN;41100;41;LOIR ET CHER;1
41228;;Saint-Rimay;SAINT-RIMAY;41800;41;LOIR ET CHER;1
41229;;Saint-Romain-sur-Cher;SAINT-ROMAIN-SUR-CHER;41140;41;LOIR ET CHER;1
41230;;Saint-Sulpice-de-Pommeray;SAINT-SULPICE-DE-POMMERAY;41000;41;LOIR ET CHER;1
41231;;Saint-Viâtre;SAINT-VIATRE;41210;41;LOIR ET CHER;1
41232;;Salbris;SALBRIS;41300;41;LOIR ET CHER;1
41233;;Sambin;SAMBIN;41120;41;LOIR ET CHER;1
41234;;Santenay;SANTENAY;41190;41;LOIR ET CHER;1
41235;;Sargé-sur-Braye;SARGE-SUR-BRAYE;41170;41;LOIR ET CHER;1
41236;;Sasnières;SASNIERES;41310;41;LOIR ET CHER;1
41237;;Sassay;SASSAY;41700;41;LOIR ET CHER;1
41238;;Savigny-sur-Braye;SAVIGNY-SUR-BRAYE;41360;41;LOIR ET CHER;1
41239;;Seigy;SEIGY;41110;41;LOIR ET CHER;1
41240;;Seillac;SEILLAC;41150;41;LOIR ET CHER;1
41241;;Selles-Saint-Denis;SELLES-SAINT-DENIS;41300;41;LOIR ET CHER;1
41242;;Selles-sur-Cher;SELLES-SUR-CHER;41130;41;LOIR ET CHER;1
41243;;Selommes;SELOMMES;41100;41;LOIR ET CHER;1
41244;;Semerville;SEMERVILLE;41160;41;LOIR ET CHER;1
41245;;Séris;SERIS;41500;41;LOIR ET CHER;1
41246;;Seur;SEUR;41120;41;LOIR ET CHER;1
41247;;Soings-en-Sologne;SOINGS-EN-SOLOGNE;41230;41;LOIR ET CHER;1
41248;;Souday;SOUDAY;41170;41;LOIR ET CHER;1
41249;;Souesmes;SOUESMES;41300;41;LOIR ET CHER;1
41250;;Sougé;SOUGE;41800;41;LOIR ET CHER;1
41251;;Souvigny-en-Sologne;SOUVIGNY-EN-SOLOGNE;41600;41;LOIR ET CHER;1
41252;;Suèvres;SUEVRES;41500;41;LOIR ET CHER;1
41253;;Talcy;TALCY;41370;41;LOIR ET CHER;1
41254;Le;Temple;TEMPLE;41170;41;LOIR ET CHER;1
41255;;Ternay;TERNAY;41800;41;LOIR ET CHER;1
41256;;Theillay;THEILLAY;41300;41;LOIR ET CHER;1
41257;;Thenay;THENAY;41400;41;LOIR ET CHER;1
41258;;Thésée;THESEE;41140;41;LOIR ET CHER;1
41259;;Thoré-la-Rochette;THORE-LA-ROCHETTE;41100;41;LOIR ET CHER;1
41260;;Thoury;THOURY;41220;41;LOIR ET CHER;1
41261;;Tourailles;TOURAILLES;41190;41;LOIR ET CHER;1
41262;;Tour-en-Sologne;TOUR-EN-SOLOGNE;41250;41;LOIR ET CHER;1
41263;;Tréhet;TREHET;41800;41;LOIR ET CHER;1
41264;;Tripleville;TRIPLEVILLE;41240;41;LOIR ET CHER;1
41265;;Troo;TROO;41800;41;LOIR ET CHER;1
41266;;Valaire;VALAIRE;41120;41;LOIR ET CHER;1
41267;;Vallières-les-Grandes;VALLIERES-LES-GRANDES;41400;41;LOIR ET CHER;1
41268;;Veilleins;VEILLEINS;41230;41;LOIR ET CHER;1
41269;;Vendôme;VENDOME;41100;41;LOIR ET CHER;1
41270;;Verdes;VERDES;41240;41;LOIR ET CHER;1
41271;;Vernou-en-Sologne;VERNOU-EN-SOLOGNE;41230;41;LOIR ET CHER;1
41272;;Veuves;VEUVES;41150;41;LOIR ET CHER;1
41273;;Vievy-le-Rayé;VIEVY-LE-RAYE;41290;41;LOIR ET CHER;1
41274;;Villavard;VILLAVARD;41800;41;LOIR ET CHER;1
41275;La;Ville-aux-Clercs;VILLE-AUX-CLERCS;41160;41;LOIR ET CHER;1
41276;;Villebarou;VILLEBAROU;41000;41;LOIR ET CHER;1
41277;;Villebout;VILLEBOUT;41270;41;LOIR ET CHER;1
41278;;Villechauve;VILLECHAUVE;41310;41;LOIR ET CHER;1
41279;;Villedieu-le-Château;VILLEDIEU-LE-CHATEAU;41800;41;LOIR ET CHER;1
41280;;Villefranche-sur-Cher;VILLEFRANCHE-SUR-CHER;41200;41;LOIR ET CHER;1
41281;;Villefrancœur;VILLEFRANCOEUR;41330;41;LOIR ET CHER;1
41282;;Villeherviers;VILLEHERVIERS;41200;41;LOIR ET CHER;1
41283;;Villemardy;VILLEMARDY;41100;41;LOIR ET CHER;1
41284;;Villeneuve-Frouville;VILLENEUVE-FROUVILLE;41290;41;LOIR ET CHER;1
41285;;Villeny;VILLENY;41220;41;LOIR ET CHER;1
41286;;Villeporcher;VILLEPORCHER;41310;41;LOIR ET CHER;1
41287;;Villerable;VILLERABLE;41100;41;LOIR ET CHER;1
41288;;Villerbon;VILLERBON;41000;41;LOIR ET CHER;1
41289;;Villermain;VILLERMAIN;41240;41;LOIR ET CHER;1
41290;;Villeromain;VILLEROMAIN;41100;41;LOIR ET CHER;1
41291;;Villetrun;VILLETRUN;41100;41;LOIR ET CHER;1
41292;;Villexanton;VILLEXANTON;41500;41;LOIR ET CHER;1
41293;;Villiersfaux;VILLIERSFAUX;41100;41;LOIR ET CHER;1
41294;;Villiers-sur-Loir;VILLIERS-SUR-LOIR;41100;41;LOIR ET CHER;1
41295;;Vineuil;VINEUIL;41350;41;LOIR ET CHER;1
41296;;Vouzon;VOUZON;41600;41;LOIR ET CHER;1
41297;;Yvoy-le-Marron;YVOY-LE-MARRON;41600;41;LOIR ET CHER;1
42001;;Aboën;ABOEN;42380;42;LOIRE;1
42002;;Ailleux;AILLEUX;42130;42;LOIRE;1
42003;;Ambierle;AMBIERLE;42820;42;LOIRE;1
42004;;Amions;AMIONS;42260;42;LOIRE;1
42005;;Andrézieux-Bouthéon;ANDREZIEUX-BOUTHEON;42160;42;LOIRE;1
42006;;Apinac;APINAC;42550;42;LOIRE;1
42007;;Arcinges;ARCINGES;42460;42;LOIRE;1
42008;;Arcon;ARCON;42370;42;LOIRE;1
42009;;Arthun;ARTHUN;42130;42;LOIRE;1
42010;;Aveizieux;AVEIZIEUX;42330;42;LOIRE;1
42011;;Balbigny;BALBIGNY;42510;42;LOIRE;1
42012;;Bard;BARD;42600;42;LOIRE;1
42013;;Bellegarde-en-Forez;BELLEGARDE-EN-FOREZ;42210;42;LOIRE;1
42014;;Belleroche;BELLEROCHE;42670;42;LOIRE;1
42015;;Belmont-de-la-Loire;BELMONT-DE-LA-LOIRE;42670;42;LOIRE;1
42016;La;Bénisson-Dieu;BENISSON-DIEU;42720;42;LOIRE;1
42017;Le;Bessat;BESSAT;42660;42;LOIRE;1
42018;;Bessey;BESSEY;42520;42;LOIRE;1
42019;;Boën;BOEN;42130;42;LOIRE;1
42020;;Boisset-lès-Montrond;BOISSET-LES-MONTROND;42210;42;LOIRE;1
42021;;Boisset-Saint-Priest;BOISSET-SAINT-PRIEST;42560;42;LOIRE;1
42022;;Bonson;BONSON;42160;42;LOIRE;1
42023;;Bourg-Argental;BOURG-ARGENTAL;42220;42;LOIRE;1
42025;;Boyer;BOYER;42460;42;LOIRE;1
42026;;Briennon;BRIENNON;42720;42;LOIRE;1
42027;;Bully;BULLY;42260;42;LOIRE;1
42028;;Burdignes;BURDIGNES;42220;42;LOIRE;1
42029;;Bussières;BUSSIERES;42510;42;LOIRE;1
42030;;Bussy-Albieux;BUSSY-ALBIEUX;42260;42;LOIRE;1
42031;;Caloire;CALOIRE;42240;42;LOIRE;1
42032;;Cellieu;CELLIEU;42320;42;LOIRE;1
42033;Le;Cergne;CERGNE;42460;42;LOIRE;1
42034;;Cervières;CERVIERES;42440;42;LOIRE;1
42035;;Cezay;CEZAY;42130;42;LOIRE;1
42036;;Chagnon;CHAGNON;42800;42;LOIRE;1
42037;;Chalain-d'Uzore;CHALAIN-D'UZORE;42600;42;LOIRE;1
42038;;Chalain-le-Comtal;CHALAIN-LE-COMTAL;42600;42;LOIRE;1
42039;;Chalmazel;CHALMAZEL;42920;42;LOIRE;1
42040;La;Chamba;CHAMBA;42440;42;LOIRE;1
42041;;Chambéon;CHAMBEON;42110;42;LOIRE;1
42042;;Chambles;CHAMBLES;42170;42;LOIRE;1
42043;;Chambœuf;CHAMBOEUF;42330;42;LOIRE;1
42044;Le;Chambon-Feugerolles;CHAMBON-FEUGEROLLES;42500;42;LOIRE;1
42045;La;Chambonie;CHAMBONIE;42440;42;LOIRE;1
42046;;Champdieu;CHAMPDIEU;42600;42;LOIRE;1
42047;;Champoly;CHAMPOLY;42430;42;LOIRE;1
42048;;Chandon;CHANDON;42190;42;LOIRE;1
42049;;Changy;CHANGY;42310;42;LOIRE;1
42050;La;Chapelle-en-Lafaye;CHAPELLE-EN-LAFAYE;42380;42;LOIRE;1
42051;La;Chapelle-Villars;CHAPELLE-VILLARS;42410;42;LOIRE;1
42052;;Charlieu;CHARLIEU;42190;42;LOIRE;1
42053;;Châteauneuf;CHATEAUNEUF;42800;42;LOIRE;1
42054;;Châtelneuf;CHATELNEUF;42940;42;LOIRE;1
42055;;Châtelus;CHATELUS;42140;42;LOIRE;1
42056;;Chavanay;CHAVANAY;42410;42;LOIRE;1
42058;;Chazelles-sur-Lavieu;CHAZELLES-SUR-LAVIEU;42560;42;LOIRE;1
42059;;Chazelles-sur-Lyon;CHAZELLES-SUR-LYON;42140;42;LOIRE;1
42060;;Chenereilles;CHENEREILLES;42560;42;LOIRE;1
42061;;Cherier;CHERIER;42430;42;LOIRE;1
42062;;Chevrières;CHEVRIERES;42140;42;LOIRE;1
42063;;Chirassimont;CHIRASSIMONT;42114;42;LOIRE;1
42064;;Chuyer;CHUYER;42410;42;LOIRE;1
42065;;Civens;CIVENS;42110;42;LOIRE;1
42066;;Cleppé;CLEPPE;42110;42;LOIRE;1
42067;;Colombier;COLOMBIER;42220;42;LOIRE;1
42068;;Combre;COMBRE;42840;42;LOIRE;1
42069;;Commelle-Vernay;COMMELLE-VERNAY;42120;42;LOIRE;1
42070;;Cordelle;CORDELLE;42123;42;LOIRE;1
42071;Le;Coteau;COTEAU;42120;42;LOIRE;1
42072;La;Côte-en-Couzan;COTE-EN-COUZAN;42111;42;LOIRE;1
42073;;Cottance;COTTANCE;42360;42;LOIRE;1
42074;;Coutouvre;COUTOUVRE;42460;42;LOIRE;1
42075;;Craintilleux;CRAINTILLEUX;42210;42;LOIRE;1
42076;;Cremeaux;CREMEAUX;42260;42;LOIRE;1
42077;;Croizet-sur-Gand;CROIZET-SUR-GAND;42540;42;LOIRE;1
42078;Le;Crozet;CROZET;42310;42;LOIRE;1
42079;;Cuinzier;CUINZIER;42460;42;LOIRE;1
42081;;Cuzieu;CUZIEU;42330;42;LOIRE;1
42082;;Dancé;DANCE;42260;42;LOIRE;1
42083;;Dargoire;DARGOIRE;42800;42;LOIRE;1
42084;;Débats-Rivière-d'Orpra;DEBATS-RIVIERE-D'ORPRA;42130;42;LOIRE;1
42085;;Doizieux;DOIZIEUX;42740;42;LOIRE;1
42086;;Écoche;ECOCHE;42670;42;LOIRE;1
42087;;Écotay-l'Olme;ECOTAY-L'OLME;42600;42;LOIRE;1
42088;;Épercieux-Saint-Paul;EPERCIEUX-SAINT-PAUL;42110;42;LOIRE;1
42089;;Essertines-en-Châtelneuf;ESSERTINES-EN-CHATELNEUF;42600;42;LOIRE;1
42090;;Essertines-en-Donzy;ESSERTINES-EN-DONZY;42360;42;LOIRE;1
42091;;Estivareilles;ESTIVAREILLES;42380;42;LOIRE;1
42092;L';Étrat;ETRAT;42580;42;LOIRE;1
42093;;Farnay;FARNAY;42320;42;LOIRE;1
42094;;Feurs;FEURS;42110;42;LOIRE;1
42095;;Firminy;FIRMINY;42700;42;LOIRE;1
42096;;Fontanès;FONTANES;42140;42;LOIRE;1
42097;La;Fouillouse;FOUILLOUSE;42480;42;LOIRE;1
42098;;Fourneaux;FOURNEAUX;42470;42;LOIRE;1
42099;;Fraisses;FRAISSES;42490;42;LOIRE;1
42100;La;Gimond;GIMOND;42140;42;LOIRE;1
42101;;Graix;GRAIX;42220;42;LOIRE;1
42102;;Grammond;GRAMMOND;42140;42;LOIRE;1
42103;La;Grand-Croix;GRAND-CROIX;42320;42;LOIRE;1
42104;La;Gresle;GRESLE;42460;42;LOIRE;1
42105;;Grézieux-le-Fromental;GREZIEUX-LE-FROMENTAL;42600;42;LOIRE;1
42106;;Grézolles;GREZOLLES;42260;42;LOIRE;1
42107;;Gumières;GUMIERES;42560;42;LOIRE;1
42108;L';Hôpital-le-Grand;HOPITAL-LE-GRAND;42210;42;LOIRE;1
42109;L';Hôpital-sous-Rochefort;HOPITAL-SOUS-ROCHEFORT;42130;42;LOIRE;1
42110;L';Horme;HORME;42152;42;LOIRE;1
42112;;Jarnosse;JARNOSSE;42460;42;LOIRE;1
42113;;Jas;JAS;42110;42;LOIRE;1
42114;;Jeansagnière;JEANSAGNIERE;42920;42;LOIRE;1
42115;;Jonzieux;JONZIEUX;42660;42;LOIRE;1
42116;;Juré;JURE;42430;42;LOIRE;1
42117;;Lavieu;LAVIEU;42560;42;LOIRE;1
42118;;Lay;LAY;42470;42;LOIRE;1
42119;;Leigneux;LEIGNEUX;42130;42;LOIRE;1
42120;;Lentigny;LENTIGNY;42155;42;LOIRE;1
42121;;Lérigneux;LERIGNEUX;42600;42;LOIRE;1
42122;;Lézigneux;LEZIGNEUX;42600;42;LOIRE;1
42123;;Lorette;LORETTE;42420;42;LOIRE;1
42124;;Lupé;LUPE;42520;42;LOIRE;1
42125;;Luré;LURE;42260;42;LOIRE;1
42126;;Luriecq;LURIECQ;42380;42;LOIRE;1
42127;;Mably;MABLY;42300;42;LOIRE;1
42128;;Machézal;MACHEZAL;42114;42;LOIRE;1
42129;;Maclas;MACLAS;42520;42;LOIRE;1
42130;;Magneux-Haute-Rive;MAGNEUX-HAUTE-RIVE;42600;42;LOIRE;1
42131;;Maizilly;MAIZILLY;42750;42;LOIRE;1
42132;;Malleval;MALLEVAL;42520;42;LOIRE;1
42133;;Marcenod;MARCENOD;42140;42;LOIRE;1
42134;;Marcilly-le-Châtel;MARCILLY-LE-CHATEL;42130;42;LOIRE;1
42135;;Marclopt;MARCLOPT;42210;42;LOIRE;1
42136;;Marcoux;MARCOUX;42130;42;LOIRE;1
42137;;Margerie-Chantagret;MARGERIE-CHANTAGRET;42560;42;LOIRE;1
42138;;Maringes;MARINGES;42140;42;LOIRE;1
42139;;Marlhes;MARLHES;42660;42;LOIRE;1
42140;;Marols;MAROLS;42560;42;LOIRE;1
42141;;Mars;MARS;42750;42;LOIRE;1
42142;;Merle-Leignec;MERLE-LEIGNEC;42380;42;LOIRE;1
42143;;Mizérieux;MIZERIEUX;42110;42;LOIRE;1
42145;;Montagny;MONTAGNY;42840;42;LOIRE;1
42146;;Montarcher;MONTARCHER;42380;42;LOIRE;1
42147;;Montbrison;MONTBRISON;42600;42;LOIRE;1
42148;;Montchal;MONTCHAL;42360;42;LOIRE;1
42149;;Montrond-les-Bains;MONTROND-LES-BAINS;42210;42;LOIRE;1
42150;;Montverdun;MONTVERDUN;42130;42;LOIRE;1
42151;;Mornand-en-Forez;MORNAND-EN-FOREZ;42600;42;LOIRE;1
42152;;Nandax;NANDAX;42720;42;LOIRE;1
42153;;Neaux;NEAUX;42470;42;LOIRE;1
42154;;Néronde;NERONDE;42510;42;LOIRE;1
42155;;Nervieux;NERVIEUX;42510;42;LOIRE;1
42156;;Neulise;NEULISE;42590;42;LOIRE;1
42157;;Noailly;NOAILLY;42640;42;LOIRE;1
42158;Les;Noës;NOES;42370;42;LOIRE;1
42159;;Noirétable;NOIRETABLE;42440;42;LOIRE;1
42160;;Nollieux;NOLLIEUX;42260;42;LOIRE;1
42161;;Notre-Dame-de-Boisset;NOTRE-DAME-DE-BOISSET;42120;42;LOIRE;1
42162;;Ouches;OUCHES;42155;42;LOIRE;1
42163;La;Pacaudière;PACAUDIERE;42310;42;LOIRE;1
42164;;Palogneux;PALOGNEUX;42890;42;LOIRE;1
42165;;Panissières;PANISSIERES;42360;42;LOIRE;1
42166;;Parigny;PARIGNY;42120;42;LOIRE;1
42167;;Pavezin;PAVEZIN;42410;42;LOIRE;1
42168;;Pélussin;PELUSSIN;42410;42;LOIRE;1
42169;;Périgneux;PERIGNEUX;42380;42;LOIRE;1
42170;;Perreux;PERREUX;42120;42;LOIRE;1
42171;;Pinay;PINAY;42590;42;LOIRE;1
42172;;Planfoy;PLANFOY;42660;42;LOIRE;1
42173;;Pommiers;POMMIERS;42260;42;LOIRE;1
42174;;Poncins;PONCINS;42110;42;LOIRE;1
42175;;Pouilly-lès-Feurs;POUILLY-LES-FEURS;42110;42;LOIRE;1
42176;;Pouilly-les-Nonains;POUILLY-LES-NONAINS;42155;42;LOIRE;1
42177;;Pouilly-sous-Charlieu;POUILLY-SOUS-CHARLIEU;42720;42;LOIRE;1
42178;;Pradines;PRADINES;42630;42;LOIRE;1
42179;;Pralong;PRALONG;42600;42;LOIRE;1
42180;;Précieux;PRECIEUX;42600;42;LOIRE;1
42181;;Régny;REGNY;42630;42;LOIRE;1
42182;;Renaison;RENAISON;42370;42;LOIRE;1
42183;La;Ricamarie;RICAMARIE;42150;42;LOIRE;1
42184;;Riorges;RIORGES;42153;42;LOIRE;1
42185;;Rivas;RIVAS;42340;42;LOIRE;1
42186;;Rive-de-Gier;RIVE-DE-GIER;42800;42;LOIRE;1
42187;;Roanne;ROANNE;42300;42;LOIRE;1
42188;;Roche;ROCHE;42600;42;LOIRE;1
42189;;Roche-la-Molière;ROCHE-LA-MOLIERE;42230;42;LOIRE;1
42191;;Roisey;ROISEY;42520;42;LOIRE;1
42192;;Rozier-Côtes-d'Aurec;ROZIER-COTES-D'AUREC;42380;42;LOIRE;1
42193;;Rozier-en-Donzy;ROZIER-EN-DONZY;42810;42;LOIRE;1
42194;;Sail-les-Bains;SAIL-LES-BAINS;42310;42;LOIRE;1
42195;;Sail-sous-Couzan;SAIL-SOUS-COUZAN;42890;42;LOIRE;1
42196;;Sainte-Agathe-en-Donzy;SAINTE-AGATHE-EN-DONZY;42510;42;LOIRE;1
42197;;Sainte-Agathe-la-Bouteresse;SAINTE-AGATHE-LA-BOUTERESSE;42130;42;LOIRE;1
42198;;Saint-Alban-les-Eaux;SAINT-ALBAN-LES-EAUX;42370;42;LOIRE;1
42199;;Saint-André-d'Apchon;SAINT-ANDRE-D'APCHON;42370;42;LOIRE;1
42200;;Saint-André-le-Puy;SAINT-ANDRE-LE-PUY;42210;42;LOIRE;1
42201;;Saint-Appolinard;SAINT-APPOLINARD;42520;42;LOIRE;1
42202;;Saint-Barthélemy-Lestra;SAINT-BARTHELEMY-LESTRA;42110;42;LOIRE;1
42203;;Saint-Bonnet-des-Quarts;SAINT-BONNET-DES-QUARTS;42310;42;LOIRE;1
42204;;Saint-Bonnet-le-Château;SAINT-BONNET-LE-CHATEAU;42380;42;LOIRE;1
42205;;Saint-Bonnet-le-Courreau;SAINT-BONNET-LE-COURREAU;42940;42;LOIRE;1
42206;;Saint-Bonnet-les-Oules;SAINT-BONNET-LES-OULES;42330;42;LOIRE;1
42207;;Saint-Chamond;SAINT-CHAMOND;42400;42;LOIRE;1
42208;;Saint-Christo-en-Jarez;SAINT-CHRISTO-EN-JAREZ;42320;42;LOIRE;1
42209;;Sainte-Colombe-sur-Gand;SAINTE-COLOMBE-SUR-GAND;42540;42;LOIRE;1
42210;;Sainte-Croix-en-Jarez;SAINTE-CROIX-EN-JAREZ;42800;42;LOIRE;1
42211;;Saint-Cyprien;SAINT-CYPRIEN;42160;42;LOIRE;1
42212;;Saint-Cyr-de-Favières;SAINT-CYR-DE-FAVIERES;42132;42;LOIRE;1
42213;;Saint-Cyr-de-Valorges;SAINT-CYR-DE-VALORGES;42114;42;LOIRE;1
42214;;Saint-Cyr-les-Vignes;SAINT-CYR-LES-VIGNES;42210;42;LOIRE;1
42215;;Saint-Denis-de-Cabanne;SAINT-DENIS-DE-CABANNE;42750;42;LOIRE;1
42216;;Saint-Denis-sur-Coise;SAINT-DENIS-SUR-COISE;42140;42;LOIRE;1
42217;;Saint-Didier-sur-Rochefort;SAINT-DIDIER-SUR-ROCHEFORT;42111;42;LOIRE;1
42218;;Saint-Étienne;SAINT-ETIENNE;42000;42;LOIRE;1
42219;;Saint-Étienne-le-Molard;SAINT-ETIENNE-LE-MOLARD;42130;42;LOIRE;1
42220;;Saint-Forgeux-Lespinasse;SAINT-FORGEUX-LESPINASSE;42640;42;LOIRE;1
42221;;Sainte-Foy-Saint-Sulpice;SAINTE-FOY-SAINT-SULPICE;42110;42;LOIRE;1
42222;;Saint-Galmier;SAINT-GALMIER;42330;42;LOIRE;1
42223;;Saint-Genest-Lerpt;SAINT-GENEST-LERPT;42530;42;LOIRE;1
42224;;Saint-Genest-Malifaux;SAINT-GENEST-MALIFAUX;42660;42;LOIRE;1
42225;;Genilac;GENILAC;42800;42;LOIRE;1
42226;;Saint-Georges-de-Baroille;SAINT-GEORGES-DE-BAROILLE;42510;42;LOIRE;1
42227;;Saint-Georges-en-Couzan;SAINT-GEORGES-EN-COUZAN;42990;42;LOIRE;1
42228;;Saint-Georges-Haute-Ville;SAINT-GEORGES-HAUTE-VILLE;42610;42;LOIRE;1
42229;;Saint-Germain-la-Montagne;SAINT-GERMAIN-LA-MONTAGNE;42670;42;LOIRE;1
42230;;Saint-Germain-Laval;SAINT-GERMAIN-LAVAL;42260;42;LOIRE;1
42231;;Saint-Germain-Lespinasse;SAINT-GERMAIN-LESPINASSE;42640;42;LOIRE;1
42232;;Saint-Haon-le-Châtel;SAINT-HAON-LE-CHATEL;42370;42;LOIRE;1
42233;;Saint-Haon-le-Vieux;SAINT-HAON-LE-VIEUX;42370;42;LOIRE;1
42234;;Saint-Héand;SAINT-HEAND;42570;42;LOIRE;1
42235;;Saint-Hilaire-Cusson-la-Valmitte;SAINT-HILAIRE-CUSSON-LA-VALMITTE;42380;42;LOIRE;1
42236;;Saint-Hilaire-sous-Charlieu;SAINT-HILAIRE-SOUS-CHARLIEU;42190;42;LOIRE;1
42237;;Saint-Jean-Bonnefonds;SAINT-JEAN-BONNEFONDS;42650;42;LOIRE;1
42238;;Saint-Jean-la-Vêtre;SAINT-JEAN-LA-VETRE;42440;42;LOIRE;1
42239;;Saint-Jean-Saint-Maurice-sur-Loire;SAINT-JEAN-SAINT-MAURICE-SUR-LOIRE;42155;42;LOIRE;1
42240;;Saint-Jean-Soleymieux;SAINT-JEAN-SOLEYMIEUX;42560;42;LOIRE;1
42241;;Saint-Jodard;SAINT-JODARD;42590;42;LOIRE;1
42242;;Saint-Joseph;SAINT-JOSEPH;42800;42;LOIRE;1
42243;;Saint-Julien-d'Oddes;SAINT-JULIEN-D'ODDES;42260;42;LOIRE;1
42245;;Saint-Julien-la-Vêtre;SAINT-JULIEN-LA-VETRE;42440;42;LOIRE;1
42246;;Saint-Julien-Molin-Molette;SAINT-JULIEN-MOLIN-MOLETTE;42220;42;LOIRE;1
42247;;Saint-Just-en-Bas;SAINT-JUST-EN-BAS;42136;42;LOIRE;1
42248;;Saint-Just-en-Chevalet;SAINT-JUST-EN-CHEVALET;42430;42;LOIRE;1
42249;;Saint-Just-la-Pendue;SAINT-JUST-LA-PENDUE;42540;42;LOIRE;1
42251;;Saint-Laurent-la-Conche;SAINT-LAURENT-LA-CONCHE;42210;42;LOIRE;1
42252;;Saint-Laurent-Rochefort;SAINT-LAURENT-ROCHEFORT;42130;42;LOIRE;1
42253;;Saint-Léger-sur-Roanne;SAINT-LEGER-SUR-ROANNE;42155;42;LOIRE;1
42254;;Saint-Marcel-de-Félines;SAINT-MARCEL-DE-FELINES;42122;42;LOIRE;1
42255;;Saint-Marcel-d'Urfé;SAINT-MARCEL-D'URFE;42430;42;LOIRE;1
42256;;Saint-Marcellin-en-Forez;SAINT-MARCELLIN-EN-FOREZ;42680;42;LOIRE;1
42257;;Saint-Martin-d'Estréaux;SAINT-MARTIN-D'ESTREAUX;42620;42;LOIRE;1
42259;;Saint-Martin-la-Plaine;SAINT-MARTIN-LA-PLAINE;42800;42;LOIRE;1
42260;;Saint-Martin-la-Sauveté;SAINT-MARTIN-LA-SAUVETE;42260;42;LOIRE;1
42261;;Saint-Martin-Lestra;SAINT-MARTIN-LESTRA;42110;42;LOIRE;1
42262;;Saint-Maurice-en-Gourgois;SAINT-MAURICE-EN-GOURGOIS;42240;42;LOIRE;1
42264;;Saint-Médard-en-Forez;SAINT-MEDARD-EN-FOREZ;42330;42;LOIRE;1
42265;;Saint-Michel-sur-Rhône;SAINT-MICHEL-SUR-RHONE;42410;42;LOIRE;1
42266;;Saint-Nizier-de-Fornas;SAINT-NIZIER-DE-FORNAS;42380;42;LOIRE;1
42267;;Saint-Nizier-sous-Charlieu;SAINT-NIZIER-SOUS-CHARLIEU;42190;42;LOIRE;1
42268;;Saint-Paul-de-Vézelin;SAINT-PAUL-DE-VEZELIN;42590;42;LOIRE;1
42269;;Saint-Paul-d'Uzore;SAINT-PAUL-D'UZORE;42600;42;LOIRE;1
42270;;Saint-Paul-en-Cornillon;SAINT-PAUL-EN-CORNILLON;42240;42;LOIRE;1
42271;;Saint-Paul-en-Jarez;SAINT-PAUL-EN-JAREZ;42740;42;LOIRE;1
42272;;Saint-Pierre-de-Bœuf;SAINT-PIERRE-DE-BOEUF;42520;42;LOIRE;1
42273;;Saint-Pierre-la-Noaille;SAINT-PIERRE-LA-NOAILLE;42190;42;LOIRE;1
42274;;Saint-Polgues;SAINT-POLGUES;42260;42;LOIRE;1
42275;;Saint-Priest-en-Jarez;SAINT-PRIEST-EN-JAREZ;42270;42;LOIRE;1
42276;;Saint-Priest-la-Prugne;SAINT-PRIEST-LA-PRUGNE;42830;42;LOIRE;1
42277;;Saint-Priest-la-Roche;SAINT-PRIEST-LA-ROCHE;42590;42;LOIRE;1
42278;;Saint-Priest-la-Vêtre;SAINT-PRIEST-LA-VETRE;42440;42;LOIRE;1
42279;;Saint-Just-Saint-Rambert;SAINT-JUST-SAINT-RAMBERT;42170;42;LOIRE;1
42280;;Saint-Régis-du-Coin;SAINT-REGIS-DU-COIN;42660;42;LOIRE;1
42281;;Saint-Rirand;SAINT-RIRAND;42370;42;LOIRE;1
42282;;Saint-Romain-d'Urfé;SAINT-ROMAIN-D'URFE;42430;42;LOIRE;1
42283;;Saint-Romain-en-Jarez;SAINT-ROMAIN-EN-JAREZ;42800;42;LOIRE;1
42284;;Saint-Romain-la-Motte;SAINT-ROMAIN-LA-MOTTE;42640;42;LOIRE;1
42285;;Saint-Romain-le-Puy;SAINT-ROMAIN-LE-PUY;42610;42;LOIRE;1
42286;;Saint-Romain-les-Atheux;SAINT-ROMAIN-LES-ATHEUX;42660;42;LOIRE;1
42287;;Saint-Sauveur-en-Rue;SAINT-SAUVEUR-EN-RUE;42220;42;LOIRE;1
42288;;Saint-Sixte;SAINT-SIXTE;42130;42;LOIRE;1
42289;;Saint-Symphorien-de-Lay;SAINT-SYMPHORIEN-DE-LAY;42470;42;LOIRE;1
42290;;Saint-Thomas-la-Garde;SAINT-THOMAS-LA-GARDE;42600;42;LOIRE;1
42291;;Saint-Thurin;SAINT-THURIN;42111;42;LOIRE;1
42293;;Saint-Victor-sur-Rhins;SAINT-VICTOR-SUR-RHINS;42630;42;LOIRE;1
42294;;Saint-Vincent-de-Boisset;SAINT-VINCENT-DE-BOISSET;42120;42;LOIRE;1
42295;Les;Salles;SALLES;42440;42;LOIRE;1
42296;;Salt-en-Donzy;SALT-EN-DONZY;42110;42;LOIRE;1
42297;;Salvizinet;SALVIZINET;42110;42;LOIRE;1
42298;;Sauvain;SAUVAIN;42990;42;LOIRE;1
42299;;Savigneux;SAVIGNEUX;42600;42;LOIRE;1
42300;;Sevelinges;SEVELINGES;42460;42;LOIRE;1
42301;;Soleymieux;SOLEYMIEUX;42560;42;LOIRE;1
42302;;Sorbiers;SORBIERS;42290;42;LOIRE;1
42303;;Souternon;SOUTERNON;42260;42;LOIRE;1
42304;;Sury-le-Comtal;SURY-LE-COMTAL;42450;42;LOIRE;1
42305;La;Talaudière;TALAUDIERE;42350;42;LOIRE;1
42306;;Tarentaise;TARENTAISE;42660;42;LOIRE;1
42307;;Tartaras;TARTARAS;42800;42;LOIRE;1
42308;La;Terrasse-sur-Dorlay;TERRASSE-SUR-DORLAY;42740;42;LOIRE;1
42310;;Thélis-la-Combe;THELIS-LA-COMBE;42220;42;LOIRE;1
42311;La;Tour-en-Jarez;TOUR-EN-JAREZ;42580;42;LOIRE;1
42312;La;Tourette;TOURETTE;42380;42;LOIRE;1
42313;;Trelins;TRELINS;42130;42;LOIRE;1
42314;La;Tuilière;TUILIERE;42830;42;LOIRE;1
42315;;Unias;UNIAS;42210;42;LOIRE;1
42316;;Unieux;UNIEUX;42240;42;LOIRE;1
42317;;Urbise;URBISE;42310;42;LOIRE;1
42318;;Usson-en-Forez;USSON-EN-FOREZ;42550;42;LOIRE;1
42319;;Valeille;VALEILLE;42110;42;LOIRE;1
42320;;Valfleury;VALFLEURY;42320;42;LOIRE;1
42321;La;Valla-sur-Rochefort;VALLA-SUR-ROCHEFORT;42111;42;LOIRE;1
42322;La;Valla-en-Gier;VALLA-EN-GIER;42131;42;LOIRE;1
42323;;Veauche;VEAUCHE;42340;42;LOIRE;1
42324;;Veauchette;VEAUCHETTE;42340;42;LOIRE;1
42325;;Vendranges;VENDRANGES;42590;42;LOIRE;1
42326;;Véranne;VERANNE;42520;42;LOIRE;1
42327;;Vérin;VERIN;42410;42;LOIRE;1
42328;;Verrières-en-Forez;VERRIERES-EN-FOREZ;42600;42;LOIRE;1
42329;La;Versanne;VERSANNE;42220;42;LOIRE;1
42330;;Villars;VILLARS;42390;42;LOIRE;1
42331;;Villemontais;VILLEMONTAIS;42155;42;LOIRE;1
42332;;Villerest;VILLEREST;42300;42;LOIRE;1
42333;;Villers;VILLERS;42460;42;LOIRE;1
42334;;Violay;VIOLAY;42780;42;LOIRE;1
42335;;Viricelles;VIRICELLES;42140;42;LOIRE;1
42336;;Virigneux;VIRIGNEUX;42140;42;LOIRE;1
42337;;Vivans;VIVANS;42310;42;LOIRE;1
42338;;Vougy;VOUGY;42720;42;LOIRE;1
42339;;Chausseterre;CHAUSSETERRE;42430;42;LOIRE;1
43001;;Agnat;AGNAT;43100;43;HAUTE LOIRE;1
43002;;Aiguilhe;AIGUILHE;43000;43;HAUTE LOIRE;1
43003;;Allègre;ALLEGRE;43270;43;HAUTE LOIRE;1
43004;;Alleyrac;ALLEYRAC;43150;43;HAUTE LOIRE;1
43005;;Alleyras;ALLEYRAS;43580;43;HAUTE LOIRE;1
43006;;Ally;ALLY;43380;43;HAUTE LOIRE;1
43007;;Araules;ARAULES;43200;43;HAUTE LOIRE;1
43008;;Arlempdes;ARLEMPDES;43490;43;HAUTE LOIRE;1
43009;;Arlet;ARLET;43380;43;HAUTE LOIRE;1
43010;;Arsac-en-Velay;ARSAC-EN-VELAY;43700;43;HAUTE LOIRE;1
43011;;Aubazat;AUBAZAT;43380;43;HAUTE LOIRE;1
43012;;Aurec-sur-Loire;AUREC-SUR-LOIRE;43110;43;HAUTE LOIRE;1
43013;;Vissac-Auteyrac;VISSAC-AUTEYRAC;43300;43;HAUTE LOIRE;1
43014;;Autrac;AUTRAC;43450;43;HAUTE LOIRE;1
43015;;Auvers;AUVERS;43300;43;HAUTE LOIRE;1
43016;;Auzon;AUZON;43390;43;HAUTE LOIRE;1
43017;;Azérat;AZERAT;43390;43;HAUTE LOIRE;1
43018;;Bains;BAINS;43370;43;HAUTE LOIRE;1
43019;;Barges;BARGES;43340;43;HAUTE LOIRE;1
43020;;Bas-en-Basset;BAS-EN-BASSET;43210;43;HAUTE LOIRE;1
43021;;Beaulieu;BEAULIEU;43800;43;HAUTE LOIRE;1
43022;;Beaumont;BEAUMONT;43100;43;HAUTE LOIRE;1
43023;;Beaune-sur-Arzon;BEAUNE-SUR-ARZON;43500;43;HAUTE LOIRE;1
43024;;Beaux;BEAUX;43200;43;HAUTE LOIRE;1
43025;;Beauzac;BEAUZAC;43590;43;HAUTE LOIRE;1
43026;;Bellevue-la-Montagne;BELLEVUE-LA-MONTAGNE;43350;43;HAUTE LOIRE;1
43027;;Berbezit;BERBEZIT;43160;43;HAUTE LOIRE;1
43028;;Bessamorel;BESSAMOREL;43200;43;HAUTE LOIRE;1
43029;La;Besseyre-Saint-Mary;BESSEYRE-SAINT-MARY;43170;43;HAUTE LOIRE;1
43030;;Blanzac;BLANZAC;43350;43;HAUTE LOIRE;1
43031;;Blassac;BLASSAC;43380;43;HAUTE LOIRE;1
43032;;Blavozy;BLAVOZY;43700;43;HAUTE LOIRE;1
43033;;Blesle;BLESLE;43450;43;HAUTE LOIRE;1
43034;;Boisset;BOISSET;43500;43;HAUTE LOIRE;1
43035;;Bonneval;BONNEVAL;43160;43;HAUTE LOIRE;1
43036;;Borne;BORNE;43350;43;HAUTE LOIRE;1
43037;Le;Bouchet-Saint-Nicolas;BOUCHET-SAINT-NICOLAS;43510;43;HAUTE LOIRE;1
43038;;Bournoncle-Saint-Pierre;BOURNONCLE-SAINT-PIERRE;43360;43;HAUTE LOIRE;1
43039;Le;Brignon;BRIGNON;43370;43;HAUTE LOIRE;1
43040;;Brioude;BRIOUDE;43100;43;HAUTE LOIRE;1
43041;;Brives-Charensac;BRIVES-CHARENSAC;43700;43;HAUTE LOIRE;1
43042;;Cayres;CAYRES;43510;43;HAUTE LOIRE;1
43043;;Céaux-d'Allègre;CEAUX-D'ALLEGRE;43270;43;HAUTE LOIRE;1
43044;;Cerzat;CERZAT;43380;43;HAUTE LOIRE;1
43045;;Ceyssac;CEYSSAC;43000;43;HAUTE LOIRE;1
43046;;Chadrac;CHADRAC;43770;43;HAUTE LOIRE;1
43047;;Chadron;CHADRON;43150;43;HAUTE LOIRE;1
43048;La;Chaise-Dieu;CHAISE-DIEU;43160;43;HAUTE LOIRE;1
43049;;Chamalières-sur-Loire;CHAMALIERES-SUR-LOIRE;43800;43;HAUTE LOIRE;1
43050;;Chambezon;CHAMBEZON;43410;43;HAUTE LOIRE;1
43051;Le;Chambon-sur-Lignon;CHAMBON-SUR-LIGNON;43400;43;HAUTE LOIRE;1
43052;;Champagnac-le-Vieux;CHAMPAGNAC-LE-VIEUX;43440;43;HAUTE LOIRE;1
43053;;Champclause;CHAMPCLAUSE;43260;43;HAUTE LOIRE;1
43054;;Chanaleilles;CHANALEILLES;43170;43;HAUTE LOIRE;1
43055;;Chaniat;CHANIAT;43100;43;HAUTE LOIRE;1
43056;;Chanteuges;CHANTEUGES;43300;43;HAUTE LOIRE;1
43057;La;Chapelle-Bertin;CHAPELLE-BERTIN;43270;43;HAUTE LOIRE;1
43058;La;Chapelle-d'Aurec;CHAPELLE-D'AUREC;43120;43;HAUTE LOIRE;1
43059;La;Chapelle-Geneste;CHAPELLE-GENESTE;43160;43;HAUTE LOIRE;1
43060;;Charraix;CHARRAIX;43300;43;HAUTE LOIRE;1
43061;;Chaspinhac;CHASPINHAC;43700;43;HAUTE LOIRE;1
43062;;Chaspuzac;CHASPUZAC;43320;43;HAUTE LOIRE;1
43063;;Chassagnes;CHASSAGNES;43230;43;HAUTE LOIRE;1
43064;;Chassignolles;CHASSIGNOLLES;43440;43;HAUTE LOIRE;1
43065;;Chastel;CHASTEL;43300;43;HAUTE LOIRE;1
43066;;Chaudeyrolles;CHAUDEYROLLES;43430;43;HAUTE LOIRE;1
43067;;Chavaniac-Lafayette;CHAVANIAC-LAFAYETTE;43230;43;HAUTE LOIRE;1
43068;;Chazelles;CHAZELLES;43300;43;HAUTE LOIRE;1
43069;;Chenereilles;CHENEREILLES;43190;43;HAUTE LOIRE;1
43070;;Chilhac;CHILHAC;43380;43;HAUTE LOIRE;1
43071;;Chomelix;CHOMELIX;43500;43;HAUTE LOIRE;1
43072;La;Chomette;CHOMETTE;43230;43;HAUTE LOIRE;1
43073;;Cistrières;CISTRIERES;43160;43;HAUTE LOIRE;1
43074;;Cohade;COHADE;43100;43;HAUTE LOIRE;1
43075;;Collat;COLLAT;43230;43;HAUTE LOIRE;1
43076;;Connangles;CONNANGLES;43160;43;HAUTE LOIRE;1
43077;;Costaros;COSTAROS;43490;43;HAUTE LOIRE;1
43078;;Coubon;COUBON;43700;43;HAUTE LOIRE;1
43079;;Couteuges;COUTEUGES;43230;43;HAUTE LOIRE;1
43080;;Craponne-sur-Arzon;CRAPONNE-SUR-ARZON;43500;43;HAUTE LOIRE;1
43081;;Croisances;CROISANCES;43580;43;HAUTE LOIRE;1
43082;;Cronce;CRONCE;43300;43;HAUTE LOIRE;1
43083;;Cubelles;CUBELLES;43170;43;HAUTE LOIRE;1
43084;;Cussac-sur-Loire;CUSSAC-SUR-LOIRE;43370;43;HAUTE LOIRE;1
43085;;Desges;DESGES;43300;43;HAUTE LOIRE;1
43086;;Domeyrat;DOMEYRAT;43230;43;HAUTE LOIRE;1
43087;;Dunières;DUNIERES;43220;43;HAUTE LOIRE;1
43088;;Espalem;ESPALEM;43450;43;HAUTE LOIRE;1
43089;;Espaly-Saint-Marcel;ESPALY-SAINT-MARCEL;43000;43;HAUTE LOIRE;1
43090;;Esplantas;ESPLANTAS;43170;43;HAUTE LOIRE;1
43091;Les;Estables;ESTABLES;43150;43;HAUTE LOIRE;1
43092;;Fay-sur-Lignon;FAY-SUR-LIGNON;43430;43;HAUTE LOIRE;1
43093;;Félines;FELINES;43160;43;HAUTE LOIRE;1
43094;;Ferrussac;FERRUSSAC;43300;43;HAUTE LOIRE;1
43095;;Fix-Saint-Geneys;FIX-SAINT-GENEYS;43320;43;HAUTE LOIRE;1
43096;;Fontannes;FONTANNES;43100;43;HAUTE LOIRE;1
43097;;Freycenet-la-Cuche;FREYCENET-LA-CUCHE;43150;43;HAUTE LOIRE;1
43098;;Freycenet-la-Tour;FREYCENET-LA-TOUR;43150;43;HAUTE LOIRE;1
43099;;Frugerès-les-Mines;FRUGERES-LES-MINES;43250;43;HAUTE LOIRE;1
43100;;Frugières-le-Pin;FRUGIERES-LE-PIN;43230;43;HAUTE LOIRE;1
43101;;Goudet;GOUDET;43150;43;HAUTE LOIRE;1
43102;;Grazac;GRAZAC;43200;43;HAUTE LOIRE;1
43103;;Grenier-Montgon;GRENIER-MONTGON;43450;43;HAUTE LOIRE;1
43104;;Grèzes;GREZES;43170;43;HAUTE LOIRE;1
43105;;Javaugues;JAVAUGUES;43100;43;HAUTE LOIRE;1
43106;;Jax;JAX;43230;43;HAUTE LOIRE;1
43107;;Josat;JOSAT;43230;43;HAUTE LOIRE;1
43108;;Jullianges;JULLIANGES;43500;43;HAUTE LOIRE;1
43109;;Lafarre;LAFARRE;43490;43;HAUTE LOIRE;1
43110;;Lamothe;LAMOTHE;43100;43;HAUTE LOIRE;1
43111;;Landos;LANDOS;43340;43;HAUTE LOIRE;1
43112;;Langeac;LANGEAC;43300;43;HAUTE LOIRE;1
43113;;Lantriac;LANTRIAC;43260;43;HAUTE LOIRE;1
43114;;Lapte;LAPTE;43200;43;HAUTE LOIRE;1
43115;;Laussonne;LAUSSONNE;43150;43;HAUTE LOIRE;1
43116;;Laval-sur-Doulon;LAVAL-SUR-DOULON;43440;43;HAUTE LOIRE;1
43117;;Lavaudieu;LAVAUDIEU;43100;43;HAUTE LOIRE;1
43118;;Lavoûte-Chilhac;LAVOUTE-CHILHAC;43380;43;HAUTE LOIRE;1
43119;;Lavoûte-sur-Loire;LAVOUTE-SUR-LOIRE;43800;43;HAUTE LOIRE;1
43120;;Lempdes-sur-Allagnon;LEMPDES-SUR-ALLAGNON;43410;43;HAUTE LOIRE;1
43121;;Léotoing;LEOTOING;43410;43;HAUTE LOIRE;1
43122;;Lissac;LISSAC;43350;43;HAUTE LOIRE;1
43123;;Lorlanges;LORLANGES;43360;43;HAUTE LOIRE;1
43124;;Loudes;LOUDES;43320;43;HAUTE LOIRE;1
43125;;Lubilhac;LUBILHAC;43100;43;HAUTE LOIRE;1
43126;;Malrevers;MALREVERS;43800;43;HAUTE LOIRE;1
43127;;Malvalette;MALVALETTE;43210;43;HAUTE LOIRE;1
43128;;Malvières;MALVIERES;43160;43;HAUTE LOIRE;1
43129;Le;Mas-de-Tence;MAS-DE-TENCE;43190;43;HAUTE LOIRE;1
43130;;Mazet-Saint-Voy;MAZET-SAINT-VOY;43520;43;HAUTE LOIRE;1
43131;;Mazerat-Aurouze;MAZERAT-AUROUZE;43230;43;HAUTE LOIRE;1
43132;;Mazeyrat-d'Allier;MAZEYRAT-D'ALLIER;43300;43;HAUTE LOIRE;1
43133;;Mercœur;MERCOEUR;43100;43;HAUTE LOIRE;1
43134;;Mézères;MEZERES;43800;43;HAUTE LOIRE;1
43135;Le;Monastier-sur-Gazeille;MONASTIER-SUR-GAZEILLE;43150;43;HAUTE LOIRE;1
43136;;Monistrol-d'Allier;MONISTROL-D'ALLIER;43580;43;HAUTE LOIRE;1
43137;;Monistrol-sur-Loire;MONISTROL-SUR-LOIRE;43120;43;HAUTE LOIRE;1
43138;;Monlet;MONLET;43270;43;HAUTE LOIRE;1
43139;;Montclard;MONTCLARD;43230;43;HAUTE LOIRE;1
43140;Le;Monteil;MONTEIL;43700;43;HAUTE LOIRE;1
43141;;Montfaucon-en-Velay;MONTFAUCON-EN-VELAY;43290;43;HAUTE LOIRE;1
43142;;Montregard;MONTREGARD;43290;43;HAUTE LOIRE;1
43143;;Montusclat;MONTUSCLAT;43260;43;HAUTE LOIRE;1
43144;;Moudeyres;MOUDEYRES;43150;43;HAUTE LOIRE;1
43145;;Ouides;OUIDES;43510;43;HAUTE LOIRE;1
43147;;Paulhac;PAULHAC;43100;43;HAUTE LOIRE;1
43148;;Paulhaguet;PAULHAGUET;43230;43;HAUTE LOIRE;1
43149;;Pébrac;PEBRAC;43300;43;HAUTE LOIRE;1
43150;Le;Pertuis;PERTUIS;43200;43;HAUTE LOIRE;1
43151;;Pinols;PINOLS;43300;43;HAUTE LOIRE;1
43152;;Polignac;POLIGNAC;43770;43;HAUTE LOIRE;1
43153;;Pont-Salomon;PONT-SALOMON;43330;43;HAUTE LOIRE;1
43154;;Pradelles;PRADELLES;43420;43;HAUTE LOIRE;1
43155;;Prades;PRADES;43300;43;HAUTE LOIRE;1
43156;;Présailles;PRESAILLES;43150;43;HAUTE LOIRE;1
43157;Le;Puy-en-Velay;PUY-EN-VELAY;43000;43;HAUTE LOIRE;1
43158;;Queyrières;QUEYRIERES;43260;43;HAUTE LOIRE;1
43159;;Raucoules;RAUCOULES;43290;43;HAUTE LOIRE;1
43160;;Rauret;RAURET;43340;43;HAUTE LOIRE;1
43162;;Retournac;RETOURNAC;43130;43;HAUTE LOIRE;1
43163;;Riotord;RIOTORD;43220;43;HAUTE LOIRE;1
43164;;Roche-en-Régnier;ROCHE-EN-REGNIER;43130;43;HAUTE LOIRE;1
43165;;Rosières;ROSIERES;43800;43;HAUTE LOIRE;1
43166;;Saint-André-de-Chalencon;SAINT-ANDRE-DE-CHALENCON;43130;43;HAUTE LOIRE;1
43167;;Saint-Arcons-d'Allier;SAINT-ARCONS-D'ALLIER;43300;43;HAUTE LOIRE;1
43168;;Saint-Arcons-de-Barges;SAINT-ARCONS-DE-BARGES;43420;43;HAUTE LOIRE;1
43169;;Saint-Austremoine;SAINT-AUSTREMOINE;43380;43;HAUTE LOIRE;1
43170;;Saint-Beauzire;SAINT-BEAUZIRE;43100;43;HAUTE LOIRE;1
43171;;Saint-Bérain;SAINT-BERAIN;43300;43;HAUTE LOIRE;1
43172;;Saint-Bonnet-le-Froid;SAINT-BONNET-LE-FROID;43290;43;HAUTE LOIRE;1
43173;;Saint-Christophe-d'Allier;SAINT-CHRISTOPHE-D'ALLIER;43340;43;HAUTE LOIRE;1
43174;;Saint-Christophe-sur-Dolaison;SAINT-CHRISTOPHE-SUR-DOLAISON;43370;43;HAUTE LOIRE;1
43175;;Saint-Cirgues;SAINT-CIRGUES;43380;43;HAUTE LOIRE;1
43176;;Saint-Didier-d'Allier;SAINT-DIDIER-D'ALLIER;43580;43;HAUTE LOIRE;1
43177;;Saint-Didier-en-Velay;SAINT-DIDIER-EN-VELAY;43140;43;HAUTE LOIRE;1
43178;;Saint-Didier-sur-Doulon;SAINT-DIDIER-SUR-DOULON;43440;43;HAUTE LOIRE;1
43180;;Saint-Étienne-du-Vigan;SAINT-ETIENNE-DU-VIGAN;43420;43;HAUTE LOIRE;1
43181;;Saint-Étienne-Lardeyrol;SAINT-ETIENNE-LARDEYROL;43260;43;HAUTE LOIRE;1
43182;;Saint-Étienne-sur-Blesle;SAINT-ETIENNE-SUR-BLESLE;43450;43;HAUTE LOIRE;1
43183;;Sainte-Eugénie-de-Villeneuve;SAINTE-EUGENIE-DE-VILLENEUVE;43230;43;HAUTE LOIRE;1
43184;;Saint-Ferréol-d'Auroure;SAINT-FERREOL-D'AUROURE;43330;43;HAUTE LOIRE;1
43185;;Sainte-Florine;SAINTE-FLORINE;43250;43;HAUTE LOIRE;1
43186;;Saint-Front;SAINT-FRONT;43550;43;HAUTE LOIRE;1
43187;;Saint-Geneys-près-Saint-Paulien;SAINT-GENEYS-PRES-SAINT-PAULIEN;43350;43;HAUTE LOIRE;1
43188;;Saint-Georges-d'Aurac;SAINT-GEORGES-D'AURAC;43230;43;HAUTE LOIRE;1
43189;;Saint-Georges-Lagricol;SAINT-GEORGES-LAGRICOL;43500;43;HAUTE LOIRE;1
43190;;Saint-Germain-Laprade;SAINT-GERMAIN-LAPRADE;43700;43;HAUTE LOIRE;1
43191;;Saint-Géron;SAINT-GERON;43360;43;HAUTE LOIRE;1
43192;;Saint-Haon;SAINT-HAON;43340;43;HAUTE LOIRE;1
43193;;Saint-Hilaire;SAINT-HILAIRE;43390;43;HAUTE LOIRE;1
43194;;Saint-Hostien;SAINT-HOSTIEN;43260;43;HAUTE LOIRE;1
43195;;Saint-Ilpize;SAINT-ILPIZE;43380;43;HAUTE LOIRE;1
43196;;Saint-Jean-d'Aubrigoux;SAINT-JEAN-D'AUBRIGOUX;43500;43;HAUTE LOIRE;1
43197;;Saint-Jean-de-Nay;SAINT-JEAN-DE-NAY;43320;43;HAUTE LOIRE;1
43198;;Saint-Jean-Lachalm;SAINT-JEAN-LACHALM;43510;43;HAUTE LOIRE;1
43199;;Saint-Jeures;SAINT-JEURES;43200;43;HAUTE LOIRE;1
43200;;Saint-Julien-Chapteuil;SAINT-JULIEN-CHAPTEUIL;43260;43;HAUTE LOIRE;1
43201;;Saint-Julien-d'Ance;SAINT-JULIEN-D'ANCE;43500;43;HAUTE LOIRE;1
43202;;Saint-Julien-des-Chazes;SAINT-JULIEN-DES-CHAZES;43300;43;HAUTE LOIRE;1
43203;;Saint-Julien-du-Pinet;SAINT-JULIEN-DU-PINET;43200;43;HAUTE LOIRE;1
43204;;Saint-Julien-Molhesabate;SAINT-JULIEN-MOLHESABATE;43220;43;HAUTE LOIRE;1
43205;;Saint-Just-Malmont;SAINT-JUST-MALMONT;43240;43;HAUTE LOIRE;1
43206;;Saint-Just-près-Brioude;SAINT-JUST-PRES-BRIOUDE;43100;43;HAUTE LOIRE;1
43207;;Saint-Laurent-Chabreuges;SAINT-LAURENT-CHABREUGES;43100;43;HAUTE LOIRE;1
43208;;Sainte-Marguerite;SAINTE-MARGUERITE;43230;43;HAUTE LOIRE;1
43210;;Saint-Martin-de-Fugères;SAINT-MARTIN-DE-FUGERES;43150;43;HAUTE LOIRE;1
43211;;Saint-Maurice-de-Lignon;SAINT-MAURICE-DE-LIGNON;43200;43;HAUTE LOIRE;1
43212;;Saint-Pal-de-Chalencon;SAINT-PAL-DE-CHALENCON;43500;43;HAUTE LOIRE;1
43213;;Saint-Pal-de-Mons;SAINT-PAL-DE-MONS;43620;43;HAUTE LOIRE;1
43214;;Saint-Pal-de-Senouire;SAINT-PAL-DE-SENOUIRE;43160;43;HAUTE LOIRE;1
43215;;Saint-Paul-de-Tartas;SAINT-PAUL-DE-TARTAS;43420;43;HAUTE LOIRE;1
43216;;Saint-Paulien;SAINT-PAULIEN;43350;43;HAUTE LOIRE;1
43217;;Saint-Pierre-du-Champ;SAINT-PIERRE-DU-CHAMP;43130;43;HAUTE LOIRE;1
43218;;Saint-Pierre-Eynac;SAINT-PIERRE-EYNAC;43260;43;HAUTE LOIRE;1
43219;;Saint-Préjet-Armandon;SAINT-PREJET-ARMANDON;43230;43;HAUTE LOIRE;1
43220;;Saint-Préjet-d'Allier;SAINT-PREJET-D'ALLIER;43580;43;HAUTE LOIRE;1
43221;;Saint-Privat-d'Allier;SAINT-PRIVAT-D'ALLIER;43580;43;HAUTE LOIRE;1
43222;;Saint-Privat-du-Dragon;SAINT-PRIVAT-DU-DRAGON;43380;43;HAUTE LOIRE;1
43223;;Saint-Romain-Lachalm;SAINT-ROMAIN-LACHALM;43620;43;HAUTE LOIRE;1
43224;;Sainte-Sigolène;SAINTE-SIGOLENE;43600;43;HAUTE LOIRE;1
43225;;Saint-Vénérand;SAINT-VENERAND;43580;43;HAUTE LOIRE;1
43226;;Saint-Vert;SAINT-VERT;43440;43;HAUTE LOIRE;1
43227;;Saint-Victor-Malescours;SAINT-VICTOR-MALESCOURS;43140;43;HAUTE LOIRE;1
43228;;Saint-Victor-sur-Arlanc;SAINT-VICTOR-SUR-ARLANC;43500;43;HAUTE LOIRE;1
43229;;Saint-Vidal;SAINT-VIDAL;43320;43;HAUTE LOIRE;1
43230;;Saint-Vincent;SAINT-VINCENT;43800;43;HAUTE LOIRE;1
43231;;Salettes;SALETTES;43150;43;HAUTE LOIRE;1
43232;;Salzuit;SALZUIT;43230;43;HAUTE LOIRE;1
43233;;Sanssac-l'Église;SANSSAC-L'EGLISE;43320;43;HAUTE LOIRE;1
43234;;Saugues;SAUGUES;43170;43;HAUTE LOIRE;1
43236;La;Séauve-sur-Semène;SEAUVE-SUR-SEMENE;43140;43;HAUTE LOIRE;1
43237;;Sembadel;SEMBADEL;43160;43;HAUTE LOIRE;1
43238;;Séneujols;SENEUJOLS;43510;43;HAUTE LOIRE;1
43239;;Siaugues-Sainte-Marie;SIAUGUES-SAINTE-MARIE;43300;43;HAUTE LOIRE;1
43240;;Solignac-sous-Roche;SOLIGNAC-SOUS-ROCHE;43130;43;HAUTE LOIRE;1
43241;;Solignac-sur-Loire;SOLIGNAC-SUR-LOIRE;43370;43;HAUTE LOIRE;1
43242;;Tailhac;TAILHAC;43300;43;HAUTE LOIRE;1
43244;;Tence;TENCE;43190;43;HAUTE LOIRE;1
43245;;Thoras;THORAS;43170;43;HAUTE LOIRE;1
43246;;Tiranges;TIRANGES;43130;43;HAUTE LOIRE;1
43247;;Torsiac;TORSIAC;43450;43;HAUTE LOIRE;1
43249;;Valprivas;VALPRIVAS;43210;43;HAUTE LOIRE;1
43250;;Vals-le-Chastel;VALS-LE-CHASTEL;43230;43;HAUTE LOIRE;1
43251;;Vals-près-le-Puy;VALS-PRES-LE-PUY;43750;43;HAUTE LOIRE;1
43252;;Varennes-Saint-Honorat;VARENNES-SAINT-HONORAT;43270;43;HAUTE LOIRE;1
43253;Les;Vastres;VASTRES;43430;43;HAUTE LOIRE;1
43254;;Vazeilles-Limandre;VAZEILLES-LIMANDRE;43320;43;HAUTE LOIRE;1
43255;;Vazeilles-près-Saugues;VAZEILLES-PRES-SAUGUES;43580;43;HAUTE LOIRE;1
43256;;Venteuges;VENTEUGES;43170;43;HAUTE LOIRE;1
43257;;Vergezac;VERGEZAC;43320;43;HAUTE LOIRE;1
43258;;Vergongheon;VERGONGHEON;43360;43;HAUTE LOIRE;1
43259;;Vernassal;VERNASSAL;43270;43;HAUTE LOIRE;1
43260;Le;Vernet;VERNET;43320;43;HAUTE LOIRE;1
43261;;Vézézoux;VEZEZOUX;43390;43;HAUTE LOIRE;1
43262;;Vieille-Brioude;VIEILLE-BRIOUDE;43100;43;HAUTE LOIRE;1
43263;;Vielprat;VIELPRAT;43490;43;HAUTE LOIRE;1
43264;;Villeneuve-d'Allier;VILLENEUVE-D'ALLIER;43380;43;HAUTE LOIRE;1
43265;Les;Villettes;VILLETTES;43600;43;HAUTE LOIRE;1
43267;;Vorey;VOREY;43800;43;HAUTE LOIRE;1
43268;;Yssingeaux;YSSINGEAUX;43200;43;HAUTE LOIRE;1
44001;;Abbaretz;ABBARETZ;44170;44;LOIRE ATLANTIQUE;1
44002;;Aigrefeuille-sur-Maine;AIGREFEUILLE-SUR-MAINE;44140;44;LOIRE ATLANTIQUE;1
44003;;Ancenis;ANCENIS;44150;44;LOIRE ATLANTIQUE;1
44004;;Anetz;ANETZ;44150;44;LOIRE ATLANTIQUE;1
44005;;Arthon-en-Retz;ARTHON-EN-RETZ;44320;44;LOIRE ATLANTIQUE;1
44006;;Assérac;ASSERAC;44410;44;LOIRE ATLANTIQUE;1
44007;;Avessac;AVESSAC;44460;44;LOIRE ATLANTIQUE;1
44008;;Barbechat;BARBECHAT;44450;44;LOIRE ATLANTIQUE;1
44009;;Basse-Goulaine;BASSE-GOULAINE;44115;44;LOIRE ATLANTIQUE;1
44010;;Batz-sur-Mer;BATZ-SUR-MER;44740;44;LOIRE ATLANTIQUE;1
44011;;Belligné;BELLIGNE;44370;44;LOIRE ATLANTIQUE;1
44012;La;Bernerie-en-Retz;BERNERIE-EN-RETZ;44760;44;LOIRE ATLANTIQUE;1
44013;;Besné;BESNE;44160;44;LOIRE ATLANTIQUE;1
44014;Le;Bignon;BIGNON;44140;44;LOIRE ATLANTIQUE;1
44015;;Blain;BLAIN;44130;44;LOIRE ATLANTIQUE;1
44016;La;Boissière-du-Doré;BOISSIERE-DU-DORE;44430;44;LOIRE ATLANTIQUE;1
44017;;Bonnœuvre;BONNOEUVRE;44540;44;LOIRE ATLANTIQUE;1
44018;;Bouaye;BOUAYE;44830;44;LOIRE ATLANTIQUE;1
44019;;Bouée;BOUEE;44260;44;LOIRE ATLANTIQUE;1
44020;;Bouguenais;BOUGUENAIS;44340;44;LOIRE ATLANTIQUE;1
44021;;Bourgneuf-en-Retz;BOURGNEUF-EN-RETZ;44580;44;LOIRE ATLANTIQUE;1
44022;;Boussay;BOUSSAY;44190;44;LOIRE ATLANTIQUE;1
44023;;Bouvron;BOUVRON;44130;44;LOIRE ATLANTIQUE;1
44024;;Brains;BRAINS;44830;44;LOIRE ATLANTIQUE;1
44025;;Campbon;CAMPBON;44750;44;LOIRE ATLANTIQUE;1
44026;;Carquefou;CARQUEFOU;44470;44;LOIRE ATLANTIQUE;1
44027;;Casson;CASSON;44390;44;LOIRE ATLANTIQUE;1
44028;Le;Cellier;CELLIER;44850;44;LOIRE ATLANTIQUE;1
44029;La;Chapelle-Basse-Mer;CHAPELLE-BASSE-MER;44450;44;LOIRE ATLANTIQUE;1
44030;La;Chapelle-des-Marais;CHAPELLE-DES-MARAIS;44410;44;LOIRE ATLANTIQUE;1
44031;La;Chapelle-Glain;CHAPELLE-GLAIN;44670;44;LOIRE ATLANTIQUE;1
44032;La;Chapelle-Heulin;CHAPELLE-HEULIN;44330;44;LOIRE ATLANTIQUE;1
44033;La;Chapelle-Launay;CHAPELLE-LAUNAY;44260;44;LOIRE ATLANTIQUE;1
44034;La;Chapelle-Saint-Sauveur;CHAPELLE-SAINT-SAUVEUR;44370;44;LOIRE ATLANTIQUE;1
44035;La;Chapelle-sur-Erdre;CHAPELLE-SUR-ERDRE;44240;44;LOIRE ATLANTIQUE;1
44036;;Châteaubriant;CHATEAUBRIANT;44110;44;LOIRE ATLANTIQUE;1
44037;;Château-Thébaud;CHATEAU-THEBAUD;44690;44;LOIRE ATLANTIQUE;1
44038;;Chauvé;CHAUVE;44320;44;LOIRE ATLANTIQUE;1
44039;;Cheix-en-Retz;CHEIX-EN-RETZ;44640;44;LOIRE ATLANTIQUE;1
44040;;Chéméré;CHEMERE;44680;44;LOIRE ATLANTIQUE;1
44041;La;Chevrolière;CHEVROLIERE;44118;44;LOIRE ATLANTIQUE;1
44043;;Clisson;CLISSON;44190;44;LOIRE ATLANTIQUE;1
44044;;Conquereuil;CONQUEREUIL;44290;44;LOIRE ATLANTIQUE;1
44045;;Cordemais;CORDEMAIS;44360;44;LOIRE ATLANTIQUE;1
44046;;Corsept;CORSEPT;44560;44;LOIRE ATLANTIQUE;1
44047;;Couëron;COUERON;44220;44;LOIRE ATLANTIQUE;1
44048;;Couffé;COUFFE;44521;44;LOIRE ATLANTIQUE;1
44049;Le;Croisic;CROISIC;44490;44;LOIRE ATLANTIQUE;1
44050;;Crossac;CROSSAC;44160;44;LOIRE ATLANTIQUE;1
44051;;Derval;DERVAL;44590;44;LOIRE ATLANTIQUE;1
44052;;Donges;DONGES;44480;44;LOIRE ATLANTIQUE;1
44053;;Drefféac;DREFFEAC;44530;44;LOIRE ATLANTIQUE;1
44054;;Erbray;ERBRAY;44110;44;LOIRE ATLANTIQUE;1
44055;La;Baule-Escoublac;BAULE-ESCOUBLAC;44500;44;LOIRE ATLANTIQUE;1
44056;;Fay-de-Bretagne;FAY-DE-BRETAGNE;44130;44;LOIRE ATLANTIQUE;1
44057;;Fégréac;FEGREAC;44460;44;LOIRE ATLANTIQUE;1
44058;;Fercé;FERCE;44660;44;LOIRE ATLANTIQUE;1
44059;;Fresnay-en-Retz;FRESNAY-EN-RETZ;44580;44;LOIRE ATLANTIQUE;1
44060;Le;Fresne-sur-Loire;FRESNE-SUR-LOIRE;49123;44;MAINE ET LOIRE;1
44061;;Frossay;FROSSAY;44320;44;LOIRE ATLANTIQUE;1
44062;Le;Gâvre;GAVRE;44130;44;LOIRE ATLANTIQUE;1
44063;;Gétigné;GETIGNE;44190;44;LOIRE ATLANTIQUE;1
44064;;Gorges;GORGES;44190;44;LOIRE ATLANTIQUE;1
44065;;Grand-Auverné;GRAND-AUVERNE;44520;44;LOIRE ATLANTIQUE;1
44066;;Grandchamps-des-Fontaines;GRANDCHAMPS-DES-FONTAINES;44119;44;LOIRE ATLANTIQUE;1
44067;;Guémené-Penfao;GUEMENE-PENFAO;44290;44;LOIRE ATLANTIQUE;1
44068;;Guenrouet;GUENROUET;44530;44;LOIRE ATLANTIQUE;1
44069;;Guérande;GUERANDE;44350;44;LOIRE ATLANTIQUE;1
44070;La;Haie-Fouassière;HAIE-FOUASSIERE;44690;44;LOIRE ATLANTIQUE;1
44071;;Haute-Goulaine;HAUTE-GOULAINE;44115;44;LOIRE ATLANTIQUE;1
44072;;Herbignac;HERBIGNAC;44410;44;LOIRE ATLANTIQUE;1
44073;;Héric;HERIC;44810;44;LOIRE ATLANTIQUE;1
44074;;Indre;INDRE;44610;44;LOIRE ATLANTIQUE;1
44075;;Issé;ISSE;44520;44;LOIRE ATLANTIQUE;1
44076;;Jans;JANS;44170;44;LOIRE ATLANTIQUE;1
44077;;Joué-sur-Erdre;JOUE-SUR-ERDRE;44440;44;LOIRE ATLANTIQUE;1
44078;;Juigné-des-Moutiers;JUIGNE-DES-MOUTIERS;44670;44;LOIRE ATLANTIQUE;1
44079;Le;Landreau;LANDREAU;44430;44;LOIRE ATLANTIQUE;1
44080;;Lavau-sur-Loire;LAVAU-SUR-LOIRE;44260;44;LOIRE ATLANTIQUE;1
44081;;Legé;LEGE;44650;44;LOIRE ATLANTIQUE;1
44082;;Ligné;LIGNE;44850;44;LOIRE ATLANTIQUE;1
44083;La;Limouzinière;LIMOUZINIERE;44310;44;LOIRE ATLANTIQUE;1
44084;Le;Loroux-Bottereau;LOROUX-BOTTEREAU;44430;44;LOIRE ATLANTIQUE;1
44085;;Louisfert;LOUISFERT;44110;44;LOIRE ATLANTIQUE;1
44086;;Lusanger;LUSANGER;44590;44;LOIRE ATLANTIQUE;1
44087;;Machecoul;MACHECOUL;44270;44;LOIRE ATLANTIQUE;1
44088;;Maisdon-sur-Sèvre;MAISDON-SUR-SEVRE;44690;44;LOIRE ATLANTIQUE;1
44089;;Malville;MALVILLE;44260;44;LOIRE ATLANTIQUE;1
44090;La;Marne;MARNE;44270;44;LOIRE ATLANTIQUE;1
44091;;Marsac-sur-Don;MARSAC-SUR-DON;44170;44;LOIRE ATLANTIQUE;1
44092;;Massérac;MASSERAC;44290;44;LOIRE ATLANTIQUE;1
44093;;Maumusson;MAUMUSSON;44540;44;LOIRE ATLANTIQUE;1
44094;;Mauves-sur-Loire;MAUVES-SUR-LOIRE;44470;44;LOIRE ATLANTIQUE;1
44095;La;Meilleraye-de-Bretagne;MEILLERAYE-DE-BRETAGNE;44520;44;LOIRE ATLANTIQUE;1
44096;;Mésanger;MESANGER;44522;44;LOIRE ATLANTIQUE;1
44097;;Mesquer;MESQUER;44420;44;LOIRE ATLANTIQUE;1
44098;;Missillac;MISSILLAC;44780;44;LOIRE ATLANTIQUE;1
44099;;Moisdon-la-Rivière;MOISDON-LA-RIVIERE;44520;44;LOIRE ATLANTIQUE;1
44100;;Monnières;MONNIERES;44690;44;LOIRE ATLANTIQUE;1
44101;La;Montagne;MONTAGNE;44620;44;LOIRE ATLANTIQUE;1
44102;;Montbert;MONTBERT;44140;44;LOIRE ATLANTIQUE;1
44103;;Montoir-de-Bretagne;MONTOIR-DE-BRETAGNE;44550;44;LOIRE ATLANTIQUE;1
44104;;Montrelais;MONTRELAIS;44370;44;LOIRE ATLANTIQUE;1
44105;;Mouais;MOUAIS;44590;44;LOIRE ATLANTIQUE;1
44106;Les;Moutiers-en-Retz;MOUTIERS-EN-RETZ;44580;44;LOIRE ATLANTIQUE;1
44107;;Mouzeil;MOUZEIL;44850;44;LOIRE ATLANTIQUE;1
44108;;Mouzillon;MOUZILLON;44330;44;LOIRE ATLANTIQUE;1
44109;;Nantes;NANTES;44000;44;LOIRE ATLANTIQUE;1
44110;;Nort-sur-Erdre;NORT-SUR-ERDRE;44390;44;LOIRE ATLANTIQUE;1
44111;;Notre-Dame-des-Landes;NOTRE-DAME-DES-LANDES;44130;44;LOIRE ATLANTIQUE;1
44112;;Noyal-sur-Brutz;NOYAL-SUR-BRUTZ;44110;44;LOIRE ATLANTIQUE;1
44113;;Nozay;NOZAY;44170;44;LOIRE ATLANTIQUE;1
44114;;Orvault;ORVAULT;44700;44;LOIRE ATLANTIQUE;1
44115;;Oudon;OUDON;44521;44;LOIRE ATLANTIQUE;1
44116;;Paimbœuf;PAIMBOEUF;44560;44;LOIRE ATLANTIQUE;1
44117;Le;Pallet;PALLET;44330;44;LOIRE ATLANTIQUE;1
44118;;Pannecé;PANNECE;44440;44;LOIRE ATLANTIQUE;1
44119;;Paulx;PAULX;44270;44;LOIRE ATLANTIQUE;1
44120;Le;Pellerin;PELLERIN;44640;44;LOIRE ATLANTIQUE;1
44121;;Petit-Auverné;PETIT-AUVERNE;44670;44;LOIRE ATLANTIQUE;1
44122;;Petit-Mars;PETIT-MARS;44390;44;LOIRE ATLANTIQUE;1
44123;;Pierric;PIERRIC;44290;44;LOIRE ATLANTIQUE;1
44124;Le;Pin;PIN;44540;44;LOIRE ATLANTIQUE;1
44125;;Piriac-sur-Mer;PIRIAC-SUR-MER;44420;44;LOIRE ATLANTIQUE;1
44126;La;Plaine-sur-Mer;PLAINE-SUR-MER;44770;44;LOIRE ATLANTIQUE;1
44127;La;Planche;PLANCHE;44140;44;LOIRE ATLANTIQUE;1
44128;;Plessé;PLESSE;44630;44;LOIRE ATLANTIQUE;1
44129;;Pontchâteau;PONTCHATEAU;44160;44;LOIRE ATLANTIQUE;1
44130;;Pont-Saint-Martin;PONT-SAINT-MARTIN;44860;44;LOIRE ATLANTIQUE;1
44131;;Pornic;PORNIC;44210;44;LOIRE ATLANTIQUE;1
44132;;Pornichet;PORNICHET;44380;44;LOIRE ATLANTIQUE;1
44133;;Port-Saint-Père;PORT-SAINT-PERE;44710;44;LOIRE ATLANTIQUE;1
44134;;Pouillé-les-Côteaux;POUILLE-LES-COTEAUX;44522;44;LOIRE ATLANTIQUE;1
44135;Le;Pouliguen;POULIGUEN;44510;44;LOIRE ATLANTIQUE;1
44136;;Préfailles;PREFAILLES;44770;44;LOIRE ATLANTIQUE;1
44137;;Prinquiau;PRINQUIAU;44260;44;LOIRE ATLANTIQUE;1
44138;;Puceul;PUCEUL;44390;44;LOIRE ATLANTIQUE;1
44139;;Quilly;QUILLY;44750;44;LOIRE ATLANTIQUE;1
44140;La;Regrippière;REGRIPPIERE;44330;44;LOIRE ATLANTIQUE;1
44141;La;Remaudière;REMAUDIERE;44430;44;LOIRE ATLANTIQUE;1
44142;;Remouillé;REMOUILLE;44140;44;LOIRE ATLANTIQUE;1
44143;;Rezé;REZE;44400;44;LOIRE ATLANTIQUE;1
44144;;Riaillé;RIAILLE;44440;44;LOIRE ATLANTIQUE;1
44145;;Rouans;ROUANS;44640;44;LOIRE ATLANTIQUE;1
44146;;Rougé;ROUGE;44660;44;LOIRE ATLANTIQUE;1
44147;La;Rouxière;ROUXIERE;44370;44;LOIRE ATLANTIQUE;1
44148;;Ruffigné;RUFFIGNE;44660;44;LOIRE ATLANTIQUE;1
44149;;Saffré;SAFFRE;44390;44;LOIRE ATLANTIQUE;1
44150;;Saint-Aignan-Grandlieu;SAINT-AIGNAN-GRANDLIEU;44860;44;LOIRE ATLANTIQUE;1
44151;;Saint-André-des-Eaux;SAINT-ANDRE-DES-EAUX;44117;44;LOIRE ATLANTIQUE;1
44152;;Sainte-Anne-sur-Brivet;SAINTE-ANNE-SUR-BRIVET;44160;44;LOIRE ATLANTIQUE;1
44153;;Saint-Aubin-des-Châteaux;SAINT-AUBIN-DES-CHATEAUX;44110;44;LOIRE ATLANTIQUE;1
44154;;Saint-Brevin-les-Pins;SAINT-BREVIN-LES-PINS;44250;44;LOIRE ATLANTIQUE;1
44155;;Saint-Colomban;SAINT-COLOMBAN;44310;44;LOIRE ATLANTIQUE;1
44156;;Corcoué-sur-Logne;CORCOUE-SUR-LOGNE;44650;44;LOIRE ATLANTIQUE;1
44157;;Saint-Étienne-de-Mer-Morte;SAINT-ETIENNE-DE-MER-MORTE;44270;44;LOIRE ATLANTIQUE;1
44158;;Saint-Étienne-de-Montluc;SAINT-ETIENNE-DE-MONTLUC;44360;44;LOIRE ATLANTIQUE;1
44159;;Saint-Fiacre-sur-Maine;SAINT-FIACRE-SUR-MAINE;44690;44;LOIRE ATLANTIQUE;1
44160;;Saint-Géréon;SAINT-GEREON;44150;44;LOIRE ATLANTIQUE;1
44161;;Saint-Gildas-des-Bois;SAINT-GILDAS-DES-BOIS;44530;44;LOIRE ATLANTIQUE;1
44162;;Saint-Herblain;SAINT-HERBLAIN;44800;44;LOIRE ATLANTIQUE;1
44163;;Saint-Herblon;SAINT-HERBLON;44150;44;LOIRE ATLANTIQUE;1
44164;;Saint-Hilaire-de-Chaléons;SAINT-HILAIRE-DE-CHALEONS;44680;44;LOIRE ATLANTIQUE;1
44165;;Saint-Hilaire-de-Clisson;SAINT-HILAIRE-DE-CLISSON;44190;44;LOIRE ATLANTIQUE;1
44166;;Saint-Jean-de-Boiseau;SAINT-JEAN-DE-BOISEAU;44640;44;LOIRE ATLANTIQUE;1
44168;;Saint-Joachim;SAINT-JOACHIM;44720;44;LOIRE ATLANTIQUE;1
44169;;Saint-Julien-de-Concelles;SAINT-JULIEN-DE-CONCELLES;44450;44;LOIRE ATLANTIQUE;1
44170;;Saint-Julien-de-Vouvantes;SAINT-JULIEN-DE-VOUVANTES;44670;44;LOIRE ATLANTIQUE;1
44171;;Saint-Léger-les-Vignes;SAINT-LEGER-LES-VIGNES;44710;44;LOIRE ATLANTIQUE;1
44172;;Sainte-Luce-sur-Loire;SAINTE-LUCE-SUR-LOIRE;44980;44;LOIRE ATLANTIQUE;1
44173;;Saint-Lumine-de-Clisson;SAINT-LUMINE-DE-CLISSON;44190;44;LOIRE ATLANTIQUE;1
44174;;Saint-Lumine-de-Coutais;SAINT-LUMINE-DE-COUTAIS;44310;44;LOIRE ATLANTIQUE;1
44175;;Saint-Lyphard;SAINT-LYPHARD;44410;44;LOIRE ATLANTIQUE;1
44176;;Saint-Malo-de-Guersac;SAINT-MALO-DE-GUERSAC;44550;44;LOIRE ATLANTIQUE;1
44178;;Saint-Mars-de-Coutais;SAINT-MARS-DE-COUTAIS;44680;44;LOIRE ATLANTIQUE;1
44179;;Saint-Mars-du-Désert;SAINT-MARS-DU-DESERT;44850;44;LOIRE ATLANTIQUE;1
44180;;Saint-Mars-la-Jaille;SAINT-MARS-LA-JAILLE;44540;44;LOIRE ATLANTIQUE;1
44181;;Saint-Même-le-Tenu;SAINT-MEME-LE-TENU;44270;44;LOIRE ATLANTIQUE;1
44182;;Saint-Michel-Chef-Chef;SAINT-MICHEL-CHEF-CHEF;44730;44;LOIRE ATLANTIQUE;1
44183;;Saint-Molf;SAINT-MOLF;44350;44;LOIRE ATLANTIQUE;1
44184;;Saint-Nazaire;SAINT-NAZAIRE;44600;44;LOIRE ATLANTIQUE;1
44185;;Saint-Nicolas-de-Redon;SAINT-NICOLAS-DE-REDON;44460;44;LOIRE ATLANTIQUE;1
44186;;Sainte-Pazanne;SAINTE-PAZANNE;44680;44;LOIRE ATLANTIQUE;1
44187;;Saint-Père-en-Retz;SAINT-PERE-EN-RETZ;44320;44;LOIRE ATLANTIQUE;1
44188;;Saint-Philbert-de-Grand-Lieu;SAINT-PHILBERT-DE-GRAND-LIEU;44310;44;LOIRE ATLANTIQUE;1
44189;;Sainte-Reine-de-Bretagne;SAINTE-REINE-DE-BRETAGNE;44160;44;LOIRE ATLANTIQUE;1
44190;;Saint-Sébastien-sur-Loire;SAINT-SEBASTIEN-SUR-LOIRE;44230;44;LOIRE ATLANTIQUE;1
44191;;Saint-Sulpice-des-Landes;SAINT-SULPICE-DES-LANDES;44540;44;LOIRE ATLANTIQUE;1
44192;;Saint-Viaud;SAINT-VIAUD;44320;44;LOIRE ATLANTIQUE;1
44193;;Saint-Vincent-des-Landes;SAINT-VINCENT-DES-LANDES;44590;44;LOIRE ATLANTIQUE;1
44194;;Sautron;SAUTRON;44880;44;LOIRE ATLANTIQUE;1
44195;;Savenay;SAVENAY;44260;44;LOIRE ATLANTIQUE;1
44196;;Sévérac;SEVERAC;44530;44;LOIRE ATLANTIQUE;1
44197;;Sion-les-Mines;SION-LES-MINES;44590;44;LOIRE ATLANTIQUE;1
44198;Les;Sorinières;SORINIERES;44840;44;LOIRE ATLANTIQUE;1
44199;;Soudan;SOUDAN;44110;44;LOIRE ATLANTIQUE;1
44200;;Soulvache;SOULVACHE;44660;44;LOIRE ATLANTIQUE;1
44201;;Sucé-sur-Erdre;SUCE-SUR-ERDRE;44240;44;LOIRE ATLANTIQUE;1
44202;;Teillé;TEILLE;44440;44;LOIRE ATLANTIQUE;1
44203;Le;Temple-de-Bretagne;TEMPLE-DE-BRETAGNE;44360;44;LOIRE ATLANTIQUE;1
44204;;Thouaré-sur-Loire;THOUARE-SUR-LOIRE;44470;44;LOIRE ATLANTIQUE;1
44205;Les;Touches;TOUCHES;44390;44;LOIRE ATLANTIQUE;1
44206;;Touvois;TOUVOIS;44650;44;LOIRE ATLANTIQUE;1
44207;;Trans-sur-Erdre;TRANS-SUR-ERDRE;44440;44;LOIRE ATLANTIQUE;1
44208;;Treffieux;TREFFIEUX;44170;44;LOIRE ATLANTIQUE;1
44209;;Treillières;TREILLIERES;44119;44;LOIRE ATLANTIQUE;1
44210;;Trignac;TRIGNAC;44570;44;LOIRE ATLANTIQUE;1
44211;La;Turballe;TURBALLE;44420;44;LOIRE ATLANTIQUE;1
44212;;Vallet;VALLET;44330;44;LOIRE ATLANTIQUE;1
44213;;Varades;VARADES;44370;44;LOIRE ATLANTIQUE;1
44214;;Vay;VAY;44170;44;LOIRE ATLANTIQUE;1
44215;;Vertou;VERTOU;44120;44;LOIRE ATLANTIQUE;1
44216;;Vieillevigne;VIEILLEVIGNE;44116;44;LOIRE ATLANTIQUE;1
44217;;Vigneux-de-Bretagne;VIGNEUX-DE-BRETAGNE;44360;44;LOIRE ATLANTIQUE;1
44218;;Villepot;VILLEPOT;44110;44;LOIRE ATLANTIQUE;1
44219;;Vritz;VRITZ;49440;44;MAINE ET LOIRE;1
44220;;Vue;VUE;44640;44;LOIRE ATLANTIQUE;1
44221;La;Chevallerais;CHEVALLERAIS;44810;44;LOIRE ATLANTIQUE;1
44222;La;Roche-Blanche;ROCHE-BLANCHE;44522;44;LOIRE ATLANTIQUE;1
44223;;Geneston;GENESTON;44140;44;LOIRE ATLANTIQUE;1
44224;La;Grigonnais;GRIGONNAIS;44170;44;LOIRE ATLANTIQUE;1
45001;;Adon;ADON;45230;45;LOIRET;1
45002;;Aillant-sur-Milleron;AILLANT-SUR-MILLERON;45230;45;LOIRET;1
45004;;Amilly;AMILLY;45200;45;LOIRET;1
45005;;Andonville;ANDONVILLE;45480;45;LOIRET;1
45006;;Ardon;ARDON;45160;45;LOIRET;1
45008;;Artenay;ARTENAY;45410;45;LOIRET;1
45009;;Aschères-le-Marché;ASCHERES-LE-MARCHE;45170;45;LOIRET;1
45010;;Ascoux;ASCOUX;45300;45;LOIRET;1
45011;;Attray;ATTRAY;45170;45;LOIRET;1
45012;;Audeville;AUDEVILLE;45300;45;LOIRET;1
45013;;Augerville-la-Rivière;AUGERVILLE-LA-RIVIERE;45330;45;LOIRET;1
45014;;Aulnay-la-Rivière;AULNAY-LA-RIVIERE;45390;45;LOIRET;1
45015;;Autruy-sur-Juine;AUTRUY-SUR-JUINE;45480;45;LOIRET;1
45016;;Autry-le-Châtel;AUTRY-LE-CHATEL;45500;45;LOIRET;1
45017;;Auvilliers-en-Gâtinais;AUVILLIERS-EN-GATINAIS;45270;45;LOIRET;1
45018;;Auxy;AUXY;45340;45;LOIRET;1
45019;;Baccon;BACCON;45130;45;LOIRET;1
45020;Le;Bardon;BARDON;45130;45;LOIRET;1
45021;;Barville-en-Gâtinais;BARVILLE-EN-GATINAIS;45340;45;LOIRET;1
45022;;Batilly-en-Gâtinais;BATILLY-EN-GATINAIS;45340;45;LOIRET;1
45023;;Batilly-en-Puisaye;BATILLY-EN-PUISAYE;45420;45;LOIRET;1
45024;;Baule;BAULE;45130;45;LOIRET;1
45025;;Bazoches-les-Gallerandes;BAZOCHES-LES-GALLERANDES;45480;45;LOIRET;1
45026;;Bazoches-sur-le-Betz;BAZOCHES-SUR-LE-BETZ;45210;45;LOIRET;1
45027;;Beauchamps-sur-Huillard;BEAUCHAMPS-SUR-HUILLARD;45270;45;LOIRET;1
45028;;Beaugency;BEAUGENCY;45190;45;LOIRET;1
45029;;Beaulieu-sur-Loire;BEAULIEU-SUR-LOIRE;45630;45;LOIRET;1
45030;;Beaune-la-Rolande;BEAUNE-LA-ROLANDE;45340;45;LOIRET;1
45031;;Bellegarde;BELLEGARDE;45270;45;LOIRET;1
45032;Le;Bignon-Mirabeau;BIGNON-MIRABEAU;45210;45;LOIRET;1
45033;;Boësses;BOESSES;45390;45;LOIRET;1
45034;;Boigny-sur-Bionne;BOIGNY-SUR-BIONNE;45760;45;LOIRET;1
45035;;Boiscommun;BOISCOMMUN;45340;45;LOIRET;1
45036;;Boismorand;BOISMORAND;45290;45;LOIRET;1
45037;;Boisseaux;BOISSEAUX;45480;45;LOIRET;1
45038;;Bondaroy;BONDAROY;45300;45;LOIRET;1
45039;;Bonnée;BONNEE;45460;45;LOIRET;1
45040;;Bonny-sur-Loire;BONNY-SUR-LOIRE;45420;45;LOIRET;1
45041;;Bordeaux-en-Gâtinais;BORDEAUX-EN-GATINAIS;45340;45;LOIRET;1
45042;Les;Bordes;BORDES;45460;45;LOIRET;1
45043;;Bou;BOU;45430;45;LOIRET;1
45044;;Bougy-lez-Neuville;BOUGY-LEZ-NEUVILLE;45170;45;LOIRET;1
45045;;Bouilly-en-Gâtinais;BOUILLY-EN-GATINAIS;45300;45;LOIRET;1
45046;;Boulay-les-Barres;BOULAY-LES-BARRES;45140;45;LOIRET;1
45047;;Bouzonville-aux-Bois;BOUZONVILLE-AUX-BOIS;45300;45;LOIRET;1
45049;;Bouzy-la-Forêt;BOUZY-LA-FORET;45460;45;LOIRET;1
45050;;Boynes;BOYNES;45300;45;LOIRET;1
45051;;Bray-en-Val;BRAY-EN-VAL;45460;45;LOIRET;1
45052;;Breteau;BRETEAU;45250;45;LOIRET;1
45053;;Briare;BRIARE;45250;45;LOIRET;1
45054;;Briarres-sur-Essonne;BRIARRES-SUR-ESSONNE;45390;45;LOIRET;1
45055;;Bricy;BRICY;45310;45;LOIRET;1
45056;;Bromeilles;BROMEILLES;45390;45;LOIRET;1
45057;;Labrosse;LABROSSE;45330;45;LOIRET;1
45058;;Bucy-le-Roi;BUCY-LE-ROI;45410;45;LOIRET;1
45059;;Bucy-Saint-Liphard;BUCY-SAINT-LIPHARD;45140;45;LOIRET;1
45060;La;Bussière;BUSSIERE;45230;45;LOIRET;1
45061;;Cepoy;CEPOY;45120;45;LOIRET;1
45062;;Cercottes;CERCOTTES;45520;45;LOIRET;1
45063;;Cerdon;CERDON;45620;45;LOIRET;1
45064;;Cernoy-en-Berry;CERNOY-EN-BERRY;45360;45;LOIRET;1
45065;;Césarville-Dossainville;CESARVILLE-DOSSAINVILLE;45300;45;LOIRET;1
45066;;Chailly-en-Gâtinais;CHAILLY-EN-GATINAIS;45260;45;LOIRET;1
45067;;Chaingy;CHAINGY;45380;45;LOIRET;1
45068;;Châlette-sur-Loing;CHALETTE-SUR-LOING;45120;45;LOIRET;1
45069;;Chambon-la-Forêt;CHAMBON-LA-FORET;45340;45;LOIRET;1
45070;;Champoulet;CHAMPOULET;45420;45;LOIRET;1
45072;;Chanteau;CHANTEAU;45400;45;LOIRET;1
45073;;Chantecoq;CHANTECOQ;45320;45;LOIRET;1
45074;La;Chapelle-Onzerain;CHAPELLE-ONZERAIN;45310;45;LOIRET;1
45075;La;Chapelle-Saint-Mesmin;CHAPELLE-SAINT-MESMIN;45380;45;LOIRET;1
45076;La;Chapelle-Saint-Sépulcre;CHAPELLE-SAINT-SEPULCRE;45210;45;LOIRET;1
45077;La;Chapelle-sur-Aveyron;CHAPELLE-SUR-AVEYRON;45230;45;LOIRET;1
45078;;Chapelon;CHAPELON;45270;45;LOIRET;1
45079;Le;Charme;CHARME;45230;45;LOIRET;1
45080;;Charmont-en-Beauce;CHARMONT-EN-BEAUCE;45480;45;LOIRET;1
45081;;Charsonville;CHARSONVILLE;45130;45;LOIRET;1
45082;;Châteauneuf-sur-Loire;CHATEAUNEUF-SUR-LOIRE;45110;45;LOIRET;1
45083;;Château-Renard;CHATEAU-RENARD;45220;45;LOIRET;1
45084;;Châtenoy;CHATENOY;45260;45;LOIRET;1
45085;;Châtillon-Coligny;CHATILLON-COLIGNY;45230;45;LOIRET;1
45086;;Châtillon-le-Roi;CHATILLON-LE-ROI;45480;45;LOIRET;1
45087;;Châtillon-sur-Loire;CHATILLON-SUR-LOIRE;45360;45;LOIRET;1
45088;;Chaussy;CHAUSSY;45480;45;LOIRET;1
45089;;Chécy;CHECY;45430;45;LOIRET;1
45091;;Chevannes;CHEVANNES;45210;45;LOIRET;1
45092;;Chevillon-sur-Huillard;CHEVILLON-SUR-HUILLARD;45700;45;LOIRET;1
45093;;Chevilly;CHEVILLY;45520;45;LOIRET;1
45094;;Chevry-sous-le-Bignon;CHEVRY-SOUS-LE-BIGNON;45210;45;LOIRET;1
45095;;Chilleurs-aux-Bois;CHILLEURS-AUX-BOIS;45170;45;LOIRET;1
45096;Les;Choux;CHOUX;45290;45;LOIRET;1
45097;;Chuelles;CHUELLES;45220;45;LOIRET;1
45098;;Cléry-Saint-André;CLERY-SAINT-ANDRE;45370;45;LOIRET;1
45099;;Coinces;COINCES;45310;45;LOIRET;1
45100;;Combleux;COMBLEUX;45800;45;LOIRET;1
45101;;Combreux;COMBREUX;45530;45;LOIRET;1
45102;;Conflans-sur-Loing;CONFLANS-SUR-LOING;45700;45;LOIRET;1
45103;;Corbeilles;CORBEILLES;45490;45;LOIRET;1
45104;;Corquilleroy;CORQUILLEROY;45120;45;LOIRET;1
45105;;Cortrat;CORTRAT;45700;45;LOIRET;1
45106;;Coudray;COUDRAY;45330;45;LOIRET;1
45107;;Coudroy;COUDROY;45260;45;LOIRET;1
45108;;Coullons;COULLONS;45720;45;LOIRET;1
45109;;Coulmiers;COULMIERS;45130;45;LOIRET;1
45110;;Courcelles;COURCELLES;45300;45;LOIRET;1
45111;;Courcy-aux-Loges;COURCY-AUX-LOGES;45300;45;LOIRET;1
45112;La;Cour-Marigny;COUR-MARIGNY;45260;45;LOIRET;1
45113;;Courtemaux;COURTEMAUX;45320;45;LOIRET;1
45114;;Courtempierre;COURTEMPIERRE;45490;45;LOIRET;1
45115;;Courtenay;COURTENAY;45320;45;LOIRET;1
45116;;Cravant;CRAVANT;45190;45;LOIRET;1
45118;;Crottes-en-Pithiverais;CROTTES-EN-PITHIVERAIS;45170;45;LOIRET;1
45119;;Dadonville;DADONVILLE;45300;45;LOIRET;1
45120;;Dammarie-en-Puisaye;DAMMARIE-EN-PUISAYE;45420;45;LOIRET;1
45121;;Dammarie-sur-Loing;DAMMARIE-SUR-LOING;45230;45;LOIRET;1
45122;;Dampierre-en-Burly;DAMPIERRE-EN-BURLY;45570;45;LOIRET;1
45123;;Darvoy;DARVOY;45150;45;LOIRET;1
45124;;Desmonts;DESMONTS;45390;45;LOIRET;1
45125;;Dimancheville;DIMANCHEVILLE;45390;45;LOIRET;1
45126;;Donnery;DONNERY;45450;45;LOIRET;1
45127;;Dordives;DORDIVES;45680;45;LOIRET;1
45129;;Douchy;DOUCHY;45220;45;LOIRET;1
45130;;Dry;DRY;45370;45;LOIRET;1
45131;;Échilleuses;ECHILLEUSES;45390;45;LOIRET;1
45132;;Égry;EGRY;45340;45;LOIRET;1
45133;;Engenville;ENGENVILLE;45300;45;LOIRET;1
45134;;Épieds-en-Beauce;EPIEDS-EN-BEAUCE;45130;45;LOIRET;1
45135;;Erceville;ERCEVILLE;45480;45;LOIRET;1
45136;;Ervauville;ERVAUVILLE;45320;45;LOIRET;1
45137;;Escrennes;ESCRENNES;45300;45;LOIRET;1
45138;;Escrignelles;ESCRIGNELLES;45250;45;LOIRET;1
45139;;Estouy;ESTOUY;45300;45;LOIRET;1
45141;;Faverelles;FAVERELLES;45420;45;LOIRET;1
45142;;Fay-aux-Loges;FAY-AUX-LOGES;45450;45;LOIRET;1
45143;;Feins-en-Gâtinais;FEINS-EN-GATINAIS;45230;45;LOIRET;1
45144;;Férolles;FEROLLES;45150;45;LOIRET;1
45145;;Ferrières-en-Gâtinais;FERRIERES-EN-GATINAIS;45210;45;LOIRET;1
45146;La;Ferté-Saint-Aubin;FERTE-SAINT-AUBIN;45240;45;LOIRET;1
45147;;Fleury-les-Aubrais;FLEURY-LES-AUBRAIS;45400;45;LOIRET;1
45148;;Fontenay-sur-Loing;FONTENAY-SUR-LOING;45210;45;LOIRET;1
45149;;Foucherolles;FOUCHEROLLES;45320;45;LOIRET;1
45150;;Fréville-du-Gâtinais;FREVILLE-DU-GATINAIS;45270;45;LOIRET;1
45151;;Gaubertin;GAUBERTIN;45340;45;LOIRET;1
45152;;Gémigny;GEMIGNY;45310;45;LOIRET;1
45153;;Germigny-des-Prés;GERMIGNY-DES-PRES;45110;45;LOIRET;1
45154;;Gidy;GIDY;45520;45;LOIRET;1
45155;;Gien;GIEN;45500;45;LOIRET;1
45156;;Girolles;GIROLLES;45120;45;LOIRET;1
45157;;Givraines;GIVRAINES;45300;45;LOIRET;1
45158;;Gondreville;GONDREVILLE;45490;45;LOIRET;1
45159;;Grangermont;GRANGERMONT;45390;45;LOIRET;1
45160;;Greneville-en-Beauce;GRENEVILLE-EN-BEAUCE;45480;45;LOIRET;1
45161;;Griselles;GRISELLES;45210;45;LOIRET;1
45162;;Guigneville;GUIGNEVILLE;45300;45;LOIRET;1
45164;;Guilly;GUILLY;45600;45;LOIRET;1
45165;;Gy-les-Nonains;GY-LES-NONAINS;45220;45;LOIRET;1
45166;;Huêtre;HUETRE;45520;45;LOIRET;1
45167;;Huisseau-sur-Mauves;HUISSEAU-SUR-MAUVES;45130;45;LOIRET;1
45168;;Ingrannes;INGRANNES;45450;45;LOIRET;1
45169;;Ingré;INGRE;45140;45;LOIRET;1
45170;;Intville-la-Guétard;INTVILLE-LA-GUETARD;45300;45;LOIRET;1
45171;;Isdes;ISDES;45620;45;LOIRET;1
45173;;Jargeau;JARGEAU;45150;45;LOIRET;1
45174;;Jouy-en-Pithiverais;JOUY-EN-PITHIVERAIS;45480;45;LOIRET;1
45175;;Jouy-le-Potier;JOUY-LE-POTIER;45370;45;LOIRET;1
45176;;Juranville;JURANVILLE;45340;45;LOIRET;1
45177;;Laas;LAAS;45300;45;LOIRET;1
45178;;Ladon;LADON;45270;45;LOIRET;1
45179;;Lailly-en-Val;LAILLY-EN-VAL;45740;45;LOIRET;1
45180;;Langesse;LANGESSE;45290;45;LOIRET;1
45181;;Léouville;LEOUVILLE;45480;45;LOIRET;1
45182;;Ligny-le-Ribault;LIGNY-LE-RIBAULT;45240;45;LOIRET;1
45183;;Lion-en-Beauce;LION-EN-BEAUCE;45410;45;LOIRET;1
45184;;Lion-en-Sullias;LION-EN-SULLIAS;45600;45;LOIRET;1
45185;;Lombreuil;LOMBREUIL;45700;45;LOIRET;1
45186;;Lorcy;LORCY;45490;45;LOIRET;1
45187;;Lorris;LORRIS;45260;45;LOIRET;1
45188;;Loury;LOURY;45470;45;LOIRET;1
45189;;Louzouer;LOUZOUER;45210;45;LOIRET;1
45190;;Mainvilliers;MAINVILLIERS;45330;45;LOIRET;1
45191;;Malesherbes;MALESHERBES;45330;45;LOIRET;1
45192;;Manchecourt;MANCHECOURT;45300;45;LOIRET;1
45193;;Marcilly-en-Villette;MARCILLY-EN-VILLETTE;45240;45;LOIRET;1
45194;;Mardié;MARDIE;45430;45;LOIRET;1
45195;;Mareau-aux-Bois;MAREAU-AUX-BOIS;45300;45;LOIRET;1
45196;;Mareau-aux-Prés;MAREAU-AUX-PRES;45370;45;LOIRET;1
45197;;Marigny-les-Usages;MARIGNY-LES-USAGES;45760;45;LOIRET;1
45198;;Marsainvilliers;MARSAINVILLIERS;45300;45;LOIRET;1
45199;;Melleroy;MELLEROY;45220;45;LOIRET;1
45200;;Ménestreau-en-Villette;MENESTREAU-EN-VILLETTE;45240;45;LOIRET;1
45201;;Mérinville;MERINVILLE;45210;45;LOIRET;1
45202;;Messas;MESSAS;45190;45;LOIRET;1
45203;;Meung-sur-Loire;MEUNG-SUR-LOIRE;45130;45;LOIRET;1
45204;;Mézières-lez-Cléry;MEZIERES-LEZ-CLERY;45370;45;LOIRET;1
45205;;Mézières-en-Gâtinais;MEZIERES-EN-GATINAIS;45270;45;LOIRET;1
45206;;Mignères;MIGNERES;45490;45;LOIRET;1
45207;;Mignerette;MIGNERETTE;45490;45;LOIRET;1
45208;;Montargis;MONTARGIS;45200;45;LOIRET;1
45209;;Montbarrois;MONTBARROIS;45340;45;LOIRET;1
45210;;Montbouy;MONTBOUY;45230;45;LOIRET;1
45211;;Montcorbon;MONTCORBON;45220;45;LOIRET;1
45212;;Montcresson;MONTCRESSON;45700;45;LOIRET;1
45213;;Montereau;MONTEREAU;45260;45;LOIRET;1
45214;;Montigny;MONTIGNY;45170;45;LOIRET;1
45215;;Montliard;MONTLIARD;45340;45;LOIRET;1
45216;;Mormant-sur-Vernisson;MORMANT-SUR-VERNISSON;45700;45;LOIRET;1
45217;;Morville-en-Beauce;MORVILLE-EN-BEAUCE;45300;45;LOIRET;1
45218;Le;Moulinet-sur-Solin;MOULINET-SUR-SOLIN;45290;45;LOIRET;1
45219;;Moulon;MOULON;45270;45;LOIRET;1
45220;;Nancray-sur-Rimarde;NANCRAY-SUR-RIMARDE;45340;45;LOIRET;1
45221;;Nangeville;NANGEVILLE;45330;45;LOIRET;1
45222;;Nargis;NARGIS;45210;45;LOIRET;1
45223;;Nesploy;NESPLOY;45270;45;LOIRET;1
45224;;Neuville-aux-Bois;NEUVILLE-AUX-BOIS;45170;45;LOIRET;1
45225;La;Neuville-sur-Essonne;NEUVILLE-SUR-ESSONNE;45390;45;LOIRET;1
45226;;Neuvy-en-Sullias;NEUVY-EN-SULLIAS;45510;45;LOIRET;1
45227;;Nevoy;NEVOY;45500;45;LOIRET;1
45228;;Nibelle;NIBELLE;45340;45;LOIRET;1
45229;;Nogent-sur-Vernisson;NOGENT-SUR-VERNISSON;45290;45;LOIRET;1
45230;;Noyers;NOYERS;45260;45;LOIRET;1
45231;;Oison;OISON;45170;45;LOIRET;1
45232;;Olivet;OLIVET;45160;45;LOIRET;1
45233;;Ondreville-sur-Essonne;ONDREVILLE-SUR-ESSONNE;45390;45;LOIRET;1
45234;;Orléans;ORLEANS;45000;45;LOIRET;1
45235;;Ormes;ORMES;45140;45;LOIRET;1
45236;;Orveau-Bellesauve;ORVEAU-BELLESAUVE;45330;45;LOIRET;1
45237;;Orville;ORVILLE;45390;45;LOIRET;1
45238;;Ousson-sur-Loire;OUSSON-SUR-LOIRE;45250;45;LOIRET;1
45239;;Oussoy-en-Gâtinais;OUSSOY-EN-GATINAIS;45290;45;LOIRET;1
45240;;Outarville;OUTARVILLE;45480;45;LOIRET;1
45241;;Ouvrouer-les-Champs;OUVROUER-LES-CHAMPS;45150;45;LOIRET;1
45242;;Ouzouer-des-Champs;OUZOUER-DES-CHAMPS;45290;45;LOIRET;1
45243;;Ouzouer-sous-Bellegarde;OUZOUER-SOUS-BELLEGARDE;45270;45;LOIRET;1
45244;;Ouzouer-sur-Loire;OUZOUER-SUR-LOIRE;45570;45;LOIRET;1
45245;;Ouzouer-sur-Trézée;OUZOUER-SUR-TREZEE;45250;45;LOIRET;1
45246;;Pannecières;PANNECIERES;45300;45;LOIRET;1
45247;;Pannes;PANNES;45700;45;LOIRET;1
45248;;Patay;PATAY;45310;45;LOIRET;1
45249;;Paucourt;PAUCOURT;45200;45;LOIRET;1
45250;;Pers-en-Gâtinais;PERS-EN-GATINAIS;45210;45;LOIRET;1
45251;;Pierrefitte-ès-Bois;PIERREFITTE-ES-BOIS;45360;45;LOIRET;1
45252;;Pithiviers;PITHIVIERS;45300;45;LOIRET;1
45253;;Pithiviers-le-Vieil;PITHIVIERS-LE-VIEIL;45300;45;LOIRET;1
45254;;Poilly-lez-Gien;POILLY-LEZ-GIEN;45500;45;LOIRET;1
45255;;Préfontaines;PREFONTAINES;45490;45;LOIRET;1
45256;;Presnoy;PRESNOY;45260;45;LOIRET;1
45257;;Pressigny-les-Pins;PRESSIGNY-LES-PINS;45290;45;LOIRET;1
45258;;Puiseaux;PUISEAUX;45390;45;LOIRET;1
45259;;Quiers-sur-Bézonde;QUIERS-SUR-BEZONDE;45270;45;LOIRET;1
45260;;Ramoulu;RAMOULU;45300;45;LOIRET;1
45261;;Rebréchien;REBRECHIEN;45470;45;LOIRET;1
45262;;Rouvray-Sainte-Croix;ROUVRAY-SAINTE-CROIX;45310;45;LOIRET;1
45263;;Rouvres-Saint-Jean;ROUVRES-SAINT-JEAN;45300;45;LOIRET;1
45264;;Rozières-en-Beauce;ROZIERES-EN-BEAUCE;45130;45;LOIRET;1
45265;;Rozoy-le-Vieil;ROZOY-LE-VIEIL;45210;45;LOIRET;1
45266;;Ruan;RUAN;45410;45;LOIRET;1
45267;;Saint-Aignan-des-Gués;SAINT-AIGNAN-DES-GUES;45460;45;LOIRET;1
45268;;Saint-Aignan-le-Jaillard;SAINT-AIGNAN-LE-JAILLARD;45600;45;LOIRET;1
45269;;Saint-Ay;SAINT-AY;45130;45;LOIRET;1
45270;;Saint-Benoît-sur-Loire;SAINT-BENOIT-SUR-LOIRE;45730;45;LOIRET;1
45271;;Saint-Brisson-sur-Loire;SAINT-BRISSON-SUR-LOIRE;45500;45;LOIRET;1
45272;;Saint-Cyr-en-Val;SAINT-CYR-EN-VAL;45590;45;LOIRET;1
45273;;Saint-Denis-de-l'Hôtel;SAINT-DENIS-DE-L'HOTEL;45550;45;LOIRET;1
45274;;Saint-Denis-en-Val;SAINT-DENIS-EN-VAL;45560;45;LOIRET;1
45275;;Saint-Firmin-des-Bois;SAINT-FIRMIN-DES-BOIS;45220;45;LOIRET;1
45276;;Saint-Firmin-sur-Loire;SAINT-FIRMIN-SUR-LOIRE;45360;45;LOIRET;1
45277;;Saint-Florent;SAINT-FLORENT;45600;45;LOIRET;1
45278;;Sainte-Geneviève-des-Bois;SAINTE-GENEVIEVE-DES-BOIS;45230;45;LOIRET;1
45279;;Saint-Germain-des-Prés;SAINT-GERMAIN-DES-PRES;45220;45;LOIRET;1
45280;;Saint-Gondon;SAINT-GONDON;45500;45;LOIRET;1
45281;;Saint-Hilaire-les-Andrésis;SAINT-HILAIRE-LES-ANDRESIS;45320;45;LOIRET;1
45282;;Saint-Hilaire-Saint-Mesmin;SAINT-HILAIRE-SAINT-MESMIN;45160;45;LOIRET;1
45283;;Saint-Hilaire-sur-Puiseaux;SAINT-HILAIRE-SUR-PUISEAUX;45700;45;LOIRET;1
45284;;Saint-Jean-de-Braye;SAINT-JEAN-DE-BRAYE;45800;45;LOIRET;1
45285;;Saint-Jean-de-la-Ruelle;SAINT-JEAN-DE-LA-RUELLE;45140;45;LOIRET;1
45286;;Saint-Jean-le-Blanc;SAINT-JEAN-LE-BLANC;45650;45;LOIRET;1
45287;;Saint-Loup-de-Gonois;SAINT-LOUP-DE-GONOIS;45210;45;LOIRET;1
45288;;Saint-Loup-des-Vignes;SAINT-LOUP-DES-VIGNES;45340;45;LOIRET;1
45289;;Saint-Lyé-la-Forêt;SAINT-LYE-LA-FORET;45170;45;LOIRET;1
45290;;Saint-Martin-d'Abbat;SAINT-MARTIN-D'ABBAT;45110;45;LOIRET;1
45291;;Saint-Martin-sur-Ocre;SAINT-MARTIN-SUR-OCRE;45500;45;LOIRET;1
45292;;Saint-Maurice-sur-Aveyron;SAINT-MAURICE-SUR-AVEYRON;45230;45;LOIRET;1
45293;;Saint-Maurice-sur-Fessard;SAINT-MAURICE-SUR-FESSARD;45700;45;LOIRET;1
45294;;Saint-Michel;SAINT-MICHEL;45340;45;LOIRET;1
45296;;Saint-Péravy-la-Colombe;SAINT-PERAVY-LA-COLOMBE;45310;45;LOIRET;1
45297;;Saint-Père-sur-Loire;SAINT-PERE-SUR-LOIRE;45600;45;LOIRET;1
45298;;Saint-Pryvé-Saint-Mesmin;SAINT-PRYVE-SAINT-MESMIN;45750;45;LOIRET;1
45299;;Saint-Sigismond;SAINT-SIGISMOND;45310;45;LOIRET;1
45300;;Sandillon;SANDILLON;45640;45;LOIRET;1
45301;;Santeau;SANTEAU;45170;45;LOIRET;1
45302;;Saran;SARAN;45770;45;LOIRET;1
45303;;Sceaux-du-Gâtinais;SCEAUX-DU-GATINAIS;45490;45;LOIRET;1
45305;;Seichebrières;SEICHEBRIERES;45530;45;LOIRET;1
45306;La;Selle-en-Hermoy;SELLE-EN-HERMOY;45210;45;LOIRET;1
45307;La;Selle-sur-le-Bied;SELLE-SUR-LE-BIED;45210;45;LOIRET;1
45308;;Semoy;SEMOY;45400;45;LOIRET;1
45309;;Sennely;SENNELY;45240;45;LOIRET;1
45310;;Sermaises;SERMAISES;45300;45;LOIRET;1
45311;;Sigloy;SIGLOY;45110;45;LOIRET;1
45312;;Solterre;SOLTERRE;45700;45;LOIRET;1
45313;;Sougy;SOUGY;45410;45;LOIRET;1
45314;;Sully-la-Chapelle;SULLY-LA-CHAPELLE;45450;45;LOIRET;1
45315;;Sully-sur-Loire;SULLY-SUR-LOIRE;45600;45;LOIRET;1
45316;;Sury-aux-Bois;SURY-AUX-BOIS;45530;45;LOIRET;1
45317;;Tavers;TAVERS;45190;45;LOIRET;1
45320;;Thignonville;THIGNONVILLE;45300;45;LOIRET;1
45321;;Thimory;THIMORY;45260;45;LOIRET;1
45322;;Thorailles;THORAILLES;45210;45;LOIRET;1
45323;;Thou;THOU;45420;45;LOIRET;1
45324;;Tigy;TIGY;45510;45;LOIRET;1
45325;;Tivernon;TIVERNON;45170;45;LOIRET;1
45326;;Tournoisis;TOURNOISIS;45310;45;LOIRET;1
45327;;Traînou;TRAINOU;45470;45;LOIRET;1
45328;;Treilles-en-Gâtinais;TREILLES-EN-GATINAIS;45490;45;LOIRET;1
45329;;Triguères;TRIGUERES;45220;45;LOIRET;1
45330;;Trinay;TRINAY;45410;45;LOIRET;1
45331;;Vannes-sur-Cosson;VANNES-SUR-COSSON;45510;45;LOIRET;1
45332;;Varennes-Changy;VARENNES-CHANGY;45290;45;LOIRET;1
45333;;Vennecy;VENNECY;45760;45;LOIRET;1
45334;;Vieilles-Maisons-sur-Joudry;VIEILLES-MAISONS-SUR-JOUDRY;45260;45;LOIRET;1
45335;;Vienne-en-Val;VIENNE-EN-VAL;45510;45;LOIRET;1
45336;;Viglain;VIGLAIN;45600;45;LOIRET;1
45337;;Villamblain;VILLAMBLAIN;45310;45;LOIRET;1
45338;;Villemandeur;VILLEMANDEUR;45700;45;LOIRET;1
45339;;Villemoutiers;VILLEMOUTIERS;45270;45;LOIRET;1
45340;;Villemurlin;VILLEMURLIN;45600;45;LOIRET;1
45341;;Villeneuve-sur-Conie;VILLENEUVE-SUR-CONIE;45310;45;LOIRET;1
45342;;Villereau;VILLEREAU;45170;45;LOIRET;1
45343;;Villevoques;VILLEVOQUES;45700;45;LOIRET;1
45344;;Villorceau;VILLORCEAU;45190;45;LOIRET;1
45345;;Vimory;VIMORY;45700;45;LOIRET;1
45346;;Vitry-aux-Loges;VITRY-AUX-LOGES;45530;45;LOIRET;1
45347;;Vrigny;VRIGNY;45300;45;LOIRET;1
45348;;Yèvre-la-Ville;YEVRE-LA-VILLE;45300;45;LOIRET;1
46001;;Albas;ALBAS;46140;46;LOT;1
46002;;Albiac;ALBIAC;46500;46;LOT;1
46003;;Alvignac;ALVIGNAC;46500;46;LOT;1
46004;;Anglars;ANGLARS;46120;46;LOT;1
46005;;Anglars-Juillac;ANGLARS-JUILLAC;46140;46;LOT;1
46006;;Anglars-Nozac;ANGLARS-NOZAC;46300;46;LOT;1
46007;;Arcambal;ARCAMBAL;46090;46;LOT;1
46008;Les;Arques;ARQUES;46250;46;LOT;1
46009;;Assier;ASSIER;46320;46;LOT;1
46010;;Aujols;AUJOLS;46090;46;LOT;1
46011;;Autoire;AUTOIRE;46400;46;LOT;1
46012;;Aynac;AYNAC;46120;46;LOT;1
46013;;Bach;BACH;46230;46;LOT;1
46014;;Bagat-en-Quercy;BAGAT-EN-QUERCY;46800;46;LOT;1
46015;;Bagnac-sur-Célé;BAGNAC-SUR-CELE;46270;46;LOT;1
46016;;Baladou;BALADOU;46600;46;LOT;1
46017;;Bannes;BANNES;46400;46;LOT;1
46018;Le;Bastit;BASTIT;46500;46;LOT;1
46019;;Beaumat;BEAUMAT;46240;46;LOT;1
46020;;Beauregard;BEAUREGARD;46260;46;LOT;1
46021;;Béduer;BEDUER;46100;46;LOT;1
46022;;Bélaye;BELAYE;46140;46;LOT;1
46023;;Belfort-du-Quercy;BELFORT-DU-QUERCY;46230;46;LOT;1
46024;;Belmont-Bretenoux;BELMONT-BRETENOUX;46130;46;LOT;1
46025;;Belmontet;BELMONTET;46800;46;LOT;1
46026;;Belmont-Sainte-Foi;BELMONT-SAINTE-FOI;46230;46;LOT;1
46027;;Berganty;BERGANTY;46090;46;LOT;1
46028;;Bétaille;BETAILLE;46110;46;LOT;1
46029;;Biars-sur-Cère;BIARS-SUR-CERE;46130;46;LOT;1
46030;;Bio;BIO;46500;46;LOT;1
46031;;Blars;BLARS;46330;46;LOT;1
46032;;Boissières;BOISSIERES;46150;46;LOT;1
46033;Le;Boulvé;BOULVE;46800;46;LOT;1
46034;Le;Bourg;BOURG;46120;46;LOT;1
46035;;Boussac;BOUSSAC;46100;46;LOT;1
46036;Le;Bouyssou;BOUYSSOU;46120;46;LOT;1
46037;;Bouziès;BOUZIES;46330;46;LOT;1
46038;;Bretenoux;BRETENOUX;46130;46;LOT;1
46039;;Brengues;BRENGUES;46320;46;LOT;1
46040;;Cabrerets;CABRERETS;46330;46;LOT;1
46041;;Cadrieu;CADRIEU;46160;46;LOT;1
46042;;Cahors;CAHORS;46000;46;LOT;1
46043;;Cahus;CAHUS;46130;46;LOT;1
46044;;Caillac;CAILLAC;46140;46;LOT;1
46045;;Cajarc;CAJARC;46160;46;LOT;1
46046;;Calamane;CALAMANE;46150;46;LOT;1
46047;;Calès;CALES;46350;46;LOT;1
46048;;Calviac;CALVIAC;46190;46;LOT;1
46049;;Calvignac;CALVIGNAC;46160;46;LOT;1
46050;;Cambayrac;CAMBAYRAC;46140;46;LOT;1
46051;;Cambes;CAMBES;46100;46;LOT;1
46052;;Camboulit;CAMBOULIT;46100;46;LOT;1
46053;;Camburat;CAMBURAT;46100;46;LOT;1
46054;;Caniac-du-Causse;CANIAC-DU-CAUSSE;46240;46;LOT;1
46055;;Capdenac;CAPDENAC;46100;46;LOT;1
46056;;Carayac;CARAYAC;46160;46;LOT;1
46057;;Cardaillac;CARDAILLAC;46100;46;LOT;1
46058;;Carennac;CARENNAC;46110;46;LOT;1
46059;;Carlucet;CARLUCET;46500;46;LOT;1
46060;;Carnac-Rouffiac;CARNAC-ROUFFIAC;46140;46;LOT;1
46061;;Cassagnes;CASSAGNES;46700;46;LOT;1
46062;;Castelfranc;CASTELFRANC;46140;46;LOT;1
46063;;Castelnau-Montratier;CASTELNAU-MONTRATIER;46170;46;LOT;1
46064;;Catus;CATUS;46150;46;LOT;1
46065;;Cavagnac;CAVAGNAC;46110;46;LOT;1
46066;;Cazals;CAZALS;46250;46;LOT;1
46067;;Cazillac;CAZILLAC;46600;46;LOT;1
46068;;Cénevières;CENEVIERES;46330;46;LOT;1
46069;;Cézac;CEZAC;46170;46;LOT;1
46070;;Cieurac;CIEURAC;46230;46;LOT;1
46071;;Comiac;COMIAC;46190;46;LOT;1
46072;;Concorès;CONCORES;46310;46;LOT;1
46073;;Concots;CONCOTS;46260;46;LOT;1
46074;;Condat;CONDAT;46110;46;LOT;1
46075;;Corn;CORN;46100;46;LOT;1
46076;;Cornac;CORNAC;46130;46;LOT;1
46077;;Cours;COURS;46090;46;LOT;1
46078;;Couzou;COUZOU;46500;46;LOT;1
46079;;Cras;CRAS;46360;46;LOT;1
46080;;Crayssac;CRAYSSAC;46150;46;LOT;1
46081;;Crégols;CREGOLS;46330;46;LOT;1
46082;;Cremps;CREMPS;46230;46;LOT;1
46083;;Cressensac;CRESSENSAC;46600;46;LOT;1
46084;;Creysse;CREYSSE;46600;46;LOT;1
46085;;Cuzac;CUZAC;46270;46;LOT;1
46086;;Cuzance;CUZANCE;46600;46;LOT;1
46087;;Dégagnac;DEGAGNAC;46340;46;LOT;1
46088;;Douelle;DOUELLE;46140;46;LOT;1
46089;;Duravel;DURAVEL;46700;46;LOT;1
46090;;Durbans;DURBANS;46320;46;LOT;1
46091;;Escamps;ESCAMPS;46230;46;LOT;1
46092;;Esclauzels;ESCLAUZELS;46090;46;LOT;1
46093;;Espagnac-Sainte-Eulalie;ESPAGNAC-SAINTE-EULALIE;46320;46;LOT;1
46094;;Espédaillac;ESPEDAILLAC;46320;46;LOT;1
46095;;Espère;ESPERE;46090;46;LOT;1
46096;;Espeyroux;ESPEYROUX;46120;46;LOT;1
46097;;Estal;ESTAL;46130;46;LOT;1
46098;;Fajoles;FAJOLES;46300;46;LOT;1
46099;;Fargues;FARGUES;46800;46;LOT;1
46100;;Faycelles;FAYCELLES;46100;46;LOT;1
46101;;Felzins;FELZINS;46270;46;LOT;1
46102;;Figeac;FIGEAC;46100;46;LOT;1
46103;;Flaugnac;FLAUGNAC;46170;46;LOT;1
46104;;Flaujac-Gare;FLAUJAC-GARE;46320;46;LOT;1
46105;;Flaujac-Poujols;FLAUJAC-POUJOLS;46090;46;LOT;1
46106;;Floirac;FLOIRAC;46600;46;LOT;1
46107;;Floressas;FLORESSAS;46700;46;LOT;1
46108;;Fons;FONS;46100;46;LOT;1
46109;;Fontanes;FONTANES;46230;46;LOT;1
46110;;Fontanes-du-Causse;FONTANES-DU-CAUSSE;46240;46;LOT;1
46111;;Fourmagnac;FOURMAGNAC;46100;46;LOT;1
46112;;Francoulès;FRANCOULES;46090;46;LOT;1
46113;;Frayssinet;FRAYSSINET;46310;46;LOT;1
46114;;Frayssinet-le-Gélat;FRAYSSINET-LE-GELAT;46250;46;LOT;1
46115;;Frayssinhes;FRAYSSINHES;46400;46;LOT;1
46116;;Frontenac;FRONTENAC;46160;46;LOT;1
46117;;Gagnac-sur-Cère;GAGNAC-SUR-CERE;46130;46;LOT;1
46118;;Gignac;GIGNAC;46600;46;LOT;1
46119;;Gigouzac;GIGOUZAC;46150;46;LOT;1
46120;;Gindou;GINDOU;46250;46;LOT;1
46121;;Ginouillac;GINOUILLAC;46300;46;LOT;1
46122;;Gintrac;GINTRAC;46130;46;LOT;1
46123;;Girac;GIRAC;46130;46;LOT;1
46124;;Glanes;GLANES;46130;46;LOT;1
46125;;Gorses;GORSES;46210;46;LOT;1
46126;;Goujounac;GOUJOUNAC;46250;46;LOT;1
46127;;Gourdon;GOURDON;46300;46;LOT;1
46128;;Gramat;GRAMAT;46500;46;LOT;1
46129;;Gréalou;GREALOU;46160;46;LOT;1
46130;;Grézels;GREZELS;46700;46;LOT;1
46131;;Grèzes;GREZES;46320;46;LOT;1
46132;;Issendolus;ISSENDOLUS;46500;46;LOT;1
46133;;Issepts;ISSEPTS;46320;46;LOT;1
46134;Les;Junies;JUNIES;46150;46;LOT;1
46135;;Labastide-du-Haut-Mont;LABASTIDE-DU-HAUT-MONT;46210;46;LOT;1
46136;;Labastide-du-Vert;LABASTIDE-DU-VERT;46150;46;LOT;1
46137;;Labastide-Marnhac;LABASTIDE-MARNHAC;46090;46;LOT;1
46138;;Labastide-Murat;LABASTIDE-MURAT;46240;46;LOT;1
46139;;Labathude;LABATHUDE;46120;46;LOT;1
46140;;Laburgade;LABURGADE;46230;46;LOT;1
46141;;Lacam-d'Ourcet;LACAM-D'OURCET;46190;46;LOT;1
46142;;Lacapelle-Cabanac;LACAPELLE-CABANAC;46700;46;LOT;1
46143;;Lacapelle-Marival;LACAPELLE-MARIVAL;46120;46;LOT;1
46144;;Lacave;LACAVE;46200;46;LOT;1
46145;;Lachapelle-Auzac;LACHAPELLE-AUZAC;46200;46;LOT;1
46146;;Ladirat;LADIRAT;46400;46;LOT;1
46147;;Lagardelle;LAGARDELLE;46220;46;LOT;1
46148;;Lalbenque;LALBENQUE;46230;46;LOT;1
46149;;Lamagdelaine;LAMAGDELAINE;46090;46;LOT;1
46150;;Lamativie;LAMATIVIE;46190;46;LOT;1
46151;;Lamothe-Cassel;LAMOTHE-CASSEL;46240;46;LOT;1
46152;;Lamothe-Fénelon;LAMOTHE-FENELON;46350;46;LOT;1
46153;;Lanzac;LANZAC;46200;46;LOT;1
46154;;Laramière;LARAMIERE;46260;46;LOT;1
46155;;Larnagol;LARNAGOL;46160;46;LOT;1
46156;;Laroque-des-Arcs;LAROQUE-DES-ARCS;46090;46;LOT;1
46157;;Larroque-Toirac;LARROQUE-TOIRAC;46160;46;LOT;1
46158;;Lascabanes;LASCABANES;46800;46;LOT;1
46159;;Latouille-Lentillac;LATOUILLE-LENTILLAC;46400;46;LOT;1
46160;;Latronquière;LATRONQUIERE;46210;46;LOT;1
46161;;Lauresses;LAURESSES;46210;46;LOT;1
46162;;Lauzès;LAUZES;46360;46;LOT;1
46163;;Laval-de-Cère;LAVAL-DE-CERE;46130;46;LOT;1
46164;;Lavercantière;LAVERCANTIERE;46340;46;LOT;1
46165;;Lavergne;LAVERGNE;46500;46;LOT;1
46166;;Lebreil;LEBREIL;46800;46;LOT;1
46167;;Lentillac-du-Causse;LENTILLAC-DU-CAUSSE;46330;46;LOT;1
46168;;Lentillac-Saint-Blaise;LENTILLAC-SAINT-BLAISE;46100;46;LOT;1
46169;;Léobard;LEOBARD;46300;46;LOT;1
46170;;Leyme;LEYME;46120;46;LOT;1
46171;;Lherm;LHERM;46150;46;LOT;1
46172;;Lhospitalet;LHOSPITALET;46170;46;LOT;1
46173;;Limogne-en-Quercy;LIMOGNE-EN-QUERCY;46260;46;LOT;1
46174;;Linac;LINAC;46270;46;LOT;1
46175;;Lissac-et-Mouret;LISSAC-ET-MOURET;46100;46;LOT;1
46176;;Livernon;LIVERNON;46320;46;LOT;1
46177;;Loubressac;LOUBRESSAC;46130;46;LOT;1
46178;;Loupiac;LOUPIAC;46350;46;LOT;1
46179;;Lugagnac;LUGAGNAC;46260;46;LOT;1
46180;;Lunan;LUNAN;46100;46;LOT;1
46181;;Lunegarde;LUNEGARDE;46240;46;LOT;1
46182;;Luzech;LUZECH;46140;46;LOT;1
46183;;Marcilhac-sur-Célé;MARCILHAC-SUR-CELE;46160;46;LOT;1
46184;;Marminiac;MARMINIAC;46250;46;LOT;1
46185;;Martel;MARTEL;46600;46;LOT;1
46186;;Masclat;MASCLAT;46350;46;LOT;1
46187;;Mauroux;MAUROUX;46700;46;LOT;1
46188;;Maxou;MAXOU;46090;46;LOT;1
46189;;Mayrinhac-Lentour;MAYRINHAC-LENTOUR;46500;46;LOT;1
46190;;Mechmont;MECHMONT;46150;46;LOT;1
46191;;Mercuès;MERCUES;46090;46;LOT;1
46192;;Meyronne;MEYRONNE;46200;46;LOT;1
46193;;Miers;MIERS;46500;46;LOT;1
46194;;Milhac;MILHAC;46300;46;LOT;1
46195;;Molières;MOLIERES;46120;46;LOT;1
46196;;Montamel;MONTAMEL;46310;46;LOT;1
46197;Le;Montat;MONTAT;46090;46;LOT;1
46198;;Montbrun;MONTBRUN;46160;46;LOT;1
46199;;Montcabrier;MONTCABRIER;46700;46;LOT;1
46200;;Montcléra;MONTCLERA;46250;46;LOT;1
46201;;Montcuq;MONTCUQ;46800;46;LOT;1
46202;;Montdoumerc;MONTDOUMERC;46230;46;LOT;1
46203;;Montet-et-Bouxal;MONTET-ET-BOUXAL;46210;46;LOT;1
46204;;Montfaucon;MONTFAUCON;46240;46;LOT;1
46205;;Montgesty;MONTGESTY;46150;46;LOT;1
46206;;Montlauzun;MONTLAUZUN;46800;46;LOT;1
46207;;Montredon;MONTREDON;46270;46;LOT;1
46208;;Montvalent;MONTVALENT;46600;46;LOT;1
46209;;Nadaillac-de-Rouge;NADAILLAC-DE-ROUGE;46350;46;LOT;1
46210;;Nadillac;NADILLAC;46360;46;LOT;1
46211;;Nuzéjouls;NUZEJOULS;46150;46;LOT;1
46212;;Orniac;ORNIAC;46330;46;LOT;1
46213;;Padirac;PADIRAC;46500;46;LOT;1
46214;;Parnac;PARNAC;46140;46;LOT;1
46215;;Payrac;PAYRAC;46350;46;LOT;1
46216;;Payrignac;PAYRIGNAC;46300;46;LOT;1
46217;;Pern;PERN;46170;46;LOT;1
46218;;Pescadoires;PESCADOIRES;46220;46;LOT;1
46219;;Peyrilles;PEYRILLES;46310;46;LOT;1
46220;;Pinsac;PINSAC;46200;46;LOT;1
46221;;Planioles;PLANIOLES;46100;46;LOT;1
46222;;Pomarède;POMAREDE;46250;46;LOT;1
46223;;Pontcirq;PONTCIRQ;46150;46;LOT;1
46224;;Pradines;PRADINES;46090;46;LOT;1
46225;;Prayssac;PRAYSSAC;46220;46;LOT;1
46226;;Prendeignes;PRENDEIGNES;46270;46;LOT;1
46227;;Promilhanes;PROMILHANES;46260;46;LOT;1
46228;;Prudhomat;PRUDHOMAT;46130;46;LOT;1
46229;;Puybrun;PUYBRUN;46130;46;LOT;1
46230;;Puyjourdes;PUYJOURDES;46260;46;LOT;1
46231;;Puy-l'Évêque;PUY-L'EVEQUE;46700;46;LOT;1
46232;Les;Quatre-Routes-du-Lot;QUATRE-ROUTES-DU-LOT;46110;46;LOT;1
46233;;Quissac;QUISSAC;46320;46;LOT;1
46234;;Rampoux;RAMPOUX;46340;46;LOT;1
46235;;Reilhac;REILHAC;46500;46;LOT;1
46236;;Reilhaguet;REILHAGUET;46350;46;LOT;1
46237;;Reyrevignes;REYREVIGNES;46320;46;LOT;1
46238;;Rignac;RIGNAC;46500;46;LOT;1
46239;Le;Roc;ROC;46200;46;LOT;1
46240;;Rocamadour;ROCAMADOUR;46500;46;LOT;1
46241;;Rouffilhac;ROUFFILHAC;46300;46;LOT;1
46242;;Rudelle;RUDELLE;46120;46;LOT;1
46243;;Rueyres;RUEYRES;46120;46;LOT;1
46244;;Sabadel-Latronquière;SABADEL-LATRONQUIERE;46210;46;LOT;1
46245;;Sabadel-Lauzès;SABADEL-LAUZES;46360;46;LOT;1
46246;;Saignes;SAIGNES;46500;46;LOT;1
46247;;Saillac;SAILLAC;46260;46;LOT;1
46248;;Sainte-Alauzie;SAINTE-ALAUZIE;46170;46;LOT;1
46249;;Saint-Bressou;SAINT-BRESSOU;46120;46;LOT;1
46250;;Saint-Caprais;SAINT-CAPRAIS;46250;46;LOT;1
46251;;Saint-Céré;SAINT-CERE;46400;46;LOT;1
46252;;Saint-Cernin;SAINT-CERNIN;46360;46;LOT;1
46253;;Saint-Chamarand;SAINT-CHAMARAND;46310;46;LOT;1
46254;;Saint-Chels;SAINT-CHELS;46160;46;LOT;1
46255;;Saint-Cirgues;SAINT-CIRGUES;46210;46;LOT;1
46256;;Saint-Cirq-Lapopie;SAINT-CIRQ-LAPOPIE;46330;46;LOT;1
46257;;Saint-Cirq-Madelon;SAINT-CIRQ-MADELON;46300;46;LOT;1
46258;;Saint-Cirq-Souillaguet;SAINT-CIRQ-SOUILLAGUET;46300;46;LOT;1
46259;;Saint-Clair;SAINT-CLAIR;46300;46;LOT;1
46260;;Sainte-Colombe;SAINTE-COLOMBE;46120;46;LOT;1
46261;;Sainte-Croix;SAINTE-CROIX;46800;46;LOT;1
46262;;Saint-Cyprien;SAINT-CYPRIEN;46800;46;LOT;1
46263;;Saint-Daunès;SAINT-DAUNES;46800;46;LOT;1
46264;;Saint-Denis-Catus;SAINT-DENIS-CATUS;46150;46;LOT;1
46265;;Saint-Denis-lès-Martel;SAINT-DENIS-LES-MARTEL;46600;46;LOT;1
46266;;Saint-Félix;SAINT-FELIX;46100;46;LOT;1
46267;;Saint-Germain-du-Bel-Air;SAINT-GERMAIN-DU-BEL-AIR;46310;46;LOT;1
46268;;Saint-Géry;SAINT-GERY;46330;46;LOT;1
46269;;Saint-Hilaire;SAINT-HILAIRE;46210;46;LOT;1
46270;;Saint-Jean-de-Laur;SAINT-JEAN-DE-LAUR;46260;46;LOT;1
46271;;Saint-Jean-Lespinasse;SAINT-JEAN-LESPINASSE;46400;46;LOT;1
46272;;Saint-Jean-Mirabel;SAINT-JEAN-MIRABEL;46270;46;LOT;1
46273;;Saint-Laurent-les-Tours;SAINT-LAURENT-LES-TOURS;46400;46;LOT;1
46274;;Saint-Laurent-Lolmie;SAINT-LAURENT-LOLMIE;46800;46;LOT;1
46275;;Saint-Martin-de-Vers;SAINT-MARTIN-DE-VERS;46360;46;LOT;1
46276;;Saint-Martin-Labouval;SAINT-MARTIN-LABOUVAL;46330;46;LOT;1
46277;;Saint-Martin-le-Redon;SAINT-MARTIN-LE-REDON;46700;46;LOT;1
46278;;Saint-Matré;SAINT-MATRE;46800;46;LOT;1
46279;;Saint-Maurice-en-Quercy;SAINT-MAURICE-EN-QUERCY;46120;46;LOT;1
46280;;Saint-Médard;SAINT-MEDARD;46150;46;LOT;1
46281;;Saint-Médard-de-Presque;SAINT-MEDARD-DE-PRESQUE;46400;46;LOT;1
46282;;Saint-Médard-Nicourby;SAINT-MEDARD-NICOURBY;46210;46;LOT;1
46283;;Saint-Michel-de-Bannières;SAINT-MICHEL-DE-BANNIERES;46110;46;LOT;1
46284;;Saint-Michel-Loubéjou;SAINT-MICHEL-LOUBEJOU;46130;46;LOT;1
46285;;Saint-Pantaléon;SAINT-PANTALEON;46800;46;LOT;1
46286;;Saint-Paul-de-Vern;SAINT-PAUL-DE-VERN;46400;46;LOT;1
46287;;Saint-Paul-de-Loubressac;SAINT-PAUL-DE-LOUBRESSAC;46170;46;LOT;1
46288;;Saint-Perdoux;SAINT-PERDOUX;46100;46;LOT;1
46289;;Saint-Pierre-Toirac;SAINT-PIERRE-TOIRAC;46160;46;LOT;1
46290;;Saint-Projet;SAINT-PROJET;46300;46;LOT;1
46291;;Saint-Sauveur-la-Vallée;SAINT-SAUVEUR-LA-VALLEE;46240;46;LOT;1
46292;;Saint-Simon;SAINT-SIMON;46320;46;LOT;1
46293;;Saint-Sozy;SAINT-SOZY;46200;46;LOT;1
46294;;Saint-Sulpice;SAINT-SULPICE;46160;46;LOT;1
46295;;Saint-Vincent-du-Pendit;SAINT-VINCENT-DU-PENDIT;46400;46;LOT;1
46296;;Saint-Vincent-Rive-d'Olt;SAINT-VINCENT-RIVE-D'OLT;46140;46;LOT;1
46297;;Salviac;SALVIAC;46340;46;LOT;1
46298;;Sarrazac;SARRAZAC;46600;46;LOT;1
46299;;Sauliac-sur-Célé;SAULIAC-SUR-CELE;46330;46;LOT;1
46300;;Saux;SAUX;46800;46;LOT;1
46301;;Sauzet;SAUZET;46140;46;LOT;1
46302;;Sénaillac-Latronquière;SENAILLAC-LATRONQUIERE;46210;46;LOT;1
46303;;Sénaillac-Lauzès;SENAILLAC-LAUZES;46360;46;LOT;1
46304;;Séniergues;SENIERGUES;46240;46;LOT;1
46305;;Sérignac;SERIGNAC;46700;46;LOT;1
46306;;Sonac;SONAC;46320;46;LOT;1
46307;;Soturac;SOTURAC;46700;46;LOT;1
46308;;Soucirac;SOUCIRAC;46300;46;LOT;1
46309;;Souillac;SOUILLAC;46200;46;LOT;1
46310;;Soulomès;SOULOMES;46240;46;LOT;1
46311;;Sousceyrac;SOUSCEYRAC;46190;46;LOT;1
46312;;Strenquels;STRENQUELS;46110;46;LOT;1
46313;;Tauriac;TAURIAC;46130;46;LOT;1
46314;;Terrou;TERROU;46120;46;LOT;1
46315;;Teyssieu;TEYSSIEU;46190;46;LOT;1
46316;;Thédirac;THEDIRAC;46150;46;LOT;1
46317;;Thégra;THEGRA;46500;46;LOT;1
46318;;Thémines;THEMINES;46120;46;LOT;1
46319;;Théminettes;THEMINETTES;46120;46;LOT;1
46320;;Tour-de-Faure;TOUR-DE-FAURE;46330;46;LOT;1
46321;;Touzac;TOUZAC;46700;46;LOT;1
46322;;Trespoux-Rassiels;TRESPOUX-RASSIELS;46090;46;LOT;1
46323;;Ussel;USSEL;46240;46;LOT;1
46324;;Uzech;UZECH;46310;46;LOT;1
46325;;Vaillac;VAILLAC;46240;46;LOT;1
46326;;Valprionde;VALPRIONDE;46800;46;LOT;1
46327;;Valroufié;VALROUFIE;46090;46;LOT;1
46328;;Varaire;VARAIRE;46260;46;LOT;1
46329;;Vaylats;VAYLATS;46230;46;LOT;1
46330;;Vayrac;VAYRAC;46110;46;LOT;1
46331;;Vers;VERS;46090;46;LOT;1
46332;;Viazac;VIAZAC;46100;46;LOT;1
46333;;Vidaillac;VIDAILLAC;46260;46;LOT;1
46334;Le;Vigan;VIGAN;46300;46;LOT;1
46335;;Villesèque;VILLESEQUE;46090;46;LOT;1
46336;;Vire-sur-Lot;VIRE-SUR-LOT;46700;46;LOT;1
46337;;Mayrac;MAYRAC;46200;46;LOT;1
46338;;Bessonies;BESSONIES;46210;46;LOT;1
46339;;Saint-Jean-Lagineste;SAINT-JEAN-LAGINESTE;46400;46;LOT;1
46340;;Saint-Pierre-Lafeuille;SAINT-PIERRE-LAFEUILLE;46090;46;LOT;1
47001;;Agen;AGEN;47000;47;LOT ET GARONNE;1
47002;;Agmé;AGME;47350;47;LOT ET GARONNE;1
47003;;Agnac;AGNAC;47800;47;LOT ET GARONNE;1
47004;;Aiguillon;AIGUILLON;47190;47;LOT ET GARONNE;1
47005;;Allemans-du-Dropt;ALLEMANS-DU-DROPT;47800;47;LOT ET GARONNE;1
47006;;Allez-et-Cazeneuve;ALLEZ-ET-CAZENEUVE;47110;47;LOT ET GARONNE;1
47007;;Allons;ALLONS;47420;47;LOT ET GARONNE;1
47008;;Ambrus;AMBRUS;47160;47;LOT ET GARONNE;1
47009;;Andiran;ANDIRAN;47170;47;LOT ET GARONNE;1
47010;;Antagnac;ANTAGNAC;47700;47;LOT ET GARONNE;1
47011;;Anthé;ANTHE;47370;47;LOT ET GARONNE;1
47012;;Anzex;ANZEX;47700;47;LOT ET GARONNE;1
47013;;Argenton;ARGENTON;47250;47;LOT ET GARONNE;1
47014;;Armillac;ARMILLAC;47800;47;LOT ET GARONNE;1
47015;;Astaffort;ASTAFFORT;47220;47;LOT ET GARONNE;1
47016;;Aubiac;AUBIAC;47310;47;LOT ET GARONNE;1
47017;;Auradou;AURADOU;47140;47;LOT ET GARONNE;1
47018;;Auriac-sur-Dropt;AURIAC-SUR-DROPT;47120;47;LOT ET GARONNE;1
47019;;Bajamont;BAJAMONT;47480;47;LOT ET GARONNE;1
47020;;Baleyssagues;BALEYSSAGUES;47120;47;LOT ET GARONNE;1
47021;;Barbaste;BARBASTE;47230;47;LOT ET GARONNE;1
47022;;Bazens;BAZENS;47130;47;LOT ET GARONNE;1
47023;;Beaugas;BEAUGAS;47290;47;LOT ET GARONNE;1
47024;;Beaupuy;BEAUPUY;47200;47;LOT ET GARONNE;1
47025;;Beauville;BEAUVILLE;47470;47;LOT ET GARONNE;1
47026;;Beauziac;BEAUZIAC;47700;47;LOT ET GARONNE;1
47027;;Bias;BIAS;47300;47;LOT ET GARONNE;1
47028;;Birac-sur-Trec;BIRAC-SUR-TREC;47200;47;LOT ET GARONNE;1
47029;;Blanquefort-sur-Briolance;BLANQUEFORT-SUR-BRIOLANCE;47500;47;LOT ET GARONNE;1
47030;;Blaymont;BLAYMONT;47470;47;LOT ET GARONNE;1
47031;;Boé;BOE;47550;47;LOT ET GARONNE;1
47032;;Bon-Encontre;BON-ENCONTRE;47240;47;LOT ET GARONNE;1
47033;;Boudy-de-Beauregard;BOUDY-DE-BEAUREGARD;47290;47;LOT ET GARONNE;1
47034;;Bouglon;BOUGLON;47250;47;LOT ET GARONNE;1
47035;;Bourgougnague;BOURGOUGNAGUE;47410;47;LOT ET GARONNE;1
47036;;Bourlens;BOURLENS;47370;47;LOT ET GARONNE;1
47037;;Bournel;BOURNEL;47210;47;LOT ET GARONNE;1
47038;;Bourran;BOURRAN;47320;47;LOT ET GARONNE;1
47039;;Boussès;BOUSSES;47420;47;LOT ET GARONNE;1
47040;;Brax;BRAX;47310;47;LOT ET GARONNE;1
47041;;Bruch;BRUCH;47130;47;LOT ET GARONNE;1
47042;;Brugnac;BRUGNAC;47260;47;LOT ET GARONNE;1
47043;;Buzet-sur-Baïse;BUZET-SUR-BAISE;47160;47;LOT ET GARONNE;1
47044;;Cahuzac;CAHUZAC;47330;47;LOT ET GARONNE;1
47045;;Calignac;CALIGNAC;47600;47;LOT ET GARONNE;1
47046;;Calonges;CALONGES;47430;47;LOT ET GARONNE;1
47047;;Cambes;CAMBES;47350;47;LOT ET GARONNE;1
47048;;Cancon;CANCON;47290;47;LOT ET GARONNE;1
47049;;Casseneuil;CASSENEUIL;47440;47;LOT ET GARONNE;1
47050;;Cassignas;CASSIGNAS;47340;47;LOT ET GARONNE;1
47051;;Castelculier;CASTELCULIER;47240;47;LOT ET GARONNE;1
47052;;Casteljaloux;CASTELJALOUX;47700;47;LOT ET GARONNE;1
47053;;Castella;CASTELLA;47340;47;LOT ET GARONNE;1
47054;;Castelmoron-sur-Lot;CASTELMORON-SUR-LOT;47260;47;LOT ET GARONNE;1
47055;;Castelnaud-de-Gratecambe;CASTELNAUD-DE-GRATECAMBE;47290;47;LOT ET GARONNE;1
47056;;Castelnau-sur-Gupie;CASTELNAU-SUR-GUPIE;47200;47;LOT ET GARONNE;1
47057;;Castillonnès;CASTILLONNES;47330;47;LOT ET GARONNE;1
47058;;Caubeyres;CAUBEYRES;47160;47;LOT ET GARONNE;1
47059;;Caubon-Saint-Sauveur;CAUBON-SAINT-SAUVEUR;47120;47;LOT ET GARONNE;1
47060;;Caudecoste;CAUDECOSTE;47220;47;LOT ET GARONNE;1
47061;;Caumont-sur-Garonne;CAUMONT-SUR-GARONNE;47430;47;LOT ET GARONNE;1
47062;;Cauzac;CAUZAC;47470;47;LOT ET GARONNE;1
47063;;Cavarc;CAVARC;47330;47;LOT ET GARONNE;1
47064;;Cazideroque;CAZIDEROQUE;47370;47;LOT ET GARONNE;1
47065;;Clairac;CLAIRAC;47320;47;LOT ET GARONNE;1
47066;;Clermont-Dessous;CLERMONT-DESSOUS;47130;47;LOT ET GARONNE;1
47067;;Clermont-Soubiran;CLERMONT-SOUBIRAN;47270;47;LOT ET GARONNE;1
47068;;Cocumont;COCUMONT;47250;47;LOT ET GARONNE;1
47069;;Colayrac-Saint-Cirq;COLAYRAC-SAINT-CIRQ;47450;47;LOT ET GARONNE;1
47070;;Condezaygues;CONDEZAYGUES;47500;47;LOT ET GARONNE;1
47071;;Coulx;COULX;47260;47;LOT ET GARONNE;1
47072;;Courbiac;COURBIAC;47370;47;LOT ET GARONNE;1
47073;;Cours;COURS;47360;47;LOT ET GARONNE;1
47074;;Couthures-sur-Garonne;COUTHURES-SUR-GARONNE;47200;47;LOT ET GARONNE;1
47075;La;Croix-Blanche;CROIX-BLANCHE;47340;47;LOT ET GARONNE;1
47076;;Cuq;CUQ;47220;47;LOT ET GARONNE;1
47077;;Cuzorn;CUZORN;47500;47;LOT ET GARONNE;1
47078;;Damazan;DAMAZAN;47160;47;LOT ET GARONNE;1
47079;;Dausse;DAUSSE;47140;47;LOT ET GARONNE;1
47080;;Dévillac;DEVILLAC;47210;47;LOT ET GARONNE;1
47081;;Dolmayrac;DOLMAYRAC;47110;47;LOT ET GARONNE;1
47082;;Dondas;DONDAS;47470;47;LOT ET GARONNE;1
47083;;Doudrac;DOUDRAC;47210;47;LOT ET GARONNE;1
47084;;Douzains;DOUZAINS;47330;47;LOT ET GARONNE;1
47085;;Durance;DURANCE;47420;47;LOT ET GARONNE;1
47086;;Duras;DURAS;47120;47;LOT ET GARONNE;1
47087;;Engayrac;ENGAYRAC;47470;47;LOT ET GARONNE;1
47088;;Escassefort;ESCASSEFORT;47350;47;LOT ET GARONNE;1
47089;;Esclottes;ESCLOTTES;47120;47;LOT ET GARONNE;1
47090;;Espiens;ESPIENS;47600;47;LOT ET GARONNE;1
47091;;Estillac;ESTILLAC;47310;47;LOT ET GARONNE;1
47092;;Fals;FALS;47220;47;LOT ET GARONNE;1
47093;;Fargues-sur-Ourbise;FARGUES-SUR-OURBISE;47700;47;LOT ET GARONNE;1
47094;;Fauguerolles;FAUGUEROLLES;47400;47;LOT ET GARONNE;1
47095;;Fauillet;FAUILLET;47400;47;LOT ET GARONNE;1
47096;;Ferrensac;FERRENSAC;47330;47;LOT ET GARONNE;1
47097;;Feugarolles;FEUGAROLLES;47230;47;LOT ET GARONNE;1
47098;;Fieux;FIEUX;47600;47;LOT ET GARONNE;1
47099;;Fongrave;FONGRAVE;47260;47;LOT ET GARONNE;1
47100;;Foulayronnes;FOULAYRONNES;47510;47;LOT ET GARONNE;1
47101;;Fourques-sur-Garonne;FOURQUES-SUR-GARONNE;47200;47;LOT ET GARONNE;1
47102;;Francescas;FRANCESCAS;47600;47;LOT ET GARONNE;1
47103;;Fréchou;FRECHOU;47600;47;LOT ET GARONNE;1
47104;;Frégimont;FREGIMONT;47360;47;LOT ET GARONNE;1
47105;;Frespech;FRESPECH;47140;47;LOT ET GARONNE;1
47106;;Fumel;FUMEL;47500;47;LOT ET GARONNE;1
47107;;Galapian;GALAPIAN;47190;47;LOT ET GARONNE;1
47108;;Gaujac;GAUJAC;47200;47;LOT ET GARONNE;1
47109;;Gavaudun;GAVAUDUN;47150;47;LOT ET GARONNE;1
47110;;Gontaud-de-Nogaret;GONTAUD-DE-NOGARET;47400;47;LOT ET GARONNE;1
47111;;Granges-sur-Lot;GRANGES-SUR-LOT;47260;47;LOT ET GARONNE;1
47112;;Grateloup-Saint-Gayrand;GRATELOUP-SAINT-GAYRAND;47400;47;LOT ET GARONNE;1
47113;;Grayssas;GRAYSSAS;47270;47;LOT ET GARONNE;1
47114;;Grézet-Cavagnan;GREZET-CAVAGNAN;47250;47;LOT ET GARONNE;1
47115;;Guérin;GUERIN;47250;47;LOT ET GARONNE;1
47117;;Hautefage-la-Tour;HAUTEFAGE-LA-TOUR;47340;47;LOT ET GARONNE;1
47118;;Hautesvignes;HAUTESVIGNES;47400;47;LOT ET GARONNE;1
47119;;Houeillès;HOUEILLES;47420;47;LOT ET GARONNE;1
47120;;Jusix;JUSIX;47200;47;LOT ET GARONNE;1
47121;;Labastide-Castel-Amouroux;LABASTIDE-CASTEL-AMOUROUX;47250;47;LOT ET GARONNE;1
47122;;Labretonie;LABRETONIE;47350;47;LOT ET GARONNE;1
47123;;Lacapelle-Biron;LACAPELLE-BIRON;47150;47;LOT ET GARONNE;1
47124;;Lacaussade;LACAUSSADE;47150;47;LOT ET GARONNE;1
47125;;Lacépède;LACEPEDE;47360;47;LOT ET GARONNE;1
47126;;Lachapelle;LACHAPELLE;47350;47;LOT ET GARONNE;1
47127;;Lafitte-sur-Lot;LAFITTE-SUR-LOT;47320;47;LOT ET GARONNE;1
47128;;Lafox;LAFOX;47240;47;LOT ET GARONNE;1
47129;;Lagarrigue;LAGARRIGUE;47190;47;LOT ET GARONNE;1
47130;;Lagruère;LAGRUERE;47400;47;LOT ET GARONNE;1
47131;;Lagupie;LAGUPIE;47200;47;LOT ET GARONNE;1
47132;;Lalandusse;LALANDUSSE;47330;47;LOT ET GARONNE;1
47133;;Lamontjoie;LAMONTJOIE;47310;47;LOT ET GARONNE;1
47134;;Lannes;LANNES;47170;47;LOT ET GARONNE;1
47135;;Laparade;LAPARADE;47260;47;LOT ET GARONNE;1
47136;;Laperche;LAPERCHE;47800;47;LOT ET GARONNE;1
47137;;Laplume;LAPLUME;47310;47;LOT ET GARONNE;1
47138;;Laroque-Timbaut;LAROQUE-TIMBAUT;47340;47;LOT ET GARONNE;1
47139;;Lasserre;LASSERRE;47600;47;LOT ET GARONNE;1
47140;;Laugnac;LAUGNAC;47360;47;LOT ET GARONNE;1
47141;;Laussou;LAUSSOU;47150;47;LOT ET GARONNE;1
47142;;Lauzun;LAUZUN;47410;47;LOT ET GARONNE;1
47143;;Lavardac;LAVARDAC;47230;47;LOT ET GARONNE;1
47144;;Lavergne;LAVERGNE;47800;47;LOT ET GARONNE;1
47145;;Layrac;LAYRAC;47390;47;LOT ET GARONNE;1
47146;;Lédat;LEDAT;47300;47;LOT ET GARONNE;1
47147;;Lévignac-de-Guyenne;LEVIGNAC-DE-GUYENNE;47120;47;LOT ET GARONNE;1
47148;;Leyritz-Moncassin;LEYRITZ-MONCASSIN;47700;47;LOT ET GARONNE;1
47150;;Longueville;LONGUEVILLE;47200;47;LOT ET GARONNE;1
47151;;Loubès-Bernac;LOUBES-BERNAC;47120;47;LOT ET GARONNE;1
47152;;Lougratte;LOUGRATTE;47290;47;LOT ET GARONNE;1
47154;;Lusignan-Petit;LUSIGNAN-PETIT;47360;47;LOT ET GARONNE;1
47155;;Madaillan;MADAILLAN;47360;47;LOT ET GARONNE;1
47156;;Marcellus;MARCELLUS;47200;47;LOT ET GARONNE;1
47157;;Marmande;MARMANDE;47200;47;LOT ET GARONNE;1
47158;;Marmont-Pachas;MARMONT-PACHAS;47220;47;LOT ET GARONNE;1
47159;Le;Mas-d'Agenais;MAS-D'AGENAIS;47430;47;LOT ET GARONNE;1
47160;;Masquières;MASQUIERES;47370;47;LOT ET GARONNE;1
47161;;Massels;MASSELS;47140;47;LOT ET GARONNE;1
47162;;Massoulès;MASSOULES;47140;47;LOT ET GARONNE;1
47163;;Mauvezin-sur-Gupie;MAUVEZIN-SUR-GUPIE;47200;47;LOT ET GARONNE;1
47164;;Mazières-Naresse;MAZIERES-NARESSE;47210;47;LOT ET GARONNE;1
47165;;Meilhan-sur-Garonne;MEILHAN-SUR-GARONNE;47200;47;LOT ET GARONNE;1
47167;;Mézin;MEZIN;47170;47;LOT ET GARONNE;1
47168;;Miramont-de-Guyenne;MIRAMONT-DE-GUYENNE;47800;47;LOT ET GARONNE;1
47169;;Moirax;MOIRAX;47310;47;LOT ET GARONNE;1
47170;;Monbahus;MONBAHUS;47290;47;LOT ET GARONNE;1
47171;;Monbalen;MONBALEN;47340;47;LOT ET GARONNE;1
47172;;Moncaut;MONCAUT;47310;47;LOT ET GARONNE;1
47173;;Monclar;MONCLAR;47380;47;LOT ET GARONNE;1
47174;;Moncrabeau;MONCRABEAU;47600;47;LOT ET GARONNE;1
47175;;Monflanquin;MONFLANQUIN;47150;47;LOT ET GARONNE;1
47176;;Mongaillard;MONGAILLARD;47230;47;LOT ET GARONNE;1
47177;;Monheurt;MONHEURT;47160;47;LOT ET GARONNE;1
47178;;Monségur;MONSEGUR;47150;47;LOT ET GARONNE;1
47179;;Monsempron-Libos;MONSEMPRON-LIBOS;47500;47;LOT ET GARONNE;1
47180;;Montagnac-sur-Auvignon;MONTAGNAC-SUR-AUVIGNON;47600;47;LOT ET GARONNE;1
47181;;Montagnac-sur-Lède;MONTAGNAC-SUR-LEDE;47150;47;LOT ET GARONNE;1
47182;;Montastruc;MONTASTRUC;47380;47;LOT ET GARONNE;1
47183;;Montauriol;MONTAURIOL;47330;47;LOT ET GARONNE;1
47184;;Montaut;MONTAUT;47210;47;LOT ET GARONNE;1
47185;;Montayral;MONTAYRAL;47500;47;LOT ET GARONNE;1
47186;;Montesquieu;MONTESQUIEU;47130;47;LOT ET GARONNE;1
47187;;Monteton;MONTETON;47120;47;LOT ET GARONNE;1
47188;;Montignac-de-Lauzun;MONTIGNAC-DE-LAUZUN;47800;47;LOT ET GARONNE;1
47189;;Montignac-Toupinerie;MONTIGNAC-TOUPINERIE;47350;47;LOT ET GARONNE;1
47190;;Montpezat;MONTPEZAT;47360;47;LOT ET GARONNE;1
47191;;Montpouillan;MONTPOUILLAN;47200;47;LOT ET GARONNE;1
47192;;Monviel;MONVIEL;47290;47;LOT ET GARONNE;1
47193;;Moulinet;MOULINET;47290;47;LOT ET GARONNE;1
47194;;Moustier;MOUSTIER;47800;47;LOT ET GARONNE;1
47195;;Nérac;NERAC;47600;47;LOT ET GARONNE;1
47196;;Nicole;NICOLE;47190;47;LOT ET GARONNE;1
47197;;Nomdieu;NOMDIEU;47600;47;LOT ET GARONNE;1
47198;;Pailloles;PAILLOLES;47440;47;LOT ET GARONNE;1
47199;;Pardaillan;PARDAILLAN;47120;47;LOT ET GARONNE;1
47200;;Parranquet;PARRANQUET;47210;47;LOT ET GARONNE;1
47201;Le;Passage;PASSAGE;47520;47;LOT ET GARONNE;1
47202;;Paulhiac;PAULHIAC;47150;47;LOT ET GARONNE;1
47203;;Penne-d'Agenais;PENNE-D'AGENAIS;47140;47;LOT ET GARONNE;1
47204;;Peyrière;PEYRIERE;47350;47;LOT ET GARONNE;1
47205;;Pindères;PINDERES;47700;47;LOT ET GARONNE;1
47206;;Pinel-Hauterive;PINEL-HAUTERIVE;47380;47;LOT ET GARONNE;1
47207;;Pompiey;POMPIEY;47230;47;LOT ET GARONNE;1
47208;;Pompogne;POMPOGNE;47420;47;LOT ET GARONNE;1
47209;;Pont-du-Casse;PONT-DU-CASSE;47480;47;LOT ET GARONNE;1
47210;;Port-Sainte-Marie;PORT-SAINTE-MARIE;47130;47;LOT ET GARONNE;1
47211;;Poudenas;POUDENAS;47170;47;LOT ET GARONNE;1
47212;;Poussignac;POUSSIGNAC;47700;47;LOT ET GARONNE;1
47213;;Prayssas;PRAYSSAS;47360;47;LOT ET GARONNE;1
47214;;Puch-d'Agenais;PUCH-D'AGENAIS;47160;47;LOT ET GARONNE;1
47215;;Pujols;PUJOLS;47300;47;LOT ET GARONNE;1
47216;;Puymiclan;PUYMICLAN;47350;47;LOT ET GARONNE;1
47217;;Puymirol;PUYMIROL;47270;47;LOT ET GARONNE;1
47218;;Puysserampion;PUYSSERAMPION;47800;47;LOT ET GARONNE;1
47219;;Rayet;RAYET;47210;47;LOT ET GARONNE;1
47220;;Razimet;RAZIMET;47160;47;LOT ET GARONNE;1
47221;;Réaup-Lisse;REAUP-LISSE;47170;47;LOT ET GARONNE;1
47222;La;Réunion;REUNION;47700;47;LOT ET GARONNE;1
47223;;Rives;RIVES;47210;47;LOT ET GARONNE;1
47224;;Romestaing;ROMESTAING;47250;47;LOT ET GARONNE;1
47225;;Roquefort;ROQUEFORT;47310;47;LOT ET GARONNE;1
47226;;Roumagne;ROUMAGNE;47800;47;LOT ET GARONNE;1
47227;;Ruffiac;RUFFIAC;47700;47;LOT ET GARONNE;1
47228;;Saint-Antoine-de-Ficalba;SAINT-ANTOINE-DE-FICALBA;47340;47;LOT ET GARONNE;1
47229;;Saint-Astier;SAINT-ASTIER;47120;47;LOT ET GARONNE;1
47230;;Saint-Aubin;SAINT-AUBIN;47150;47;LOT ET GARONNE;1
47231;;Saint-Avit;SAINT-AVIT;47350;47;LOT ET GARONNE;1
47232;;Saint-Barthélemy-d'Agenais;SAINT-BARTHELEMY-D'AGENAIS;47350;47;LOT ET GARONNE;1
47233;;Sainte-Bazeille;SAINTE-BAZEILLE;47200;47;LOT ET GARONNE;1
47234;;Saint-Caprais-de-Lerm;SAINT-CAPRAIS-DE-LERM;47270;47;LOT ET GARONNE;1
47235;;Saint-Colomb-de-Lauzun;SAINT-COLOMB-DE-LAUZUN;47410;47;LOT ET GARONNE;1
47236;;Sainte-Colombe-de-Duras;SAINTE-COLOMBE-DE-DURAS;47120;47;LOT ET GARONNE;1
47237;;Sainte-Colombe-de-Villeneuve;SAINTE-COLOMBE-DE-VILLENEUVE;47300;47;LOT ET GARONNE;1
47238;;Sainte-Colombe-en-Bruilhois;SAINTE-COLOMBE-EN-BRUILHOIS;47310;47;LOT ET GARONNE;1
47239;;Saint-Étienne-de-Fougères;SAINT-ETIENNE-DE-FOUGERES;47380;47;LOT ET GARONNE;1
47240;;Saint-Étienne-de-Villeréal;SAINT-ETIENNE-DE-VILLEREAL;47210;47;LOT ET GARONNE;1
47241;;Saint-Eutrope-de-Born;SAINT-EUTROPE-DE-BORN;47210;47;LOT ET GARONNE;1
47242;;Saint-Front-sur-Lémance;SAINT-FRONT-SUR-LEMANCE;47500;47;LOT ET GARONNE;1
47244;;Sainte-Gemme-Martaillac;SAINTE-GEMME-MARTAILLAC;47250;47;LOT ET GARONNE;1
47245;;Saint-Géraud;SAINT-GERAUD;47120;47;LOT ET GARONNE;1
47246;;Saint-Hilaire-de-Lusignan;SAINT-HILAIRE-DE-LUSIGNAN;47450;47;LOT ET GARONNE;1
47247;;Saint-Jean-de-Duras;SAINT-JEAN-DE-DURAS;47120;47;LOT ET GARONNE;1
47248;;Saint-Jean-de-Thurac;SAINT-JEAN-DE-THURAC;47270;47;LOT ET GARONNE;1
47249;;Saint-Laurent;SAINT-LAURENT;47130;47;LOT ET GARONNE;1
47250;;Saint-Léger;SAINT-LEGER;47160;47;LOT ET GARONNE;1
47251;;Saint-Léon;SAINT-LEON;47160;47;LOT ET GARONNE;1
47252;;Sainte-Livrade-sur-Lot;SAINTE-LIVRADE-SUR-LOT;47110;47;LOT ET GARONNE;1
47253;;Sainte-Marthe;SAINTE-MARTHE;47430;47;LOT ET GARONNE;1
47254;;Saint-Martin-Curton;SAINT-MARTIN-CURTON;47700;47;LOT ET GARONNE;1
47255;;Saint-Martin-de-Beauville;SAINT-MARTIN-DE-BEAUVILLE;47270;47;LOT ET GARONNE;1
47256;;Saint-Martin-de-Villeréal;SAINT-MARTIN-DE-VILLEREAL;47210;47;LOT ET GARONNE;1
47257;;Saint-Martin-Petit;SAINT-MARTIN-PETIT;47200;47;LOT ET GARONNE;1
47258;;Sainte-Maure-de-Peyriac;SAINTE-MAURE-DE-PEYRIAC;47170;47;LOT ET GARONNE;1
47259;;Saint-Maurice-de-Lestapel;SAINT-MAURICE-DE-LESTAPEL;47290;47;LOT ET GARONNE;1
47260;;Saint-Maurin;SAINT-MAURIN;47270;47;LOT ET GARONNE;1
47262;;Saint-Nicolas-de-la-Balerme;SAINT-NICOLAS-DE-LA-BALERME;47220;47;LOT ET GARONNE;1
47263;;Saint-Pardoux-du-Breuil;SAINT-PARDOUX-DU-BREUIL;47200;47;LOT ET GARONNE;1
47264;;Saint-Pardoux-Isaac;SAINT-PARDOUX-ISAAC;47800;47;LOT ET GARONNE;1
47265;;Saint-Pastour;SAINT-PASTOUR;47290;47;LOT ET GARONNE;1
47266;;Saint-Pé-Saint-Simon;SAINT-PE-SAINT-SIMON;47170;47;LOT ET GARONNE;1
47267;;Saint-Pierre-de-Buzet;SAINT-PIERRE-DE-BUZET;47160;47;LOT ET GARONNE;1
47269;;Saint-Pierre-de-Clairac;SAINT-PIERRE-DE-CLAIRAC;47270;47;LOT ET GARONNE;1
47271;;Saint-Pierre-sur-Dropt;SAINT-PIERRE-SUR-DROPT;47120;47;LOT ET GARONNE;1
47272;;Saint-Quentin-du-Dropt;SAINT-QUENTIN-DU-DROPT;47330;47;LOT ET GARONNE;1
47273;;Saint-Robert;SAINT-ROBERT;47340;47;LOT ET GARONNE;1
47274;;Saint-Romain-le-Noble;SAINT-ROMAIN-LE-NOBLE;47270;47;LOT ET GARONNE;1
47275;;Saint-Salvy;SAINT-SALVY;47360;47;LOT ET GARONNE;1
47276;;Saint-Sardos;SAINT-SARDOS;47360;47;LOT ET GARONNE;1
47277;;Saint-Sauveur-de-Meilhan;SAINT-SAUVEUR-DE-MEILHAN;47200;47;LOT ET GARONNE;1
47278;;Saint-Sernin;SAINT-SERNIN;47120;47;LOT ET GARONNE;1
47279;;Saint-Sixte;SAINT-SIXTE;47220;47;LOT ET GARONNE;1
47280;;Saint-Sylvestre-sur-Lot;SAINT-SYLVESTRE-SUR-LOT;47140;47;LOT ET GARONNE;1
47281;;Saint-Urcisse;SAINT-URCISSE;47270;47;LOT ET GARONNE;1
47282;;Saint-Vincent-de-Lamontjoie;SAINT-VINCENT-DE-LAMONTJOIE;47310;47;LOT ET GARONNE;1
47283;;Saint-Vite;SAINT-VITE;47500;47;LOT ET GARONNE;1
47284;;Salles;SALLES;47150;47;LOT ET GARONNE;1
47285;;Samazan;SAMAZAN;47250;47;LOT ET GARONNE;1
47286;;Sauméjan;SAUMEJAN;47420;47;LOT ET GARONNE;1
47287;;Saumont;SAUMONT;47600;47;LOT ET GARONNE;1
47288;;Sauvagnas;SAUVAGNAS;47340;47;LOT ET GARONNE;1
47289;La;Sauvetat-de-Savères;SAUVETAT-DE-SAVERES;47270;47;LOT ET GARONNE;1
47290;La;Sauvetat-du-Dropt;SAUVETAT-DU-DROPT;47800;47;LOT ET GARONNE;1
47291;La;Sauvetat-sur-Lède;SAUVETAT-SUR-LEDE;47150;47;LOT ET GARONNE;1
47292;;Sauveterre-la-Lémance;SAUVETERRE-LA-LEMANCE;47500;47;LOT ET GARONNE;1
47293;;Sauveterre-Saint-Denis;SAUVETERRE-SAINT-DENIS;47220;47;LOT ET GARONNE;1
47294;;Savignac-de-Duras;SAVIGNAC-DE-DURAS;47120;47;LOT ET GARONNE;1
47295;;Savignac-sur-Leyze;SAVIGNAC-SUR-LEYZE;47150;47;LOT ET GARONNE;1
47296;;Ségalas;SEGALAS;47410;47;LOT ET GARONNE;1
47297;;Sembas;SEMBAS;47360;47;LOT ET GARONNE;1
47298;;Sénestis;SENESTIS;47430;47;LOT ET GARONNE;1
47299;;Sérignac-Péboudou;SERIGNAC-PEBOUDOU;47410;47;LOT ET GARONNE;1
47300;;Sérignac-sur-Garonne;SERIGNAC-SUR-GARONNE;47310;47;LOT ET GARONNE;1
47301;;Seyches;SEYCHES;47350;47;LOT ET GARONNE;1
47302;;Sos;SOS;47170;47;LOT ET GARONNE;1
47303;;Soumensac;SOUMENSAC;47120;47;LOT ET GARONNE;1
47304;;Taillebourg;TAILLEBOURG;47200;47;LOT ET GARONNE;1
47305;;Tayrac;TAYRAC;47270;47;LOT ET GARONNE;1
47306;Le;Temple-sur-Lot;TEMPLE-SUR-LOT;47110;47;LOT ET GARONNE;1
47307;;Thézac;THEZAC;47370;47;LOT ET GARONNE;1
47308;;Thouars-sur-Garonne;THOUARS-SUR-GARONNE;47230;47;LOT ET GARONNE;1
47309;;Tombebœuf;TOMBEBOEUF;47380;47;LOT ET GARONNE;1
47310;;Tonneins;TONNEINS;47400;47;LOT ET GARONNE;1
47311;;Tourliac;TOURLIAC;47210;47;LOT ET GARONNE;1
47312;;Tournon-d'Agenais;TOURNON-D'AGENAIS;47370;47;LOT ET GARONNE;1
47313;;Tourtrès;TOURTRES;47380;47;LOT ET GARONNE;1
47314;;Trémons;TREMONS;47140;47;LOT ET GARONNE;1
47315;;Trentels;TRENTELS;47140;47;LOT ET GARONNE;1
47316;;Varès;VARES;47400;47;LOT ET GARONNE;1
47317;;Verteuil-d'Agenais;VERTEUIL-D'AGENAIS;47260;47;LOT ET GARONNE;1
47318;;Vianne;VIANNE;47230;47;LOT ET GARONNE;1
47319;;Villebramar;VILLEBRAMAR;47380;47;LOT ET GARONNE;1
47320;;Villefranche-du-Queyran;VILLEFRANCHE-DU-QUEYRAN;47160;47;LOT ET GARONNE;1
47321;;Villeneuve-de-Duras;VILLENEUVE-DE-DURAS;47120;47;LOT ET GARONNE;1
47323;;Villeneuve-sur-Lot;VILLENEUVE-SUR-LOT;47300;47;LOT ET GARONNE;1
47324;;Villeréal;VILLEREAL;47210;47;LOT ET GARONNE;1
47325;;Villeton;VILLETON;47400;47;LOT ET GARONNE;1
47326;;Virazeil;VIRAZEIL;47200;47;LOT ET GARONNE;1
47327;;Xaintrailles;XAINTRAILLES;47230;47;LOT ET GARONNE;1
47328;;Saint-Georges;SAINT-GEORGES;47370;47;LOT ET GARONNE;1
48001;;Albaret-le-Comtal;ALBARET-LE-COMTAL;48310;48;LOZERE;1
48002;;Albaret-Sainte-Marie;ALBARET-SAINTE-MARIE;48200;48;LOZERE;1
48003;;Allenc;ALLENC;48190;48;LOZERE;1
48004;;Altier;ALTIER;48800;48;LOZERE;1
48005;;Antrenas;ANTRENAS;48100;48;LOZERE;1
48007;;Arzenc-d'Apcher;ARZENC-D'APCHER;48310;48;LOZERE;1
48008;;Arzenc-de-Randon;ARZENC-DE-RANDON;48170;48;LOZERE;1
48009;;Aumont-Aubrac;AUMONT-AUBRAC;48130;48;LOZERE;1
48010;;Auroux;AUROUX;48600;48;LOZERE;1
48012;Les;Monts-Verts;MONTS-VERTS;48200;48;LOZERE;1
48013;;Badaroux;BADAROUX;48000;48;LOZERE;1
48014;;Bagnols-les-Bains;BAGNOLS-LES-BAINS;48190;48;LOZERE;1
48015;;Pied-de-Borne;PIED-DE-BORNE;48800;48;LOZERE;1
48016;;Balsièges;BALSIEGES;48000;48;LOZERE;1
48017;;Banassac;BANASSAC;48500;48;LOZERE;1
48018;;Barjac;BARJAC;48000;48;LOZERE;1
48019;;Barre-des-Cévennes;BARRE-DES-CEVENNES;48400;48;LOZERE;1
48020;;Bassurels;BASSURELS;48400;48;LOZERE;1
48021;La;Bastide-Puylaurent;BASTIDE-PUYLAURENT;48250;48;LOZERE;1
48022;;Bédouès;BEDOUES;48400;48;LOZERE;1
48023;;Belvezet;BELVEZET;48170;48;LOZERE;1
48025;Les;Bessons;BESSONS;48200;48;LOZERE;1
48026;;Blavignac;BLAVIGNAC;48200;48;LOZERE;1
48027;Le;Bleymard;BLEYMARD;48190;48;LOZERE;1
48028;Les;Bondons;BONDONS;48400;48;LOZERE;1
48029;Le;Born;BORN;48000;48;LOZERE;1
48030;;Brenoux;BRENOUX;48000;48;LOZERE;1
48031;;Brion;BRION;48310;48;LOZERE;1
48032;Le;Buisson;BUISSON;48100;48;LOZERE;1
48033;;Canilhac;CANILHAC;48500;48;LOZERE;1
48034;La;Canourgue;CANOURGUE;48500;48;LOZERE;1
48036;;Cassagnas;CASSAGNAS;48400;48;LOZERE;1
48037;;Chadenet;CHADENET;48190;48;LOZERE;1
48038;;Chambon-le-Château;CHAMBON-LE-CHATEAU;48600;48;LOZERE;1
48039;;Chanac;CHANAC;48230;48;LOZERE;1
48040;;Chasseradès;CHASSERADES;48250;48;LOZERE;1
48041;;Chastanier;CHASTANIER;48300;48;LOZERE;1
48042;;Chastel-Nouvel;CHASTEL-NOUVEL;48000;48;LOZERE;1
48043;;Châteauneuf-de-Randon;CHATEAUNEUF-DE-RANDON;48170;48;LOZERE;1
48044;;Chauchailles;CHAUCHAILLES;48310;48;LOZERE;1
48045;;Chaudeyrac;CHAUDEYRAC;48170;48;LOZERE;1
48046;;Chaulhac;CHAULHAC;48140;48;LOZERE;1
48047;La;Chaze-de-Peyre;CHAZE-DE-PEYRE;48130;48;LOZERE;1
48048;;Cheylard-l'Évêque;CHEYLARD-L'EVEQUE;48300;48;LOZERE;1
48049;;Chirac;CHIRAC;48100;48;LOZERE;1
48050;;Cocurès;COCURES;48400;48;LOZERE;1
48051;Le;Collet-de-Dèze;COLLET-DE-DEZE;48160;48;LOZERE;1
48053;;Cubières;CUBIERES;48190;48;LOZERE;1
48054;;Cubiérettes;CUBIERETTES;48190;48;LOZERE;1
48055;;Cultures;CULTURES;48230;48;LOZERE;1
48056;;Esclanèdes;ESCLANEDES;48230;48;LOZERE;1
48057;;Estables;ESTABLES;48700;48;LOZERE;1
48058;La;Fage-Montivernoux;FAGE-MONTIVERNOUX;48310;48;LOZERE;1
48059;La;Fage-Saint-Julien;FAGE-SAINT-JULIEN;48200;48;LOZERE;1
48060;;Fau-de-Peyre;FAU-DE-PEYRE;48130;48;LOZERE;1
48061;;Florac;FLORAC;48400;48;LOZERE;1
48062;;Fontanes;FONTANES;48300;48;LOZERE;1
48063;;Fontans;FONTANS;48700;48;LOZERE;1
48064;;Fournels;FOURNELS;48310;48;LOZERE;1
48065;;Fraissinet-de-Fourques;FRAISSINET-DE-FOURQUES;48400;48;LOZERE;1
48066;;Fraissinet-de-Lozère;FRAISSINET-DE-LOZERE;48220;48;LOZERE;1
48067;;Gabriac;GABRIAC;48110;48;LOZERE;1
48068;;Gabrias;GABRIAS;48100;48;LOZERE;1
48069;;Gatuzières;GATUZIERES;48150;48;LOZERE;1
48070;;Grandrieu;GRANDRIEU;48600;48;LOZERE;1
48071;;Grandvals;GRANDVALS;48260;48;LOZERE;1
48072;;Grèzes;GREZES;48100;48;LOZERE;1
48073;Les;Hermaux;HERMAUX;48340;48;LOZERE;1
48074;;Hures-la-Parade;HURES-LA-PARADE;48150;48;LOZERE;1
48075;;Ispagnac;ISPAGNAC;48320;48;LOZERE;1
48076;;Javols;JAVOLS;48130;48;LOZERE;1
48077;;Julianges;JULIANGES;48140;48;LOZERE;1
48078;;Lachamp;LACHAMP;48100;48;LOZERE;1
48079;;Lajo;LAJO;48120;48;LOZERE;1
48080;;Langogne;LANGOGNE;48300;48;LOZERE;1
48081;;Lanuéjols;LANUEJOLS;48000;48;LOZERE;1
48082;;Laubert;LAUBERT;48170;48;LOZERE;1
48083;Les;Laubies;LAUBIES;48700;48;LOZERE;1
48084;;Laval-Atger;LAVAL-ATGER;48600;48;LOZERE;1
48085;;Laval-du-Tarn;LAVAL-DU-TARN;48500;48;LOZERE;1
48086;;Luc;LUC;48250;48;LOZERE;1
48087;;Malbouzon;MALBOUZON;48270;48;LOZERE;1
48088;La;Malène;MALENE;48210;48;LOZERE;1
48089;Le;Malzieu-Forain;MALZIEU-FORAIN;48140;48;LOZERE;1
48090;Le;Malzieu-Ville;MALZIEU-VILLE;48140;48;LOZERE;1
48091;;Marchastel;MARCHASTEL;48260;48;LOZERE;1
48092;;Marvejols;MARVEJOLS;48100;48;LOZERE;1
48093;;Mas-d'Orcières;MAS-D'ORCIERES;48190;48;LOZERE;1
48094;Le;Massegros;MASSEGROS;48500;48;LOZERE;1
48095;;Mende;MENDE;48000;48;LOZERE;1
48096;;Meyrueis;MEYRUEIS;48150;48;LOZERE;1
48097;;Moissac-Vallée-Française;MOISSAC-VALLEE-FRANCAISE;48110;48;LOZERE;1
48098;;Molezon;MOLEZON;48110;48;LOZERE;1
48099;Le;Monastier-Pin-Moriès;MONASTIER-PIN-MORIES;48100;48;LOZERE;1
48100;;Montbel;MONTBEL;48170;48;LOZERE;1
48101;;Montbrun;MONTBRUN;48210;48;LOZERE;1
48103;;Montrodat;MONTRODAT;48100;48;LOZERE;1
48104;;Nasbinals;NASBINALS;48260;48;LOZERE;1
48105;;Naussac;NAUSSAC;48300;48;LOZERE;1
48106;;Noalhac;NOALHAC;48310;48;LOZERE;1
48107;;Palhers;PALHERS;48100;48;LOZERE;1
48108;La;Panouse;PANOUSE;48600;48;LOZERE;1
48110;;Paulhac-en-Margeride;PAULHAC-EN-MARGERIDE;48140;48;LOZERE;1
48111;;Pelouse;PELOUSE;48000;48;LOZERE;1
48112;;Pierrefiche;PIERREFICHE;48300;48;LOZERE;1
48115;Le;Pompidou;POMPIDOU;48110;48;LOZERE;1
48116;Le;Pont-de-Montvert;PONT-DE-MONTVERT;48220;48;LOZERE;1
48117;;Pourcharesses;POURCHARESSES;48800;48;LOZERE;1
48119;;Prévenchères;PREVENCHERES;48800;48;LOZERE;1
48120;;Prinsuéjols;PRINSUEJOLS;48100;48;LOZERE;1
48121;;Prunières;PRUNIERES;48200;48;LOZERE;1
48122;;Quézac;QUEZAC;48320;48;LOZERE;1
48123;;Recoules-d'Aubrac;RECOULES-D'AUBRAC;48260;48;LOZERE;1
48124;;Recoules-de-Fumas;RECOULES-DE-FUMAS;48100;48;LOZERE;1
48125;Le;Recoux;RECOUX;48500;48;LOZERE;1
48126;;Ribennes;RIBENNES;48700;48;LOZERE;1
48127;;Rieutort-de-Randon;RIEUTORT-DE-RANDON;48700;48;LOZERE;1
48128;;Rimeize;RIMEIZE;48200;48;LOZERE;1
48129;;Rocles;ROCLES;48300;48;LOZERE;1
48130;;Rousses;ROUSSES;48400;48;LOZERE;1
48131;Le;Rozier;ROZIER;48150;48;LOZERE;1
48132;;Saint-Alban-sur-Limagnole;SAINT-ALBAN-SUR-LIMAGNOLE;48120;48;LOZERE;1
48133;;Saint-Amans;SAINT-AMANS;48700;48;LOZERE;1
48134;;Saint-Andéol-de-Clerguemort;SAINT-ANDEOL-DE-CLERGUEMORT;48160;48;LOZERE;1
48135;;Saint-André-Capcèze;SAINT-ANDRE-CAPCEZE;48800;48;LOZERE;1
48136;;Saint-André-de-Lancize;SAINT-ANDRE-DE-LANCIZE;48240;48;LOZERE;1
48137;;Saint-Bauzile;SAINT-BAUZILE;48000;48;LOZERE;1
48138;;Saint-Bonnet-de-Chirac;SAINT-BONNET-DE-CHIRAC;48100;48;LOZERE;1
48139;;Saint-Bonnet-de-Montauroux;SAINT-BONNET-DE-MONTAUROUX;48600;48;LOZERE;1
48140;;Saint-Chély-d'Apcher;SAINT-CHELY-D'APCHER;48200;48;LOZERE;1
48141;;Mas-Saint-Chély;MAS-SAINT-CHELY;48210;48;LOZERE;1
48142;;Sainte-Colombe-de-Peyre;SAINTE-COLOMBE-DE-PEYRE;48130;48;LOZERE;1
48144;;Sainte-Croix-Vallée-Française;SAINTE-CROIX-VALLEE-FRANCAISE;48110;48;LOZERE;1
48145;;Saint-Denis-en-Margeride;SAINT-DENIS-EN-MARGERIDE;48700;48;LOZERE;1
48146;;Sainte-Enimie;SAINTE-ENIMIE;48210;48;LOZERE;1
48147;;Saint-Étienne-du-Valdonnez;SAINT-ETIENNE-DU-VALDONNEZ;48000;48;LOZERE;1
48148;;Saint-Étienne-Vallée-Française;SAINT-ETIENNE-VALLEE-FRANCAISE;48330;48;LOZERE;1
48149;;Sainte-Eulalie;SAINTE-EULALIE;48120;48;LOZERE;1
48150;;Saint-Flour-de-Mercoire;SAINT-FLOUR-DE-MERCOIRE;48300;48;LOZERE;1
48151;;Saint-Frézal-d'Albuges;SAINT-FREZAL-D'ALBUGES;48170;48;LOZERE;1
48152;;Saint-Frézal-de-Ventalon;SAINT-FREZAL-DE-VENTALON;48240;48;LOZERE;1
48153;;Saint-Gal;SAINT-GAL;48700;48;LOZERE;1
48154;;Saint-Georges-de-Lévéjac;SAINT-GEORGES-DE-LEVEJAC;48500;48;LOZERE;1
48155;;Saint-Germain-de-Calberte;SAINT-GERMAIN-DE-CALBERTE;48370;48;LOZERE;1
48156;;Saint-Germain-du-Teil;SAINT-GERMAIN-DU-TEIL;48340;48;LOZERE;1
48157;;Sainte-Hélène;SAINTE-HELENE;48190;48;LOZERE;1
48158;;Saint-Hilaire-de-Lavit;SAINT-HILAIRE-DE-LAVIT;48160;48;LOZERE;1
48160;;Saint-Jean-la-Fouillouse;SAINT-JEAN-LA-FOUILLOUSE;48170;48;LOZERE;1
48161;;Saint-Juéry;SAINT-JUERY;48310;48;LOZERE;1
48162;;Saint-Julien-d'Arpaon;SAINT-JULIEN-D'ARPAON;48400;48;LOZERE;1
48163;;Saint-Julien-des-Points;SAINT-JULIEN-DES-POINTS;48160;48;LOZERE;1
48164;;Saint-Julien-du-Tournel;SAINT-JULIEN-DU-TOURNEL;48190;48;LOZERE;1
48165;;Saint-Laurent-de-Muret;SAINT-LAURENT-DE-MURET;48100;48;LOZERE;1
48166;;Saint-Laurent-de-Trèves;SAINT-LAURENT-DE-TREVES;48400;48;LOZERE;1
48167;;Saint-Laurent-de-Veyrès;SAINT-LAURENT-DE-VEYRES;48310;48;LOZERE;1
48168;;Saint-Léger-de-Peyre;SAINT-LEGER-DE-PEYRE;48100;48;LOZERE;1
48169;;Saint-Léger-du-Malzieu;SAINT-LEGER-DU-MALZIEU;48140;48;LOZERE;1
48170;;Saint-Martin-de-Boubaux;SAINT-MARTIN-DE-BOUBAUX;48160;48;LOZERE;1
48171;;Saint-Martin-de-Lansuscle;SAINT-MARTIN-DE-LANSUSCLE;48110;48;LOZERE;1
48172;;Saint-Maurice-de-Ventalon;SAINT-MAURICE-DE-VENTALON;48220;48;LOZERE;1
48173;;Saint-Michel-de-Dèze;SAINT-MICHEL-DE-DEZE;48160;48;LOZERE;1
48174;;Saint-Paul-le-Froid;SAINT-PAUL-LE-FROID;48600;48;LOZERE;1
48175;;Saint-Pierre-de-Nogaret;SAINT-PIERRE-DE-NOGARET;48340;48;LOZERE;1
48176;;Saint-Pierre-des-Tripiers;SAINT-PIERRE-DES-TRIPIERS;48150;48;LOZERE;1
48177;;Saint-Pierre-le-Vieux;SAINT-PIERRE-LE-VIEUX;48200;48;LOZERE;1
48178;;Saint-Privat-de-Vallongue;SAINT-PRIVAT-DE-VALLONGUE;48240;48;LOZERE;1
48179;;Saint-Privat-du-Fau;SAINT-PRIVAT-DU-FAU;48140;48;LOZERE;1
48180;;Saint-Rome-de-Dolan;SAINT-ROME-DE-DOLAN;48500;48;LOZERE;1
48181;;Saint-Saturnin;SAINT-SATURNIN;48500;48;LOZERE;1
48182;;Saint-Sauveur-de-Ginestoux;SAINT-SAUVEUR-DE-GINESTOUX;48170;48;LOZERE;1
48183;;Saint-Sauveur-de-Peyre;SAINT-SAUVEUR-DE-PEYRE;48130;48;LOZERE;1
48184;;Saint-Symphorien;SAINT-SYMPHORIEN;48600;48;LOZERE;1
48185;Les;Salelles;SALELLES;48230;48;LOZERE;1
48186;La;Salle-Prunet;SALLE-PRUNET;48400;48;LOZERE;1
48187;Les;Salces;SALCES;48100;48;LOZERE;1
48188;;Serverette;SERVERETTE;48700;48;LOZERE;1
48189;;Servières;SERVIERES;48000;48;LOZERE;1
48190;;Termes;TERMES;48310;48;LOZERE;1
48191;La;Tieule;TIEULE;48500;48;LOZERE;1
48192;;Trélans;TRELANS;48340;48;LOZERE;1
48193;;Vebron;VEBRON;48400;48;LOZERE;1
48194;;Vialas;VIALAS;48220;48;LOZERE;1
48195;Les;Vignes;VIGNES;48210;48;LOZERE;1
48197;La;Villedieu;VILLEDIEU;48700;48;LOZERE;1
48198;;Villefort;VILLEFORT;48800;48;LOZERE;1
49001;Les;Alleuds;ALLEUDS;49320;49;MAINE ET LOIRE;1
49002;;Allonnes;ALLONNES;49650;49;MAINE ET LOIRE;1
49003;;Ambillou-Château;AMBILLOU-CHATEAU;49700;49;MAINE ET LOIRE;1
49004;;Andard;ANDARD;49800;49;MAINE ET LOIRE;1
49005;;Andigné;ANDIGNE;49220;49;MAINE ET LOIRE;1
49006;;Andrezé;ANDREZE;49600;49;MAINE ET LOIRE;1
49007;;Angers;ANGERS;49000;49;MAINE ET LOIRE;1
49008;;Angrie;ANGRIE;49440;49;MAINE ET LOIRE;1
49009;;Antoigné;ANTOIGNE;49260;49;MAINE ET LOIRE;1
49010;;Armaillé;ARMAILLE;49420;49;MAINE ET LOIRE;1
49011;;Artannes-sur-Thouet;ARTANNES-SUR-THOUET;49260;49;MAINE ET LOIRE;1
49012;;Aubigné-sur-Layon;AUBIGNE-SUR-LAYON;49540;49;MAINE ET LOIRE;1
49013;;Auverse;AUVERSE;49490;49;MAINE ET LOIRE;1
49014;;Aviré;AVIRE;49500;49;MAINE ET LOIRE;1
49015;;Avrillé;AVRILLE;49240;49;MAINE ET LOIRE;1
49017;;Baracé;BARACE;49430;49;MAINE ET LOIRE;1
49018;;Baugé;BAUGE;49150;49;MAINE ET LOIRE;1
49019;;Bauné;BAUNE;49140;49;MAINE ET LOIRE;1
49020;;Beaucouzé;BEAUCOUZE;49070;49;MAINE ET LOIRE;1
49021;;Beaufort-en-Vallée;BEAUFORT-EN-VALLEE;49250;49;MAINE ET LOIRE;1
49022;;Beaulieu-sur-Layon;BEAULIEU-SUR-LAYON;49750;49;MAINE ET LOIRE;1
49023;;Beaupréau;BEAUPREAU;49600;49;MAINE ET LOIRE;1
49024;;Beausse;BEAUSSE;49410;49;MAINE ET LOIRE;1
49025;;Beauvau;BEAUVAU;49140;49;MAINE ET LOIRE;1
49026;;Bécon-les-Granits;BECON-LES-GRANITS;49370;49;MAINE ET LOIRE;1
49027;;Bégrolles-en-Mauges;BEGROLLES-EN-MAUGES;49122;49;MAINE ET LOIRE;1
49028;;Béhuard;BEHUARD;49170;49;MAINE ET LOIRE;1
49029;;Blaison-Gohier;BLAISON-GOHIER;49320;49;MAINE ET LOIRE;1
49030;;Blou;BLOU;49160;49;MAINE ET LOIRE;1
49031;;Bocé;BOCE;49150;49;MAINE ET LOIRE;1
49032;La;Bohalle;BOHALLE;49800;49;MAINE ET LOIRE;1
49033;La;Boissière-sur-Èvre;BOISSIERE-SUR-EVRE;49110;49;MAINE ET LOIRE;1
49034;;Botz-en-Mauges;BOTZ-EN-MAUGES;49110;49;MAINE ET LOIRE;1
49035;;Bouchemaine;BOUCHEMAINE;49080;49;MAINE ET LOIRE;1
49036;;Bouillé-Ménard;BOUILLE-MENARD;49520;49;MAINE ET LOIRE;1
49037;Le;Bourg-d'Iré;BOURG-D'IRE;49520;49;MAINE ET LOIRE;1
49038;;Bourg-l'Évêque;BOURG-L'EVEQUE;49520;49;MAINE ET LOIRE;1
49039;;Bourgneuf-en-Mauges;BOURGNEUF-EN-MAUGES;49290;49;MAINE ET LOIRE;1
49040;;Bouzillé;BOUZILLE;49530;49;MAINE ET LOIRE;1
49041;;Brain-sur-Allonnes;BRAIN-SUR-ALLONNES;49650;49;MAINE ET LOIRE;1
49042;;Brain-sur-l'Authion;BRAIN-SUR-L'AUTHION;49800;49;MAINE ET LOIRE;1
49043;;Brain-sur-Longuenée;BRAIN-SUR-LONGUENEE;49220;49;MAINE ET LOIRE;1
49044;;Breil;BREIL;49490;49;MAINE ET LOIRE;1
49045;La;Breille-les-Pins;BREILLE-LES-PINS;49390;49;MAINE ET LOIRE;1
49046;;Brézé;BREZE;49260;49;MAINE ET LOIRE;1
49047;;Brigné;BRIGNE;49700;49;MAINE ET LOIRE;1
49048;;Briollay;BRIOLLAY;49125;49;MAINE ET LOIRE;1
49049;;Brion;BRION;49250;49;MAINE ET LOIRE;1
49050;;Brissac-Quincé;BRISSAC-QUINCE;49320;49;MAINE ET LOIRE;1
49051;;Brissarthe;BRISSARTHE;49330;49;MAINE ET LOIRE;1
49052;;Broc;BROC;49490;49;MAINE ET LOIRE;1
49053;;Brossay;BROSSAY;49700;49;MAINE ET LOIRE;1
49054;;Candé;CANDE;49440;49;MAINE ET LOIRE;1
49055;;Cantenay-Épinard;CANTENAY-EPINARD;49460;49;MAINE ET LOIRE;1
49056;;Carbay;CARBAY;49420;49;MAINE ET LOIRE;1
49057;;Cernusson;CERNUSSON;49310;49;MAINE ET LOIRE;1
49058;Les;Cerqueux;CERQUEUX;49360;49;MAINE ET LOIRE;1
49059;Les;Cerqueux-sous-Passavant;CERQUEUX-SOUS-PASSAVANT;49310;49;MAINE ET LOIRE;1
49060;;Chacé;CHACE;49400;49;MAINE ET LOIRE;1
49061;;Challain-la-Potherie;CHALLAIN-LA-POTHERIE;49440;49;MAINE ET LOIRE;1
49062;;Chalonnes-sous-le-Lude;CHALONNES-SOUS-LE-LUDE;49490;49;MAINE ET LOIRE;1
49063;;Chalonnes-sur-Loire;CHALONNES-SUR-LOIRE;49290;49;MAINE ET LOIRE;1
49064;;Chambellay;CHAMBELLAY;49220;49;MAINE ET LOIRE;1
49065;;Champigné;CHAMPIGNE;49330;49;MAINE ET LOIRE;1
49066;;Champ-sur-Layon;CHAMP-SUR-LAYON;49380;49;MAINE ET LOIRE;1
49067;;Champteussé-sur-Baconne;CHAMPTEUSSE-SUR-BACONNE;49220;49;MAINE ET LOIRE;1
49068;;Champtocé-sur-Loire;CHAMPTOCE-SUR-LOIRE;49123;49;MAINE ET LOIRE;1
49069;;Champtoceaux;CHAMPTOCEAUX;49270;49;MAINE ET LOIRE;1
49070;;Chanteloup-les-Bois;CHANTELOUP-LES-BOIS;49340;49;MAINE ET LOIRE;1
49071;;Chanzeaux;CHANZEAUX;49750;49;MAINE ET LOIRE;1
49072;La;Chapelle-du-Genêt;CHAPELLE-DU-GENET;49600;49;MAINE ET LOIRE;1
49073;La;Chapelle-Hullin;CHAPELLE-HULLIN;49860;49;MAINE ET LOIRE;1
49074;La;Chapelle-Rousselin;CHAPELLE-ROUSSELIN;49120;49;MAINE ET LOIRE;1
49075;La;Chapelle-Saint-Florent;CHAPELLE-SAINT-FLORENT;49410;49;MAINE ET LOIRE;1
49076;La;Chapelle-Saint-Laud;CHAPELLE-SAINT-LAUD;49140;49;MAINE ET LOIRE;1
49077;La;Chapelle-sur-Oudon;CHAPELLE-SUR-OUDON;49500;49;MAINE ET LOIRE;1
49078;;Charcé-Saint-Ellier-sur-Aubance;CHARCE-SAINT-ELLIER-SUR-AUBANCE;49320;49;MAINE ET LOIRE;1
49079;;Chartrené;CHARTRENE;49150;49;MAINE ET LOIRE;1
49080;;Châteauneuf-sur-Sarthe;CHATEAUNEUF-SUR-SARTHE;49330;49;MAINE ET LOIRE;1
49081;;Châtelais;CHATELAIS;49520;49;MAINE ET LOIRE;1
49082;;Chaudefonds-sur-Layon;CHAUDEFONDS-SUR-LAYON;49290;49;MAINE ET LOIRE;1
49083;;Chaudron-en-Mauges;CHAUDRON-EN-MAUGES;49110;49;MAINE ET LOIRE;1
49084;;Chaumont-d'Anjou;CHAUMONT-D'ANJOU;49140;49;MAINE ET LOIRE;1
49085;La;Chaussaire;CHAUSSAIRE;49600;49;MAINE ET LOIRE;1
49086;;Chavagnes;CHAVAGNES;49380;49;MAINE ET LOIRE;1
49087;;Chavaignes;CHAVAIGNES;49490;49;MAINE ET LOIRE;1
49088;;Chazé-Henry;CHAZE-HENRY;49860;49;MAINE ET LOIRE;1
49089;;Chazé-sur-Argos;CHAZE-SUR-ARGOS;49500;49;MAINE ET LOIRE;1
49090;;Cheffes;CHEFFES;49125;49;MAINE ET LOIRE;1
49091;;Chemellier;CHEMELLIER;49320;49;MAINE ET LOIRE;1
49092;;Chemillé;CHEMILLE;49120;49;MAINE ET LOIRE;1
49093;;Chemiré-sur-Sarthe;CHEMIRE-SUR-SARTHE;49640;49;MAINE ET LOIRE;1
49094;;Chênehutte-Trèves-Cunault;CHENEHUTTE-TREVES-CUNAULT;49350;49;MAINE ET LOIRE;1
49095;;Chenillé-Changé;CHENILLE-CHANGE;49220;49;MAINE ET LOIRE;1
49096;;Cherré;CHERRE;49330;49;MAINE ET LOIRE;1
49097;;Cheviré-le-Rouge;CHEVIRE-LE-ROUGE;49150;49;MAINE ET LOIRE;1
49098;;Chigné;CHIGNE;49490;49;MAINE ET LOIRE;1
49099;;Cholet;CHOLET;49300;49;MAINE ET LOIRE;1
49100;;Cizay-la-Madeleine;CIZAY-LA-MADELEINE;49700;49;MAINE ET LOIRE;1
49101;;Clefs;CLEFS;49150;49;MAINE ET LOIRE;1
49102;;Cléré-sur-Layon;CLERE-SUR-LAYON;49560;49;MAINE ET LOIRE;1
49103;;Combrée;COMBREE;49520;49;MAINE ET LOIRE;1
49104;;Concourson-sur-Layon;CONCOURSON-SUR-LAYON;49700;49;MAINE ET LOIRE;1
49105;;Contigné;CONTIGNE;49330;49;MAINE ET LOIRE;1
49106;;Corné;CORNE;49250;49;MAINE ET LOIRE;1
49107;;Cornillé-les-Caves;CORNILLE-LES-CAVES;49140;49;MAINE ET LOIRE;1
49108;La;Cornuaille;CORNUAILLE;49440;49;MAINE ET LOIRE;1
49109;;Coron;CORON;49690;49;MAINE ET LOIRE;1
49110;;Corzé;CORZE;49140;49;MAINE ET LOIRE;1
49111;;Cossé-d'Anjou;COSSE-D'ANJOU;49120;49;MAINE ET LOIRE;1
49112;Le;Coudray-Macouard;COUDRAY-MACOUARD;49260;49;MAINE ET LOIRE;1
49113;;Courchamps;COURCHAMPS;49260;49;MAINE ET LOIRE;1
49114;;Courléon;COURLEON;49390;49;MAINE ET LOIRE;1
49115;;Coutures;COUTURES;49320;49;MAINE ET LOIRE;1
49116;;Cuon;CUON;49150;49;MAINE ET LOIRE;1
49117;La;Daguenière;DAGUENIERE;49800;49;MAINE ET LOIRE;1
49119;;Daumeray;DAUMERAY;49640;49;MAINE ET LOIRE;1
49120;;Denée;DENEE;49190;49;MAINE ET LOIRE;1
49121;;Dénezé-sous-Doué;DENEZE-SOUS-DOUE;49700;49;MAINE ET LOIRE;1
49122;;Dénezé-sous-le-Lude;DENEZE-SOUS-LE-LUDE;49490;49;MAINE ET LOIRE;1
49123;;Distré;DISTRE;49400;49;MAINE ET LOIRE;1
49125;;Doué-la-Fontaine;DOUE-LA-FONTAINE;49700;49;MAINE ET LOIRE;1
49126;;Drain;DRAIN;49530;49;MAINE ET LOIRE;1
49127;;Durtal;DURTAL;49430;49;MAINE ET LOIRE;1
49128;;Échemiré;ECHEMIRE;49150;49;MAINE ET LOIRE;1
49129;;Écouflant;ECOUFLANT;49000;49;MAINE ET LOIRE;1
49130;;Écuillé;ECUILLE;49460;49;MAINE ET LOIRE;1
49131;;Épieds;EPIEDS;49260;49;MAINE ET LOIRE;1
49132;;Étriché;ETRICHE;49330;49;MAINE ET LOIRE;1
49133;;Faveraye-Mâchelles;FAVERAYE-MACHELLES;49380;49;MAINE ET LOIRE;1
49134;;Faye-d'Anjou;FAYE-D'ANJOU;49380;49;MAINE ET LOIRE;1
49135;;Feneu;FENEU;49460;49;MAINE ET LOIRE;1
49136;La;Ferrière-de-Flée;FERRIERE-DE-FLEE;49500;49;MAINE ET LOIRE;1
49137;Le;Fief-Sauvin;FIEF-SAUVIN;49600;49;MAINE ET LOIRE;1
49138;;Fontaine-Guérin;FONTAINE-GUERIN;49250;49;MAINE ET LOIRE;1
49139;;Fontaine-Milon;FONTAINE-MILON;49140;49;MAINE ET LOIRE;1
49140;;Fontevraud-l'Abbaye;FONTEVRAUD-L'ABBAYE;49590;49;MAINE ET LOIRE;1
49141;;Forges;FORGES;49700;49;MAINE ET LOIRE;1
49142;La;Fosse-de-Tigné;FOSSE-DE-TIGNE;49540;49;MAINE ET LOIRE;1
49143;;Fougeré;FOUGERE;49150;49;MAINE ET LOIRE;1
49144;;Freigné;FREIGNE;49440;49;MAINE ET LOIRE;1
49145;Le;Fuilet;FUILET;49270;49;MAINE ET LOIRE;1
49147;;Gée;GEE;49250;49;MAINE ET LOIRE;1
49148;;Gené;GENE;49220;49;MAINE ET LOIRE;1
49149;;Gennes;GENNES;49350;49;MAINE ET LOIRE;1
49150;;Genneteil;GENNETEIL;49490;49;MAINE ET LOIRE;1
49151;;Gesté;GESTE;49600;49;MAINE ET LOIRE;1
49153;;Valanjou;VALANJOU;49670;49;MAINE ET LOIRE;1
49154;;Grézillé;GREZILLE;49320;49;MAINE ET LOIRE;1
49155;;Grez-Neuville;GREZ-NEUVILLE;49220;49;MAINE ET LOIRE;1
49156;;Grugé-l'Hôpital;GRUGE-L'HOPITAL;49520;49;MAINE ET LOIRE;1
49157;Le;Guédeniau;GUEDENIAU;49150;49;MAINE ET LOIRE;1
49158;L';Hôtellerie-de-Flée;HOTELLERIE-DE-FLEE;49500;49;MAINE ET LOIRE;1
49159;;Huillé;HUILLE;49430;49;MAINE ET LOIRE;1
49160;;Ingrandes;INGRANDES;49123;49;MAINE ET LOIRE;1
49161;La;Jaille-Yvon;JAILLE-YVON;49220;49;MAINE ET LOIRE;1
49162;;Jallais;JALLAIS;49510;49;MAINE ET LOIRE;1
49163;;Jarzé;JARZE;49140;49;MAINE ET LOIRE;1
49165;La;Jubaudière;JUBAUDIERE;49510;49;MAINE ET LOIRE;1
49167;;Juigné-sur-Loire;JUIGNE-SUR-LOIRE;49610;49;MAINE ET LOIRE;1
49169;La;Jumellière;JUMELLIERE;49120;49;MAINE ET LOIRE;1
49170;;Juvardeil;JUVARDEIL;49330;49;MAINE ET LOIRE;1
49171;La;Lande-Chasles;LANDE-CHASLES;49150;49;MAINE ET LOIRE;1
49172;;Landemont;LANDEMONT;49270;49;MAINE ET LOIRE;1
49173;;Lasse;LASSE;49490;49;MAINE ET LOIRE;1
49174;;Lézigné;LEZIGNE;49430;49;MAINE ET LOIRE;1
49175;;Linières-Bouton;LINIERES-BOUTON;49490;49;MAINE ET LOIRE;1
49176;Le;Lion-d'Angers;LION-D'ANGERS;49220;49;MAINE ET LOIRE;1
49177;;Liré;LIRE;49530;49;MAINE ET LOIRE;1
49178;;Loiré;LOIRE;49440;49;MAINE ET LOIRE;1
49179;Le;Longeron;LONGERON;49710;49;MAINE ET LOIRE;1
49180;;Longué-Jumelles;LONGUE-JUMELLES;49160;49;MAINE ET LOIRE;1
49181;;Louerre;LOUERRE;49700;49;MAINE ET LOIRE;1
49182;;Louresse-Rochemenier;LOURESSE-ROCHEMENIER;49700;49;MAINE ET LOIRE;1
49183;Le;Louroux-Béconnais;LOUROUX-BECONNAIS;49370;49;MAINE ET LOIRE;1
49184;;Louvaines;LOUVAINES;49500;49;MAINE ET LOIRE;1
49185;;Lué-en-Baugeois;LUE-EN-BAUGEOIS;49140;49;MAINE ET LOIRE;1
49186;;Luigné;LUIGNE;49320;49;MAINE ET LOIRE;1
49187;;Marans;MARANS;49500;49;MAINE ET LOIRE;1
49188;;Marcé;MARCE;49140;49;MAINE ET LOIRE;1
49189;;Marigné;MARIGNE;49330;49;MAINE ET LOIRE;1
49190;Le;Marillais;MARILLAIS;49410;49;MAINE ET LOIRE;1
49191;;Martigné-Briand;MARTIGNE-BRIAND;49540;49;MAINE ET LOIRE;1
49192;;Maulévrier;MAULEVRIER;49360;49;MAINE ET LOIRE;1
49193;Le;May-sur-Èvre;MAY-SUR-EVRE;49122;49;MAINE ET LOIRE;1
49194;;Mazé;MAZE;49250;49;MAINE ET LOIRE;1
49195;;Mazières-en-Mauges;MAZIERES-EN-MAUGES;49280;49;MAINE ET LOIRE;1
49196;La;Meignanne;MEIGNANNE;49220;49;MAINE ET LOIRE;1
49197;;Meigné-le-Vicomte;MEIGNE-LE-VICOMTE;49490;49;MAINE ET LOIRE;1
49198;;Meigné;MEIGNE;49700;49;MAINE ET LOIRE;1
49199;;Melay;MELAY;49120;49;MAINE ET LOIRE;1
49200;La;Membrolle-sur-Longuenée;MEMBROLLE-SUR-LONGUENEE;49220;49;MAINE ET LOIRE;1
49201;La;Ménitré;MENITRE;49250;49;MAINE ET LOIRE;1
49202;;Méon;MEON;49490;49;MAINE ET LOIRE;1
49204;Le;Mesnil-en-Vallée;MESNIL-EN-VALLEE;49410;49;MAINE ET LOIRE;1
49205;;Miré;MIRE;49330;49;MAINE ET LOIRE;1
49206;;Montfaucon-Montigné;MONTFAUCON-MONTIGNE;49230;49;MAINE ET LOIRE;1
49207;;Montfort;MONTFORT;49700;49;MAINE ET LOIRE;1
49208;;Montguillon;MONTGUILLON;49500;49;MAINE ET LOIRE;1
49209;;Montigné-lès-Rairies;MONTIGNE-LES-RAIRIES;49430;49;MAINE ET LOIRE;1
49211;;Montilliers;MONTILLIERS;49310;49;MAINE ET LOIRE;1
49212;;Montjean-sur-Loire;MONTJEAN-SUR-LOIRE;49570;49;MAINE ET LOIRE;1
49213;;Montpollin;MONTPOLLIN;49150;49;MAINE ET LOIRE;1
49214;;Montreuil-Juigné;MONTREUIL-JUIGNE;49460;49;MAINE ET LOIRE;1
49215;;Montreuil-Bellay;MONTREUIL-BELLAY;49260;49;MAINE ET LOIRE;1
49216;;Montreuil-sur-Loir;MONTREUIL-SUR-LOIR;49140;49;MAINE ET LOIRE;1
49217;;Montreuil-sur-Maine;MONTREUIL-SUR-MAINE;49220;49;MAINE ET LOIRE;1
49218;;Montrevault;MONTREVAULT;49110;49;MAINE ET LOIRE;1
49219;;Montsoreau;MONTSOREAU;49730;49;MAINE ET LOIRE;1
49220;;Morannes;MORANNES;49640;49;MAINE ET LOIRE;1
49221;;Mouliherne;MOULIHERNE;49390;49;MAINE ET LOIRE;1
49222;;Mozé-sur-Louet;MOZE-SUR-LOUET;49610;49;MAINE ET LOIRE;1
49223;;Mûrs-Erigné;MURS-ERIGNE;49130;49;MAINE ET LOIRE;1
49224;;Neuillé;NEUILLE;49680;49;MAINE ET LOIRE;1
49225;;Neuvy-en-Mauges;NEUVY-EN-MAUGES;49120;49;MAINE ET LOIRE;1
49226;;Noëllet;NOELLET;49520;49;MAINE ET LOIRE;1
49227;;Notre-Dame-d'Allençon;NOTRE-DAME-D'ALLENCON;49380;49;MAINE ET LOIRE;1
49228;;Noyant;NOYANT;49490;49;MAINE ET LOIRE;1
49229;;Noyant-la-Gravoyère;NOYANT-LA-GRAVOYERE;49520;49;MAINE ET LOIRE;1
49230;;Noyant-la-Plaine;NOYANT-LA-PLAINE;49700;49;MAINE ET LOIRE;1
49231;;Nuaillé;NUAILLE;49340;49;MAINE ET LOIRE;1
49232;;Nueil-sur-Layon;NUEIL-SUR-LAYON;49560;49;MAINE ET LOIRE;1
49233;;Nyoiseau;NYOISEAU;49500;49;MAINE ET LOIRE;1
49234;;Parçay-les-Pins;PARCAY-LES-PINS;49390;49;MAINE ET LOIRE;1
49235;;Parnay;PARNAY;49730;49;MAINE ET LOIRE;1
49236;;Passavant-sur-Layon;PASSAVANT-SUR-LAYON;49560;49;MAINE ET LOIRE;1
49237;La;Pellerine;PELLERINE;49490;49;MAINE ET LOIRE;1
49238;;Pellouailles-les-Vignes;PELLOUAILLES-LES-VIGNES;49112;49;MAINE ET LOIRE;1
49239;Le;Pin-en-Mauges;PIN-EN-MAUGES;49110;49;MAINE ET LOIRE;1
49240;La;Plaine;PLAINE;49360;49;MAINE ET LOIRE;1
49241;Le;Plessis-Grammoire;PLESSIS-GRAMMOIRE;49124;49;MAINE ET LOIRE;1
49242;Le;Plessis-Macé;PLESSIS-MACE;49220;49;MAINE ET LOIRE;1
49243;La;Poitevinière;POITEVINIERE;49510;49;MAINE ET LOIRE;1
49244;La;Pommeraye;POMMERAYE;49620;49;MAINE ET LOIRE;1
49245;;Pontigné;PONTIGNE;49150;49;MAINE ET LOIRE;1
49246;Les;Ponts-de-Cé;PONTS-DE-CE;49130;49;MAINE ET LOIRE;1
49247;La;Possonnière;POSSONNIERE;49170;49;MAINE ET LOIRE;1
49248;;Pouancé;POUANCE;49420;49;MAINE ET LOIRE;1
49249;La;Pouëze;POUEZE;49370;49;MAINE ET LOIRE;1
49250;La;Prévière;PREVIERE;49420;49;MAINE ET LOIRE;1
49251;;Pruillé;PRUILLE;49220;49;MAINE ET LOIRE;1
49252;Le;Puiset-Doré;PUISET-DORE;49600;49;MAINE ET LOIRE;1
49253;Le;Puy-Notre-Dame;PUY-NOTRE-DAME;49260;49;MAINE ET LOIRE;1
49254;;Querré;QUERRE;49330;49;MAINE ET LOIRE;1
49256;;Rablay-sur-Layon;RABLAY-SUR-LAYON;49750;49;MAINE ET LOIRE;1
49257;Les;Rairies;RAIRIES;49430;49;MAINE ET LOIRE;1
49258;La;Renaudière;RENAUDIERE;49450;49;MAINE ET LOIRE;1
49259;;Rochefort-sur-Loire;ROCHEFORT-SUR-LOIRE;49190;49;MAINE ET LOIRE;1
49260;La;Romagne;ROMAGNE;49740;49;MAINE ET LOIRE;1
49261;Les;Rosiers-sur-Loire;ROSIERS-SUR-LOIRE;49350;49;MAINE ET LOIRE;1
49262;;Rou-Marson;ROU-MARSON;49400;49;MAINE ET LOIRE;1
49263;;Roussay;ROUSSAY;49450;49;MAINE ET LOIRE;1
49264;;Saint-André-de-la-Marche;SAINT-ANDRE-DE-LA-MARCHE;49450;49;MAINE ET LOIRE;1
49265;;Saint-Aubin-de-Luigné;SAINT-AUBIN-DE-LUIGNE;49190;49;MAINE ET LOIRE;1
49266;;Saint-Augustin-des-Bois;SAINT-AUGUSTIN-DES-BOIS;49170;49;MAINE ET LOIRE;1
49267;;Saint-Barthélemy-d'Anjou;SAINT-BARTHELEMY-D'ANJOU;49124;49;MAINE ET LOIRE;1
49268;;Sainte-Christine;SAINTE-CHRISTINE;49120;49;MAINE ET LOIRE;1
49269;;Saint-Christophe-du-Bois;SAINT-CHRISTOPHE-DU-BOIS;49280;49;MAINE ET LOIRE;1
49270;;Saint-Christophe-la-Couperie;SAINT-CHRISTOPHE-LA-COUPERIE;49270;49;MAINE ET LOIRE;1
49271;;Saint-Clément-de-la-Place;SAINT-CLEMENT-DE-LA-PLACE;49370;49;MAINE ET LOIRE;1
49272;;Saint-Clément-des-Levées;SAINT-CLEMENT-DES-LEVEES;49350;49;MAINE ET LOIRE;1
49273;;Saint-Crespin-sur-Moine;SAINT-CRESPIN-SUR-MOINE;49230;49;MAINE ET LOIRE;1
49274;;Saint-Cyr-en-Bourg;SAINT-CYR-EN-BOURG;49260;49;MAINE ET LOIRE;1
49276;;Saint-Florent-le-Vieil;SAINT-FLORENT-LE-VIEIL;49410;49;MAINE ET LOIRE;1
49277;;Sainte-Gemmes-d'Andigné;SAINTE-GEMMES-D'ANDIGNE;49500;49;MAINE ET LOIRE;1
49278;;Sainte-Gemmes-sur-Loire;SAINTE-GEMMES-SUR-LOIRE;49130;49;MAINE ET LOIRE;1
49279;;Saint-Georges-des-Sept-Voies;SAINT-GEORGES-DES-SEPT-VOIES;49350;49;MAINE ET LOIRE;1
49280;;Saint-Georges-du-Bois;SAINT-GEORGES-DU-BOIS;49250;49;MAINE ET LOIRE;1
49281;;Saint-Georges-des-Gardes;SAINT-GEORGES-DES-GARDES;49120;49;MAINE ET LOIRE;1
49282;;Saint-Georges-sur-Layon;SAINT-GEORGES-SUR-LAYON;49700;49;MAINE ET LOIRE;1
49283;;Saint-Georges-sur-Loire;SAINT-GEORGES-SUR-LOIRE;49170;49;MAINE ET LOIRE;1
49284;;Saint-Germain-des-Prés;SAINT-GERMAIN-DES-PRES;49170;49;MAINE ET LOIRE;1
49285;;Saint-Germain-sur-Moine;SAINT-GERMAIN-SUR-MOINE;49230;49;MAINE ET LOIRE;1
49288;;Saint-Jean-de-la-Croix;SAINT-JEAN-DE-LA-CROIX;49130;49;MAINE ET LOIRE;1
49289;;Saint-Jean-de-Linières;SAINT-JEAN-DE-LINIERES;49070;49;MAINE ET LOIRE;1
49290;;Saint-Jean-des-Mauvrets;SAINT-JEAN-DES-MAUVRETS;49320;49;MAINE ET LOIRE;1
49291;;Saint-Just-sur-Dive;SAINT-JUST-SUR-DIVE;49260;49;MAINE ET LOIRE;1
49292;;Saint-Lambert-du-Lattay;SAINT-LAMBERT-DU-LATTAY;49750;49;MAINE ET LOIRE;1
49294;;Saint-Lambert-la-Potherie;SAINT-LAMBERT-LA-POTHERIE;49070;49;MAINE ET LOIRE;1
49295;;Saint-Laurent-de-la-Plaine;SAINT-LAURENT-DE-LA-PLAINE;49290;49;MAINE ET LOIRE;1
49296;;Saint-Laurent-des-Autels;SAINT-LAURENT-DES-AUTELS;49270;49;MAINE ET LOIRE;1
49297;;Saint-Laurent-du-Mottay;SAINT-LAURENT-DU-MOTTAY;49410;49;MAINE ET LOIRE;1
49298;;Saint-Léger-des-Bois;SAINT-LEGER-DES-BOIS;49170;49;MAINE ET LOIRE;1
49299;;Saint-Léger-sous-Cholet;SAINT-LEGER-SOUS-CHOLET;49280;49;MAINE ET LOIRE;1
49300;;Saint-Lézin;SAINT-LEZIN;49120;49;MAINE ET LOIRE;1
49301;;Saint-Macaire-en-Mauges;SAINT-MACAIRE-EN-MAUGES;49450;49;MAINE ET LOIRE;1
49302;;Saint-Macaire-du-Bois;SAINT-MACAIRE-DU-BOIS;49260;49;MAINE ET LOIRE;1
49303;;Saint-Martin-d'Arcé;SAINT-MARTIN-D'ARCE;49150;49;MAINE ET LOIRE;1
49304;;Saint-Martin-de-la-Place;SAINT-MARTIN-DE-LA-PLACE;49160;49;MAINE ET LOIRE;1
49305;;Saint-Martin-du-Bois;SAINT-MARTIN-DU-BOIS;49500;49;MAINE ET LOIRE;1
49306;;Saint-Martin-du-Fouilloux;SAINT-MARTIN-DU-FOUILLOUX;49170;49;MAINE ET LOIRE;1
49307;;Saint-Mathurin-sur-Loire;SAINT-MATHURIN-SUR-LOIRE;49250;49;MAINE ET LOIRE;1
49308;;Saint-Melaine-sur-Aubance;SAINT-MELAINE-SUR-AUBANCE;49610;49;MAINE ET LOIRE;1
49309;;Saint-Michel-et-Chanveaux;SAINT-MICHEL-ET-CHANVEAUX;49420;49;MAINE ET LOIRE;1
49310;;Saint-Paul-du-Bois;SAINT-PAUL-DU-BOIS;49310;49;MAINE ET LOIRE;1
49311;;Saint-Philbert-du-Peuple;SAINT-PHILBERT-DU-PEUPLE;49160;49;MAINE ET LOIRE;1
49312;;Saint-Philbert-en-Mauges;SAINT-PHILBERT-EN-MAUGES;49600;49;MAINE ET LOIRE;1
49313;;Saint-Pierre-Montlimart;SAINT-PIERRE-MONTLIMART;49110;49;MAINE ET LOIRE;1
49314;;Saint-Quentin-en-Mauges;SAINT-QUENTIN-EN-MAUGES;49110;49;MAINE ET LOIRE;1
49315;;Saint-Quentin-lès-Beaurepaire;SAINT-QUENTIN-LES-BEAUREPAIRE;49150;49;MAINE ET LOIRE;1
49316;;Saint-Rémy-en-Mauges;SAINT-REMY-EN-MAUGES;49110;49;MAINE ET LOIRE;1
49317;;Saint-Rémy-la-Varenne;SAINT-REMY-LA-VARENNE;49250;49;MAINE ET LOIRE;1
49318;;Saint-Saturnin-sur-Loire;SAINT-SATURNIN-SUR-LOIRE;49320;49;MAINE ET LOIRE;1
49319;;Saint-Sauveur-de-Flée;SAINT-SAUVEUR-DE-FLEE;49500;49;MAINE ET LOIRE;1
49320;;Saint-Sauveur-de-Landemont;SAINT-SAUVEUR-DE-LANDEMONT;49270;49;MAINE ET LOIRE;1
49321;;Saint-Sigismond;SAINT-SIGISMOND;49123;49;MAINE ET LOIRE;1
49322;;Saint-Sulpice;SAINT-SULPICE;49320;49;MAINE ET LOIRE;1
49323;;Saint-Sylvain-d'Anjou;SAINT-SYLVAIN-D'ANJOU;49480;49;MAINE ET LOIRE;1
49324;La;Salle-et-Chapelle-Aubry;SALLE-ET-CHAPELLE-AUBRY;49110;49;MAINE ET LOIRE;1
49325;La;Salle-de-Vihiers;SALLE-DE-VIHIERS;49310;49;MAINE ET LOIRE;1
49326;;Sarrigné;SARRIGNE;49800;49;MAINE ET LOIRE;1
49327;;Saulgé-l'Hôpital;SAULGE-L'HOPITAL;49320;49;MAINE ET LOIRE;1
49328;;Saumur;SAUMUR;49400;49;MAINE ET LOIRE;1
49329;;Savennières;SAVENNIERES;49170;49;MAINE ET LOIRE;1
49330;;Sceaux-d'Anjou;SCEAUX-D'ANJOU;49330;49;MAINE ET LOIRE;1
49331;;Segré;SEGRE;49500;49;MAINE ET LOIRE;1
49332;La;Séguinière;SEGUINIERE;49280;49;MAINE ET LOIRE;1
49333;;Seiches-sur-le-Loir;SEICHES-SUR-LE-LOIR;49140;49;MAINE ET LOIRE;1
49334;;Sermaise;SERMAISE;49140;49;MAINE ET LOIRE;1
49335;;Sœurdres;SOEURDRES;49330;49;MAINE ET LOIRE;1
49336;;Somloire;SOMLOIRE;49360;49;MAINE ET LOIRE;1
49337;;Soucelles;SOUCELLES;49140;49;MAINE ET LOIRE;1
49338;;Soulaines-sur-Aubance;SOULAINES-SUR-AUBANCE;49610;49;MAINE ET LOIRE;1
49339;;Soulaire-et-Bourg;SOULAIRE-ET-BOURG;49460;49;MAINE ET LOIRE;1
49341;;Souzay-Champigny;SOUZAY-CHAMPIGNY;49400;49;MAINE ET LOIRE;1
49342;;Tancoigné;TANCOIGNE;49310;49;MAINE ET LOIRE;1
49343;La;Tessoualle;TESSOUALLE;49280;49;MAINE ET LOIRE;1
49344;;Thorigné-d'Anjou;THORIGNE-D'ANJOU;49220;49;MAINE ET LOIRE;1
49345;;Thouarcé;THOUARCE;49380;49;MAINE ET LOIRE;1
49346;Le;Thoureil;THOUREIL;49350;49;MAINE ET LOIRE;1
49347;;Tiercé;TIERCE;49125;49;MAINE ET LOIRE;1
49348;;Tigné;TIGNE;49540;49;MAINE ET LOIRE;1
49349;;Tillières;TILLIERES;49230;49;MAINE ET LOIRE;1
49350;;Torfou;TORFOU;49660;49;MAINE ET LOIRE;1
49351;La;Tourlandry;TOURLANDRY;49120;49;MAINE ET LOIRE;1
49352;;Toutlemonde;TOUTLEMONDE;49360;49;MAINE ET LOIRE;1
49353;;Trélazé;TRELAZE;49800;49;MAINE ET LOIRE;1
49354;Le;Tremblay;TREMBLAY;49520;49;MAINE ET LOIRE;1
49355;;Trémentines;TREMENTINES;49340;49;MAINE ET LOIRE;1
49356;;Trémont;TREMONT;49310;49;MAINE ET LOIRE;1
49358;;Turquant;TURQUANT;49730;49;MAINE ET LOIRE;1
49359;Les;Ulmes;ULMES;49700;49;MAINE ET LOIRE;1
49360;La;Varenne;VARENNE;49270;49;MAINE ET LOIRE;1
49361;;Varennes-sur-Loire;VARENNES-SUR-LOIRE;49730;49;MAINE ET LOIRE;1
49362;;Varrains;VARRAINS;49400;49;MAINE ET LOIRE;1
49363;;Vauchrétien;VAUCHRETIEN;49320;49;MAINE ET LOIRE;1
49364;;Vaudelnay;VAUDELNAY;49260;49;MAINE ET LOIRE;1
49365;Les;Verchers-sur-Layon;VERCHERS-SUR-LAYON;49700;49;MAINE ET LOIRE;1
49366;;Vergonnes;VERGONNES;49420;49;MAINE ET LOIRE;1
49367;;Vern-d'Anjou;VERN-D'ANJOU;49220;49;MAINE ET LOIRE;1
49368;;Vernantes;VERNANTES;49390;49;MAINE ET LOIRE;1
49369;;Vernoil-le-Fourrier;VERNOIL-LE-FOURRIER;49390;49;MAINE ET LOIRE;1
49370;;Verrie;VERRIE;49400;49;MAINE ET LOIRE;1
49371;;Vezins;VEZINS;49340;49;MAINE ET LOIRE;1
49372;Le;Vieil-Baugé;VIEIL-BAUGE;49150;49;MAINE ET LOIRE;1
49373;;Vihiers;VIHIERS;49310;49;MAINE ET LOIRE;1
49374;;Villebernier;VILLEBERNIER;49400;49;MAINE ET LOIRE;1
49375;;Villedieu-la-Blouère;VILLEDIEU-LA-BLOUERE;49450;49;MAINE ET LOIRE;1
49376;;Villemoisan;VILLEMOISAN;49370;49;MAINE ET LOIRE;1
49377;;Villevêque;VILLEVEQUE;49140;49;MAINE ET LOIRE;1
49378;;Vivy;VIVY;49680;49;MAINE ET LOIRE;1
49380;;Vaulandry;VAULANDRY;49150;49;MAINE ET LOIRE;1
49381;;Yzernay;YZERNAY;49360;49;MAINE ET LOIRE;1
50001;;Acqueville;ACQUEVILLE;50440;50;MANCHE;1
50002;;Agneaux;AGNEAUX;50180;50;MANCHE;1
50003;;Agon-Coutainville;AGON-COUTAINVILLE;50230;50;MANCHE;1
50004;;Airel;AIREL;50680;50;MANCHE;1
50005;;Amfreville;AMFREVILLE;50480;50;MANCHE;1
50006;;Amigny;AMIGNY;50620;50;MANCHE;1
50007;;Ancteville;ANCTEVILLE;50200;50;MANCHE;1
50008;;Anctoville-sur-Boscq;ANCTOVILLE-SUR-BOSCQ;50400;50;MANCHE;1
50009;;Angey;ANGEY;50530;50;MANCHE;1
50010;;Angoville-au-Plain;ANGOVILLE-AU-PLAIN;50480;50;MANCHE;1
50012;;Angoville-sur-Ay;ANGOVILLE-SUR-AY;50430;50;MANCHE;1
50013;;Anneville-en-Saire;ANNEVILLE-EN-SAIRE;50760;50;MANCHE;1
50014;;Anneville-sur-Mer;ANNEVILLE-SUR-MER;50560;50;MANCHE;1
50015;;Annoville;ANNOVILLE;50660;50;MANCHE;1
50016;;Appeville;APPEVILLE;50500;50;MANCHE;1
50018;;Argouges;ARGOUGES;50240;50;MANCHE;1
50019;;Aucey-la-Plaine;AUCEY-LA-PLAINE;50170;50;MANCHE;1
50020;;Auderville;AUDERVILLE;50440;50;MANCHE;1
50021;;Audouville-la-Hubert;AUDOUVILLE-LA-HUBERT;50480;50;MANCHE;1
50022;;Aumeville-Lestre;AUMEVILLE-LESTRE;50630;50;MANCHE;1
50023;;Auvers;AUVERS;50500;50;MANCHE;1
50024;;Auxais;AUXAIS;50500;50;MANCHE;1
50025;;Avranches;AVRANCHES;50300;50;MANCHE;1
50026;;Azeville;AZEVILLE;50310;50;MANCHE;1
50027;;Bacilly;BACILLY;50530;50;MANCHE;1
50028;La;Baleine;BALEINE;50450;50;MANCHE;1
50029;;Barenton;BARENTON;50720;50;MANCHE;1
50030;;Barfleur;BARFLEUR;50760;50;MANCHE;1
50031;;Barneville-Carteret;BARNEVILLE-CARTERET;50270;50;MANCHE;1
50032;La;Barre-de-Semilly;BARRE-DE-SEMILLY;50810;50;MANCHE;1
50033;;Baubigny;BAUBIGNY;50270;50;MANCHE;1
50034;;Baudre;BAUDRE;50000;50;MANCHE;1
50035;;Baudreville;BAUDREVILLE;50250;50;MANCHE;1
50036;;Baupte;BAUPTE;50500;50;MANCHE;1
50037;La;Bazoge;BAZOGE;50520;50;MANCHE;1
50038;;Beauchamps;BEAUCHAMPS;50320;50;MANCHE;1
50039;;Beaucoudray;BEAUCOUDRAY;50420;50;MANCHE;1
50040;;Beauficel;BEAUFICEL;50150;50;MANCHE;1
50041;;Beaumont-Hague;BEAUMONT-HAGUE;50440;50;MANCHE;1
50042;;Beauvoir;BEAUVOIR;50170;50;MANCHE;1
50043;;Bellefontaine;BELLEFONTAINE;50520;50;MANCHE;1
50044;;Belval;BELVAL;50210;50;MANCHE;1
50045;;Benoîtville;BENOITVILLE;50340;50;MANCHE;1
50046;;Bérigny;BERIGNY;50810;50;MANCHE;1
50048;;Beslon;BESLON;50800;50;MANCHE;1
50049;;Besneville;BESNEVILLE;50390;50;MANCHE;1
50050;;Beuvrigny;BEUVRIGNY;50420;50;MANCHE;1
50051;;Beuzeville-au-Plain;BEUZEVILLE-AU-PLAIN;50480;50;MANCHE;1
50052;;Beuzeville-la-Bastille;BEUZEVILLE-LA-BASTILLE;50360;50;MANCHE;1
50054;;Biéville;BIEVILLE;50160;50;MANCHE;1
50055;;Biniville;BINIVILLE;50390;50;MANCHE;1
50056;;Bion;BION;50140;50;MANCHE;1
50057;;Biville;BIVILLE;50440;50;MANCHE;1
50058;;Blainville-sur-Mer;BLAINVILLE-SUR-MER;50560;50;MANCHE;1
50059;;Blosville;BLOSVILLE;50480;50;MANCHE;1
50060;La;Bloutière;BLOUTIERE;50800;50;MANCHE;1
50061;;Boisroger;BOISROGER;50200;50;MANCHE;1
50062;;Boisyvon;BOISYVON;50800;50;MANCHE;1
50063;;Bolleville;BOLLEVILLE;50250;50;MANCHE;1
50064;La;Bonneville;BONNEVILLE;50360;50;MANCHE;1
50066;;Jullouville;JULLOUVILLE;50610;50;MANCHE;1
50069;;Bourguenolles;BOURGUENOLLES;50800;50;MANCHE;1
50070;;Boutteville;BOUTTEVILLE;50480;50;MANCHE;1
50071;;Braffais;BRAFFAIS;50870;50;MANCHE;1
50072;;Brainville;BRAINVILLE;50200;50;MANCHE;1
50073;;Branville-Hague;BRANVILLE-HAGUE;50440;50;MANCHE;1
50074;;Brécey;BRECEY;50370;50;MANCHE;1
50075;;Brectouville;BRECTOUVILLE;50160;50;MANCHE;1
50076;;Bréhal;BREHAL;50290;50;MANCHE;1
50077;;Bretteville;BRETTEVILLE;50110;50;MANCHE;1
50078;;Bretteville-sur-Ay;BRETTEVILLE-SUR-AY;50430;50;MANCHE;1
50079;;Breuville;BREUVILLE;50260;50;MANCHE;1
50080;;Brévands;BREVANDS;50500;50;MANCHE;1
50081;;Bréville-sur-Mer;BREVILLE-SUR-MER;50290;50;MANCHE;1
50082;;Bricquebec;BRICQUEBEC;50260;50;MANCHE;1
50083;;Bricquebosq;BRICQUEBOSQ;50340;50;MANCHE;1
50084;;Bricqueville-la-Blouette;BRICQUEVILLE-LA-BLOUETTE;50200;50;MANCHE;1
50085;;Bricqueville-sur-Mer;BRICQUEVILLE-SUR-MER;50290;50;MANCHE;1
50086;;Brillevast;BRILLEVAST;50330;50;MANCHE;1
50087;;Brix;BRIX;50700;50;MANCHE;1
50088;;Brouains;BROUAINS;50150;50;MANCHE;1
50089;;Brucheville;BRUCHEVILLE;50480;50;MANCHE;1
50090;;Buais;BUAIS;50640;50;MANCHE;1
50092;;Cambernon;CAMBERNON;50200;50;MANCHE;1
50093;;Cametours;CAMETOURS;50570;50;MANCHE;1
50094;;Camprond;CAMPROND;50210;50;MANCHE;1
50095;;Canisy;CANISY;50750;50;MANCHE;1
50096;;Canteloup;CANTELOUP;50330;50;MANCHE;1
50097;;Canville-la-Rocque;CANVILLE-LA-ROCQUE;50580;50;MANCHE;1
50098;;Carantilly;CARANTILLY;50570;50;MANCHE;1
50099;;Carentan;CARENTAN;50500;50;MANCHE;1
50100;;Carnet;CARNET;50240;50;MANCHE;1
50101;;Carneville;CARNEVILLE;50330;50;MANCHE;1
50102;;Carolles;CAROLLES;50740;50;MANCHE;1
50103;;Carquebut;CARQUEBUT;50480;50;MANCHE;1
50105;;Catteville;CATTEVILLE;50390;50;MANCHE;1
50106;;Cavigny;CAVIGNY;50620;50;MANCHE;1
50107;;Catz;CATZ;50500;50;MANCHE;1
50108;;Céaux;CEAUX;50220;50;MANCHE;1
50109;;Cérences;CERENCES;50510;50;MANCHE;1
50110;;Cerisy-la-Forêt;CERISY-LA-FORET;50680;50;MANCHE;1
50111;;Cerisy-la-Salle;CERISY-LA-SALLE;50210;50;MANCHE;1
50112;La;Chaise-Baudouin;CHAISE-BAUDOUIN;50370;50;MANCHE;1
50114;Les;Chambres;CHAMBRES;50320;50;MANCHE;1
50115;;Champcervon;CHAMPCERVON;50320;50;MANCHE;1
50116;;Champcey;CHAMPCEY;50530;50;MANCHE;1
50117;;Champeaux;CHAMPEAUX;50530;50;MANCHE;1
50118;;Champrepus;CHAMPREPUS;50800;50;MANCHE;1
50119;Les;Champs-de-Losque;CHAMPS-DE-LOSQUE;50620;50;MANCHE;1
50120;;Chanteloup;CHANTELOUP;50510;50;MANCHE;1
50121;La;Chapelle-Cécelin;CHAPELLE-CECELIN;50800;50;MANCHE;1
50123;La;Chapelle-en-Juger;CHAPELLE-EN-JUGER;50570;50;MANCHE;1
50124;La;Chapelle-Urée;CHAPELLE-UREE;50370;50;MANCHE;1
50125;;Chasseguey;CHASSEGUEY;50520;50;MANCHE;1
50126;;Chavoy;CHAVOY;50870;50;MANCHE;1
50127;;Chef-du-Pont;CHEF-DU-PONT;50480;50;MANCHE;1
50128;Le;Chefresne;CHEFRESNE;50410;50;MANCHE;1
50129;;Cherbourg-Octeville;CHERBOURG-OCTEVILLE;50100;50;MANCHE;1
50130;;Chérencé-le-Héron;CHERENCE-LE-HERON;50800;50;MANCHE;1
50131;;Chérencé-le-Roussel;CHERENCE-LE-ROUSSEL;50520;50;MANCHE;1
50132;Les;Chéris;CHERIS;50220;50;MANCHE;1
50133;;Chèvreville;CHEVREVILLE;50600;50;MANCHE;1
50134;;Chevry;CHEVRY;50420;50;MANCHE;1
50135;;Clitourps;CLITOURPS;50330;50;MANCHE;1
50136;;Coigny;COIGNY;50250;50;MANCHE;1
50137;La;Colombe;COLOMBE;50800;50;MANCHE;1
50138;;Colomby;COLOMBY;50700;50;MANCHE;1
50139;;Condé-sur-Vire;CONDE-SUR-VIRE;50890;50;MANCHE;1
50140;;Contrières;CONTRIERES;50660;50;MANCHE;1
50142;;Cosqueville;COSQUEVILLE;50330;50;MANCHE;1
50143;;Coudeville-sur-Mer;COUDEVILLE-SUR-MER;50290;50;MANCHE;1
50144;;Coulouvray-Boisbenâtre;COULOUVRAY-BOISBENATRE;50670;50;MANCHE;1
50145;;Courcy;COURCY;50200;50;MANCHE;1
50146;;Courtils;COURTILS;50220;50;MANCHE;1
50147;;Coutances;COUTANCES;50200;50;MANCHE;1
50148;;Couvains;COUVAINS;50680;50;MANCHE;1
50149;;Couville;COUVILLE;50690;50;MANCHE;1
50150;;Crasville;CRASVILLE;50630;50;MANCHE;1
50151;;Créances;CREANCES;50710;50;MANCHE;1
50152;Les;Cresnays;CRESNAYS;50370;50;MANCHE;1
50153;;Cretteville;CRETTEVILLE;50250;50;MANCHE;1
50154;La;Croix-Avranchin;CROIX-AVRANCHIN;50240;50;MANCHE;1
50155;;Crollon;CROLLON;50220;50;MANCHE;1
50156;;Crosville-sur-Douve;CROSVILLE-SUR-DOUVE;50360;50;MANCHE;1
50158;;Cuves;CUVES;50670;50;MANCHE;1
50159;;Dangy;DANGY;50750;50;MANCHE;1
50160;;Denneville;DENNEVILLE;50580;50;MANCHE;1
50161;Le;Dézert;DEZERT;50620;50;MANCHE;1
50162;;Digosville;DIGOSVILLE;50110;50;MANCHE;1
50163;;Digulleville;DIGULLEVILLE;50440;50;MANCHE;1
50164;;Domjean;DOMJEAN;50420;50;MANCHE;1
50165;;Donville-les-Bains;DONVILLE-LES-BAINS;50350;50;MANCHE;1
50166;;Doville;DOVILLE;50250;50;MANCHE;1
50167;;Dragey-Ronthon;DRAGEY-RONTHON;50530;50;MANCHE;1
50168;;Ducey;DUCEY;50220;50;MANCHE;1
50169;;Écausseville;ECAUSSEVILLE;50310;50;MANCHE;1
50170;;Écoquenéauville;ECOQUENEAUVILLE;50480;50;MANCHE;1
50171;;Éculleville;ECULLEVILLE;50440;50;MANCHE;1
50172;;Émondeville;EMONDEVILLE;50310;50;MANCHE;1
50173;;Équeurdreville-Hainneville;EQUEURDREVILLE-HAINNEVILLE;50120;50;MANCHE;1
50174;;Équilly;EQUILLY;50320;50;MANCHE;1
50175;;Éroudeville;EROUDEVILLE;50310;50;MANCHE;1
50176;L';Étang-Bertrand;ETANG-BERTRAND;50260;50;MANCHE;1
50177;;Étienville;ETIENVILLE;50360;50;MANCHE;1
50178;;Fermanville;FERMANVILLE;50840;50;MANCHE;1
50179;;Ferrières;FERRIERES;50640;50;MANCHE;1
50180;;Fervaches;FERVACHES;50420;50;MANCHE;1
50181;;Feugères;FEUGERES;50190;50;MANCHE;1
50182;La;Feuillie;FEUILLIE;50190;50;MANCHE;1
50183;;Fierville-les-Mines;FIERVILLE-LES-MINES;50580;50;MANCHE;1
50184;;Flamanville;FLAMANVILLE;50340;50;MANCHE;1
50185;;Fleury;FLEURY;50800;50;MANCHE;1
50186;;Flottemanville;FLOTTEMANVILLE;50700;50;MANCHE;1
50187;;Flottemanville-Hague;FLOTTEMANVILLE-HAGUE;50690;50;MANCHE;1
50188;;Folligny;FOLLIGNY;50320;50;MANCHE;1
50189;;Fontenay;FONTENAY;50140;50;MANCHE;1
50190;;Fontenay-sur-Mer;FONTENAY-SUR-MER;50310;50;MANCHE;1
50191;;Foucarville;FOUCARVILLE;50480;50;MANCHE;1
50192;;Fourneaux;FOURNEAUX;50420;50;MANCHE;1
50193;Le;Fresne-Poret;FRESNE-PORET;50850;50;MANCHE;1
50194;;Fresville;FRESVILLE;50310;50;MANCHE;1
50195;;Gathemo;GATHEMO;50150;50;MANCHE;1
50196;;Gatteville-le-Phare;GATTEVILLE-LE-PHARE;50760;50;MANCHE;1
50197;;Gavray;GAVRAY;50450;50;MANCHE;1
50198;;Geffosses;GEFFOSSES;50560;50;MANCHE;1
50199;;Genêts;GENETS;50530;50;MANCHE;1
50200;;Ger;GER;50850;50;MANCHE;1
50202;;Giéville;GIEVILLE;50160;50;MANCHE;1
50203;La;Glacerie;GLACERIE;50470;50;MANCHE;1
50204;;Glatigny;GLATIGNY;50250;50;MANCHE;1
50205;La;Godefroy;GODEFROY;50300;50;MANCHE;1
50206;La;Gohannière;GOHANNIERE;50300;50;MANCHE;1
50207;;Golleville;GOLLEVILLE;50390;50;MANCHE;1
50208;;Gonfreville;GONFREVILLE;50190;50;MANCHE;1
50209;;Gonneville;GONNEVILLE;50330;50;MANCHE;1
50210;;Gorges;GORGES;50190;50;MANCHE;1
50211;;Gouberville;GOUBERVILLE;50330;50;MANCHE;1
50212;;Gourbesville;GOURBESVILLE;50480;50;MANCHE;1
50213;;Gourfaleur;GOURFALEUR;50750;50;MANCHE;1
50214;;Gouvets;GOUVETS;50420;50;MANCHE;1
50215;;Gouville-sur-Mer;GOUVILLE-SUR-MER;50560;50;MANCHE;1
50216;;Graignes-Mesnil-Angot;GRAIGNES-MESNIL-ANGOT;50620;50;MANCHE;1
50217;Le;Grand-Celland;GRAND-CELLAND;50370;50;MANCHE;1
50218;;Granville;GRANVILLE;50400;50;MANCHE;1
50219;;Gratot;GRATOT;50200;50;MANCHE;1
50220;;Gréville-Hague;GREVILLE-HAGUE;50440;50;MANCHE;1
50221;;Grimesnil;GRIMESNIL;50450;50;MANCHE;1
50222;;Grosville;GROSVILLE;50340;50;MANCHE;1
50223;;Guéhébert;GUEHEBERT;50210;50;MANCHE;1
50224;;Guilberville;GUILBERVILLE;50160;50;MANCHE;1
50225;Le;Guislain;GUISLAIN;50410;50;MANCHE;1
50227;Le;Ham;HAM;50310;50;MANCHE;1
50228;;Hambye;HAMBYE;50450;50;MANCHE;1
50229;;Hamelin;HAMELIN;50730;50;MANCHE;1
50230;;Hardinvast;HARDINVAST;50690;50;MANCHE;1
50231;;Hauteville-sur-Mer;HAUTEVILLE-SUR-MER;50590;50;MANCHE;1
50232;;Hauteville-la-Guichard;HAUTEVILLE-LA-GUICHARD;50570;50;MANCHE;1
50233;;Hautteville-Bocage;HAUTTEVILLE-BOCAGE;50390;50;MANCHE;1
50234;La;Haye-Bellefond;HAYE-BELLEFOND;50410;50;MANCHE;1
50235;La;Haye-d'Ectot;HAYE-D'ECTOT;50270;50;MANCHE;1
50236;La;Haye-du-Puits;HAYE-DU-PUITS;50250;50;MANCHE;1
50237;La;Haye-Pesnel;HAYE-PESNEL;50320;50;MANCHE;1
50238;;Héauville;HEAUVILLE;50340;50;MANCHE;1
50239;;Hébécrevon;HEBECREVON;50180;50;MANCHE;1
50240;;Helleville;HELLEVILLE;50340;50;MANCHE;1
50241;;Hémevez;HEMEVEZ;50700;50;MANCHE;1
50242;;Herqueville;HERQUEVILLE;50440;50;MANCHE;1
50243;;Heugueville-sur-Sienne;HEUGUEVILLE-SUR-SIENNE;50200;50;MANCHE;1
50244;;Hérenguerville;HERENGUERVILLE;50660;50;MANCHE;1
50245;;Heussé;HEUSSE;50640;50;MANCHE;1
50246;;Hiesville;HIESVILLE;50480;50;MANCHE;1
50247;;Hocquigny;HOCQUIGNY;50320;50;MANCHE;1
50248;Le;Hommet-d'Arthenay;HOMMET-D'ARTHENAY;50620;50;MANCHE;1
50249;;Houesville;HOUESVILLE;50480;50;MANCHE;1
50250;;Houtteville;HOUTTEVILLE;50250;50;MANCHE;1
50251;;Huberville;HUBERVILLE;50700;50;MANCHE;1
50252;;Hudimesnil;HUDIMESNIL;50510;50;MANCHE;1
50253;;Huisnes-sur-Mer;HUISNES-SUR-MER;50170;50;MANCHE;1
50254;;Husson;HUSSON;50640;50;MANCHE;1
50255;;Hyenville;HYENVILLE;50660;50;MANCHE;1
50256;;Isigny-le-Buat;ISIGNY-LE-BUAT;50540;50;MANCHE;1
50257;;Jobourg;JOBOURG;50440;50;MANCHE;1
50258;;Joganville;JOGANVILLE;50310;50;MANCHE;1
50259;;Juilley;JUILLEY;50220;50;MANCHE;1
50260;;Juvigny-le-Tertre;JUVIGNY-LE-TERTRE;50520;50;MANCHE;1
50261;;Lamberville;LAMBERVILLE;50160;50;MANCHE;1
50262;La;Lande-d'Airou;LANDE-D'AIROU;50800;50;MANCHE;1
50263;;Lapenty;LAPENTY;50600;50;MANCHE;1
50265;;Laulne;LAULNE;50430;50;MANCHE;1
50266;;Lengronne;LENGRONNE;50510;50;MANCHE;1
50267;;Lessay;LESSAY;50430;50;MANCHE;1
50268;;Lestre;LESTRE;50310;50;MANCHE;1
50269;;Liesville-sur-Douve;LIESVILLE-SUR-DOUVE;50480;50;MANCHE;1
50270;;Lieusaint;LIEUSAINT;50700;50;MANCHE;1
50271;;Lingeard;LINGEARD;50670;50;MANCHE;1
50272;;Lingreville;LINGREVILLE;50660;50;MANCHE;1
50273;;Lithaire;LITHAIRE;50250;50;MANCHE;1
50274;Les;Loges-Marchis;LOGES-MARCHIS;50600;50;MANCHE;1
50275;Les;Loges-sur-Brécey;LOGES-SUR-BRECEY;50370;50;MANCHE;1
50276;;Lolif;LOLIF;50530;50;MANCHE;1
50277;;Longueville;LONGUEVILLE;50290;50;MANCHE;1
50278;Le;Loreur;LOREUR;50510;50;MANCHE;1
50279;Le;Lorey;LOREY;50570;50;MANCHE;1
50280;;Lozon;LOZON;50570;50;MANCHE;1
50281;La;Lucerne-d'Outremer;LUCERNE-D'OUTREMER;50320;50;MANCHE;1
50282;Le;Luot;LUOT;50870;50;MANCHE;1
50283;La;Luzerne;LUZERNE;50680;50;MANCHE;1
50284;;Macey;MACEY;50170;50;MANCHE;1
50285;;Magneville;MAGNEVILLE;50260;50;MANCHE;1
50287;La;Mancellière-sur-Vire;MANCELLIERE-SUR-VIRE;50750;50;MANCHE;1
50288;;Marcey-les-Grèves;MARCEY-LES-GREVES;50300;50;MANCHE;1
50289;;Marchésieux;MARCHESIEUX;50190;50;MANCHE;1
50290;;Marcilly;MARCILLY;50220;50;MANCHE;1
50291;;Margueray;MARGUERAY;50410;50;MANCHE;1
50292;;Marigny;MARIGNY;50570;50;MANCHE;1
50293;;Martigny;MARTIGNY;50600;50;MANCHE;1
50294;;Martinvast;MARTINVAST;50690;50;MANCHE;1
50295;;Maupertuis;MAUPERTUIS;50410;50;MANCHE;1
50296;;Maupertus-sur-Mer;MAUPERTUS-SUR-MER;50330;50;MANCHE;1
50297;La;Meauffe;MEAUFFE;50880;50;MANCHE;1
50298;;Méautis;MEAUTIS;50500;50;MANCHE;1
50299;Le;Mesnil;MESNIL;50580;50;MANCHE;1
50300;Le;Mesnil-Adelée;MESNIL-ADELEE;50520;50;MANCHE;1
50301;Le;Mesnil-Amand;MESNIL-AMAND;50450;50;MANCHE;1
50302;Le;Mesnil-Amey;MESNIL-AMEY;50570;50;MANCHE;1
50304;Le;Mesnil-Aubert;MESNIL-AUBERT;50510;50;MANCHE;1
50305;Le;Mesnil-au-Val;MESNIL-AU-VAL;50110;50;MANCHE;1
50308;Le;Mesnilbus;MESNILBUS;50490;50;MANCHE;1
50310;Le;Mesnil-Eury;MESNIL-EURY;50570;50;MANCHE;1
50311;Le;Mesnil-Garnier;MESNIL-GARNIER;50450;50;MANCHE;1
50312;Le;Mesnil-Gilbert;MESNIL-GILBERT;50670;50;MANCHE;1
50313;Le;Mesnil-Herman;MESNIL-HERMAN;50750;50;MANCHE;1
50315;Le;Mesnillard;MESNILLARD;50600;50;MANCHE;1
50316;Le;Mesnil-Opac;MESNIL-OPAC;50860;50;MANCHE;1
50317;Le;Mesnil-Ozenne;MESNIL-OZENNE;50220;50;MANCHE;1
50318;Le;Mesnil-Rainfray;MESNIL-RAINFRAY;50520;50;MANCHE;1
50319;Le;Mesnil-Raoult;MESNIL-RAOULT;50420;50;MANCHE;1
50320;Le;Mesnil-Rogues;MESNIL-ROGUES;50450;50;MANCHE;1
50321;Le;Mesnil-Rouxelin;MESNIL-ROUXELIN;50000;50;MANCHE;1
50323;Le;Mesnil-Tôve;MESNIL-TOVE;50520;50;MANCHE;1
50324;Le;Mesnil-Véneron;MESNIL-VENERON;50620;50;MANCHE;1
50325;Le;Mesnil-Vigot;MESNIL-VIGOT;50570;50;MANCHE;1
50326;Le;Mesnil-Villeman;MESNIL-VILLEMAN;50450;50;MANCHE;1
50327;La;Meurdraquière;MEURDRAQUIERE;50510;50;MANCHE;1
50328;;Millières;MILLIERES;50190;50;MANCHE;1
50329;;Milly;MILLY;50600;50;MANCHE;1
50330;;Mobecq;MOBECQ;50250;50;MANCHE;1
50332;Les;Moitiers-d'Allonne;MOITIERS-D'ALLONNE;50270;50;MANCHE;1
50333;Les;Moitiers-en-Bauptois;MOITIERS-EN-BAUPTOIS;50360;50;MANCHE;1
50334;;Montabot;MONTABOT;50410;50;MANCHE;1
50335;;Montaigu-la-Brisette;MONTAIGU-LA-BRISETTE;50700;50;MANCHE;1
50336;;Montaigu-les-Bois;MONTAIGU-LES-BOIS;50450;50;MANCHE;1
50337;;Montanel;MONTANEL;50240;50;MANCHE;1
50338;;Montbray;MONTBRAY;50410;50;MANCHE;1
50339;;Montchaton;MONTCHATON;50660;50;MANCHE;1
50340;;Montcuit;MONTCUIT;50490;50;MANCHE;1
50341;;Montebourg;MONTEBOURG;50310;50;MANCHE;1
50342;;Montfarville;MONTFARVILLE;50760;50;MANCHE;1
50343;;Montgardon;MONTGARDON;50250;50;MANCHE;1
50345;;Monthuchon;MONTHUCHON;50200;50;MANCHE;1
50347;;Montjoie-Saint-Martin;MONTJOIE-SAINT-MARTIN;50240;50;MANCHE;1
50348;;Montmartin-en-Graignes;MONTMARTIN-EN-GRAIGNES;50620;50;MANCHE;1
50349;;Montmartin-sur-Mer;MONTMARTIN-SUR-MER;50590;50;MANCHE;1
50350;;Montpinchon;MONTPINCHON;50210;50;MANCHE;1
50351;;Montrabot;MONTRABOT;50810;50;MANCHE;1
50352;;Montreuil-sur-Lozon;MONTREUIL-SUR-LOZON;50570;50;MANCHE;1
50353;Le;Mont-Saint-Michel;MONT-SAINT-MICHEL;50170;50;MANCHE;1
50354;;Montsurvent;MONTSURVENT;50200;50;MANCHE;1
50355;;Montviron;MONTVIRON;50530;50;MANCHE;1
50356;;Moon-sur-Elle;MOON-SUR-ELLE;50680;50;MANCHE;1
50357;;Morigny;MORIGNY;50410;50;MANCHE;1
50358;;Morsalines;MORSALINES;50630;50;MANCHE;1
50359;;Mortain;MORTAIN;50140;50;MANCHE;1
50360;;Morville;MORVILLE;50700;50;MANCHE;1
50361;La;Mouche;MOUCHE;50320;50;MANCHE;1
50362;;Moulines;MOULINES;50600;50;MANCHE;1
50363;;Moyon;MOYON;50860;50;MANCHE;1
50364;;Muneville-le-Bingard;MUNEVILLE-LE-BINGARD;50490;50;MANCHE;1
50365;;Muneville-sur-Mer;MUNEVILLE-SUR-MER;50290;50;MANCHE;1
50368;;Nay;NAY;50190;50;MANCHE;1
50369;;Négreville;NEGREVILLE;50260;50;MANCHE;1
50370;;Néhou;NEHOU;50390;50;MANCHE;1
50371;Le;Neufbourg;NEUFBOURG;50140;50;MANCHE;1
50372;;Neufmesnil;NEUFMESNIL;50250;50;MANCHE;1
50373;;Neuville-au-Plain;NEUVILLE-AU-PLAIN;50480;50;MANCHE;1
50374;;Neuville-en-Beaumont;NEUVILLE-EN-BEAUMONT;50250;50;MANCHE;1
50375;;Néville-sur-Mer;NEVILLE-SUR-MER;50330;50;MANCHE;1
50376;;Nicorps;NICORPS;50200;50;MANCHE;1
50378;;Notre-Dame-de-Cenilly;NOTRE-DAME-DE-CENILLY;50210;50;MANCHE;1
50379;;Notre-Dame-de-Livoye;NOTRE-DAME-DE-LIVOYE;50370;50;MANCHE;1
50380;;Notre-Dame-d'Elle;NOTRE-DAME-D'ELLE;50810;50;MANCHE;1
50381;;Notre-Dame-du-Touchet;NOTRE-DAME-DU-TOUCHET;50140;50;MANCHE;1
50382;;Nouainville;NOUAINVILLE;50690;50;MANCHE;1
50384;;Octeville-l'Avenel;OCTEVILLE-L'AVENEL;50630;50;MANCHE;1
50385;;Omonville-la-Petite;OMONVILLE-LA-PETITE;50440;50;MANCHE;1
50386;;Omonville-la-Rogue;OMONVILLE-LA-ROGUE;50440;50;MANCHE;1
50387;;Orglandes;ORGLANDES;50390;50;MANCHE;1
50388;;Orval;ORVAL;50660;50;MANCHE;1
50389;;Ouville;OUVILLE;50210;50;MANCHE;1
50390;;Ozeville;OZEVILLE;50310;50;MANCHE;1
50391;;Parigny;PARIGNY;50600;50;MANCHE;1
50393;;Percy;PERCY;50410;50;MANCHE;1
50394;;Périers;PERIERS;50190;50;MANCHE;1
50395;La;Pernelle;PERNELLE;50630;50;MANCHE;1
50396;Les;Perques;PERQUES;50260;50;MANCHE;1
50397;;Perriers-en-Beauficel;PERRIERS-EN-BEAUFICEL;50150;50;MANCHE;1
50398;Le;Perron;PERRON;50160;50;MANCHE;1
50399;Le;Petit-Celland;PETIT-CELLAND;50370;50;MANCHE;1
50400;;Picauville;PICAUVILLE;50360;50;MANCHE;1
50401;;Pierreville;PIERREVILLE;50340;50;MANCHE;1
50402;Les;Pieux;PIEUX;50340;50;MANCHE;1
50403;;Pirou;PIROU;50770;50;MANCHE;1
50404;;Placy-Montaigu;PLACY-MONTAIGU;50160;50;MANCHE;1
50405;Le;Plessis-Lastelle;PLESSIS-LASTELLE;50250;50;MANCHE;1
50406;;Plomb;PLOMB;50870;50;MANCHE;1
50407;;Poilley;POILLEY;50220;50;MANCHE;1
50408;;Pontaubault;PONTAUBAULT;50220;50;MANCHE;1
50409;;Pont-Hébert;PONT-HEBERT;50880;50;MANCHE;1
50410;;Pontorson;PONTORSON;50170;50;MANCHE;1
50411;;Ponts;PONTS;50300;50;MANCHE;1
50412;;Portbail;PORTBAIL;50580;50;MANCHE;1
50413;;Précey;PRECEY;50220;50;MANCHE;1
50414;;Précorbin;PRECORBIN;50810;50;MANCHE;1
50415;;Prétot-Sainte-Suzanne;PRETOT-SAINTE-SUZANNE;50250;50;MANCHE;1
50416;;Querqueville;QUERQUEVILLE;50460;50;MANCHE;1
50417;;Quettehou;QUETTEHOU;50630;50;MANCHE;1
50418;;Quettetot;QUETTETOT;50260;50;MANCHE;1
50419;;Quettreville-sur-Sienne;QUETTREVILLE-SUR-SIENNE;50660;50;MANCHE;1
50420;;Quibou;QUIBOU;50750;50;MANCHE;1
50421;;Quinéville;QUINEVILLE;50310;50;MANCHE;1
50422;;Raids;RAIDS;50500;50;MANCHE;1
50423;;Rampan;RAMPAN;50000;50;MANCHE;1
50425;;Rauville-la-Bigot;RAUVILLE-LA-BIGOT;50260;50;MANCHE;1
50426;;Rauville-la-Place;RAUVILLE-LA-PLACE;50390;50;MANCHE;1
50427;;Ravenoville;RAVENOVILLE;50480;50;MANCHE;1
50428;;Reffuveille;REFFUVEILLE;50520;50;MANCHE;1
50429;;Regnéville-sur-Mer;REGNEVILLE-SUR-MER;50590;50;MANCHE;1
50430;;Reigneville-Bocage;REIGNEVILLE-BOCAGE;50390;50;MANCHE;1
50431;;Remilly-sur-Lozon;REMILLY-SUR-LOZON;50570;50;MANCHE;1
50432;;Réthoville;RETHOVILLE;50330;50;MANCHE;1
50433;;Réville;REVILLE;50760;50;MANCHE;1
50434;La;Rochelle-Normande;ROCHELLE-NORMANDE;50530;50;MANCHE;1
50435;;Rocheville;ROCHEVILLE;50260;50;MANCHE;1
50436;;Romagny;ROMAGNY;50140;50;MANCHE;1
50437;;Roncey;RONCEY;50210;50;MANCHE;1
50438;La;Ronde-Haye;RONDE-HAYE;50490;50;MANCHE;1
50440;;Rouffigny;ROUFFIGNY;50800;50;MANCHE;1
50441;;Rouxeville;ROUXEVILLE;50810;50;MANCHE;1
50442;Le;Rozel;ROZEL;50340;50;MANCHE;1
50443;;Sacey;SACEY;50170;50;MANCHE;1
50444;;Saint-Amand;SAINT-AMAND;50160;50;MANCHE;1
50445;;Saint-André-de-Bohon;SAINT-ANDRE-DE-BOHON;50500;50;MANCHE;1
50446;;Saint-André-de-l'Épine;SAINT-ANDRE-DE-L'EPINE;50680;50;MANCHE;1
50447;;Saint-Aubin-des-Préaux;SAINT-AUBIN-DES-PREAUX;50380;50;MANCHE;1
50448;;Saint-Aubin-de-Terregatte;SAINT-AUBIN-DE-TERREGATTE;50111;50;MANCHE;1
50449;;Saint-Aubin-du-Perron;SAINT-AUBIN-DU-PERRON;50490;50;MANCHE;1
50450;;Saint-Barthélemy;SAINT-BARTHELEMY;50140;50;MANCHE;1
50451;;Saint-Brice;SAINT-BRICE;50300;50;MANCHE;1
50452;;Saint-Brice-de-Landelles;SAINT-BRICE-DE-LANDELLES;50730;50;MANCHE;1
50453;;Sainte-Cécile;SAINTE-CECILE;50800;50;MANCHE;1
50454;;Saint-Christophe-du-Foc;SAINT-CHRISTOPHE-DU-FOC;50340;50;MANCHE;1
50455;;Saint-Clair-sur-l'Elle;SAINT-CLAIR-SUR-L'ELLE;50680;50;MANCHE;1
50456;;Saint-Clément-Rancoudray;SAINT-CLEMENT-RANCOUDRAY;50140;50;MANCHE;1
50457;;Sainte-Colombe;SAINTE-COLOMBE;50390;50;MANCHE;1
50458;;Saint-Côme-du-Mont;SAINT-COME-DU-MONT;50500;50;MANCHE;1
50460;;Sainte-Croix-Hague;SAINTE-CROIX-HAGUE;50440;50;MANCHE;1
50461;;Saint-Cyr;SAINT-CYR;50310;50;MANCHE;1
50462;;Saint-Cyr-du-Bailleul;SAINT-CYR-DU-BAILLEUL;50720;50;MANCHE;1
50463;;Saint-Denis-le-Gast;SAINT-DENIS-LE-GAST;50450;50;MANCHE;1
50464;;Saint-Denis-le-Vêtu;SAINT-DENIS-LE-VETU;50210;50;MANCHE;1
50465;;Saint-Ébremond-de-Bonfossé;SAINT-EBREMOND-DE-BONFOSSE;50750;50;MANCHE;1
50467;;Saint-Floxel;SAINT-FLOXEL;50310;50;MANCHE;1
50468;;Saint-Fromond;SAINT-FROMOND;50620;50;MANCHE;1
50469;;Sainte-Geneviève;SAINTE-GENEVIEVE;50760;50;MANCHE;1
50470;;Saint-Georges-de-Bohon;SAINT-GEORGES-DE-BOHON;50500;50;MANCHE;1
50471;;Saint-Georges-de-la-Rivière;SAINT-GEORGES-DE-LA-RIVIERE;50270;50;MANCHE;1
50472;;Saint-Georges-de-Livoye;SAINT-GEORGES-DE-LIVOYE;50370;50;MANCHE;1
50473;;Saint-Georges-d'Elle;SAINT-GEORGES-D'ELLE;50680;50;MANCHE;1
50474;;Saint-Georges-de-Rouelley;SAINT-GEORGES-DE-ROUELLEY;50720;50;MANCHE;1
50475;;Saint-Georges-Montcocq;SAINT-GEORGES-MONTCOCQ;50000;50;MANCHE;1
50476;;Saint-Germain-d'Elle;SAINT-GERMAIN-D'ELLE;50810;50;MANCHE;1
50477;;Saint-Germain-des-Vaux;SAINT-GERMAIN-DES-VAUX;50440;50;MANCHE;1
50478;;Saint-Germain-de-Tournebut;SAINT-GERMAIN-DE-TOURNEBUT;50700;50;MANCHE;1
50479;;Saint-Germain-de-Varreville;SAINT-GERMAIN-DE-VARREVILLE;50480;50;MANCHE;1
50480;;Saint-Germain-le-Gaillard;SAINT-GERMAIN-LE-GAILLARD;50340;50;MANCHE;1
50481;;Saint-Germain-sur-Ay;SAINT-GERMAIN-SUR-AY;50430;50;MANCHE;1
50482;;Saint-Germain-sur-Sèves;SAINT-GERMAIN-SUR-SEVES;50190;50;MANCHE;1
50483;;Saint-Gilles;SAINT-GILLES;50180;50;MANCHE;1
50484;;Saint-Hilaire-du-Harcouët;SAINT-HILAIRE-DU-HARCOUET;50600;50;MANCHE;1
50485;;Saint-Hilaire-Petitville;SAINT-HILAIRE-PETITVILLE;50500;50;MANCHE;1
50486;;Saint-Jacques-de-Néhou;SAINT-JACQUES-DE-NEHOU;50390;50;MANCHE;1
50487;;Saint-James;SAINT-JAMES;50240;50;MANCHE;1
50488;;Saint-Jean-de-Daye;SAINT-JEAN-DE-DAYE;50620;50;MANCHE;1
50489;;Saint-Jean-de-la-Haize;SAINT-JEAN-DE-LA-HAIZE;50300;50;MANCHE;1
50490;;Saint-Jean-de-la-Rivière;SAINT-JEAN-DE-LA-RIVIERE;50270;50;MANCHE;1
50491;;Saint-Jean-de-Savigny;SAINT-JEAN-DE-SAVIGNY;50680;50;MANCHE;1
50492;;Saint-Jean-des-Baisants;SAINT-JEAN-DES-BAISANTS;50810;50;MANCHE;1
50493;;Saint-Jean-des-Champs;SAINT-JEAN-DES-CHAMPS;50320;50;MANCHE;1
50494;;Saint-Jean-du-Corail;SAINT-JEAN-DU-CORAIL;50140;50;MANCHE;1
50495;;Saint-Jean-du-Corail-des-Bois;SAINT-JEAN-DU-CORAIL-DES-BOIS;50370;50;MANCHE;1
50496;;Saint-Jean-le-Thomas;SAINT-JEAN-LE-THOMAS;50530;50;MANCHE;1
50497;;Saint-Jores;SAINT-JORES;50250;50;MANCHE;1
50498;;Saint-Joseph;SAINT-JOSEPH;50700;50;MANCHE;1
50499;;Saint-Laurent-de-Cuves;SAINT-LAURENT-DE-CUVES;50670;50;MANCHE;1
50500;;Saint-Laurent-de-Terregatte;SAINT-LAURENT-DE-TERREGATTE;50111;50;MANCHE;1
50502;;Saint-Lô;SAINT-LO;50000;50;MANCHE;1
50503;;Saint-Lô-d'Ourville;SAINT-LO-D'OURVILLE;50580;50;MANCHE;1
50504;;Saint-Louet-sur-Vire;SAINT-LOUET-SUR-VIRE;50420;50;MANCHE;1
50505;;Saint-Loup;SAINT-LOUP;50300;50;MANCHE;1
50506;;Saint-Malo-de-la-Lande;SAINT-MALO-DE-LA-LANDE;50200;50;MANCHE;1
50507;;Saint-Marcouf;SAINT-MARCOUF;50310;50;MANCHE;1
50508;;Sainte-Marie-du-Bois;SAINTE-MARIE-DU-BOIS;50640;50;MANCHE;1
50509;;Sainte-Marie-du-Mont;SAINTE-MARIE-DU-MONT;50480;50;MANCHE;1
50510;;Saint-Martin-d'Aubigny;SAINT-MARTIN-D'AUBIGNY;50190;50;MANCHE;1
50511;;Saint-Martin-d'Audouville;SAINT-MARTIN-D'AUDOUVILLE;50310;50;MANCHE;1
50512;;Saint-Martin-de-Bonfossé;SAINT-MARTIN-DE-BONFOSSE;50750;50;MANCHE;1
50513;;Saint-Martin-de-Cenilly;SAINT-MARTIN-DE-CENILLY;50210;50;MANCHE;1
50514;;Chaulieu;CHAULIEU;50150;50;MANCHE;1
50515;;Saint-Martin-de-Landelles;SAINT-MARTIN-DE-LANDELLES;50730;50;MANCHE;1
50516;;Saint-Martin-des-Champs;SAINT-MARTIN-DES-CHAMPS;50300;50;MANCHE;1
50517;;Saint-Martin-de-Varreville;SAINT-MARTIN-DE-VARREVILLE;50480;50;MANCHE;1
50518;;Saint-Martin-le-Bouillant;SAINT-MARTIN-LE-BOUILLANT;50800;50;MANCHE;1
50519;;Saint-Martin-le-Gréard;SAINT-MARTIN-LE-GREARD;50690;50;MANCHE;1
50520;;Saint-Martin-le-Hébert;SAINT-MARTIN-LE-HEBERT;;50;;
50521;;Saint-Maur-des-Bois;SAINT-MAUR-DES-BOIS;50800;50;MANCHE;1
50522;;Saint-Maurice-en-Cotentin;SAINT-MAURICE-EN-COTENTIN;50270;50;MANCHE;1
50523;;Sainte-Mère-Église;SAINTE-MERE-EGLISE;50480;50;MANCHE;1
50524;;Saint-Michel-de-la-Pierre;SAINT-MICHEL-DE-LA-PIERRE;50490;50;MANCHE;1
50525;;Saint-Michel-de-Montjoie;SAINT-MICHEL-DE-MONTJOIE;50670;50;MANCHE;1
50528;;Saint-Nicolas-de-Pierrepont;SAINT-NICOLAS-DE-PIERREPONT;50250;50;MANCHE;1
50529;;Saint-Nicolas-des-Bois;SAINT-NICOLAS-DES-BOIS;50370;50;MANCHE;1
50531;;Saint-Ovin;SAINT-OVIN;50300;50;MANCHE;1
50532;;Saint-Pair-sur-Mer;SAINT-PAIR-SUR-MER;50380;50;MANCHE;1
50533;;Saint-Patrice-de-Claids;SAINT-PATRICE-DE-CLAIDS;50190;50;MANCHE;1
50534;;Saint-Pellerin;SAINT-PELLERIN;50500;50;MANCHE;1
50535;;Sainte-Pience;SAINTE-PIENCE;50870;50;MANCHE;1
50536;;Saint-Pierre-d'Arthéglise;SAINT-PIERRE-D'ARTHEGLISE;50270;50;MANCHE;1
50537;;Saint-Pierre-de-Coutances;SAINT-PIERRE-DE-COUTANCES;50200;50;MANCHE;1
50538;;Saint-Pierre-de-Semilly;SAINT-PIERRE-DE-SEMILLY;50810;50;MANCHE;1
50539;;Saint-Pierre-Église;SAINT-PIERRE-EGLISE;50330;50;MANCHE;1
50540;;Saint-Pierre-Langers;SAINT-PIERRE-LANGERS;50530;50;MANCHE;1
50541;;Saint-Planchers;SAINT-PLANCHERS;50400;50;MANCHE;1
50542;;Saint-Pois;SAINT-POIS;50670;50;MANCHE;1
50543;;Saint-Quentin-sur-le-Homme;SAINT-QUENTIN-SUR-LE-HOMME;50220;50;MANCHE;1
50544;;Saint-Rémy-des-Landes;SAINT-REMY-DES-LANDES;50580;50;MANCHE;1
50545;;Saint-Romphaire;SAINT-ROMPHAIRE;50750;50;MANCHE;1
50546;;Saint-Samson-de-Bonfossé;SAINT-SAMSON-DE-BONFOSSE;50750;50;MANCHE;1
50548;;Saint-Sauveur-de-Pierrepont;SAINT-SAUVEUR-DE-PIERREPONT;50250;50;MANCHE;1
50549;;Saint-Sauveur-la-Pommeraye;SAINT-SAUVEUR-LA-POMMERAYE;50510;50;MANCHE;1
50550;;Saint-Sauveur-Lendelin;SAINT-SAUVEUR-LENDELIN;50490;50;MANCHE;1
50551;;Saint-Sauveur-le-Vicomte;SAINT-SAUVEUR-LE-VICOMTE;50390;50;MANCHE;1
50552;;Saint-Sébastien-de-Raids;SAINT-SEBASTIEN-DE-RAIDS;50190;50;MANCHE;1
50553;;Saint-Senier-de-Beuvron;SAINT-SENIER-DE-BEUVRON;50240;50;MANCHE;1
50554;;Saint-Senier-sous-Avranches;SAINT-SENIER-SOUS-AVRANCHES;50300;50;MANCHE;1
50556;;Sainte-Suzanne-sur-Vire;SAINTE-SUZANNE-SUR-VIRE;50750;50;MANCHE;1
50557;;Saint-Symphorien-des-Monts;SAINT-SYMPHORIEN-DES-MONTS;50640;50;MANCHE;1
50558;;Saint-Symphorien-le-Valois;SAINT-SYMPHORIEN-LE-VALOIS;50250;50;MANCHE;1
50562;;Saint-Vaast-la-Hougue;SAINT-VAAST-LA-HOUGUE;50550;50;MANCHE;1
50563;;Saint-Vigor-des-Monts;SAINT-VIGOR-DES-MONTS;50420;50;MANCHE;1
50564;;Sainteny;SAINTENY;50500;50;MANCHE;1
50565;;Sartilly;SARTILLY;50530;50;MANCHE;1
50567;;Saussemesnil;SAUSSEMESNIL;50700;50;MANCHE;1
50568;;Saussey;SAUSSEY;50200;50;MANCHE;1
50569;;Savigny;SAVIGNY;50210;50;MANCHE;1
50570;;Savigny-le-Vieux;SAVIGNY-LE-VIEUX;50640;50;MANCHE;1
50571;;Sébeville;SEBEVILLE;50480;50;MANCHE;1
50572;;Sénoville;SENOVILLE;50270;50;MANCHE;1
50573;;Servigny;SERVIGNY;50200;50;MANCHE;1
50574;;Servon;SERVON;50170;50;MANCHE;1
50575;;Sideville;SIDEVILLE;50690;50;MANCHE;1
50576;;Siouville-Hague;SIOUVILLE-HAGUE;50340;50;MANCHE;1
50577;;Sortosville-en-Beaumont;SORTOSVILLE-EN-BEAUMONT;50270;50;MANCHE;1
50578;;Sortosville;SORTOSVILLE;50310;50;MANCHE;1
50579;;Sottevast;SOTTEVAST;50260;50;MANCHE;1
50580;;Sotteville;SOTTEVILLE;50340;50;MANCHE;1
50581;;Soulles;SOULLES;50750;50;MANCHE;1
50582;;Sourdeval;SOURDEVAL;50150;50;MANCHE;1
50583;;Sourdeval-les-Bois;SOURDEVAL-LES-BOIS;50450;50;MANCHE;1
50584;;Subligny;SUBLIGNY;50870;50;MANCHE;1
50585;;Surtainville;SURTAINVILLE;50270;50;MANCHE;1
50586;;Surville;SURVILLE;50250;50;MANCHE;1
50587;;Taillepied;TAILLEPIED;50390;50;MANCHE;1
50588;;Tamerville;TAMERVILLE;50700;50;MANCHE;1
50589;;Tanis;TANIS;50170;50;MANCHE;1
50590;Le;Tanu;TANU;50320;50;MANCHE;1
50591;Le;Teilleul;TEILLEUL;50640;50;MANCHE;1
50592;;Tessy-sur-Vire;TESSY-SUR-VIRE;50420;50;MANCHE;1
50593;;Teurthéville-Bocage;TEURTHEVILLE-BOCAGE;50630;50;MANCHE;1
50594;;Teurthéville-Hague;TEURTHEVILLE-HAGUE;50690;50;MANCHE;1
50595;Le;Theil;THEIL;50330;50;MANCHE;1
50596;;Théville;THEVILLE;50330;50;MANCHE;1
50597;;Tirepied;TIREPIED;50870;50;MANCHE;1
50598;;Tocqueville;TOCQUEVILLE;50330;50;MANCHE;1
50599;;Tollevast;TOLLEVAST;50470;50;MANCHE;1
50600;;Tonneville;TONNEVILLE;50460;50;MANCHE;1
50601;;Torigni-sur-Vire;TORIGNI-SUR-VIRE;50160;50;MANCHE;1
50602;;Tourlaville;TOURLAVILLE;50110;50;MANCHE;1
50603;;Tourville-sur-Sienne;TOURVILLE-SUR-SIENNE;50200;50;MANCHE;1
50604;;Tréauville;TREAUVILLE;50340;50;MANCHE;1
50605;;Trelly;TRELLY;50660;50;MANCHE;1
50606;;Tribehou;TRIBEHOU;50620;50;MANCHE;1
50607;La;Trinité;TRINITE;50800;50;MANCHE;1
50608;;Troisgots;TROISGOTS;50420;50;MANCHE;1
50609;;Turqueville;TURQUEVILLE;50480;50;MANCHE;1
50610;;Urville;URVILLE;50700;50;MANCHE;1
50611;;Urville-Nacqueville;URVILLE-NACQUEVILLE;50460;50;MANCHE;1
50612;;Vains;VAINS;50300;50;MANCHE;1
50613;;Valcanville;VALCANVILLE;50760;50;MANCHE;1
50614;Le;Valdécie;VALDECIE;50260;50;MANCHE;1
50615;;Valognes;VALOGNES;50700;50;MANCHE;1
50616;Le;Val-Saint-Père;VAL-SAINT-PERE;50300;50;MANCHE;1
50617;;Varenguebec;VARENGUEBEC;50250;50;MANCHE;1
50618;;Varouville;VAROUVILLE;50330;50;MANCHE;1
50619;Le;Vast;VAST;50630;50;MANCHE;1
50620;;Vasteville;VASTEVILLE;50440;50;MANCHE;1
50621;;Vaudreville;VAUDREVILLE;50310;50;MANCHE;1
50622;;Vaudrimesnil;VAUDRIMESNIL;50490;50;MANCHE;1
50623;;Vauville;VAUVILLE;50440;50;MANCHE;1
50624;La;Vendelée;VENDELEE;50200;50;MANCHE;1
50625;;Vengeons;VENGEONS;50150;50;MANCHE;1
50626;;Ver;VER;50450;50;MANCHE;1
50627;;Vergoncey;VERGONCEY;50240;50;MANCHE;1
50628;;Vernix;VERNIX;50370;50;MANCHE;1
50629;;Vesly;VESLY;50430;50;MANCHE;1
50630;;Vessey;VESSEY;50170;50;MANCHE;1
50631;Les;Veys;VEYS;50500;50;MANCHE;1
50633;Le;Vicel;VICEL;50760;50;MANCHE;1
50634;;Videcosville;VIDECOSVILLE;50630;50;MANCHE;1
50635;;Vidouville;VIDOUVILLE;50810;50;MANCHE;1
50636;;Vierville;VIERVILLE;50480;50;MANCHE;1
50637;;Villebaudon;VILLEBAUDON;50410;50;MANCHE;1
50638;;Villechien;VILLECHIEN;50140;50;MANCHE;1
50639;;Villedieu-les-Poêles;VILLEDIEU-LES-POELES;50800;50;MANCHE;1
50640;;Villiers-le-Pré;VILLIERS-LE-PRE;50240;50;MANCHE;1
50641;;Villiers-Fossard;VILLIERS-FOSSARD;50680;50;MANCHE;1
50642;;Vindefontaine;VINDEFONTAINE;50250;50;MANCHE;1
50643;;Virandeville;VIRANDEVILLE;50690;50;MANCHE;1
50644;;Virey;VIREY;50600;50;MANCHE;1
50646;Le;Vrétot;VRETOT;50260;50;MANCHE;1
50647;;Yquelon;YQUELON;50400;50;MANCHE;1
50648;;Yvetot-Bocage;YVETOT-BOCAGE;50700;50;MANCHE;1
51001;;Ablancourt;ABLANCOURT;51240;51;MARNE;1
51002;;Saint-Martin-d'Ablois;SAINT-MARTIN-D'ABLOIS;51200;51;MARNE;1
51003;;Aigny;AIGNY;51150;51;MARNE;1
51004;;Allemanche-Launay-et-Soyer;ALLEMANCHE-LAUNAY-ET-SOYER;51260;51;MARNE;1
51005;;Allemant;ALLEMANT;51120;51;MARNE;1
51006;;Alliancelles;ALLIANCELLES;51250;51;MARNE;1
51007;;Ambonnay;AMBONNAY;51150;51;MARNE;1
51008;;Ambrières;AMBRIERES;51290;51;MARNE;1
51009;;Anglure;ANGLURE;51260;51;MARNE;1
51010;;Angluzelles-et-Courcelles;ANGLUZELLES-ET-COURCELLES;51230;51;MARNE;1
51012;;Anthenay;ANTHENAY;51700;51;MARNE;1
51013;;Aougny;AOUGNY;51170;51;MARNE;1
51014;;Arcis-le-Ponsart;ARCIS-LE-PONSART;51170;51;MARNE;1
51015;;Argers;ARGERS;51800;51;MARNE;1
51016;;Arrigny;ARRIGNY;51290;51;MARNE;1
51017;;Arzillières-Neuville;ARZILLIERES-NEUVILLE;51290;51;MARNE;1
51018;;Athis;ATHIS;51150;51;MARNE;1
51019;;Aubérive;AUBERIVE;51600;51;MARNE;1
51020;;Aubilly;AUBILLY;51170;51;MARNE;1
51022;;Aulnay-l'Aître;AULNAY-L'AITRE;51240;51;MARNE;1
51023;;Aulnay-sur-Marne;AULNAY-SUR-MARNE;51150;51;MARNE;1
51025;;Auménancourt;AUMENANCOURT;51110;51;MARNE;1
51027;;Auve;AUVE;51800;51;MARNE;1
51028;;Avenay-Val-d'Or;AVENAY-VAL-D'OR;51160;51;MARNE;1
51029;;Avize;AVIZE;51190;51;MARNE;1
51030;;Ay;AY;51160;51;MARNE;1
51031;;Baconnes;BACONNES;51400;51;MARNE;1
51032;;Bagneux;BAGNEUX;51260;51;MARNE;1
51033;Le;Baizil;BAIZIL;51270;51;MARNE;1
51034;;Bannay;BANNAY;51270;51;MARNE;1
51035;;Bannes;BANNES;51230;51;MARNE;1
51036;;Barbonne-Fayel;BARBONNE-FAYEL;51120;51;MARNE;1
51037;;Baslieux-lès-Fismes;BASLIEUX-LES-FISMES;51170;51;MARNE;1
51038;;Baslieux-sous-Châtillon;BASLIEUX-SOUS-CHATILLON;51700;51;MARNE;1
51039;;Bassu;BASSU;51300;51;MARNE;1
51040;;Bassuet;BASSUET;51300;51;MARNE;1
51041;;Baudement;BAUDEMENT;51260;51;MARNE;1
51042;;Baye;BAYE;51270;51;MARNE;1
51043;;Bazancourt;BAZANCOURT;51110;51;MARNE;1
51044;;Beaumont-sur-Vesle;BEAUMONT-SUR-VESLE;51360;51;MARNE;1
51045;;Beaunay;BEAUNAY;51270;51;MARNE;1
51046;;Beine-Nauroy;BEINE-NAUROY;51490;51;MARNE;1
51047;;Belval-en-Argonne;BELVAL-EN-ARGONNE;51330;51;MARNE;1
51048;;Belval-sous-Châtillon;BELVAL-SOUS-CHATILLON;51480;51;MARNE;1
51049;;Bergères-lès-Vertus;BERGERES-LES-VERTUS;51130;51;MARNE;1
51050;;Bergères-sous-Montmirail;BERGERES-SOUS-MONTMIRAIL;51210;51;MARNE;1
51051;;Berméricourt;BERMERICOURT;51220;51;MARNE;1
51052;;Berru;BERRU;51420;51;MARNE;1
51053;;Berzieux;BERZIEUX;51800;51;MARNE;1
51054;;Bétheniville;BETHENIVILLE;51490;51;MARNE;1
51055;;Bétheny;BETHENY;51450;51;MARNE;1
51056;;Bethon;BETHON;51260;51;MARNE;1
51057;;Bettancourt-la-Longue;BETTANCOURT-LA-LONGUE;51330;51;MARNE;1
51058;;Bezannes;BEZANNES;51430;51;MARNE;1
51059;;Bignicourt-sur-Marne;BIGNICOURT-SUR-MARNE;51300;51;MARNE;1
51060;;Bignicourt-sur-Saulx;BIGNICOURT-SUR-SAULX;51340;51;MARNE;1
51061;;Billy-le-Grand;BILLY-LE-GRAND;51400;51;MARNE;1
51062;;Binarville;BINARVILLE;51800;51;MARNE;1
51063;;Binson-et-Orquigny;BINSON-ET-ORQUIGNY;51700;51;MARNE;1
51064;;Bisseuil;BISSEUIL;51150;51;MARNE;1
51065;;Blacy;BLACY;51300;51;MARNE;1
51066;;Blaise-sous-Arzillières;BLAISE-SOUS-ARZILLIERES;51300;51;MARNE;1
51068;;Blesme;BLESME;51340;51;MARNE;1
51069;;Bligny;BLIGNY;51170;51;MARNE;1
51070;;Boissy-le-Repos;BOISSY-LE-REPOS;51210;51;MARNE;1
51071;;Bouchy-Saint-Genest;BOUCHY-SAINT-GENEST;51310;51;MARNE;1
51072;;Bouilly;BOUILLY;51390;51;MARNE;1
51073;;Bouleuse;BOULEUSE;51170;51;MARNE;1
51074;;Boult-sur-Suippe;BOULT-SUR-SUIPPE;51110;51;MARNE;1
51075;;Bourgogne;BOURGOGNE;51110;51;MARNE;1
51076;;Boursault;BOURSAULT;51480;51;MARNE;1
51077;;Bouvancourt;BOUVANCOURT;51140;51;MARNE;1
51078;;Bouy;BOUY;51400;51;MARNE;1
51079;;Bouzy;BOUZY;51150;51;MARNE;1
51080;;Brandonvillers;BRANDONVILLERS;51290;51;MARNE;1
51081;;Branscourt;BRANSCOURT;51140;51;MARNE;1
51082;;Braux-Sainte-Cohière;BRAUX-SAINTE-COHIERE;51800;51;MARNE;1
51083;;Braux-Saint-Remy;BRAUX-SAINT-REMY;51800;51;MARNE;1
51084;;Bréban;BREBAN;51320;51;MARNE;1
51085;Le;Breuil;BREUIL;51210;51;MARNE;1
51086;;Breuil;BREUIL;51140;51;MARNE;1
51087;;Breuvery-sur-Coole;BREUVERY-SUR-COOLE;51240;51;MARNE;1
51088;;Brimont;BRIMONT;51220;51;MARNE;1
51089;;Brouillet;BROUILLET;51170;51;MARNE;1
51090;;Broussy-le-Grand;BROUSSY-LE-GRAND;51230;51;MARNE;1
51091;;Broussy-le-Petit;BROUSSY-LE-PETIT;51230;51;MARNE;1
51092;;Broyes;BROYES;51120;51;MARNE;1
51093;;Brugny-Vaudancourt;BRUGNY-VAUDANCOURT;51200;51;MARNE;1
51094;;Brusson;BRUSSON;51300;51;MARNE;1
51095;Le;Buisson;BUISSON;51300;51;MARNE;1
51097;;Bussy-le-Château;BUSSY-LE-CHATEAU;51600;51;MARNE;1
51098;;Bussy-le-Repos;BUSSY-LE-REPOS;51330;51;MARNE;1
51099;;Bussy-Lettrée;BUSSY-LETTREE;51320;51;MARNE;1
51100;La;Caure;CAURE;51270;51;MARNE;1
51101;;Caurel;CAUREL;51110;51;MARNE;1
51102;;Cauroy-lès-Hermonville;CAUROY-LES-HERMONVILLE;51220;51;MARNE;1
51103;La;Celle-sous-Chantemerle;CELLE-SOUS-CHANTEMERLE;51260;51;MARNE;1
51104;;Cernay-en-Dormois;CERNAY-EN-DORMOIS;51800;51;MARNE;1
51105;;Cernay-lès-Reims;CERNAY-LES-REIMS;51420;51;MARNE;1
51106;;Cernon;CERNON;51240;51;MARNE;1
51107;;Chaintrix-Bierges;CHAINTRIX-BIERGES;51130;51;MARNE;1
51108;;Châlons-en-Champagne;CHALONS-EN-CHAMPAGNE;51000;51;MARNE;1
51109;;Châlons-sur-Vesle;CHALONS-SUR-VESLE;51140;51;MARNE;1
51110;;Chaltrait;CHALTRAIT;51130;51;MARNE;1
51111;;Chambrecy;CHAMBRECY;51170;51;MARNE;1
51112;;Chamery;CHAMERY;51500;51;MARNE;1
51113;;Champaubert;CHAMPAUBERT;51270;51;MARNE;1
51115;;Champfleury;CHAMPFLEURY;51500;51;MARNE;1
51116;;Champguyon;CHAMPGUYON;51310;51;MARNE;1
51117;;Champigneul-Champagne;CHAMPIGNEUL-CHAMPAGNE;51150;51;MARNE;1
51118;;Champigny;CHAMPIGNY;51370;51;MARNE;1
51119;;Champillon;CHAMPILLON;51160;51;MARNE;1
51120;;Champlat-et-Boujacourt;CHAMPLAT-ET-BOUJACOURT;51480;51;MARNE;1
51121;;Champvoisy;CHAMPVOISY;51700;51;MARNE;1
51122;;Changy;CHANGY;51300;51;MARNE;1
51124;;Chantemerle;CHANTEMERLE;51260;51;MARNE;1
51125;;Chapelaine;CHAPELAINE;51290;51;MARNE;1
51126;La;Chapelle-Felcourt;CHAPELLE-FELCOURT;51800;51;MARNE;1
51127;La;Chapelle-Lasson;CHAPELLE-LASSON;51260;51;MARNE;1
51128;La;Chapelle-sous-Orbais;CHAPELLE-SOUS-ORBAIS;51270;51;MARNE;1
51129;;Charleville;CHARLEVILLE;51120;51;MARNE;1
51130;;Charmont;CHARMONT;51330;51;MARNE;1
51132;Les;Charmontois;CHARMONTOIS;51330;51;MARNE;1
51133;Le;Châtelier;CHATELIER;51330;51;MARNE;1
51134;;Châtelraould-Saint-Louvent;CHATELRAOULD-SAINT-LOUVENT;51300;51;MARNE;1
51135;;Châtillon-sur-Broué;CHATILLON-SUR-BROUE;51290;51;MARNE;1
51136;;Châtillon-sur-Marne;CHATILLON-SUR-MARNE;51700;51;MARNE;1
51137;;Châtillon-sur-Morin;CHATILLON-SUR-MORIN;51310;51;MARNE;1
51138;;Châtrices;CHATRICES;51800;51;MARNE;1
51139;;Chaudefontaine;CHAUDEFONTAINE;51800;51;MARNE;1
51140;;Chaumuzy;CHAUMUZY;51170;51;MARNE;1
51141;La;Chaussée-sur-Marne;CHAUSSEE-SUR-MARNE;51240;51;MARNE;1
51142;;Chavot-Courcourt;CHAVOT-COURCOURT;51200;51;MARNE;1
51143;Le;Chemin;CHEMIN;51800;51;MARNE;1
51144;;Cheminon;CHEMINON;51250;51;MARNE;1
51145;;Chenay;CHENAY;51140;51;MARNE;1
51146;;Cheniers;CHENIERS;51510;51;MARNE;1
51147;La;Cheppe;CHEPPE;51600;51;MARNE;1
51148;;Cheppes-la-Prairie;CHEPPES-LA-PRAIRIE;51240;51;MARNE;1
51149;;Chepy;CHEPY;51240;51;MARNE;1
51150;;Cherville;CHERVILLE;51150;51;MARNE;1
51151;;Chichey;CHICHEY;51120;51;MARNE;1
51152;;Chigny-les-Roses;CHIGNY-LES-ROSES;51500;51;MARNE;1
51153;;Chouilly;CHOUILLY;51200;51;MARNE;1
51154;;Clamanges;CLAMANGES;51130;51;MARNE;1
51155;;Clesles;CLESLES;51260;51;MARNE;1
51156;;Cloyes-sur-Marne;CLOYES-SUR-MARNE;51300;51;MARNE;1
51157;;Coizard-Joches;COIZARD-JOCHES;51270;51;MARNE;1
51158;;Val-des-Marais;VAL-DES-MARAIS;51130;51;MARNE;1
51160;;Compertrix;COMPERTRIX;51510;51;MARNE;1
51161;;Condé-sur-Marne;CONDE-SUR-MARNE;51150;51;MARNE;1
51162;;Conflans-sur-Seine;CONFLANS-SUR-SEINE;51260;51;MARNE;1
51163;;Congy;CONGY;51270;51;MARNE;1
51164;;Connantray-Vaurefroy;CONNANTRAY-VAUREFROY;51230;51;MARNE;1
51165;;Connantre;CONNANTRE;51230;51;MARNE;1
51166;;Contault;CONTAULT;51330;51;MARNE;1
51167;;Coole;COOLE;51320;51;MARNE;1
51168;;Coolus;COOLUS;51510;51;MARNE;1
51169;;Corbeil;CORBEIL;51320;51;MARNE;1
51170;;Corfélix;CORFELIX;51210;51;MARNE;1
51171;;Cormicy;CORMICY;51220;51;MARNE;1
51172;;Cormontreuil;CORMONTREUIL;51350;51;MARNE;1
51173;;Cormoyeux;CORMOYEUX;51480;51;MARNE;1
51174;;Corribert;CORRIBERT;51270;51;MARNE;1
51175;;Corrobert;CORROBERT;51210;51;MARNE;1
51176;;Corroy;CORROY;51230;51;MARNE;1
51177;;Coulommes-la-Montagne;COULOMMES-LA-MONTAGNE;51390;51;MARNE;1
51178;;Coupetz;COUPETZ;51240;51;MARNE;1
51179;;Coupéville;COUPEVILLE;51240;51;MARNE;1
51181;;Courcelles-Sapicourt;COURCELLES-SAPICOURT;51140;51;MARNE;1
51182;;Courcemain;COURCEMAIN;51260;51;MARNE;1
51183;;Courcy;COURCY;51220;51;MARNE;1
51184;;Courdemanges;COURDEMANGES;51300;51;MARNE;1
51185;;Courgivaux;COURGIVAUX;51310;51;MARNE;1
51186;;Courjeonnet;COURJEONNET;51270;51;MARNE;1
51187;;Courlandon;COURLANDON;51170;51;MARNE;1
51188;;Courmas;COURMAS;51390;51;MARNE;1
51190;;Courtagnon;COURTAGNON;51480;51;MARNE;1
51191;;Courtémont;COURTEMONT;51800;51;MARNE;1
51192;;Courthiézy;COURTHIEZY;51700;51;MARNE;1
51193;;Courtisols;COURTISOLS;51460;51;MARNE;1
51194;;Courville;COURVILLE;51170;51;MARNE;1
51195;;Couvrot;COUVROT;51300;51;MARNE;1
51196;;Cramant;CRAMANT;51200;51;MARNE;1
51197;La;Croix-en-Champagne;CROIX-EN-CHAMPAGNE;51600;51;MARNE;1
51198;;Crugny;CRUGNY;51170;51;MARNE;1
51199;;Cuchery;CUCHERY;51480;51;MARNE;1
51200;;Cuis;CUIS;51200;51;MARNE;1
51201;;Cuisles;CUISLES;51700;51;MARNE;1
51202;;Cumières;CUMIERES;51480;51;MARNE;1
51203;;Cuperly;CUPERLY;51400;51;MARNE;1
51204;;Damery;DAMERY;51480;51;MARNE;1
51205;;Dampierre-au-Temple;DAMPIERRE-AU-TEMPLE;51400;51;MARNE;1
51206;;Dampierre-le-Château;DAMPIERRE-LE-CHATEAU;51330;51;MARNE;1
51208;;Dampierre-sur-Moivre;DAMPIERRE-SUR-MOIVRE;51240;51;MARNE;1
51210;;Dizy;DIZY;51200;51;MARNE;1
51211;;Dommartin-Dampierre;DOMMARTIN-DAMPIERRE;51800;51;MARNE;1
51212;;Dommartin-Lettrée;DOMMARTIN-LETTREE;51320;51;MARNE;1
51213;;Dommartin-sous-Hans;DOMMARTIN-SOUS-HANS;51800;51;MARNE;1
51214;;Dommartin-Varimont;DOMMARTIN-VARIMONT;51330;51;MARNE;1
51215;;Dompremy;DOMPREMY;51300;51;MARNE;1
51216;;Dontrien;DONTRIEN;51490;51;MARNE;1
51217;;Dormans;DORMANS;51700;51;MARNE;1
51218;;Val-de-Vière;VAL-DE-VIERE;51340;51;MARNE;1
51219;;Drosnay;DROSNAY;51290;51;MARNE;1
51220;;Drouilly;DROUILLY;51300;51;MARNE;1
51222;;Éclaires;ECLAIRES;51800;51;MARNE;1
51223;;Écollemont;ECOLLEMONT;51290;51;MARNE;1
51224;;Écriennes;ECRIENNES;51300;51;MARNE;1
51225;;Écueil;ECUEIL;51500;51;MARNE;1
51226;;Écury-le-Repos;ECURY-LE-REPOS;51230;51;MARNE;1
51227;;Écury-sur-Coole;ECURY-SUR-COOLE;51240;51;MARNE;1
51228;;Élise-Daucourt;ELISE-DAUCOURT;51800;51;MARNE;1
51229;;Épense;EPENSE;51330;51;MARNE;1
51230;;Épernay;EPERNAY;51200;51;MARNE;1
51231;L';Épine;EPINE;51460;51;MARNE;1
51232;;Époye;EPOYE;51490;51;MARNE;1
51233;;Escardes;ESCARDES;51310;51;MARNE;1
51234;;Esclavolles-Lurey;ESCLAVOLLES-LUREY;51260;51;MARNE;1
51235;Les;Essarts-lès-Sézanne;ESSARTS-LES-SEZANNE;51120;51;MARNE;1
51236;Les;Essarts-le-Vicomte;ESSARTS-LE-VICOMTE;51310;51;MARNE;1
51237;;Esternay;ESTERNAY;51310;51;MARNE;1
51238;;Étoges;ETOGES;51270;51;MARNE;1
51239;;Étréchy;ETRECHY;51130;51;MARNE;1
51240;;Étrepy;ETREPY;51340;51;MARNE;1
51241;;Euvy;EUVY;51230;51;MARNE;1
51242;;Fagnières;FAGNIERES;51510;51;MARNE;1
51243;;Faux-Fresnay;FAUX-FRESNAY;51230;51;MARNE;1
51244;;Faux-Vésigneul;FAUX-VESIGNEUL;51320;51;MARNE;1
51245;;Faverolles-et-Coëmy;FAVEROLLES-ET-COEMY;51170;51;MARNE;1
51246;;Favresse;FAVRESSE;51300;51;MARNE;1
51247;;Fèrebrianges;FEREBRIANGES;51270;51;MARNE;1
51248;;Fère-Champenoise;FERE-CHAMPENOISE;51230;51;MARNE;1
51249;;Festigny;FESTIGNY;51700;51;MARNE;1
51250;;Fismes;FISMES;51170;51;MARNE;1
51251;;Flavigny;FLAVIGNY;51190;51;MARNE;1
51252;;Fleury-la-Rivière;FLEURY-LA-RIVIERE;51480;51;MARNE;1
51253;;Florent-en-Argonne;FLORENT-EN-ARGONNE;51800;51;MARNE;1
51254;;Fontaine-Denis-Nuisy;FONTAINE-DENIS-NUISY;51120;51;MARNE;1
51255;;Fontaine-en-Dormois;FONTAINE-EN-DORMOIS;51800;51;MARNE;1
51256;;Fontaine-sur-Ay;FONTAINE-SUR-AY;51160;51;MARNE;1
51258;La;Forestière;FORESTIERE;51120;51;MARNE;1
51259;;Francheville;FRANCHEVILLE;51240;51;MARNE;1
51260;Le;Fresne;FRESNE;51240;51;MARNE;1
51261;;Fresne-lès-Reims;FRESNE-LES-REIMS;51110;51;MARNE;1
51262;;Frignicourt;FRIGNICOURT;51300;51;MARNE;1
51263;;Fromentières;FROMENTIERES;51210;51;MARNE;1
51264;Le;Gault-Soigny;GAULT-SOIGNY;51210;51;MARNE;1
51265;;Gaye;GAYE;51120;51;MARNE;1
51266;;Germaine;GERMAINE;51160;51;MARNE;1
51267;;Germigny;GERMIGNY;51390;51;MARNE;1
51268;;Germinon;GERMINON;51130;51;MARNE;1
51269;;Giffaumont-Champaubert;GIFFAUMONT-CHAMPAUBERT;51290;51;MARNE;1
51270;;Gigny-Bussy;GIGNY-BUSSY;51290;51;MARNE;1
51271;;Gionges;GIONGES;51130;51;MARNE;1
51272;;Givry-en-Argonne;GIVRY-EN-ARGONNE;51330;51;MARNE;1
51273;;Givry-lès-Loisy;GIVRY-LES-LOISY;51130;51;MARNE;1
51274;;Gizaucourt;GIZAUCOURT;51800;51;MARNE;1
51275;;Glannes;GLANNES;51300;51;MARNE;1
51276;;Gourgançon;GOURGANCON;51230;51;MARNE;1
51277;;Sainte-Marie-du-Lac-Nuisement;SAINTE-MARIE-DU-LAC-NUISEMENT;51290;51;MARNE;1
51278;Les;Grandes-Loges;GRANDES-LOGES;51400;51;MARNE;1
51279;;Granges-sur-Aube;GRANGES-SUR-AUBE;51260;51;MARNE;1
51280;;Gratreuil;GRATREUIL;51800;51;MARNE;1
51281;;Grauves;GRAUVES;51190;51;MARNE;1
51282;;Gueux;GUEUX;51390;51;MARNE;1
51283;;Hans;HANS;51800;51;MARNE;1
51284;;Haussignémont;HAUSSIGNEMONT;51300;51;MARNE;1
51285;;Haussimont;HAUSSIMONT;51320;51;MARNE;1
51286;;Hauteville;HAUTEVILLE;51290;51;MARNE;1
51287;;Hautvillers;HAUTVILLERS;51160;51;MARNE;1
51288;;Heiltz-le-Hutier;HEILTZ-LE-HUTIER;51300;51;MARNE;1
51289;;Heiltz-le-Maurupt;HEILTZ-LE-MAURUPT;51340;51;MARNE;1
51290;;Heiltz-l'Évêque;HEILTZ-L'EVEQUE;51340;51;MARNE;1
51291;;Hermonville;HERMONVILLE;51220;51;MARNE;1
51292;;Herpont;HERPONT;51460;51;MARNE;1
51293;;Heutrégiville;HEUTREGIVILLE;51110;51;MARNE;1
51294;;Hourges;HOURGES;51140;51;MARNE;1
51295;;Huiron;HUIRON;51300;51;MARNE;1
51296;;Humbauville;HUMBAUVILLE;51320;51;MARNE;1
51298;;Igny-Comblizy;IGNY-COMBLIZY;51700;51;MARNE;1
51299;;Isles-sur-Suippe;ISLES-SUR-SUIPPE;51110;51;MARNE;1
51300;;Isle-sur-Marne;ISLE-SUR-MARNE;51290;51;MARNE;1
51301;;Isse;ISSE;51150;51;MARNE;1
51302;Les;Istres-et-Bury;ISTRES-ET-BURY;51190;51;MARNE;1
51303;;Jâlons;JALONS;51150;51;MARNE;1
51304;;Janvilliers;JANVILLIERS;51210;51;MARNE;1
51305;;Janvry;JANVRY;51390;51;MARNE;1
51306;;Joiselle;JOISELLE;51310;51;MARNE;1
51307;;Jonchery-sur-Suippe;JONCHERY-SUR-SUIPPE;51600;51;MARNE;1
51308;;Jonchery-sur-Vesle;JONCHERY-SUR-VESLE;51140;51;MARNE;1
51309;;Jonquery;JONQUERY;51700;51;MARNE;1
51310;;Jouy-lès-Reims;JOUY-LES-REIMS;51390;51;MARNE;1
51311;;Jussecourt-Minecourt;JUSSECOURT-MINECOURT;51340;51;MARNE;1
51312;;Juvigny;JUVIGNY;51150;51;MARNE;1
51313;;Lachy;LACHY;51120;51;MARNE;1
51314;;Lagery;LAGERY;51170;51;MARNE;1
51315;;Landricourt;LANDRICOURT;51290;51;MARNE;1
51316;;Larzicourt;LARZICOURT;51290;51;MARNE;1
51317;;Laval-sur-Tourbe;LAVAL-SUR-TOURBE;51600;51;MARNE;1
51318;;Lavannes;LAVANNES;51110;51;MARNE;1
51319;;Lenharrée;LENHARREE;51230;51;MARNE;1
51320;;Leuvrigny;LEUVRIGNY;51700;51;MARNE;1
51321;;Lhéry;LHERY;51170;51;MARNE;1
51322;;Lignon;LIGNON;51290;51;MARNE;1
51323;;Linthelles;LINTHELLES;51230;51;MARNE;1
51324;;Linthes;LINTHES;51230;51;MARNE;1
51325;;Lisse-en-Champagne;LISSE-EN-CHAMPAGNE;51300;51;MARNE;1
51326;;Livry-Louvercy;LIVRY-LOUVERCY;51400;51;MARNE;1
51327;;Loisy-en-Brie;LOISY-EN-BRIE;51130;51;MARNE;1
51328;;Loisy-sur-Marne;LOISY-SUR-MARNE;51300;51;MARNE;1
51329;;Loivre;LOIVRE;51220;51;MARNE;1
51331;;Louvois;LOUVOIS;51150;51;MARNE;1
51333;;Ludes;LUDES;51500;51;MARNE;1
51334;;Luxémont-et-Villotte;LUXEMONT-ET-VILLOTTE;51300;51;MARNE;1
51336;;Maffrécourt;MAFFRECOURT;51800;51;MARNE;1
51337;;Magneux;MAGNEUX;51170;51;MARNE;1
51338;;Mailly-Champagne;MAILLY-CHAMPAGNE;51500;51;MARNE;1
51339;;Mairy-sur-Marne;MAIRY-SUR-MARNE;51240;51;MARNE;1
51340;;Maisons-en-Champagne;MAISONS-EN-CHAMPAGNE;51300;51;MARNE;1
51341;;Malmy;MALMY;51800;51;MARNE;1
51342;;Mancy;MANCY;51200;51;MARNE;1
51343;;Marcilly-sur-Seine;MARCILLY-SUR-SEINE;51260;51;MARNE;1
51344;;Mardeuil;MARDEUIL;51200;51;MARNE;1
51345;;Mareuil-en-Brie;MAREUIL-EN-BRIE;51270;51;MARNE;1
51346;;Mareuil-le-Port;MAREUIL-LE-PORT;51700;51;MARNE;1
51347;;Mareuil-sur-Ay;MAREUIL-SUR-AY;51160;51;MARNE;1
51348;;Marfaux;MARFAUX;51170;51;MARNE;1
51349;;Margerie-Hancourt;MARGERIE-HANCOURT;51290;51;MARNE;1
51350;;Margny;MARGNY;51210;51;MARNE;1
51351;;Marigny;MARIGNY;51230;51;MARNE;1
51352;;Marolles;MAROLLES;51300;51;MARNE;1
51353;;Marsangis;MARSANGIS;51260;51;MARNE;1
51354;;Marson;MARSON;51240;51;MARNE;1
51355;;Massiges;MASSIGES;51800;51;MARNE;1
51356;;Matignicourt-Goncourt;MATIGNICOURT-GONCOURT;51300;51;MARNE;1
51357;;Matougues;MATOUGUES;51510;51;MARNE;1
51358;;Maurupt-le-Montois;MAURUPT-LE-MONTOIS;51340;51;MARNE;1
51359;;Mécringes;MECRINGES;51210;51;MARNE;1
51360;Le;Meix-Saint-Epoing;MEIX-SAINT-EPOING;51120;51;MARNE;1
51361;Le;Meix-Tiercelin;MEIX-TIERCELIN;51320;51;MARNE;1
51362;;Merfy;MERFY;51220;51;MARNE;1
51363;;Merlaut;MERLAUT;51300;51;MARNE;1
51364;;Méry-Prémecy;MERY-PREMECY;51390;51;MARNE;1
51365;Les;Mesneux;MESNEUX;51370;51;MARNE;1
51367;Le;Mesnil-sur-Oger;MESNIL-SUR-OGER;51190;51;MARNE;1
51368;;Minaucourt-le-Mesnil-lès-Hurlus;MINAUCOURT-LE-MESNIL-LES-HURLUS;51800;51;MARNE;1
51369;;Mœurs-Verdey;MOEURS-VERDEY;51120;51;MARNE;1
51370;;Moiremont;MOIREMONT;51800;51;MARNE;1
51371;;Moivre;MOIVRE;51240;51;MARNE;1
51372;;Moncetz-Longevas;MONCETZ-LONGEVAS;51470;51;MARNE;1
51373;;Moncetz-l'Abbaye;MONCETZ-L'ABBAYE;51290;51;MARNE;1
51374;;Mondement-Montgivroux;MONDEMENT-MONTGIVROUX;51120;51;MARNE;1
51375;;Montbré;MONTBRE;51500;51;MARNE;1
51376;;Montgenost;MONTGENOST;51260;51;MARNE;1
51377;;Montépreux;MONTEPREUX;51320;51;MARNE;1
51378;;Monthelon;MONTHELON;51200;51;MARNE;1
51379;;Montigny-sur-Vesle;MONTIGNY-SUR-VESLE;51140;51;MARNE;1
51380;;Montmirail;MONTMIRAIL;51210;51;MARNE;1
51381;;Montmort-Lucy;MONTMORT-LUCY;51270;51;MARNE;1
51382;;Mont-sur-Courville;MONT-SUR-COURVILLE;51170;51;MARNE;1
51384;;Morangis;MORANGIS;51200;51;MARNE;1
51386;;Morsains;MORSAINS;51210;51;MARNE;1
51387;;Moslins;MOSLINS;51200;51;MARNE;1
51388;;Mourmelon-le-Grand;MOURMELON-LE-GRAND;51400;51;MARNE;1
51389;;Mourmelon-le-Petit;MOURMELON-LE-PETIT;51400;51;MARNE;1
51390;;Moussy;MOUSSY;51200;51;MARNE;1
51391;;Muizon;MUIZON;51140;51;MARNE;1
51392;;Mutigny;MUTIGNY;51160;51;MARNE;1
51393;;Nanteuil-la-Forêt;NANTEUIL-LA-FORET;51480;51;MARNE;1
51395;;Nesle-la-Reposte;NESLE-LA-REPOSTE;51120;51;MARNE;1
51396;;Nesle-le-Repons;NESLE-LE-REPONS;51700;51;MARNE;1
51397;La;Neuville-aux-Bois;NEUVILLE-AUX-BOIS;51330;51;MARNE;1
51398;La;Neuville-aux-Larris;NEUVILLE-AUX-LARRIS;51480;51;MARNE;1
51399;La;Neuville-au-Pont;NEUVILLE-AU-PONT;51800;51;MARNE;1
51402;;Neuvy;NEUVY;51310;51;MARNE;1
51403;;Nogent-l'Abbesse;NOGENT-L'ABBESSE;51420;51;MARNE;1
51404;;Noirlieu;NOIRLIEU;51330;51;MARNE;1
51406;;Norrois;NORROIS;51300;51;MARNE;1
51407;La;Noue;NOUE;51310;51;MARNE;1
51409;;Nuisement-sur-Coole;NUISEMENT-SUR-COOLE;51240;51;MARNE;1
51410;;Œuilly;OEUILLY;51480;51;MARNE;1
51411;;Oger;OGER;51190;51;MARNE;1
51412;;Ognes;OGNES;51230;51;MARNE;1
51413;;Oiry;OIRY;51200;51;MARNE;1
51414;;Olizy;OLIZY;51700;51;MARNE;1
51415;;Omey;OMEY;51240;51;MARNE;1
51416;;Orbais-l'Abbaye;ORBAIS-L'ABBAYE;51270;51;MARNE;1
51417;;Orconte;ORCONTE;51300;51;MARNE;1
51418;;Ormes;ORMES;51370;51;MARNE;1
51419;;Outines;OUTINES;51290;51;MARNE;1
51420;;Outrepont;OUTREPONT;51300;51;MARNE;1
51421;;Oyes;OYES;51120;51;MARNE;1
51422;;Pargny-lès-Reims;PARGNY-LES-REIMS;51390;51;MARNE;1
51423;;Pargny-sur-Saulx;PARGNY-SUR-SAULX;51340;51;MARNE;1
51424;;Passavant-en-Argonne;PASSAVANT-EN-ARGONNE;51800;51;MARNE;1
51425;;Passy-Grigny;PASSY-GRIGNY;51700;51;MARNE;1
51426;;Péas;PEAS;51120;51;MARNE;1
51428;Les;Petites-Loges;PETITES-LOGES;51400;51;MARNE;1
51429;;Pévy;PEVY;51140;51;MARNE;1
51430;;Pierre-Morains;PIERRE-MORAINS;51130;51;MARNE;1
51431;;Pierry;PIERRY;51200;51;MARNE;1
51432;;Pleurs;PLEURS;51230;51;MARNE;1
51433;;Plichancourt;PLICHANCOURT;51300;51;MARNE;1
51434;;Plivot;PLIVOT;51150;51;MARNE;1
51435;;Pocancy;POCANCY;51130;51;MARNE;1
51436;;Pogny;POGNY;51240;51;MARNE;1
51437;;Poilly;POILLY;51170;51;MARNE;1
51438;;Poix;POIX;51460;51;MARNE;1
51439;;Pomacle;POMACLE;51110;51;MARNE;1
51440;;Pontfaverger-Moronvilliers;PONTFAVERGER-MORONVILLIERS;51490;51;MARNE;1
51441;;Ponthion;PONTHION;51300;51;MARNE;1
51442;;Possesse;POSSESSE;51330;51;MARNE;1
51443;;Potangis;POTANGIS;51260;51;MARNE;1
51444;;Pouillon;POUILLON;51220;51;MARNE;1
51445;;Pourcy;POURCY;51480;51;MARNE;1
51446;;Pringy;PRINGY;51300;51;MARNE;1
51447;;Prosnes;PROSNES;51400;51;MARNE;1
51448;;Prouilly;PROUILLY;51140;51;MARNE;1
51449;;Prunay;PRUNAY;51360;51;MARNE;1
51450;;Puisieulx;PUISIEULX;51500;51;MARNE;1
51451;;Queudes;QUEUDES;51120;51;MARNE;1
51452;;Rapsécourt;RAPSECOURT;51330;51;MARNE;1
51453;;Recy;RECY;51520;51;MARNE;1
51454;;Reims;REIMS;51100;51;MARNE;1
51455;;Reims-la-Brûlée;REIMS-LA-BRULEE;51300;51;MARNE;1
51456;;Remicourt;REMICOURT;51330;51;MARNE;1
51457;;Reuil;REUIL;51480;51;MARNE;1
51458;;Reuves;REUVES;51120;51;MARNE;1
51459;;Réveillon;REVEILLON;51310;51;MARNE;1
51460;;Rieux;RIEUX;51210;51;MARNE;1
51461;;Rilly-la-Montagne;RILLY-LA-MONTAGNE;51500;51;MARNE;1
51463;Les;Rivières-Henruel;RIVIERES-HENRUEL;51300;51;MARNE;1
51464;;Romain;ROMAIN;51140;51;MARNE;1
51465;;Romery;ROMERY;51480;51;MARNE;1
51466;;Romigny;ROMIGNY;51170;51;MARNE;1
51468;;Rosnay;ROSNAY;51390;51;MARNE;1
51469;;Rouffy;ROUFFY;51130;51;MARNE;1
51470;;Rouvroy-Ripont;ROUVROY-RIPONT;51800;51;MARNE;1
51471;;Sacy;SACY;51500;51;MARNE;1
51472;;Saint-Amand-sur-Fion;SAINT-AMAND-SUR-FION;51300;51;MARNE;1
51473;;Saint-Bon;SAINT-BON;51310;51;MARNE;1
51474;;Saint-Brice-Courcelles;SAINT-BRICE-COURCELLES;51370;51;MARNE;1
51475;;Saint-Chéron;SAINT-CHERON;51290;51;MARNE;1
51476;;Saint-Étienne-au-Temple;SAINT-ETIENNE-AU-TEMPLE;51460;51;MARNE;1
51477;;Saint-Étienne-sur-Suippe;SAINT-ETIENNE-SUR-SUIPPE;51110;51;MARNE;1
51478;;Saint-Eulien;SAINT-EULIEN;52100;51;HAUTE MARNE;1
51479;;Saint-Euphraise-et-Clairizet;SAINT-EUPHRAISE-ET-CLAIRIZET;51390;51;MARNE;1
51480;;Sainte-Gemme;SAINTE-GEMME;51700;51;MARNE;1
51482;;Saint-Germain-la-Ville;SAINT-GERMAIN-LA-VILLE;51240;51;MARNE;1
51483;;Saint-Gibrien;SAINT-GIBRIEN;51510;51;MARNE;1
51484;;Saint-Gilles;SAINT-GILLES;51170;51;MARNE;1
51485;;Saint-Hilaire-au-Temple;SAINT-HILAIRE-AU-TEMPLE;51400;51;MARNE;1
51486;;Saint-Hilaire-le-Grand;SAINT-HILAIRE-LE-GRAND;51600;51;MARNE;1
51487;;Saint-Hilaire-le-Petit;SAINT-HILAIRE-LE-PETIT;51490;51;MARNE;1
51488;;Saint-Imoges;SAINT-IMOGES;51160;51;MARNE;1
51489;;Saint-Jean-devant-Possesse;SAINT-JEAN-DEVANT-POSSESSE;51330;51;MARNE;1
51490;;Saint-Jean-sur-Moivre;SAINT-JEAN-SUR-MOIVRE;51240;51;MARNE;1
51491;;Saint-Jean-sur-Tourbe;SAINT-JEAN-SUR-TOURBE;51600;51;MARNE;1
51492;;Saint-Just-Sauvage;SAINT-JUST-SAUVAGE;51260;51;MARNE;1
51493;;Saint-Léonard;SAINT-LEONARD;51500;51;MARNE;1
51495;;Saint-Loup;SAINT-LOUP;51120;51;MARNE;1
51496;;Saint-Lumier-en-Champagne;SAINT-LUMIER-EN-CHAMPAGNE;51300;51;MARNE;1
51497;;Saint-Lumier-la-Populeuse;SAINT-LUMIER-LA-POPULEUSE;51340;51;MARNE;1
51498;;Saint-Mard-sur-Auve;SAINT-MARD-SUR-AUVE;51800;51;MARNE;1
51499;;Saint-Mard-lès-Rouffy;SAINT-MARD-LES-ROUFFY;51130;51;MARNE;1
51500;;Saint-Mard-sur-le-Mont;SAINT-MARD-SUR-LE-MONT;51330;51;MARNE;1
51501;;Sainte-Marie-à-Py;SAINTE-MARIE-A-PY;51600;51;MARNE;1
51502;;Saint-Martin-aux-Champs;SAINT-MARTIN-AUX-CHAMPS;51240;51;MARNE;1
51503;;Saint-Martin-l'Heureux;SAINT-MARTIN-L'HEUREUX;51490;51;MARNE;1
51504;;Saint-Martin-sur-le-Pré;SAINT-MARTIN-SUR-LE-PRE;51520;51;MARNE;1
51505;;Saint-Masmes;SAINT-MASMES;51490;51;MARNE;1
51506;;Saint-Memmie;SAINT-MEMMIE;51470;51;MARNE;1
51507;;Sainte-Menehould;SAINTE-MENEHOULD;51800;51;MARNE;1
51508;;Saint-Ouen-Domprot;SAINT-OUEN-DOMPROT;51320;51;MARNE;1
51509;;Saint-Pierre;SAINT-PIERRE;51510;51;MARNE;1
51510;;Saint-Quentin-les-Marais;SAINT-QUENTIN-LES-MARAIS;51300;51;MARNE;1
51511;;Saint-Quentin-le-Verger;SAINT-QUENTIN-LE-VERGER;51120;51;MARNE;1
51512;;Saint-Quentin-sur-Coole;SAINT-QUENTIN-SUR-COOLE;51240;51;MARNE;1
51513;;Saint-Remy-en-Bouzemont-Saint-Genest-et-Isson;SAINT-REMY-EN-BOUZEMONT-SAINT-GENEST-ET-ISSON;51290;51;MARNE;1
51514;;Saint-Remy-sous-Broyes;SAINT-REMY-SOUS-BROYES;51120;51;MARNE;1
51515;;Saint-Remy-sur-Bussy;SAINT-REMY-SUR-BUSSY;51600;51;MARNE;1
51516;;Saint-Saturnin;SAINT-SATURNIN;51260;51;MARNE;1
51517;;Saint-Souplet-sur-Py;SAINT-SOUPLET-SUR-PY;51600;51;MARNE;1
51518;;Saint-Thierry;SAINT-THIERRY;51220;51;MARNE;1
51519;;Saint-Thomas-en-Argonne;SAINT-THOMAS-EN-ARGONNE;51800;51;MARNE;1
51520;;Saint-Utin;SAINT-UTIN;51290;51;MARNE;1
51521;;Saint-Vrain;SAINT-VRAIN;51340;51;MARNE;1
51522;;Sapignicourt;SAPIGNICOURT;52100;51;HAUTE MARNE;1
51523;;Sarcy;SARCY;51170;51;MARNE;1
51524;;Saron-sur-Aube;SARON-SUR-AUBE;51260;51;MARNE;1
51525;;Sarry;SARRY;51520;51;MARNE;1
51526;;Saudoy;SAUDOY;51120;51;MARNE;1
51527;;Savigny-sur-Ardres;SAVIGNY-SUR-ARDRES;51170;51;MARNE;1
51528;;Scrupt;SCRUPT;51340;51;MARNE;1
51529;;Selles;SELLES;51490;51;MARNE;1
51530;;Sept-Saulx;SEPT-SAULX;51400;51;MARNE;1
51531;;Sermaize-les-Bains;SERMAIZE-LES-BAINS;51250;51;MARNE;1
51532;;Sermiers;SERMIERS;51500;51;MARNE;1
51533;;Servon-Melzicourt;SERVON-MELZICOURT;51800;51;MARNE;1
51534;;Serzy-et-Prin;SERZY-ET-PRIN;51170;51;MARNE;1
51535;;Sézanne;SEZANNE;51120;51;MARNE;1
51536;;Sillery;SILLERY;51500;51;MARNE;1
51537;;Sivry-Ante;SIVRY-ANTE;51800;51;MARNE;1
51538;;Sogny-aux-Moulins;SOGNY-AUX-MOULINS;51520;51;MARNE;1
51539;;Sogny-en-l'Angle;SOGNY-EN-L'ANGLE;51340;51;MARNE;1
51542;;Soizy-aux-Bois;SOIZY-AUX-BOIS;51120;51;MARNE;1
51543;;Somme-Bionne;SOMME-BIONNE;51800;51;MARNE;1
51544;;Sommepy-Tahure;SOMMEPY-TAHURE;51600;51;MARNE;1
51545;;Sommesous;SOMMESOUS;51320;51;MARNE;1
51546;;Somme-Suippe;SOMME-SUIPPE;51600;51;MARNE;1
51547;;Somme-Tourbe;SOMME-TOURBE;51600;51;MARNE;1
51548;;Somme-Vesle;SOMME-VESLE;51460;51;MARNE;1
51549;;Somme-Yèvre;SOMME-YEVRE;51330;51;MARNE;1
51550;;Sompuis;SOMPUIS;51320;51;MARNE;1
51551;;Somsois;SOMSOIS;51290;51;MARNE;1
51552;;Songy;SONGY;51240;51;MARNE;1
51553;;Souain-Perthes-lès-Hurlus;SOUAIN-PERTHES-LES-HURLUS;51600;51;MARNE;1
51555;;Soudé;SOUDE;51320;51;MARNE;1
51556;;Soudron;SOUDRON;51320;51;MARNE;1
51557;;Soulanges;SOULANGES;51300;51;MARNE;1
51558;;Soulières;SOULIERES;51130;51;MARNE;1
51559;;Suippes;SUIPPES;51600;51;MARNE;1
51560;;Suizy-le-Franc;SUIZY-LE-FRANC;51270;51;MARNE;1
51562;;Taissy;TAISSY;51500;51;MARNE;1
51563;;Talus-Saint-Prix;TALUS-SAINT-PRIX;51270;51;MARNE;1
51564;;Tauxières-Mutry;TAUXIERES-MUTRY;51150;51;MARNE;1
51565;;Thaas;THAAS;51230;51;MARNE;1
51566;;Thibie;THIBIE;51510;51;MARNE;1
51567;;Thiéblemont-Farémont;THIEBLEMONT-FAREMONT;51300;51;MARNE;1
51568;;Thil;THIL;51220;51;MARNE;1
51569;;Thillois;THILLOIS;51370;51;MARNE;1
51570;Le;Thoult-Trosnay;THOULT-TROSNAY;51210;51;MARNE;1
51571;;Val-de-Vesle;VAL-DE-VESLE;51360;51;MARNE;1
51572;;Tilloy-et-Bellay;TILLOY-ET-BELLAY;51460;51;MARNE;1
51573;;Tinqueux;TINQUEUX;51430;51;MARNE;1
51574;;Togny-aux-Bœufs;TOGNY-AUX-BOEUFS;51240;51;MARNE;1
51576;;Tours-sur-Marne;TOURS-SUR-MARNE;51150;51;MARNE;1
51577;;Tramery;TRAMERY;51170;51;MARNE;1
51578;;Trécon;TRECON;51130;51;MARNE;1
51579;;Tréfols;TREFOLS;51210;51;MARNE;1
51580;;Trépail;TREPAIL;51380;51;MARNE;1
51581;;Treslon;TRESLON;51140;51;MARNE;1
51582;;Trigny;TRIGNY;51140;51;MARNE;1
51583;;Trois-Fontaines-l'Abbaye;TROIS-FONTAINES-L'ABBAYE;51340;51;MARNE;1
51584;;Trois-Puits;TROIS-PUITS;51500;51;MARNE;1
51585;;Troissy;TROISSY;51700;51;MARNE;1
51586;;Unchair;UNCHAIR;51170;51;MARNE;1
51587;;Vadenay;VADENAY;51400;51;MARNE;1
51588;;Valmy;VALMY;51800;51;MARNE;1
51589;;Vanault-le-Châtel;VANAULT-LE-CHATEL;51330;51;MARNE;1
51590;;Vanault-les-Dames;VANAULT-LES-DAMES;51340;51;MARNE;1
51591;;Vandeuil;VANDEUIL;51140;51;MARNE;1
51592;;Vandières;VANDIERES;51700;51;MARNE;1
51594;;Vassimont-et-Chapelaine;VASSIMONT-ET-CHAPELAINE;51320;51;MARNE;1
51595;;Vatry;VATRY;51320;51;MARNE;1
51596;;Vauchamps;VAUCHAMPS;51210;51;MARNE;1
51597;;Vauciennes;VAUCIENNES;51480;51;MARNE;1
51598;;Vauclerc;VAUCLERC;51300;51;MARNE;1
51599;;Vaudemange;VAUDEMANGE;51380;51;MARNE;1
51600;;Vaudesincourt;VAUDESINCOURT;51600;51;MARNE;1
51601;;Vavray-le-Grand;VAVRAY-LE-GRAND;51300;51;MARNE;1
51602;;Vavray-le-Petit;VAVRAY-LE-PETIT;51300;51;MARNE;1
51603;;Vélye;VELYE;51130;51;MARNE;1
51604;;Ventelay;VENTELAY;51140;51;MARNE;1
51605;;Venteuil;VENTEUIL;51480;51;MARNE;1
51607;;Verdon;VERDON;51210;51;MARNE;1
51608;;Vernancourt;VERNANCOURT;51330;51;MARNE;1
51609;;Verneuil;VERNEUIL;51700;51;MARNE;1
51610;;Verrières;VERRIERES;51800;51;MARNE;1
51611;;Vert-Toulon;VERT-TOULON;51130;51;MARNE;1
51612;;Vertus;VERTUS;51130;51;MARNE;1
51613;;Verzenay;VERZENAY;51360;51;MARNE;1
51614;;Verzy;VERZY;51380;51;MARNE;1
51616;;Vésigneul-sur-Marne;VESIGNEUL-SUR-MARNE;51240;51;MARNE;1
51617;La;Veuve;VEUVE;51520;51;MARNE;1
51618;Le;Vézier;VEZIER;51210;51;MARNE;1
51619;Le;Vieil-Dampierre;VIEIL-DAMPIERRE;51330;51;MARNE;1
51620;;Vienne-la-Ville;VIENNE-LA-VILLE;51800;51;MARNE;1
51621;;Vienne-le-Château;VIENNE-LE-CHATEAU;51800;51;MARNE;1
51622;;Ville-Dommange;VILLE-DOMMANGE;51390;51;MARNE;1
51623;;Ville-en-Selve;VILLE-EN-SELVE;51500;51;MARNE;1
51624;;Ville-en-Tardenois;VILLE-EN-TARDENOIS;51170;51;MARNE;1
51625;;Villeneuve-la-Lionne;VILLENEUVE-LA-LIONNE;51310;51;MARNE;1
51626;La;Villeneuve-lès-Charleville;VILLENEUVE-LES-CHARLEVILLE;51120;51;MARNE;1
51627;;Villeneuve-Renneville-Chevigny;VILLENEUVE-RENNEVILLE-CHEVIGNY;51130;51;MARNE;1
51628;;Villeneuve-Saint-Vistre-et-Villevotte;VILLENEUVE-SAINT-VISTRE-ET-VILLEVOTTE;51120;51;MARNE;1
51629;;Villers-Allerand;VILLERS-ALLERAND;51500;51;MARNE;1
51630;;Villers-aux-Bois;VILLERS-AUX-BOIS;51130;51;MARNE;1
51631;;Villers-aux-Nœuds;VILLERS-AUX-NOEUDS;51500;51;MARNE;1
51632;;Villers-en-Argonne;VILLERS-EN-ARGONNE;51800;51;MARNE;1
51633;;Villers-Franqueux;VILLERS-FRANQUEUX;51220;51;MARNE;1
51634;;Villers-le-Château;VILLERS-LE-CHATEAU;51510;51;MARNE;1
51635;;Villers-le-Sec;VILLERS-LE-SEC;51250;51;MARNE;1
51636;;Villers-Marmery;VILLERS-MARMERY;51380;51;MARNE;1
51637;;Villers-sous-Châtillon;VILLERS-SOUS-CHATILLON;51700;51;MARNE;1
51638;;Villeseneux;VILLESENEUX;51130;51;MARNE;1
51639;La;Ville-sous-Orbais;VILLE-SOUS-ORBAIS;51270;51;MARNE;1
51640;;Ville-sur-Tourbe;VILLE-SUR-TOURBE;51800;51;MARNE;1
51641;;Villevenard;VILLEVENARD;51270;51;MARNE;1
51642;;Villiers-aux-Corneilles;VILLIERS-AUX-CORNEILLES;51260;51;MARNE;1
51643;;Vinay;VINAY;51200;51;MARNE;1
51644;;Vincelles;VINCELLES;51700;51;MARNE;1
51645;;Vindey;VINDEY;51120;51;MARNE;1
51646;;Virginy;VIRGINY;51800;51;MARNE;1
51647;;Vitry-en-Perthois;VITRY-EN-PERTHOIS;51300;51;MARNE;1
51648;;Vitry-la-Ville;VITRY-LA-VILLE;51240;51;MARNE;1
51649;;Vitry-le-François;VITRY-LE-FRANCOIS;51300;51;MARNE;1
51650;;Voilemont;VOILEMONT;51800;51;MARNE;1
51651;;Voipreux;VOIPREUX;51130;51;MARNE;1
51652;;Vouarces;VOUARCES;51260;51;MARNE;1
51654;;Vouillers;VOUILLERS;51340;51;MARNE;1
51655;;Vouzy;VOUZY;51130;51;MARNE;1
51656;;Vraux;VRAUX;51150;51;MARNE;1
51657;;Vrigny;VRIGNY;51390;51;MARNE;1
51658;;Vroil;VROIL;51330;51;MARNE;1
51659;;Wargemoulin-Hurlus;WARGEMOULIN-HURLUS;51800;51;MARNE;1
51660;;Warmeriville;WARMERIVILLE;51110;51;MARNE;1
51662;;Witry-lès-Reims;WITRY-LES-REIMS;51420;51;MARNE;1
51663;;Magenta;MAGENTA;51200;51;MARNE;1
52001;;Ageville;AGEVILLE;52340;52;HAUTE MARNE;1
52002;;Aigremont;AIGREMONT;52400;52;HAUTE MARNE;1
52003;;Aillianville;AILLIANVILLE;52700;52;HAUTE MARNE;1
52004;;Aingoulaincourt;AINGOULAINCOURT;52230;52;HAUTE MARNE;1
52005;;Aizanville;AIZANVILLE;52120;52;HAUTE MARNE;1
52006;;Allichamps;ALLICHAMPS;52130;52;HAUTE MARNE;1
52007;;Ambonville;AMBONVILLE;52110;52;HAUTE MARNE;1
52008;;Andelot-Blancheville;ANDELOT-BLANCHEVILLE;52700;52;HAUTE MARNE;1
52009;;Andilly-en-Bassigny;ANDILLY-EN-BASSIGNY;52360;52;HAUTE MARNE;1
52011;;Annéville-la-Prairie;ANNEVILLE-LA-PRAIRIE;52310;52;HAUTE MARNE;1
52012;;Annonville;ANNONVILLE;52230;52;HAUTE MARNE;1
52013;;Anrosey;ANROSEY;52500;52;HAUTE MARNE;1
52014;;Aprey;APREY;52250;52;HAUTE MARNE;1
52015;;Arbigny-sous-Varennes;ARBIGNY-SOUS-VARENNES;52500;52;HAUTE MARNE;1
52016;;Arbot;ARBOT;52160;52;HAUTE MARNE;1
52017;;Arc-en-Barrois;ARC-EN-BARROIS;52210;52;HAUTE MARNE;1
52019;;Arnancourt;ARNANCOURT;52110;52;HAUTE MARNE;1
52021;;Attancourt;ATTANCOURT;52130;52;HAUTE MARNE;1
52022;;Aubepierre-sur-Aube;AUBEPIERRE-SUR-AUBE;52210;52;HAUTE MARNE;1
52023;;Auberive;AUBERIVE;52160;52;HAUTE MARNE;1
52025;;Audeloncourt;AUDELONCOURT;52240;52;HAUTE MARNE;1
52027;;Aujeurres;AUJEURRES;52190;52;HAUTE MARNE;1
52028;;Aulnoy-sur-Aube;AULNOY-SUR-AUBE;52160;52;HAUTE MARNE;1
52029;;Autigny-le-Grand;AUTIGNY-LE-GRAND;52300;52;HAUTE MARNE;1
52030;;Autigny-le-Petit;AUTIGNY-LE-PETIT;52300;52;HAUTE MARNE;1
52031;;Autreville-sur-la-Renne;AUTREVILLE-SUR-LA-RENNE;52120;52;HAUTE MARNE;1
52033;;Avrecourt;AVRECOURT;52140;52;HAUTE MARNE;1
52034;;Bailly-aux-Forges;BAILLY-AUX-FORGES;52130;52;HAUTE MARNE;1
52035;;Baissey;BAISSEY;52250;52;HAUTE MARNE;1
52036;;Balesmes-sur-Marne;BALESMES-SUR-MARNE;52200;52;HAUTE MARNE;1
52037;;Bannes;BANNES;52360;52;HAUTE MARNE;1
52038;;Bassoncourt;BASSONCOURT;52240;52;HAUTE MARNE;1
52039;;Baudrecourt;BAUDRECOURT;52110;52;HAUTE MARNE;1
52040;;Bay-sur-Aube;BAY-SUR-AUBE;52160;52;HAUTE MARNE;1
52042;;Beauchemin;BEAUCHEMIN;52260;52;HAUTE MARNE;1
52043;;Belmont;BELMONT;52500;52;HAUTE MARNE;1
52044;;Roches-Bettaincourt;ROCHES-BETTAINCOURT;52270;52;HAUTE MARNE;1
52045;;Bettancourt-la-Ferrée;BETTANCOURT-LA-FERREE;52100;52;HAUTE MARNE;1
52047;;Beurville;BEURVILLE;52110;52;HAUTE MARNE;1
52050;;Biesles;BIESLES;52340;52;HAUTE MARNE;1
52051;;Bize;BIZE;52500;52;HAUTE MARNE;1
52053;;Blaisy;BLAISY;52330;52;HAUTE MARNE;1
52055;;Blécourt;BLECOURT;52300;52;HAUTE MARNE;1
52056;;Blessonville;BLESSONVILLE;52120;52;HAUTE MARNE;1
52057;;Blumeray;BLUMERAY;52110;52;HAUTE MARNE;1
52058;;Bologne;BOLOGNE;52310;52;HAUTE MARNE;1
52059;;Bonnecourt;BONNECOURT;52360;52;HAUTE MARNE;1
52060;;Bourbonne-les-Bains;BOURBONNE-LES-BAINS;52400;52;HAUTE MARNE;1
52061;;Bourdons-sur-Rognon;BOURDONS-SUR-ROGNON;52700;52;HAUTE MARNE;1
52062;;Bourg;BOURG;52200;52;HAUTE MARNE;1
52063;;Bourg-Sainte-Marie;BOURG-SAINTE-MARIE;52150;52;HAUTE MARNE;1
52064;;Bourmont;BOURMONT;52150;52;HAUTE MARNE;1
52065;;Bouzancourt;BOUZANCOURT;52110;52;HAUTE MARNE;1
52066;;Brachay;BRACHAY;52110;52;HAUTE MARNE;1
52067;;Brainville-sur-Meuse;BRAINVILLE-SUR-MEUSE;52150;52;HAUTE MARNE;1
52069;;Braux-le-Châtel;BRAUX-LE-CHATEL;52120;52;HAUTE MARNE;1
52070;;Brennes;BRENNES;52200;52;HAUTE MARNE;1
52072;;Brethenay;BRETHENAY;52000;52;HAUTE MARNE;1
52074;;Breuvannes-en-Bassigny;BREUVANNES-EN-BASSIGNY;52240;52;HAUTE MARNE;1
52075;;Briaucourt;BRIAUCOURT;52700;52;HAUTE MARNE;1
52076;;Bricon;BRICON;52120;52;HAUTE MARNE;1
52079;;Brousseval;BROUSSEVAL;52130;52;HAUTE MARNE;1
52082;;Bugnières;BUGNIERES;52210;52;HAUTE MARNE;1
52083;;Champsevraine;CHAMPSEVRAINE;52500;52;HAUTE MARNE;1
52084;;Busson;BUSSON;52700;52;HAUTE MARNE;1
52085;;Buxières-lès-Clefmont;BUXIERES-LES-CLEFMONT;52240;52;HAUTE MARNE;1
52087;;Buxières-lès-Villiers;BUXIERES-LES-VILLIERS;52000;52;HAUTE MARNE;1
52088;;Ceffonds;CEFFONDS;52220;52;HAUTE MARNE;1
52089;;Celles-en-Bassigny;CELLES-EN-BASSIGNY;52360;52;HAUTE MARNE;1
52090;;Celsoy;CELSOY;52600;52;HAUTE MARNE;1
52091;;Cerisières;CERISIERES;52320;52;HAUTE MARNE;1
52092;;Chalancey;CHALANCEY;52160;52;HAUTE MARNE;1
52093;;Chalindrey;CHALINDREY;52600;52;HAUTE MARNE;1
52094;;Vals-des-Tilles;VALS-DES-TILLES;52160;52;HAUTE MARNE;1
52095;;Chalvraines;CHALVRAINES;52700;52;HAUTE MARNE;1
52097;;Chambroncourt;CHAMBRONCOURT;52700;52;HAUTE MARNE;1
52099;;Chamouilley;CHAMOUILLEY;52410;52;HAUTE MARNE;1
52101;;Champigneulles-en-Bassigny;CHAMPIGNEULLES-EN-BASSIGNY;52150;52;HAUTE MARNE;1
52102;;Champigny-lès-Langres;CHAMPIGNY-LES-LANGRES;52200;52;HAUTE MARNE;1
52103;;Champigny-sous-Varennes;CHAMPIGNY-SOUS-VARENNES;52400;52;HAUTE MARNE;1
52104;;Chancenay;CHANCENAY;52100;52;HAUTE MARNE;1
52105;;Changey;CHANGEY;52360;52;HAUTE MARNE;1
52106;;Chanoy;CHANOY;52260;52;HAUTE MARNE;1
52107;;Chantraines;CHANTRAINES;52700;52;HAUTE MARNE;1
52108;;Charmes;CHARMES;52360;52;HAUTE MARNE;1
52109;;Charmes-en-l'Angle;CHARMES-EN-L'ANGLE;52110;52;HAUTE MARNE;1
52110;;Charmes-la-Grande;CHARMES-LA-GRANDE;52110;52;HAUTE MARNE;1
52113;;Chassigny;CHASSIGNY;52190;52;HAUTE MARNE;1
52114;;Châteauvillain;CHATEAUVILLAIN;52120;52;HAUTE MARNE;1
52115;;Chatenay-Mâcheron;CHATENAY-MACHERON;52200;52;HAUTE MARNE;1
52116;;Chatenay-Vaudin;CHATENAY-VAUDIN;52360;52;HAUTE MARNE;1
52118;;Chatonrupt-Sommermont;CHATONRUPT-SOMMERMONT;52300;52;HAUTE MARNE;1
52119;;Chaudenay;CHAUDENAY;52600;52;HAUTE MARNE;1
52120;;Chauffourt;CHAUFFOURT;52140;52;HAUTE MARNE;1
52121;;Chaumont;CHAUMONT;52000;52;HAUTE MARNE;1
52122;;Chaumont-la-Ville;CHAUMONT-LA-VILLE;52150;52;HAUTE MARNE;1
52123;;Chevillon;CHEVILLON;52170;52;HAUTE MARNE;1
52124;;Chézeaux;CHEZEAUX;52400;52;HAUTE MARNE;1
52125;;Chamarandes-Choignes;CHAMARANDES-CHOIGNES;52000;52;HAUTE MARNE;1
52126;;Choilley-Dardenay;CHOILLEY-DARDENAY;52190;52;HAUTE MARNE;1
52127;;Choiseul;CHOISEUL;52240;52;HAUTE MARNE;1
52128;;Cirey-lès-Mareilles;CIREY-LES-MAREILLES;52700;52;HAUTE MARNE;1
52129;;Cirey-sur-Blaise;CIREY-SUR-BLAISE;52110;52;HAUTE MARNE;1
52130;;Cirfontaines-en-Azois;CIRFONTAINES-EN-AZOIS;52370;52;HAUTE MARNE;1
52131;;Cirfontaines-en-Ornois;CIRFONTAINES-EN-ORNOIS;52230;52;HAUTE MARNE;1
52132;;Clefmont;CLEFMONT;52240;52;HAUTE MARNE;1
52133;;Clinchamp;CLINCHAMP;52700;52;HAUTE MARNE;1
52134;;Cohons;COHONS;52600;52;HAUTE MARNE;1
52135;;Coiffy-le-Bas;COIFFY-LE-BAS;52400;52;HAUTE MARNE;1
52136;;Coiffy-le-Haut;COIFFY-LE-HAUT;52400;52;HAUTE MARNE;1
52137;;Colmier-le-Bas;COLMIER-LE-BAS;52160;52;HAUTE MARNE;1
52138;;Colmier-le-Haut;COLMIER-LE-HAUT;52160;52;HAUTE MARNE;1
52140;;Colombey-les-Deux-Églises;COLOMBEY-LES-DEUX-EGLISES;52330;52;HAUTE MARNE;1
52141;;Condes;CONDES;52000;52;HAUTE MARNE;1
52142;;Consigny;CONSIGNY;52700;52;HAUTE MARNE;1
52145;;Coublanc;COUBLANC;52500;52;HAUTE MARNE;1
52146;;Coupray;COUPRAY;52210;52;HAUTE MARNE;1
52147;;Courcelles-en-Montagne;COURCELLES-EN-MONTAGNE;52200;52;HAUTE MARNE;1
52149;;Courcelles-sur-Blaise;COURCELLES-SUR-BLAISE;52110;52;HAUTE MARNE;1
52151;;Cour-l'Évêque;COUR-L'EVEQUE;52210;52;HAUTE MARNE;1
52155;;Culmont;CULMONT;52600;52;HAUTE MARNE;1
52156;;Curel;CUREL;52300;52;HAUTE MARNE;1
52157;;Curmont;CURMONT;52330;52;HAUTE MARNE;1
52158;;Cusey;CUSEY;52190;52;HAUTE MARNE;1
52159;;Cuves;CUVES;52240;52;HAUTE MARNE;1
52160;;Daillancourt;DAILLANCOURT;52110;52;HAUTE MARNE;1
52161;;Daillecourt;DAILLECOURT;52240;52;HAUTE MARNE;1
52162;;Dammartin-sur-Meuse;DAMMARTIN-SUR-MEUSE;52140;52;HAUTE MARNE;1
52163;;Dampierre;DAMPIERRE;52360;52;HAUTE MARNE;1
52164;;Damrémont;DAMREMONT;52400;52;HAUTE MARNE;1
52165;;Dancevoir;DANCEVOIR;52210;52;HAUTE MARNE;1
52167;;Darmannes;DARMANNES;52700;52;HAUTE MARNE;1
52168;;Dinteville;DINTEVILLE;52120;52;HAUTE MARNE;1
52169;;Domblain;DOMBLAIN;52130;52;HAUTE MARNE;1
52170;;Dommarien;DOMMARIEN;52190;52;HAUTE MARNE;1
52171;;Dommartin-le-Franc;DOMMARTIN-LE-FRANC;52110;52;HAUTE MARNE;1
52172;;Dommartin-le-Saint-Père;DOMMARTIN-LE-SAINT-PERE;52110;52;HAUTE MARNE;1
52173;;Domremy-Landéville;DOMREMY-LANDEVILLE;52270;52;HAUTE MARNE;1
52174;;Doncourt-sur-Meuse;DONCOURT-SUR-MEUSE;52150;52;HAUTE MARNE;1
52175;;Donjeux;DONJEUX;52300;52;HAUTE MARNE;1
52177;;Doulaincourt-Saucourt;DOULAINCOURT-SAUCOURT;52270;52;HAUTE MARNE;1
52178;;Doulevant-le-Château;DOULEVANT-LE-CHATEAU;52110;52;HAUTE MARNE;1
52179;;Doulevant-le-Petit;DOULEVANT-LE-PETIT;52130;52;HAUTE MARNE;1
52180;;Droyes;DROYES;52220;52;HAUTE MARNE;1
52181;;Échenay;ECHENAY;52230;52;HAUTE MARNE;1
52182;;Éclaron-Braucourt-Sainte-Livière;ECLARON-BRAUCOURT-SAINTE-LIVIERE;52290;52;HAUTE MARNE;1
52183;;Ecot-la-Combe;ECOT-LA-COMBE;52700;52;HAUTE MARNE;1
52184;;Effincourt;EFFINCOURT;52300;52;HAUTE MARNE;1
52185;;Enfonvelle;ENFONVELLE;52400;52;HAUTE MARNE;1
52187;;Épizon;EPIZON;52230;52;HAUTE MARNE;1
52189;Le;Val-d'Esnoms;VAL-D'ESNOMS;52190;52;HAUTE MARNE;1
52190;;Esnouveaux;ESNOUVEAUX;52340;52;HAUTE MARNE;1
52193;;Euffigneix;EUFFIGNEIX;52000;52;HAUTE MARNE;1
52194;;Eurville-Bienville;EURVILLE-BIENVILLE;52410;52;HAUTE MARNE;1
52195;;Farincourt;FARINCOURT;52500;52;HAUTE MARNE;1
52196;;Faverolles;FAVEROLLES;52260;52;HAUTE MARNE;1
52197;;Fayl-Billot;FAYL-BILLOT;52500;52;HAUTE MARNE;1
52198;;Fays;FAYS;52130;52;HAUTE MARNE;1
52199;;Ferrière-et-Lafolie;FERRIERE-ET-LAFOLIE;52300;52;HAUTE MARNE;1
52200;;Flagey;FLAGEY;52250;52;HAUTE MARNE;1
52201;;Flammerécourt;FLAMMERECOURT;52110;52;HAUTE MARNE;1
52203;;Fontaines-sur-Marne;FONTAINES-SUR-MARNE;52170;52;HAUTE MARNE;1
52204;;Forcey;FORCEY;52700;52;HAUTE MARNE;1
52205;;Foulain;FOULAIN;52800;52;HAUTE MARNE;1
52206;;Frampas;FRAMPAS;52220;52;HAUTE MARNE;1
52207;;Frécourt;FRECOURT;52360;52;HAUTE MARNE;1
52208;;Fresnes-sur-Apance;FRESNES-SUR-APANCE;52400;52;HAUTE MARNE;1
52211;;Froncles;FRONCLES;52320;52;HAUTE MARNE;1
52212;;Fronville;FRONVILLE;52300;52;HAUTE MARNE;1
52213;;Genevrières;GENEVRIERES;52500;52;HAUTE MARNE;1
52214;La;Genevroye;GENEVROYE;52320;52;HAUTE MARNE;1
52216;;Germaines;GERMAINES;52160;52;HAUTE MARNE;1
52217;;Germainvilliers;GERMAINVILLIERS;52150;52;HAUTE MARNE;1
52218;;Germay;GERMAY;52230;52;HAUTE MARNE;1
52219;;Germisay;GERMISAY;52230;52;HAUTE MARNE;1
52220;;Giey-sur-Aujon;GIEY-SUR-AUJON;52210;52;HAUTE MARNE;1
52221;;Gillancourt;GILLANCOURT;52330;52;HAUTE MARNE;1
52222;;Gillaumé;GILLAUME;52230;52;HAUTE MARNE;1
52223;;Gilley;GILLEY;52500;52;HAUTE MARNE;1
52225;;Goncourt;GONCOURT;52150;52;HAUTE MARNE;1
52227;;Graffigny-Chemin;GRAFFIGNY-CHEMIN;52150;52;HAUTE MARNE;1
52228;;Grandchamp;GRANDCHAMP;52600;52;HAUTE MARNE;1
52229;;Grenant;GRENANT;52500;52;HAUTE MARNE;1
52230;;Gudmont-Villiers;GUDMONT-VILLIERS;52320;52;HAUTE MARNE;1
52231;;Guindrecourt-aux-Ormes;GUINDRECOURT-AUX-ORMES;52300;52;HAUTE MARNE;1
52232;;Guindrecourt-sur-Blaise;GUINDRECOURT-SUR-BLAISE;52330;52;HAUTE MARNE;1
52233;;Guyonvelle;GUYONVELLE;52400;52;HAUTE MARNE;1
52234;;Hâcourt;HACOURT;52150;52;HAUTE MARNE;1
52235;;Hallignicourt;HALLIGNICOURT;52100;52;HAUTE MARNE;1
52237;;Harréville-les-Chanteurs;HARREVILLE-LES-CHANTEURS;52150;52;HAUTE MARNE;1
52239;;Heuilley-Cotton;HEUILLEY-COTTON;52600;52;HAUTE MARNE;1
52240;;Heuilley-le-Grand;HEUILLEY-LE-GRAND;52600;52;HAUTE MARNE;1
52242;;Haute-Amance;HAUTE-AMANCE;52600;52;HAUTE MARNE;1
52243;;Huilliécourt;HUILLIECOURT;52150;52;HAUTE MARNE;1
52244;;Humbécourt;HUMBECOURT;52290;52;HAUTE MARNE;1
52245;;Humberville;HUMBERVILLE;52700;52;HAUTE MARNE;1
52246;;Humes-Jorquenay;HUMES-JORQUENAY;52200;52;HAUTE MARNE;1
52247;;Illoud;ILLOUD;52150;52;HAUTE MARNE;1
52248;;Is-en-Bassigny;IS-EN-BASSIGNY;52140;52;HAUTE MARNE;1
52249;;Isômes;ISOMES;52190;52;HAUTE MARNE;1
52250;;Joinville;JOINVILLE;52300;52;HAUTE MARNE;1
52251;;Jonchery;JONCHERY;52000;52;HAUTE MARNE;1
52253;;Juzennecourt;JUZENNECOURT;52330;52;HAUTE MARNE;1
52254;;Lachapelle-en-Blaisy;LACHAPELLE-EN-BLAISY;52330;52;HAUTE MARNE;1
52256;;Lafauche;LAFAUCHE;52700;52;HAUTE MARNE;1
52257;;Laferté-sur-Amance;LAFERTE-SUR-AMANCE;52500;52;HAUTE MARNE;1
52258;;Laferté-sur-Aube;LAFERTE-SUR-AUBE;52120;52;HAUTE MARNE;1
52260;;Lamancine;LAMANCINE;52310;52;HAUTE MARNE;1
52262;;Lamothe-en-Blaisy;LAMOTHE-EN-BLAISY;52330;52;HAUTE MARNE;1
52264;;Laneuvelle;LANEUVELLE;52400;52;HAUTE MARNE;1
52265;;Bayard-sur-Marne;BAYARD-SUR-MARNE;52170;52;HAUTE MARNE;1
52266;;Laneuville-à-Rémy;LANEUVILLE-A-REMY;52220;52;HAUTE MARNE;1
52267;;Laneuville-au-Pont;LANEUVILLE-AU-PONT;52100;52;HAUTE MARNE;1
52269;;Langres;LANGRES;52200;52;HAUTE MARNE;1
52271;;Lanques-sur-Rognon;LANQUES-SUR-ROGNON;52800;52;HAUTE MARNE;1
52272;;Lanty-sur-Aube;LANTY-SUR-AUBE;52120;52;HAUTE MARNE;1
52273;;Larivière-Arnoncourt;LARIVIERE-ARNONCOURT;52400;52;HAUTE MARNE;1
52274;;Latrecey-Ormoy-sur-Aube;LATRECEY-ORMOY-SUR-AUBE;52120;52;HAUTE MARNE;1
52275;;Lavernoy;LAVERNOY;52140;52;HAUTE MARNE;1
52276;;Laville-aux-Bois;LAVILLE-AUX-BOIS;52000;52;HAUTE MARNE;1
52277;;Lavilleneuve;LAVILLENEUVE;52140;52;HAUTE MARNE;1
52278;;Lavilleneuve-au-Roi;LAVILLENEUVE-AU-ROI;52330;52;HAUTE MARNE;1
52280;;Lecey;LECEY;52360;52;HAUTE MARNE;1
52282;;Leffonds;LEFFONDS;52210;52;HAUTE MARNE;1
52284;;Leschères-sur-le-Blaiseron;LESCHERES-SUR-LE-BLAISERON;52110;52;HAUTE MARNE;1
52285;;Leuchey;LEUCHEY;52190;52;HAUTE MARNE;1
52286;;Leurville;LEURVILLE;52700;52;HAUTE MARNE;1
52287;;Levécourt;LEVECOURT;52150;52;HAUTE MARNE;1
52288;;Lezéville;LEZEVILLE;52230;52;HAUTE MARNE;1
52289;;Liffol-le-Petit;LIFFOL-LE-PETIT;52700;52;HAUTE MARNE;1
52290;Les;Loges;LOGES;52500;52;HAUTE MARNE;1
52291;;Longchamp;LONGCHAMP;52240;52;HAUTE MARNE;1
52292;;Longeau-Percey;LONGEAU-PERCEY;52250;52;HAUTE MARNE;1
52293;;Longeville-sur-la-Laines;LONGEVILLE-SUR-LA-LAINES;52220;52;HAUTE MARNE;1
52294;;Louvemont;LOUVEMONT;52130;52;HAUTE MARNE;1
52295;;Louvières;LOUVIERES;52800;52;HAUTE MARNE;1
52296;;Louze;LOUZE;52220;52;HAUTE MARNE;1
52297;;Luzy-sur-Marne;LUZY-SUR-MARNE;52000;52;HAUTE MARNE;1
52298;;Maâtz;MAATZ;52500;52;HAUTE MARNE;1
52300;;Magneux;MAGNEUX;52130;52;HAUTE MARNE;1
52301;;Maisoncelles;MAISONCELLES;52240;52;HAUTE MARNE;1
52302;;Maizières;MAIZIERES;52300;52;HAUTE MARNE;1
52303;;Maizières-sur-Amance;MAIZIERES-SUR-AMANCE;52500;52;HAUTE MARNE;1
52304;;Malaincourt-sur-Meuse;MALAINCOURT-SUR-MEUSE;52150;52;HAUTE MARNE;1
52305;;Mandres-la-Côte;MANDRES-LA-COTE;52800;52;HAUTE MARNE;1
52306;;Manois;MANOIS;52700;52;HAUTE MARNE;1
52307;;Marac;MARAC;52260;52;HAUTE MARNE;1
52308;;Maranville;MARANVILLE;52370;52;HAUTE MARNE;1
52310;;Marbéville;MARBEVILLE;52320;52;HAUTE MARNE;1
52311;;Marcilly-en-Bassigny;MARCILLY-EN-BASSIGNY;52360;52;HAUTE MARNE;1
52312;;Mardor;MARDOR;52200;52;HAUTE MARNE;1
52313;;Mareilles;MAREILLES;52700;52;HAUTE MARNE;1
52315;;Marnay-sur-Marne;MARNAY-SUR-MARNE;52800;52;HAUTE MARNE;1
52316;;Mathons;MATHONS;52300;52;HAUTE MARNE;1
52318;;Melay;MELAY;52400;52;HAUTE MARNE;1
52319;;Mennouveaux;MENNOUVEAUX;52240;52;HAUTE MARNE;1
52320;;Merrey;MERREY;52240;52;HAUTE MARNE;1
52321;;Mertrud;MERTRUD;52110;52;HAUTE MARNE;1
52322;;Meures;MEURES;52310;52;HAUTE MARNE;1
52325;;Millières;MILLIERES;52240;52;HAUTE MARNE;1
52326;;Mirbel;MIRBEL;52320;52;HAUTE MARNE;1
52327;;Moëslains;MOESLAINS;52100;52;HAUTE MARNE;1
52328;;Montcharvot;MONTCHARVOT;52400;52;HAUTE MARNE;1
52330;;Montheries;MONTHERIES;52330;52;HAUTE MARNE;1
52331;;Montier-en-Der;MONTIER-EN-DER;52220;52;HAUTE MARNE;1
52332;;Val-de-Meuse;VAL-DE-MEUSE;52140;52;HAUTE MARNE;1
52335;;Montot-sur-Rognon;MONTOT-SUR-ROGNON;52700;52;HAUTE MARNE;1
52336;;Montreuil-sur-Blaise;MONTREUIL-SUR-BLAISE;52130;52;HAUTE MARNE;1
52337;;Montreuil-sur-Thonnance;MONTREUIL-SUR-THONNANCE;52230;52;HAUTE MARNE;1
52340;;Montsaugeon;MONTSAUGEON;52190;52;HAUTE MARNE;1
52341;;Morancourt;MORANCOURT;52110;52;HAUTE MARNE;1
52342;;Morionvilliers;MORIONVILLIERS;52700;52;HAUTE MARNE;1
52344;;Mouilleron;MOUILLERON;52160;52;HAUTE MARNE;1
52346;;Mussey-sur-Marne;MUSSEY-SUR-MARNE;52300;52;HAUTE MARNE;1
52347;;Narcy;NARCY;52170;52;HAUTE MARNE;1
52348;;Neuilly-l'Évêque;NEUILLY-L'EVEQUE;52360;52;HAUTE MARNE;1
52349;;Neuilly-sur-Suize;NEUILLY-SUR-SUIZE;52000;52;HAUTE MARNE;1
52350;;Neuvelle-lès-Voisey;NEUVELLE-LES-VOISEY;52400;52;HAUTE MARNE;1
52351;;Nijon;NIJON;52150;52;HAUTE MARNE;1
52352;;Ninville;NINVILLE;52800;52;HAUTE MARNE;1
52353;;Nogent;NOGENT;52800;52;HAUTE MARNE;1
52354;;Noidant-Chatenoy;NOIDANT-CHATENOY;52600;52;HAUTE MARNE;1
52355;;Noidant-le-Rocheux;NOIDANT-LE-ROCHEUX;52200;52;HAUTE MARNE;1
52356;;Nomécourt;NOMECOURT;52300;52;HAUTE MARNE;1
52357;;Noncourt-sur-le-Rongeant;NONCOURT-SUR-LE-RONGEANT;52230;52;HAUTE MARNE;1
52358;;Noyers;NOYERS;52240;52;HAUTE MARNE;1
52359;;Nully;NULLY;52110;52;HAUTE MARNE;1
52360;;Occey;OCCEY;52190;52;HAUTE MARNE;1
52362;;Orbigny-au-Mont;ORBIGNY-AU-MONT;52360;52;HAUTE MARNE;1
52363;;Orbigny-au-Val;ORBIGNY-AU-VAL;52360;52;HAUTE MARNE;1
52364;;Orcevaux;ORCEVAUX;52250;52;HAUTE MARNE;1
52365;;Orges;ORGES;52120;52;HAUTE MARNE;1
52366;;Ormancey;ORMANCEY;52200;52;HAUTE MARNE;1
52367;;Ormoy-lès-Sexfontaines;ORMOY-LES-SEXFONTAINES;52310;52;HAUTE MARNE;1
52369;;Orquevaux;ORQUEVAUX;52700;52;HAUTE MARNE;1
52370;;Osne-le-Val;OSNE-LE-VAL;52300;52;HAUTE MARNE;1
52371;;Oudincourt;OUDINCOURT;52310;52;HAUTE MARNE;1
52372;;Outremécourt;OUTREMECOURT;52150;52;HAUTE MARNE;1
52373;;Ozières;OZIERES;52700;52;HAUTE MARNE;1
52374;Le;Pailly;PAILLY;52600;52;HAUTE MARNE;1
52375;;Palaiseul;PALAISEUL;52600;52;HAUTE MARNE;1
52376;;Pansey;PANSEY;52230;52;HAUTE MARNE;1
52377;;Parnoy-en-Bassigny;PARNOY-EN-BASSIGNY;52400;52;HAUTE MARNE;1
52378;;Paroy-sur-Saulx;PAROY-SUR-SAULX;52300;52;HAUTE MARNE;1
52379;;Pautaines-Augeville;PAUTAINES-AUGEVILLE;52270;52;HAUTE MARNE;1
52380;;Peigney;PEIGNEY;52200;52;HAUTE MARNE;1
52383;;Perrancey-les-Vieux-Moulins;PERRANCEY-LES-VIEUX-MOULINS;52200;52;HAUTE MARNE;1
52384;;Perrogney-les-Fontaines;PERROGNEY-LES-FONTAINES;52160;52;HAUTE MARNE;1
52385;;Perrusse;PERRUSSE;52240;52;HAUTE MARNE;1
52386;;Perthes;PERTHES;52100;52;HAUTE MARNE;1
52388;;Pierremont-sur-Amance;PIERREMONT-SUR-AMANCE;52500;52;HAUTE MARNE;1
52390;;Pisseloup;PISSELOUP;52500;52;HAUTE MARNE;1
52391;;Planrupt;PLANRUPT;52220;52;HAUTE MARNE;1
52392;;Plesnoy;PLESNOY;52360;52;HAUTE MARNE;1
52393;;Poinsenot;POINSENOT;52160;52;HAUTE MARNE;1
52394;;Poinson-lès-Fayl;POINSON-LES-FAYL;52500;52;HAUTE MARNE;1
52395;;Poinson-lès-Grancey;POINSON-LES-GRANCEY;52160;52;HAUTE MARNE;1
52396;;Poinson-lès-Nogent;POINSON-LES-NOGENT;52800;52;HAUTE MARNE;1
52397;;Poiseul;POISEUL;52360;52;HAUTE MARNE;1
52398;;Poissons;POISSONS;52230;52;HAUTE MARNE;1
52399;;Pont-la-Ville;PONT-LA-VILLE;52120;52;HAUTE MARNE;1
52400;Le;Châtelet-sur-Meuse;CHATELET-SUR-MEUSE;52400;52;HAUTE MARNE;1
52401;;Poulangy;POULANGY;52800;52;HAUTE MARNE;1
52403;;Praslay;PRASLAY;52160;52;HAUTE MARNE;1
52405;;Prauthoy;PRAUTHOY;52190;52;HAUTE MARNE;1
52406;;Pressigny;PRESSIGNY;52500;52;HAUTE MARNE;1
52407;;Prez-sous-Lafauche;PREZ-SOUS-LAFAUCHE;52700;52;HAUTE MARNE;1
52411;;Puellemontier;PUELLEMONTIER;52220;52;HAUTE MARNE;1
52413;;Rachecourt-Suzémont;RACHECOURT-SUZEMONT;52130;52;HAUTE MARNE;1
52414;;Rachecourt-sur-Marne;RACHECOURT-SUR-MARNE;52170;52;HAUTE MARNE;1
52415;;Rançonnières;RANCONNIERES;52140;52;HAUTE MARNE;1
52416;;Rangecourt;RANGECOURT;52140;52;HAUTE MARNE;1
52419;;Rennepont;RENNEPONT;52370;52;HAUTE MARNE;1
52420;;Reynel;REYNEL;52700;52;HAUTE MARNE;1
52421;;Riaucourt;RIAUCOURT;52000;52;HAUTE MARNE;1
52422;;Richebourg;RICHEBOURG;52120;52;HAUTE MARNE;1
52423;;Rimaucourt;RIMAUCOURT;52700;52;HAUTE MARNE;1
52424;;Rivières-le-Bois;RIVIERES-LE-BOIS;52600;52;HAUTE MARNE;1
52425;;Rivière-les-Fosses;RIVIERE-LES-FOSSES;52190;52;HAUTE MARNE;1
52426;;Rizaucourt-Buchey;RIZAUCOURT-BUCHEY;52330;52;HAUTE MARNE;1
52427;;Robert-Magny;ROBERT-MAGNY;52220;52;HAUTE MARNE;1
52428;;Rochefort-sur-la-Côte;ROCHEFORT-SUR-LA-COTE;52700;52;HAUTE MARNE;1
52429;;Roches-sur-Marne;ROCHES-SUR-MARNE;52410;52;HAUTE MARNE;1
52431;;Rochetaillée;ROCHETAILLEE;52210;52;HAUTE MARNE;1
52432;;Rolampont;ROLAMPONT;52260;52;HAUTE MARNE;1
52433;;Romain-sur-Meuse;ROMAIN-SUR-MEUSE;52150;52;HAUTE MARNE;1
52436;;Rouécourt;ROUECOURT;52320;52;HAUTE MARNE;1
52437;;Rouelles;ROUELLES;52160;52;HAUTE MARNE;1
52438;;Rougeux;ROUGEUX;52500;52;HAUTE MARNE;1
52439;;Rouvres-sur-Aube;ROUVRES-SUR-AUBE;52160;52;HAUTE MARNE;1
52440;;Rouvroy-sur-Marne;ROUVROY-SUR-MARNE;52300;52;HAUTE MARNE;1
52442;;Rupt;RUPT;52300;52;HAUTE MARNE;1
52443;;Sailly;SAILLY;52230;52;HAUTE MARNE;1
52444;;Saint-Blin;SAINT-BLIN;52700;52;HAUTE MARNE;1
52445;;Saint-Broingt-le-Bois;SAINT-BROINGT-LE-BOIS;52190;52;HAUTE MARNE;1
52446;;Saint-Broingt-les-Fosses;SAINT-BROINGT-LES-FOSSES;52190;52;HAUTE MARNE;1
52447;;Saint-Ciergues;SAINT-CIERGUES;52200;52;HAUTE MARNE;1
52448;;Saint-Dizier;SAINT-DIZIER;52100;52;HAUTE MARNE;1
52449;;Saints-Geosmes;SAINTS-GEOSMES;52200;52;HAUTE MARNE;1
52450;;Saint-Loup-sur-Aujon;SAINT-LOUP-SUR-AUJON;52210;52;HAUTE MARNE;1
52452;;Saint-Martin-lès-Langres;SAINT-MARTIN-LES-LANGRES;52200;52;HAUTE MARNE;1
52453;;Saint-Maurice;SAINT-MAURICE;52200;52;HAUTE MARNE;1
52455;;Saint-Thiébault;SAINT-THIEBAULT;52150;52;HAUTE MARNE;1
52456;;Saint-Urbain-Maconcourt;SAINT-URBAIN-MACONCOURT;52300;52;HAUTE MARNE;1
52457;;Saint-Vallier-sur-Marne;SAINT-VALLIER-SUR-MARNE;52200;52;HAUTE MARNE;1
52459;;Sarcey;SARCEY;52800;52;HAUTE MARNE;1
52461;;Sarrey;SARREY;52140;52;HAUTE MARNE;1
52463;;Saudron;SAUDRON;52230;52;HAUTE MARNE;1
52464;;Saulles;SAULLES;52500;52;HAUTE MARNE;1
52465;;Saulxures;SAULXURES;52140;52;HAUTE MARNE;1
52467;;Savigny;SAVIGNY;52500;52;HAUTE MARNE;1
52468;;Semilly;SEMILLY;52700;52;HAUTE MARNE;1
52469;;Semoutiers-Montsaon;SEMOUTIERS-MONTSAON;52000;52;HAUTE MARNE;1
52470;;Serqueux;SERQUEUX;52400;52;HAUTE MARNE;1
52472;;Sexfontaines;SEXFONTAINES;52330;52;HAUTE MARNE;1
52473;;Signéville;SIGNEVILLE;52700;52;HAUTE MARNE;1
52474;;Silvarouvres;SILVAROUVRES;52120;52;HAUTE MARNE;1
52475;;Sommancourt;SOMMANCOURT;52130;52;HAUTE MARNE;1
52476;;Sommerécourt;SOMMERECOURT;52150;52;HAUTE MARNE;1
52479;;Sommevoire;SOMMEVOIRE;52220;52;HAUTE MARNE;1
52480;;Soncourt-sur-Marne;SONCOURT-SUR-MARNE;52320;52;HAUTE MARNE;1
52482;;Soulaucourt-sur-Mouzon;SOULAUCOURT-SUR-MOUZON;52150;52;HAUTE MARNE;1
52483;;Soyers;SOYERS;52400;52;HAUTE MARNE;1
52484;;Suzannecourt;SUZANNECOURT;52300;52;HAUTE MARNE;1
52486;;Ternat;TERNAT;52210;52;HAUTE MARNE;1
52487;;Thilleux;THILLEUX;52220;52;HAUTE MARNE;1
52488;;Thivet;THIVET;52800;52;HAUTE MARNE;1
52489;;Thol-lès-Millières;THOL-LES-MILLIERES;52240;52;HAUTE MARNE;1
52490;;Thonnance-lès-Joinville;THONNANCE-LES-JOINVILLE;52300;52;HAUTE MARNE;1
52491;;Thonnance-les-Moulins;THONNANCE-LES-MOULINS;52230;52;HAUTE MARNE;1
52492;;Torcenay;TORCENAY;52600;52;HAUTE MARNE;1
52493;;Tornay;TORNAY;52500;52;HAUTE MARNE;1
52494;;Treix;TREIX;52000;52;HAUTE MARNE;1
52495;;Trémilly;TREMILLY;52110;52;HAUTE MARNE;1
52497;;Troisfontaines-la-Ville;TROISFONTAINES-LA-VILLE;52130;52;HAUTE MARNE;1
52499;;Vaillant;VAILLANT;52160;52;HAUTE MARNE;1
52500;;Valcourt;VALCOURT;52100;52;HAUTE MARNE;1
52502;;Valleret;VALLERET;52130;52;HAUTE MARNE;1
52503;;Valleroy;VALLEROY;52500;52;HAUTE MARNE;1
52504;;Varennes-sur-Amance;VARENNES-SUR-AMANCE;52400;52;HAUTE MARNE;1
52505;;Vaudrecourt;VAUDRECOURT;52150;52;HAUTE MARNE;1
52506;;Vaudrémont;VAUDREMONT;52330;52;HAUTE MARNE;1
52507;;Vauxbons;VAUXBONS;52200;52;HAUTE MARNE;1
52509;;Vaux-sous-Aubigny;VAUX-SOUS-AUBIGNY;52190;52;HAUTE MARNE;1
52510;;Vaux-sur-Blaise;VAUX-SUR-BLAISE;52130;52;HAUTE MARNE;1
52511;;Vaux-sur-Saint-Urbain;VAUX-SUR-SAINT-URBAIN;52300;52;HAUTE MARNE;1
52512;;Vecqueville;VECQUEVILLE;52300;52;HAUTE MARNE;1
52513;;Velles;VELLES;52500;52;HAUTE MARNE;1
52514;;Verbiesles;VERBIESLES;52000;52;HAUTE MARNE;1
52515;;Verseilles-le-Bas;VERSEILLES-LE-BAS;52250;52;HAUTE MARNE;1
52516;;Verseilles-le-Haut;VERSEILLES-LE-HAUT;52250;52;HAUTE MARNE;1
52517;;Vesaignes-sous-Lafauche;VESAIGNES-SOUS-LAFAUCHE;52700;52;HAUTE MARNE;1
52518;;Vesaignes-sur-Marne;VESAIGNES-SUR-MARNE;52800;52;HAUTE MARNE;1
52519;;Vesvres-sous-Chalancey;VESVRES-SOUS-CHALANCEY;52190;52;HAUTE MARNE;1
52520;;Vicq;VICQ;52400;52;HAUTE MARNE;1
52522;;Viéville;VIEVILLE;52310;52;HAUTE MARNE;1
52523;;Vignes-la-Côte;VIGNES-LA-COTE;52700;52;HAUTE MARNE;1
52524;;Vignory;VIGNORY;52320;52;HAUTE MARNE;1
52525;;Villars-en-Azois;VILLARS-EN-AZOIS;52120;52;HAUTE MARNE;1
52526;;Villars-Santenoge;VILLARS-SANTENOGE;52160;52;HAUTE MARNE;1
52528;;Ville-en-Blaisois;VILLE-EN-BLAISOIS;52130;52;HAUTE MARNE;1
52529;;Villegusien-le-Lac;VILLEGUSIEN-LE-LAC;52190;52;HAUTE MARNE;1
52534;;Villiers-en-Lieu;VILLIERS-EN-LIEU;52100;52;HAUTE MARNE;1
52535;;Villiers-le-Sec;VILLIERS-LE-SEC;52000;52;HAUTE MARNE;1
52536;;Villiers-lès-Aprey;VILLIERS-LES-APREY;52190;52;HAUTE MARNE;1
52538;;Villiers-sur-Suize;VILLIERS-SUR-SUIZE;52210;52;HAUTE MARNE;1
52539;;Violot;VIOLOT;52600;52;HAUTE MARNE;1
52540;;Vitry-en-Montagne;VITRY-EN-MONTAGNE;52160;52;HAUTE MARNE;1
52541;;Vitry-lès-Nogent;VITRY-LES-NOGENT;52800;52;HAUTE MARNE;1
52542;;Vivey;VIVEY;52160;52;HAUTE MARNE;1
52543;;Voillecomte;VOILLECOMTE;52130;52;HAUTE MARNE;1
52544;;Voisey;VOISEY;52400;52;HAUTE MARNE;1
52545;;Voisines;VOISINES;52200;52;HAUTE MARNE;1
52546;;Voncourt;VONCOURT;52500;52;HAUTE MARNE;1
52547;;Vouécourt;VOUECOURT;52320;52;HAUTE MARNE;1
52548;;Vraincourt;VRAINCOURT;52310;52;HAUTE MARNE;1
52549;;Vroncourt-la-Côte;VRONCOURT-LA-COTE;52240;52;HAUTE MARNE;1
52550;;Wassy;WASSY;52130;52;HAUTE MARNE;1
53001;;Ahuillé;AHUILLE;53940;53;MAYENNE;1
53002;;Alexain;ALEXAIN;53240;53;MAYENNE;1
53003;;Ambrières-les-Vallées;AMBRIERES-LES-VALLEES;53300;53;MAYENNE;1
53004;;Ampoigné;AMPOIGNE;53200;53;MAYENNE;1
53005;;Andouillé;ANDOUILLE;53240;53;MAYENNE;1
53006;;Argenton-Notre-Dame;ARGENTON-NOTRE-DAME;53290;53;MAYENNE;1
53007;;Argentré;ARGENTRE;53210;53;MAYENNE;1
53008;;Aron;ARON;53440;53;MAYENNE;1
53009;;Arquenay;ARQUENAY;53170;53;MAYENNE;1
53010;;Assé-le-Bérenger;ASSE-LE-BERENGER;53600;53;MAYENNE;1
53011;;Astillé;ASTILLE;53230;53;MAYENNE;1
53012;;Athée;ATHEE;53400;53;MAYENNE;1
53013;;Averton;AVERTON;53700;53;MAYENNE;1
53014;;Azé;AZE;53200;53;MAYENNE;1
53015;La;Baconnière;BACONNIERE;53240;53;MAYENNE;1
53016;;Bais;BAIS;53160;53;MAYENNE;1
53017;;Ballée;BALLEE;53340;53;MAYENNE;1
53018;;Ballots;BALLOTS;53350;53;MAYENNE;1
53019;;Bannes;BANNES;53340;53;MAYENNE;1
53021;La;Bazoge-Montpinçon;BAZOGE-MONTPINCON;53440;53;MAYENNE;1
53022;La;Bazouge-de-Chemeré;BAZOUGE-DE-CHEMERE;53170;53;MAYENNE;1
53023;La;Bazouge-des-Alleux;BAZOUGE-DES-ALLEUX;53470;53;MAYENNE;1
53025;;Bazougers;BAZOUGERS;53170;53;MAYENNE;1
53026;;Beaulieu-sur-Oudon;BEAULIEU-SUR-OUDON;53320;53;MAYENNE;1
53027;;Beaumont-Pied-de-Bœuf;BEAUMONT-PIED-DE-BOEUF;53290;53;MAYENNE;1
53028;;Belgeard;BELGEARD;53440;53;MAYENNE;1
53029;;Bierné;BIERNE;53290;53;MAYENNE;1
53030;Le;Bignon-du-Maine;BIGNON-DU-MAINE;53170;53;MAYENNE;1
53031;La;Bigottière;BIGOTTIERE;53240;53;MAYENNE;1
53032;;Blandouet;BLANDOUET;53270;53;MAYENNE;1
53033;La;Boissière;BOISSIERE;53800;53;MAYENNE;1
53034;;Bonchamp-lès-Laval;BONCHAMP-LES-LAVAL;53960;53;MAYENNE;1
53035;;Bouchamps-lès-Craon;BOUCHAMPS-LES-CRAON;53800;53;MAYENNE;1
53036;;Bouère;BOUERE;53290;53;MAYENNE;1
53037;;Bouessay;BOUESSAY;53290;53;MAYENNE;1
53038;;Boulay-les-Ifs;BOULAY-LES-IFS;53370;53;MAYENNE;1
53039;Le;Bourgneuf-la-Forêt;BOURGNEUF-LA-FORET;53410;53;MAYENNE;1
53040;;Bourgon;BOURGON;53410;53;MAYENNE;1
53041;;Brains-sur-les-Marches;BRAINS-SUR-LES-MARCHES;53350;53;MAYENNE;1
53042;;Brecé;BRECE;53120;53;MAYENNE;1
53043;;Brée;BREE;53150;53;MAYENNE;1
53045;La;Brûlatte;BRULATTE;53410;53;MAYENNE;1
53046;Le;Buret;BURET;53170;53;MAYENNE;1
53047;;Carelles;CARELLES;53120;53;MAYENNE;1
53048;;Chailland;CHAILLAND;53420;53;MAYENNE;1
53049;;Châlons-du-Maine;CHALONS-DU-MAINE;53470;53;MAYENNE;1
53050;;Chammes;CHAMMES;53270;53;MAYENNE;1
53051;;Champéon;CHAMPEON;53640;53;MAYENNE;1
53052;;Champfrémont;CHAMPFREMONT;53370;53;MAYENNE;1
53053;;Champgenéteux;CHAMPGENETEUX;53160;53;MAYENNE;1
53054;;Changé;CHANGE;53810;53;MAYENNE;1
53055;;Chantrigné;CHANTRIGNE;53300;53;MAYENNE;1
53056;La;Chapelle-Anthenaise;CHAPELLE-ANTHENAISE;53950;53;MAYENNE;1
53057;La;Chapelle-au-Riboul;CHAPELLE-AU-RIBOUL;53440;53;MAYENNE;1
53058;La;Chapelle-Craonnaise;CHAPELLE-CRAONNAISE;53230;53;MAYENNE;1
53059;La;Chapelle-Rainsouin;CHAPELLE-RAINSOUIN;53150;53;MAYENNE;1
53061;;Charchigné;CHARCHIGNE;53250;53;MAYENNE;1
53062;;Château-Gontier;CHATEAU-GONTIER;53200;53;MAYENNE;1
53063;;Châtelain;CHATELAIN;53200;53;MAYENNE;1
53064;;Châtillon-sur-Colmont;CHATILLON-SUR-COLMONT;53100;53;MAYENNE;1
53065;;Châtres-la-Forêt;CHATRES-LA-FORET;53600;53;MAYENNE;1
53066;;Chemazé;CHEMAZE;53200;53;MAYENNE;1
53067;;Chémeré-le-Roi;CHEMERE-LE-ROI;53340;53;MAYENNE;1
53068;;Chérancé;CHERANCE;53400;53;MAYENNE;1
53069;;Chevaigné-du-Maine;CHEVAIGNE-DU-MAINE;53250;53;MAYENNE;1
53071;;Colombiers-du-Plessis;COLOMBIERS-DU-PLESSIS;53120;53;MAYENNE;1
53072;;Commer;COMMER;53470;53;MAYENNE;1
53073;;Congrier;CONGRIER;53800;53;MAYENNE;1
53074;;Contest;CONTEST;53100;53;MAYENNE;1
53075;;Cosmes;COSMES;53230;53;MAYENNE;1
53076;;Cossé-en-Champagne;COSSE-EN-CHAMPAGNE;53340;53;MAYENNE;1
53077;;Cossé-le-Vivien;COSSE-LE-VIVIEN;53230;53;MAYENNE;1
53078;;Coudray;COUDRAY;53200;53;MAYENNE;1
53079;;Couesmes-Vaucé;COUESMES-VAUCE;53300;53;MAYENNE;1
53080;;Couptrain;COUPTRAIN;53250;53;MAYENNE;1
53082;;Courbeveille;COURBEVEILLE;53230;53;MAYENNE;1
53083;;Courcité;COURCITE;53700;53;MAYENNE;1
53084;;Craon;CRAON;53400;53;MAYENNE;1
53085;;Crennes-sur-Fraubée;CRENNES-SUR-FRAUBEE;53700;53;MAYENNE;1
53086;La;Croixille;CROIXILLE;53380;53;MAYENNE;1
53087;La;Cropte;CROPTE;53170;53;MAYENNE;1
53088;;Cuillé;CUILLE;53540;53;MAYENNE;1
53089;;Daon;DAON;53200;53;MAYENNE;1
53090;;Denazé;DENAZE;53400;53;MAYENNE;1
53091;;Désertines;DESERTINES;53190;53;MAYENNE;1
53092;;Deux-Évailles;DEUX-EVAILLES;53150;53;MAYENNE;1
53093;La;Dorée;DOREE;53190;53;MAYENNE;1
53094;;Entrammes;ENTRAMMES;53260;53;MAYENNE;1
53095;;Épineux-le-Seguin;EPINEUX-LE-SEGUIN;53340;53;MAYENNE;1
53096;;Ernée;ERNEE;53500;53;MAYENNE;1
53097;;Évron;EVRON;53600;53;MAYENNE;1
53098;;Fontaine-Couverte;FONTAINE-COUVERTE;53350;53;MAYENNE;1
53099;;Forcé;FORCE;53260;53;MAYENNE;1
53100;;Fougerolles-du-Plessis;FOUGEROLLES-DU-PLESSIS;53190;53;MAYENNE;1
53101;;Fromentières;FROMENTIERES;53200;53;MAYENNE;1
53102;;Gastines;GASTINES;53540;53;MAYENNE;1
53103;Le;Genest-Saint-Isle;GENEST-SAINT-ISLE;53940;53;MAYENNE;1
53104;;Gennes-sur-Glaize;GENNES-SUR-GLAIZE;53200;53;MAYENNE;1
53105;;Gesnes;GESNES;53150;53;MAYENNE;1
53106;;Gesvres;GESVRES;53370;53;MAYENNE;1
53107;;Gorron;GORRON;53120;53;MAYENNE;1
53108;La;Gravelle;GRAVELLE;53410;53;MAYENNE;1
53109;;Grazay;GRAZAY;53440;53;MAYENNE;1
53110;;Grez-en-Bouère;GREZ-EN-BOUERE;53290;53;MAYENNE;1
53111;La;Haie-Traversaine;HAIE-TRAVERSAINE;53300;53;MAYENNE;1
53112;Le;Ham;HAM;53250;53;MAYENNE;1
53113;;Hambers;HAMBERS;53160;53;MAYENNE;1
53114;;Hardanges;HARDANGES;53640;53;MAYENNE;1
53115;;Hercé;HERCE;53120;53;MAYENNE;1
53116;Le;Horps;HORPS;53640;53;MAYENNE;1
53117;;Houssay;HOUSSAY;53360;53;MAYENNE;1
53118;Le;Housseau-Brétignolles;HOUSSEAU-BRETIGNOLLES;53110;53;MAYENNE;1
53119;L';Huisserie;HUISSERIE;53970;53;MAYENNE;1
53120;;Izé;IZE;53160;53;MAYENNE;1
53121;;Javron-les-Chapelles;JAVRON-LES-CHAPELLES;53250;53;MAYENNE;1
53122;;Jublains;JUBLAINS;53160;53;MAYENNE;1
53123;;Juvigné;JUVIGNE;53380;53;MAYENNE;1
53124;;Laigné;LAIGNE;53200;53;MAYENNE;1
53125;;Landivy;LANDIVY;53190;53;MAYENNE;1
53126;;Larchamp;LARCHAMP;53220;53;MAYENNE;1
53127;;Lassay-les-Châteaux;LASSAY-LES-CHATEAUX;53110;53;MAYENNE;1
53128;;Laubrières;LAUBRIERES;53540;53;MAYENNE;1
53129;;Launay-Villiers;LAUNAY-VILLIERS;53410;53;MAYENNE;1
53130;;Laval;LAVAL;53000;53;MAYENNE;1
53131;;Lesbois;LESBOIS;53120;53;MAYENNE;1
53132;;Levaré;LEVARE;53120;53;MAYENNE;1
53133;;Lignières-Orgères;LIGNIERES-ORGERES;53140;53;MAYENNE;1
53134;;Livet;LIVET;53150;53;MAYENNE;1
53135;;Livré-la-Touche;LIVRE-LA-TOUCHE;53400;53;MAYENNE;1
53136;;Loigné-sur-Mayenne;LOIGNE-SUR-MAYENNE;53200;53;MAYENNE;1
53137;;Loiron;LOIRON;53320;53;MAYENNE;1
53138;;Longuefuye;LONGUEFUYE;53200;53;MAYENNE;1
53139;;Loupfougères;LOUPFOUGERES;53700;53;MAYENNE;1
53140;;Louverné;LOUVERNE;53950;53;MAYENNE;1
53141;;Louvigné;LOUVIGNE;53210;53;MAYENNE;1
53142;;Madré;MADRE;53250;53;MAYENNE;1
53143;;Maisoncelles-du-Maine;MAISONCELLES-DU-MAINE;53170;53;MAYENNE;1
53144;;Marcillé-la-Ville;MARCILLE-LA-VILLE;53440;53;MAYENNE;1
53145;;Marigné-Peuton;MARIGNE-PEUTON;53200;53;MAYENNE;1
53146;;Martigné-sur-Mayenne;MARTIGNE-SUR-MAYENNE;53470;53;MAYENNE;1
53147;;Mayenne;MAYENNE;53100;53;MAYENNE;1
53148;;Mée;MEE;53400;53;MAYENNE;1
53150;;Ménil;MENIL;53200;53;MAYENNE;1
53151;;Méral;MERAL;53230;53;MAYENNE;1
53152;;Meslay-du-Maine;MESLAY-DU-MAINE;53170;53;MAYENNE;1
53153;;Mézangers;MEZANGERS;53600;53;MAYENNE;1
53154;;Montaudin;MONTAUDIN;53220;53;MAYENNE;1
53155;;Montenay;MONTENAY;53500;53;MAYENNE;1
53156;;Montflours;MONTFLOURS;53240;53;MAYENNE;1
53157;;Montigné-le-Brillant;MONTIGNE-LE-BRILLANT;53970;53;MAYENNE;1
53158;;Montjean;MONTJEAN;53320;53;MAYENNE;1
53159;;Montourtier;MONTOURTIER;53150;53;MAYENNE;1
53160;;Montreuil-Poulay;MONTREUIL-POULAY;53640;53;MAYENNE;1
53161;;Montsûrs;MONTSURS;53150;53;MAYENNE;1
53162;;Moulay;MOULAY;53100;53;MAYENNE;1
53163;;Neau;NEAU;53150;53;MAYENNE;1
53164;;Neuilly-le-Vendin;NEUILLY-LE-VENDIN;53250;53;MAYENNE;1
53165;;Niafles;NIAFLES;53400;53;MAYENNE;1
53168;;Nuillé-sur-Vicoin;NUILLE-SUR-VICOIN;53970;53;MAYENNE;1
53169;;Olivet;OLIVET;53410;53;MAYENNE;1
53170;;Oisseau;OISSEAU;53300;53;MAYENNE;1
53172;;Origné;ORIGNE;53360;53;MAYENNE;1
53173;La;Pallu;PALLU;53140;53;MAYENNE;1
53174;;Parigné-sur-Braye;PARIGNE-SUR-BRAYE;53100;53;MAYENNE;1
53175;;Parné-sur-Roc;PARNE-SUR-ROC;53260;53;MAYENNE;1
53176;Le;Pas;PAS;53300;53;MAYENNE;1
53177;La;Pellerine;PELLERINE;53220;53;MAYENNE;1
53178;;Peuton;PEUTON;53360;53;MAYENNE;1
53179;;Placé;PLACE;53240;53;MAYENNE;1
53180;;Pommerieux;POMMERIEUX;53400;53;MAYENNE;1
53181;;Pontmain;PONTMAIN;53220;53;MAYENNE;1
53182;;Port-Brillet;PORT-BRILLET;53410;53;MAYENNE;1
53184;;Préaux;PREAUX;53340;53;MAYENNE;1
53185;;Pré-en-Pail;PRE-EN-PAIL;53140;53;MAYENNE;1
53186;;Quelaines-Saint-Gault;QUELAINES-SAINT-GAULT;53360;53;MAYENNE;1
53187;;Ravigny;RAVIGNY;61420;53;ORNE;1
53188;;Renazé;RENAZE;53800;53;MAYENNE;1
53189;;Rennes-en-Grenouilles;RENNES-EN-GRENOUILLES;53110;53;MAYENNE;1
53190;Le;Ribay;RIBAY;53640;53;MAYENNE;1
53191;La;Roë;ROE;53350;53;MAYENNE;1
53192;La;Rouaudière;ROUAUDIERE;53390;53;MAYENNE;1
53193;;Ruillé-Froid-Fonds;RUILLE-FROID-FONDS;53170;53;MAYENNE;1
53194;;Ruillé-le-Gravelais;RUILLE-LE-GRAVELAIS;53320;53;MAYENNE;1
53195;;Sacé;SACE;53470;53;MAYENNE;1
53196;;Saint-Aignan-de-Couptrain;SAINT-AIGNAN-DE-COUPTRAIN;53250;53;MAYENNE;1
53197;;Saint-Aignan-sur-Roë;SAINT-AIGNAN-SUR-ROE;53390;53;MAYENNE;1
53198;;Saint-Aubin-du-Désert;SAINT-AUBIN-DU-DESERT;53700;53;MAYENNE;1
53199;;Saint-Aubin-Fosse-Louvain;SAINT-AUBIN-FOSSE-LOUVAIN;53120;53;MAYENNE;1
53200;;Saint-Baudelle;SAINT-BAUDELLE;53100;53;MAYENNE;1
53201;;Saint-Berthevin;SAINT-BERTHEVIN;53940;53;MAYENNE;1
53202;;Saint-Berthevin-la-Tannière;SAINT-BERTHEVIN-LA-TANNIERE;53220;53;MAYENNE;1
53203;;Saint-Brice;SAINT-BRICE;53290;53;MAYENNE;1
53204;;Saint-Calais-du-Désert;SAINT-CALAIS-DU-DESERT;53140;53;MAYENNE;1
53205;;Saint-Céneré;SAINT-CENERE;53150;53;MAYENNE;1
53206;;Saint-Charles-la-Forêt;SAINT-CHARLES-LA-FORET;53170;53;MAYENNE;1
53207;;Saint-Christophe-du-Luat;SAINT-CHRISTOPHE-DU-LUAT;53150;53;MAYENNE;1
53208;;Saint-Cyr-en-Pail;SAINT-CYR-EN-PAIL;53140;53;MAYENNE;1
53209;;Saint-Cyr-le-Gravelais;SAINT-CYR-LE-GRAVELAIS;53320;53;MAYENNE;1
53210;;Saint-Denis-d'Anjou;SAINT-DENIS-D'ANJOU;53290;53;MAYENNE;1
53211;;Saint-Denis-de-Gastines;SAINT-DENIS-DE-GASTINES;53500;53;MAYENNE;1
53212;;Saint-Denis-du-Maine;SAINT-DENIS-DU-MAINE;53170;53;MAYENNE;1
53213;;Saint-Ellier-du-Maine;SAINT-ELLIER-DU-MAINE;53220;53;MAYENNE;1
53214;;Saint-Erblon;SAINT-ERBLON;53390;53;MAYENNE;1
53215;;Saint-Fort;SAINT-FORT;53200;53;MAYENNE;1
53216;;Saint-Fraimbault-de-Prières;SAINT-FRAIMBAULT-DE-PRIERES;53300;53;MAYENNE;1
53218;;Sainte-Gemmes-le-Robert;SAINTE-GEMMES-LE-ROBERT;53600;53;MAYENNE;1
53219;;Saint-Georges-Buttavent;SAINT-GEORGES-BUTTAVENT;53100;53;MAYENNE;1
53220;;Saint-Georges-le-Fléchard;SAINT-GEORGES-LE-FLECHARD;53480;53;MAYENNE;1
53221;;Saint-Georges-sur-Erve;SAINT-GEORGES-SUR-ERVE;53600;53;MAYENNE;1
53222;;Saint-Germain-d'Anxure;SAINT-GERMAIN-D'ANXURE;53240;53;MAYENNE;1
53223;;Saint-Germain-de-Coulamer;SAINT-GERMAIN-DE-COULAMER;53700;53;MAYENNE;1
53224;;Saint-Germain-le-Fouilloux;SAINT-GERMAIN-LE-FOUILLOUX;53240;53;MAYENNE;1
53225;;Saint-Germain-le-Guillaume;SAINT-GERMAIN-LE-GUILLAUME;53240;53;MAYENNE;1
53226;;Saint-Hilaire-du-Maine;SAINT-HILAIRE-DU-MAINE;53380;53;MAYENNE;1
53228;;Saint-Jean-sur-Erve;SAINT-JEAN-SUR-ERVE;53270;53;MAYENNE;1
53229;;Saint-Jean-sur-Mayenne;SAINT-JEAN-SUR-MAYENNE;53240;53;MAYENNE;1
53230;;Saint-Julien-du-Terroux;SAINT-JULIEN-DU-TERROUX;53110;53;MAYENNE;1
53231;;Saint-Laurent-des-Mortiers;SAINT-LAURENT-DES-MORTIERS;53290;53;MAYENNE;1
53232;;Saint-Léger;SAINT-LEGER;53480;53;MAYENNE;1
53233;;Saint-Loup-du-Dorat;SAINT-LOUP-DU-DORAT;53290;53;MAYENNE;1
53234;;Saint-Loup-du-Gast;SAINT-LOUP-DU-GAST;53300;53;MAYENNE;1
53235;;Sainte-Marie-du-Bois;SAINTE-MARIE-DU-BOIS;53110;53;MAYENNE;1
53236;;Saint-Mars-du-Désert;SAINT-MARS-DU-DESERT;53700;53;MAYENNE;1
53237;;Saint-Mars-sur-Colmont;SAINT-MARS-SUR-COLMONT;53300;53;MAYENNE;1
53238;;Saint-Mars-sur-la-Futaie;SAINT-MARS-SUR-LA-FUTAIE;53220;53;MAYENNE;1
53239;;Saint-Martin-de-Connée;SAINT-MARTIN-DE-CONNEE;53160;53;MAYENNE;1
53240;;Saint-Martin-du-Limet;SAINT-MARTIN-DU-LIMET;53800;53;MAYENNE;1
53241;;Saint-Michel-de-Feins;SAINT-MICHEL-DE-FEINS;53290;53;MAYENNE;1
53242;;Saint-Michel-de-la-Roë;SAINT-MICHEL-DE-LA-ROE;53350;53;MAYENNE;1
53243;;Saint-Ouën-des-Toits;SAINT-OUEN-DES-TOITS;53410;53;MAYENNE;1
53244;;Saint-Ouën-des-Vallons;SAINT-OUEN-DES-VALLONS;53150;53;MAYENNE;1
53245;;Saint-Pierre-des-Landes;SAINT-PIERRE-DES-LANDES;53500;53;MAYENNE;1
53246;;Saint-Pierre-des-Nids;SAINT-PIERRE-DES-NIDS;53370;53;MAYENNE;1
53247;;Saint-Pierre-la-Cour;SAINT-PIERRE-LA-COUR;53410;53;MAYENNE;1
53248;;Saint-Pierre-sur-Erve;SAINT-PIERRE-SUR-ERVE;53270;53;MAYENNE;1
53249;;Saint-Pierre-sur-Orthe;SAINT-PIERRE-SUR-ORTHE;53160;53;MAYENNE;1
53250;;Saint-Poix;SAINT-POIX;53540;53;MAYENNE;1
53251;;Saint-Quentin-les-Anges;SAINT-QUENTIN-LES-ANGES;53400;53;MAYENNE;1
53252;;Saint-Samson;SAINT-SAMSON;53140;53;MAYENNE;1
53253;;Saint-Saturnin-du-Limet;SAINT-SATURNIN-DU-LIMET;53800;53;MAYENNE;1
53254;;Saint-Sulpice;SAINT-SULPICE;53360;53;MAYENNE;1
53255;;Sainte-Suzanne;SAINTE-SUZANNE;53270;53;MAYENNE;1
53256;;Saint-Thomas-de-Courceriers;SAINT-THOMAS-DE-COURCERIERS;53160;53;MAYENNE;1
53257;;Saulges;SAULGES;53340;53;MAYENNE;1
53258;La;Selle-Craonnaise;SELLE-CRAONNAISE;53800;53;MAYENNE;1
53259;;Senonnes;SENONNES;53390;53;MAYENNE;1
53260;;Simplé;SIMPLE;53360;53;MAYENNE;1
53261;;Soucé;SOUCE;53300;53;MAYENNE;1
53262;;Soulgé-sur-Ouette;SOULGE-SUR-OUETTE;53210;53;MAYENNE;1
53263;;Thubœuf;THUBOEUF;53110;53;MAYENNE;1
53264;;Thorigné-en-Charnie;THORIGNE-EN-CHARNIE;53270;53;MAYENNE;1
53265;;Torcé-Viviers-en-Charnie;TORCE-VIVIERS-EN-CHARNIE;53270;53;MAYENNE;1
53266;;Trans;TRANS;53160;53;MAYENNE;1
53267;;Vaiges;VAIGES;53480;53;MAYENNE;1
53269;;Vautorte;VAUTORTE;53500;53;MAYENNE;1
53270;;Vieuvy;VIEUVY;53120;53;MAYENNE;1
53271;;Villaines-la-Juhel;VILLAINES-LA-JUHEL;53700;53;MAYENNE;1
53272;;Villepail;VILLEPAIL;53250;53;MAYENNE;1
53273;;Villiers-Charlemagne;VILLIERS-CHARLEMAGNE;53170;53;MAYENNE;1
53274;;Vimarcé;VIMARCE;53160;53;MAYENNE;1
53276;;Voutré;VOUTRE;53600;53;MAYENNE;1
54001;;Abaucourt;ABAUCOURT;54610;54;MEURTHE ET MOSELLE;1
54002;;Abbéville-lès-Conflans;ABBEVILLE-LES-CONFLANS;54800;54;MEURTHE ET MOSELLE;1
54003;;Aboncourt;ABONCOURT;54115;54;MEURTHE ET MOSELLE;1
54004;;Affléville;AFFLEVILLE;54800;54;MEURTHE ET MOSELLE;1
54005;;Affracourt;AFFRACOURT;54740;54;MEURTHE ET MOSELLE;1
54006;;Agincourt;AGINCOURT;54770;54;MEURTHE ET MOSELLE;1
54007;;Aingeray;AINGERAY;54460;54;MEURTHE ET MOSELLE;1
54008;;Allain;ALLAIN;54170;54;MEURTHE ET MOSELLE;1
54009;;Allamont;ALLAMONT;54800;54;MEURTHE ET MOSELLE;1
54010;;Allamps;ALLAMPS;54112;54;MEURTHE ET MOSELLE;1
54011;;Allondrelle-la-Malmaison;ALLONDRELLE-LA-MALMAISON;54260;54;MEURTHE ET MOSELLE;1
54012;;Amance;AMANCE;54770;54;MEURTHE ET MOSELLE;1
54013;;Amenoncourt;AMENONCOURT;54450;54;MEURTHE ET MOSELLE;1
54014;;Ancerviller;ANCERVILLER;54450;54;MEURTHE ET MOSELLE;1
54015;;Anderny;ANDERNY;54560;54;MEURTHE ET MOSELLE;1
54016;;Andilly;ANDILLY;54200;54;MEURTHE ET MOSELLE;1
54017;;Angomont;ANGOMONT;54540;54;MEURTHE ET MOSELLE;1
54018;;Anoux;ANOUX;54150;54;MEURTHE ET MOSELLE;1
54019;;Ansauville;ANSAUVILLE;54470;54;MEURTHE ET MOSELLE;1
54020;;Anthelupt;ANTHELUPT;54110;54;MEURTHE ET MOSELLE;1
54021;;Armaucourt;ARMAUCOURT;54760;54;MEURTHE ET MOSELLE;1
54022;;Arnaville;ARNAVILLE;54530;54;MEURTHE ET MOSELLE;1
54023;;Arracourt;ARRACOURT;54370;54;MEURTHE ET MOSELLE;1
54024;;Arraye-et-Han;ARRAYE-ET-HAN;54760;54;MEURTHE ET MOSELLE;1
54025;;Art-sur-Meurthe;ART-SUR-MEURTHE;54510;54;MEURTHE ET MOSELLE;1
54026;;Athienville;ATHIENVILLE;54370;54;MEURTHE ET MOSELLE;1
54027;;Atton;ATTON;54700;54;MEURTHE ET MOSELLE;1
54028;;Auboué;AUBOUE;54580;54;MEURTHE ET MOSELLE;1
54029;;Audun-le-Roman;AUDUN-LE-ROMAN;54560;54;MEURTHE ET MOSELLE;1
54030;;Autrepierre;AUTREPIERRE;54450;54;MEURTHE ET MOSELLE;1
54031;;Autreville-sur-Moselle;AUTREVILLE-SUR-MOSELLE;54380;54;MEURTHE ET MOSELLE;1
54032;;Autrey;AUTREY;54160;54;MEURTHE ET MOSELLE;1
54033;;Avillers;AVILLERS;54490;54;MEURTHE ET MOSELLE;1
54034;;Avrainville;AVRAINVILLE;54385;54;MEURTHE ET MOSELLE;1
54035;;Avricourt;AVRICOURT;54450;54;MEURTHE ET MOSELLE;1
54036;;Avril;AVRIL;54150;54;MEURTHE ET MOSELLE;1
54037;;Azelot;AZELOT;54210;54;MEURTHE ET MOSELLE;1
54038;;Azerailles;AZERAILLES;54122;54;MEURTHE ET MOSELLE;1
54039;;Baccarat;BACCARAT;54120;54;MEURTHE ET MOSELLE;1
54040;;Badonviller;BADONVILLER;54540;54;MEURTHE ET MOSELLE;1
54041;;Bagneux;BAGNEUX;54170;54;MEURTHE ET MOSELLE;1
54042;;Bainville-aux-Miroirs;BAINVILLE-AUX-MIROIRS;54290;54;MEURTHE ET MOSELLE;1
54043;;Bainville-sur-Madon;BAINVILLE-SUR-MADON;54550;54;MEURTHE ET MOSELLE;1
54044;;Barbas;BARBAS;54450;54;MEURTHE ET MOSELLE;1
54045;;Barbonville;BARBONVILLE;54360;54;MEURTHE ET MOSELLE;1
54046;;Barisey-au-Plain;BARISEY-AU-PLAIN;54170;54;MEURTHE ET MOSELLE;1
54047;;Barisey-la-Côte;BARISEY-LA-COTE;54170;54;MEURTHE ET MOSELLE;1
54048;Les;Baroches;BAROCHES;54150;54;MEURTHE ET MOSELLE;1
54049;;Baslieux;BASLIEUX;54620;54;MEURTHE ET MOSELLE;1
54050;;Bathelémont;BATHELEMONT;54370;54;MEURTHE ET MOSELLE;1
54051;;Batilly;BATILLY;54980;54;MEURTHE ET MOSELLE;1
54052;;Battigny;BATTIGNY;54115;54;MEURTHE ET MOSELLE;1
54053;;Bauzemont;BAUZEMONT;54370;54;MEURTHE ET MOSELLE;1
54054;;Bayon;BAYON;54290;54;MEURTHE ET MOSELLE;1
54055;;Bayonville-sur-Mad;BAYONVILLE-SUR-MAD;54890;54;MEURTHE ET MOSELLE;1
54056;;Bazailles;BAZAILLES;54620;54;MEURTHE ET MOSELLE;1
54057;;Beaumont;BEAUMONT;54470;54;MEURTHE ET MOSELLE;1
54058;;Béchamps;BECHAMPS;54800;54;MEURTHE ET MOSELLE;1
54059;;Belleau;BELLEAU;54610;54;MEURTHE ET MOSELLE;1
54060;;Belleville;BELLEVILLE;54940;54;MEURTHE ET MOSELLE;1
54061;;Bénaménil;BENAMENIL;54450;54;MEURTHE ET MOSELLE;1
54062;;Benney;BENNEY;54740;54;MEURTHE ET MOSELLE;1
54063;;Bernécourt;BERNECOURT;54470;54;MEURTHE ET MOSELLE;1
54064;;Bertrambois;BERTRAMBOIS;54480;54;MEURTHE ET MOSELLE;1
54065;;Bertrichamps;BERTRICHAMPS;54120;54;MEURTHE ET MOSELLE;1
54066;;Bettainvillers;BETTAINVILLERS;54640;54;MEURTHE ET MOSELLE;1
54067;;Beuveille;BEUVEILLE;54620;54;MEURTHE ET MOSELLE;1
54068;;Beuvezin;BEUVEZIN;54115;54;MEURTHE ET MOSELLE;1
54069;;Beuvillers;BEUVILLERS;54560;54;MEURTHE ET MOSELLE;1
54070;;Bey-sur-Seille;BEY-SUR-SEILLE;54760;54;MEURTHE ET MOSELLE;1
54071;;Bezange-la-Grande;BEZANGE-LA-GRANDE;54370;54;MEURTHE ET MOSELLE;1
54072;;Bezaumont;BEZAUMONT;54380;54;MEURTHE ET MOSELLE;1
54073;;Bicqueley;BICQUELEY;54200;54;MEURTHE ET MOSELLE;1
54074;;Bienville-la-Petite;BIENVILLE-LA-PETITE;54300;54;MEURTHE ET MOSELLE;1
54075;;Bionville;BIONVILLE;54540;54;MEURTHE ET MOSELLE;1
54076;;Blainville-sur-l'Eau;BLAINVILLE-SUR-L'EAU;54360;54;MEURTHE ET MOSELLE;1
54077;;Blâmont;BLAMONT;54450;54;MEURTHE ET MOSELLE;1
54078;;Blémerey;BLEMEREY;54450;54;MEURTHE ET MOSELLE;1
54079;;Blénod-lès-Pont-à-Mousson;BLENOD-LES-PONT-A-MOUSSON;54700;54;MEURTHE ET MOSELLE;1
54080;;Blénod-lès-Toul;BLENOD-LES-TOUL;54113;54;MEURTHE ET MOSELLE;1
54081;;Boismont;BOISMONT;54620;54;MEURTHE ET MOSELLE;1
54082;;Boncourt;BONCOURT;54800;54;MEURTHE ET MOSELLE;1
54083;;Bonviller;BONVILLER;54300;54;MEURTHE ET MOSELLE;1
54084;;Mont-Bonvillers;MONT-BONVILLERS;54111;54;MEURTHE ET MOSELLE;1
54085;;Borville;BORVILLE;54290;54;MEURTHE ET MOSELLE;1
54086;;Boucq;BOUCQ;54200;54;MEURTHE ET MOSELLE;1
54087;;Bouillonville;BOUILLONVILLE;54470;54;MEURTHE ET MOSELLE;1
54088;;Bouvron;BOUVRON;54200;54;MEURTHE ET MOSELLE;1
54089;;Bouxières-aux-Chênes;BOUXIERES-AUX-CHENES;54770;54;MEURTHE ET MOSELLE;1
54090;;Bouxières-aux-Dames;BOUXIERES-AUX-DAMES;54136;54;MEURTHE ET MOSELLE;1
54091;;Bouxières-sous-Froidmont;BOUXIERES-SOUS-FROIDMONT;54700;54;MEURTHE ET MOSELLE;1
54092;;Bouzanville;BOUZANVILLE;54930;54;MEURTHE ET MOSELLE;1
54093;;Brainville;BRAINVILLE;54800;54;MEURTHE ET MOSELLE;1
54094;;Bralleville;BRALLEVILLE;54740;54;MEURTHE ET MOSELLE;1
54095;;Bratte;BRATTE;54610;54;MEURTHE ET MOSELLE;1
54096;;Bréhain-la-Ville;BREHAIN-LA-VILLE;54190;54;MEURTHE ET MOSELLE;1
54097;;Bréménil;BREMENIL;54540;54;MEURTHE ET MOSELLE;1
54098;;Brémoncourt;BREMONCOURT;54290;54;MEURTHE ET MOSELLE;1
54099;;Briey;BRIEY;54150;54;MEURTHE ET MOSELLE;1
54100;;Brin-sur-Seille;BRIN-SUR-SEILLE;54280;54;MEURTHE ET MOSELLE;1
54101;;Brouville;BROUVILLE;54120;54;MEURTHE ET MOSELLE;1
54102;;Bruley;BRULEY;54200;54;MEURTHE ET MOSELLE;1
54103;;Bruville;BRUVILLE;54800;54;MEURTHE ET MOSELLE;1
54104;;Buissoncourt;BUISSONCOURT;54110;54;MEURTHE ET MOSELLE;1
54105;;Bulligny;BULLIGNY;54113;54;MEURTHE ET MOSELLE;1
54106;;Bures;BURES;54370;54;MEURTHE ET MOSELLE;1
54107;;Buriville;BURIVILLE;54450;54;MEURTHE ET MOSELLE;1
54108;;Burthecourt-aux-Chênes;BURTHECOURT-AUX-CHENES;54210;54;MEURTHE ET MOSELLE;1
54109;;Ceintrey;CEINTREY;54134;54;MEURTHE ET MOSELLE;1
54110;;Cerville;CERVILLE;54420;54;MEURTHE ET MOSELLE;1
54111;;Chaligny;CHALIGNY;54230;54;MEURTHE ET MOSELLE;1
54112;;Chambley-Bussières;CHAMBLEY-BUSSIERES;54890;54;MEURTHE ET MOSELLE;1
54113;;Champenoux;CHAMPENOUX;54280;54;MEURTHE ET MOSELLE;1
54114;;Champey-sur-Moselle;CHAMPEY-SUR-MOSELLE;54700;54;MEURTHE ET MOSELLE;1
54115;;Champigneulles;CHAMPIGNEULLES;54250;54;MEURTHE ET MOSELLE;1
54116;;Chanteheux;CHANTEHEUX;54300;54;MEURTHE ET MOSELLE;1
54117;;Chaouilley;CHAOUILLEY;54330;54;MEURTHE ET MOSELLE;1
54118;;Charency-Vezin;CHARENCY-VEZIN;54260;54;MEURTHE ET MOSELLE;1
54119;;Charey;CHAREY;54470;54;MEURTHE ET MOSELLE;1
54120;;Charmes-la-Côte;CHARMES-LA-COTE;54113;54;MEURTHE ET MOSELLE;1
54121;;Charmois;CHARMOIS;54360;54;MEURTHE ET MOSELLE;1
54122;;Chaudeney-sur-Moselle;CHAUDENEY-SUR-MOSELLE;54200;54;MEURTHE ET MOSELLE;1
54123;;Chavigny;CHAVIGNY;54230;54;MEURTHE ET MOSELLE;1
54124;;Chazelles-sur-Albe;CHAZELLES-SUR-ALBE;54450;54;MEURTHE ET MOSELLE;1
54125;;Chenevières;CHENEVIERES;54122;54;MEURTHE ET MOSELLE;1
54126;;Chenicourt;CHENICOURT;54610;54;MEURTHE ET MOSELLE;1
54127;;Chenières;CHENIERES;54720;54;MEURTHE ET MOSELLE;1
54128;;Choloy-Ménillot;CHOLOY-MENILLOT;54200;54;MEURTHE ET MOSELLE;1
54129;;Cirey-sur-Vezouze;CIREY-SUR-VEZOUZE;54480;54;MEURTHE ET MOSELLE;1
54130;;Clayeures;CLAYEURES;54290;54;MEURTHE ET MOSELLE;1
54131;;Clémery;CLEMERY;54610;54;MEURTHE ET MOSELLE;1
54132;;Clérey-sur-Brenon;CLEREY-SUR-BRENON;54330;54;MEURTHE ET MOSELLE;1
54133;;Coincourt;COINCOURT;54370;54;MEURTHE ET MOSELLE;1
54134;;Colmey;COLMEY;54260;54;MEURTHE ET MOSELLE;1
54135;;Colombey-les-Belles;COLOMBEY-LES-BELLES;54170;54;MEURTHE ET MOSELLE;1
54136;;Conflans-en-Jarnisy;CONFLANS-EN-JARNISY;54800;54;MEURTHE ET MOSELLE;1
54137;;Cons-la-Grandville;CONS-LA-GRANDVILLE;54870;54;MEURTHE ET MOSELLE;1
54138;;Cosnes-et-Romain;COSNES-ET-ROMAIN;54400;54;MEURTHE ET MOSELLE;1
54139;;Courbesseaux;COURBESSEAUX;54110;54;MEURTHE ET MOSELLE;1
54140;;Courcelles;COURCELLES;54930;54;MEURTHE ET MOSELLE;1
54141;;Coyviller;COYVILLER;54210;54;MEURTHE ET MOSELLE;1
54142;;Crantenoy;CRANTENOY;54740;54;MEURTHE ET MOSELLE;1
54143;;Crépey;CREPEY;54170;54;MEURTHE ET MOSELLE;1
54144;;Crévéchamps;CREVECHAMPS;54290;54;MEURTHE ET MOSELLE;1
54145;;Crévic;CREVIC;54110;54;MEURTHE ET MOSELLE;1
54146;;Crézilles;CREZILLES;54113;54;MEURTHE ET MOSELLE;1
54147;;Crion;CRION;54300;54;MEURTHE ET MOSELLE;1
54148;;Croismare;CROISMARE;54300;54;MEURTHE ET MOSELLE;1
54149;;Crusnes;CRUSNES;54680;54;MEURTHE ET MOSELLE;1
54150;;Custines;CUSTINES;54670;54;MEURTHE ET MOSELLE;1
54151;;Cutry;CUTRY;54720;54;MEURTHE ET MOSELLE;1
54152;;Damelevières;DAMELEVIERES;54360;54;MEURTHE ET MOSELLE;1
54153;;Dampvitoux;DAMPVITOUX;54470;54;MEURTHE ET MOSELLE;1
54154;;Deneuvre;DENEUVRE;54120;54;MEURTHE ET MOSELLE;1
54155;;Deuxville;DEUXVILLE;54370;54;MEURTHE ET MOSELLE;1
54156;;Diarville;DIARVILLE;54930;54;MEURTHE ET MOSELLE;1
54157;;Dieulouard;DIEULOUARD;54380;54;MEURTHE ET MOSELLE;1
54158;;Dolcourt;DOLCOURT;54170;54;MEURTHE ET MOSELLE;1
54159;;Dombasle-sur-Meurthe;DOMBASLE-SUR-MEURTHE;54110;54;MEURTHE ET MOSELLE;1
54160;;Domèvre-en-Haye;DOMEVRE-EN-HAYE;54385;54;MEURTHE ET MOSELLE;1
54161;;Domèvre-sur-Vezouze;DOMEVRE-SUR-VEZOUZE;54450;54;MEURTHE ET MOSELLE;1
54162;;Domgermain;DOMGERMAIN;54119;54;MEURTHE ET MOSELLE;1
54163;;Domjevin;DOMJEVIN;54450;54;MEURTHE ET MOSELLE;1
54164;;Dommarie-Eulmont;DOMMARIE-EULMONT;54115;54;MEURTHE ET MOSELLE;1
54165;;Dommartemont;DOMMARTEMONT;54130;54;MEURTHE ET MOSELLE;1
54166;;Dommartin-la-Chaussée;DOMMARTIN-LA-CHAUSSEE;54470;54;MEURTHE ET MOSELLE;1
54167;;Dommartin-lès-Toul;DOMMARTIN-LES-TOUL;54200;54;MEURTHE ET MOSELLE;1
54168;;Dommartin-sous-Amance;DOMMARTIN-SOUS-AMANCE;54770;54;MEURTHE ET MOSELLE;1
54169;;Domprix;DOMPRIX;54490;54;MEURTHE ET MOSELLE;1
54170;;Domptail-en-l'Air;DOMPTAIL-EN-L'AIR;54290;54;MEURTHE ET MOSELLE;1
54171;;Doncourt-lès-Conflans;DONCOURT-LES-CONFLANS;54800;54;MEURTHE ET MOSELLE;1
54172;;Doncourt-lès-Longuyon;DONCOURT-LES-LONGUYON;54620;54;MEURTHE ET MOSELLE;1
54173;;Drouville;DROUVILLE;54370;54;MEURTHE ET MOSELLE;1
54174;;Écrouves;ECROUVES;54200;54;MEURTHE ET MOSELLE;1
54175;;Einvaux;EINVAUX;54360;54;MEURTHE ET MOSELLE;1
54176;;Einville-au-Jard;EINVILLE-AU-JARD;54370;54;MEURTHE ET MOSELLE;1
54177;;Emberménil;EMBERMENIL;54370;54;MEURTHE ET MOSELLE;1
54178;;Épiez-sur-Chiers;EPIEZ-SUR-CHIERS;54260;54;MEURTHE ET MOSELLE;1
54179;;Éply;EPLY;54610;54;MEURTHE ET MOSELLE;1
54180;;Erbéviller-sur-Amezule;ERBEVILLER-SUR-AMEZULE;54280;54;MEURTHE ET MOSELLE;1
54181;;Errouville;ERROUVILLE;54680;54;MEURTHE ET MOSELLE;1
54182;;Essey-et-Maizerais;ESSEY-ET-MAIZERAIS;54470;54;MEURTHE ET MOSELLE;1
54183;;Essey-la-Côte;ESSEY-LA-COTE;54830;54;MEURTHE ET MOSELLE;1
54184;;Essey-lès-Nancy;ESSEY-LES-NANCY;54270;54;MEURTHE ET MOSELLE;1
54185;;Étreval;ETREVAL;54330;54;MEURTHE ET MOSELLE;1
54186;;Eulmont;EULMONT;54690;54;MEURTHE ET MOSELLE;1
54187;;Euvezin;EUVEZIN;54470;54;MEURTHE ET MOSELLE;1
54188;;Faulx;FAULX;54760;54;MEURTHE ET MOSELLE;1
54189;;Favières;FAVIERES;54115;54;MEURTHE ET MOSELLE;1
54190;;Fécocourt;FECOCOURT;54115;54;MEURTHE ET MOSELLE;1
54191;;Fenneviller;FENNEVILLER;54540;54;MEURTHE ET MOSELLE;1
54192;;Ferrières;FERRIERES;54210;54;MEURTHE ET MOSELLE;1
54193;;Fey-en-Haye;FEY-EN-HAYE;54470;54;MEURTHE ET MOSELLE;1
54194;;Fillières;FILLIERES;54560;54;MEURTHE ET MOSELLE;1
54195;;Flainval;FLAINVAL;54110;54;MEURTHE ET MOSELLE;1
54196;;Flavigny-sur-Moselle;FLAVIGNY-SUR-MOSELLE;54630;54;MEURTHE ET MOSELLE;1
54197;;Fléville-devant-Nancy;FLEVILLE-DEVANT-NANCY;54710;54;MEURTHE ET MOSELLE;1
54198;;Fléville-Lixières;FLEVILLE-LIXIERES;54150;54;MEURTHE ET MOSELLE;1
54199;;Flin;FLIN;54122;54;MEURTHE ET MOSELLE;1
54200;;Flirey;FLIREY;54470;54;MEURTHE ET MOSELLE;1
54201;;Fontenoy-la-Joûte;FONTENOY-LA-JOUTE;54122;54;MEURTHE ET MOSELLE;1
54202;;Fontenoy-sur-Moselle;FONTENOY-SUR-MOSELLE;54840;54;MEURTHE ET MOSELLE;1
54203;;Forcelles-Saint-Gorgon;FORCELLES-SAINT-GORGON;54330;54;MEURTHE ET MOSELLE;1
54204;;Forcelles-sous-Gugney;FORCELLES-SOUS-GUGNEY;54930;54;MEURTHE ET MOSELLE;1
54205;;Foug;FOUG;54570;54;MEURTHE ET MOSELLE;1
54206;;Fraimbois;FRAIMBOIS;54300;54;MEURTHE ET MOSELLE;1
54207;;Fraisnes-en-Saintois;FRAISNES-EN-SAINTOIS;54930;54;MEURTHE ET MOSELLE;1
54208;;Francheville;FRANCHEVILLE;54200;54;MEURTHE ET MOSELLE;1
54209;;Franconville;FRANCONVILLE;54830;54;MEURTHE ET MOSELLE;1
54210;;Fréménil;FREMENIL;54450;54;MEURTHE ET MOSELLE;1
54211;;Frémonville;FREMONVILLE;54450;54;MEURTHE ET MOSELLE;1
54212;;Fresnois-la-Montagne;FRESNOIS-LA-MONTAGNE;54260;54;MEURTHE ET MOSELLE;1
54213;;Friauville;FRIAUVILLE;54800;54;MEURTHE ET MOSELLE;1
54214;;Frolois;FROLOIS;54160;54;MEURTHE ET MOSELLE;1
54215;;Frouard;FROUARD;54390;54;MEURTHE ET MOSELLE;1
54216;;Froville;FROVILLE;54290;54;MEURTHE ET MOSELLE;1
54217;;Gélacourt;GELACOURT;54120;54;MEURTHE ET MOSELLE;1
54218;;Gélaucourt;GELAUCOURT;54115;54;MEURTHE ET MOSELLE;1
54219;;Gellenoncourt;GELLENONCOURT;54110;54;MEURTHE ET MOSELLE;1
54220;;Gémonville;GEMONVILLE;54115;54;MEURTHE ET MOSELLE;1
54221;;Gerbécourt-et-Haplemont;GERBECOURT-ET-HAPLEMONT;54740;54;MEURTHE ET MOSELLE;1
54222;;Gerbéviller;GERBEVILLER;54830;54;MEURTHE ET MOSELLE;1
54223;;Germiny;GERMINY;54170;54;MEURTHE ET MOSELLE;1
54224;;Germonville;GERMONVILLE;54740;54;MEURTHE ET MOSELLE;1
54225;;Gézoncourt;GEZONCOURT;54380;54;MEURTHE ET MOSELLE;1
54226;;Gibeaumeix;GIBEAUMEIX;54112;54;MEURTHE ET MOSELLE;1
54227;;Giraumont;GIRAUMONT;54780;54;MEURTHE ET MOSELLE;1
54228;;Giriviller;GIRIVILLER;54830;54;MEURTHE ET MOSELLE;1
54229;;Glonville;GLONVILLE;54122;54;MEURTHE ET MOSELLE;1
54230;;Gogney;GOGNEY;54450;54;MEURTHE ET MOSELLE;1
54231;;Gondrecourt-Aix;GONDRECOURT-AIX;54800;54;MEURTHE ET MOSELLE;1
54232;;Gondreville;GONDREVILLE;54840;54;MEURTHE ET MOSELLE;1
54233;;Gondrexon;GONDREXON;54450;54;MEURTHE ET MOSELLE;1
54234;;Gorcy;GORCY;54730;54;MEURTHE ET MOSELLE;1
54235;;Goviller;GOVILLER;54330;54;MEURTHE ET MOSELLE;1
54236;;Grand-Failly;GRAND-FAILLY;54260;54;MEURTHE ET MOSELLE;1
54237;;Grimonviller;GRIMONVILLER;54115;54;MEURTHE ET MOSELLE;1
54238;;Gripport;GRIPPORT;54290;54;MEURTHE ET MOSELLE;1
54239;;Griscourt;GRISCOURT;54380;54;MEURTHE ET MOSELLE;1
54240;;Grosrouvres;GROSROUVRES;54470;54;MEURTHE ET MOSELLE;1
54241;;Gugney;GUGNEY;54930;54;MEURTHE ET MOSELLE;1
54242;;Gye;GYE;54113;54;MEURTHE ET MOSELLE;1
54243;;Hablainville;HABLAINVILLE;54120;54;MEURTHE ET MOSELLE;1
54244;;Hagéville;HAGEVILLE;54470;54;MEURTHE ET MOSELLE;1
54245;;Haigneville;HAIGNEVILLE;54290;54;MEURTHE ET MOSELLE;1
54246;;Halloville;HALLOVILLE;54450;54;MEURTHE ET MOSELLE;1
54247;;Hammeville;HAMMEVILLE;54330;54;MEURTHE ET MOSELLE;1
54248;;Hamonville;HAMONVILLE;54470;54;MEURTHE ET MOSELLE;1
54249;;Hannonville-Suzémont;HANNONVILLE-SUZEMONT;54800;54;MEURTHE ET MOSELLE;1
54250;;Haraucourt;HARAUCOURT;54110;54;MEURTHE ET MOSELLE;1
54251;;Harbouey;HARBOUEY;54450;54;MEURTHE ET MOSELLE;1
54252;;Haroué;HAROUE;54740;54;MEURTHE ET MOSELLE;1
54253;;Hatrize;HATRIZE;54800;54;MEURTHE ET MOSELLE;1
54254;;Haucourt-Moulaine;HAUCOURT-MOULAINE;54860;54;MEURTHE ET MOSELLE;1
54255;;Haudonville;HAUDONVILLE;54830;54;MEURTHE ET MOSELLE;1
54256;;Haussonville;HAUSSONVILLE;54290;54;MEURTHE ET MOSELLE;1
54257;;Heillecourt;HEILLECOURT;54180;54;MEURTHE ET MOSELLE;1
54258;;Hénaménil;HENAMENIL;54370;54;MEURTHE ET MOSELLE;1
54259;;Herbéviller;HERBEVILLER;54450;54;MEURTHE ET MOSELLE;1
54260;;Hériménil;HERIMENIL;54300;54;MEURTHE ET MOSELLE;1
54261;;Herserange;HERSERANGE;54440;54;MEURTHE ET MOSELLE;1
54262;;Hoéville;HOEVILLE;54370;54;MEURTHE ET MOSELLE;1
54263;;Homécourt;HOMECOURT;54310;54;MEURTHE ET MOSELLE;1
54264;;Houdelmont;HOUDELMONT;54330;54;MEURTHE ET MOSELLE;1
54265;;Houdemont;HOUDEMONT;54180;54;MEURTHE ET MOSELLE;1
54266;;Houdreville;HOUDREVILLE;54330;54;MEURTHE ET MOSELLE;1
54268;;Housséville;HOUSSEVILLE;54930;54;MEURTHE ET MOSELLE;1
54269;;Hudiviller;HUDIVILLER;54110;54;MEURTHE ET MOSELLE;1
54270;;Hussigny-Godbrange;HUSSIGNY-GODBRANGE;54590;54;MEURTHE ET MOSELLE;1
54271;;Igney;IGNEY;54450;54;MEURTHE ET MOSELLE;1
54272;;Jaillon;JAILLON;54200;54;MEURTHE ET MOSELLE;1
54273;;Jarny;JARNY;54800;54;MEURTHE ET MOSELLE;1
54274;;Jarville-la-Malgrange;JARVILLE-LA-MALGRANGE;54140;54;MEURTHE ET MOSELLE;1
54275;;Jaulny;JAULNY;54470;54;MEURTHE ET MOSELLE;1
54276;;Jeandelaincourt;JEANDELAINCOURT;54114;54;MEURTHE ET MOSELLE;1
54277;;Jeandelize;JEANDELIZE;54800;54;MEURTHE ET MOSELLE;1
54278;;Jevoncourt;JEVONCOURT;54740;54;MEURTHE ET MOSELLE;1
54279;;Jezainville;JEZAINVILLE;54700;54;MEURTHE ET MOSELLE;1
54280;;Jœuf;JOEUF;54240;54;MEURTHE ET MOSELLE;1
54281;;Jolivet;JOLIVET;54300;54;MEURTHE ET MOSELLE;1
54282;;Joppécourt;JOPPECOURT;54620;54;MEURTHE ET MOSELLE;1
54283;;Jouaville;JOUAVILLE;54800;54;MEURTHE ET MOSELLE;1
54284;;Joudreville;JOUDREVILLE;54490;54;MEURTHE ET MOSELLE;1
54285;;Juvrecourt;JUVRECOURT;54370;54;MEURTHE ET MOSELLE;1
54286;;Labry;LABRY;54800;54;MEURTHE ET MOSELLE;1
54287;;Lachapelle;LACHAPELLE;54120;54;MEURTHE ET MOSELLE;1
54288;;Lagney;LAGNEY;54200;54;MEURTHE ET MOSELLE;1
54289;;Laître-sous-Amance;LAITRE-SOUS-AMANCE;54770;54;MEURTHE ET MOSELLE;1
54290;;Laix;LAIX;54720;54;MEURTHE ET MOSELLE;1
54291;;Lalœuf;LALOEUF;54115;54;MEURTHE ET MOSELLE;1
54292;;Lamath;LAMATH;54300;54;MEURTHE ET MOSELLE;1
54293;;Landécourt;LANDECOURT;54360;54;MEURTHE ET MOSELLE;1
54294;;Landremont;LANDREMONT;54380;54;MEURTHE ET MOSELLE;1
54295;;Landres;LANDRES;54970;54;MEURTHE ET MOSELLE;1
54296;;Laneuvelotte;LANEUVELOTTE;54280;54;MEURTHE ET MOSELLE;1
54297;;Laneuveville-aux-Bois;LANEUVEVILLE-AUX-BOIS;54370;54;MEURTHE ET MOSELLE;1
54298;;Laneuveville-derrière-Foug;LANEUVEVILLE-DERRIERE-FOUG;54570;54;MEURTHE ET MOSELLE;1
54299;;Laneuveville-devant-Bayon;LANEUVEVILLE-DEVANT-BAYON;54740;54;MEURTHE ET MOSELLE;1
54300;;Laneuveville-devant-Nancy;LANEUVEVILLE-DEVANT-NANCY;54410;54;MEURTHE ET MOSELLE;1
54301;;Lanfroicourt;LANFROICOURT;54760;54;MEURTHE ET MOSELLE;1
54302;;Lantéfontaine;LANTEFONTAINE;54150;54;MEURTHE ET MOSELLE;1
54303;;Laronxe;LARONXE;54950;54;MEURTHE ET MOSELLE;1
54304;;Laxou;LAXOU;54520;54;MEURTHE ET MOSELLE;1
54305;;Lay-Saint-Christophe;LAY-SAINT-CHRISTOPHE;54690;54;MEURTHE ET MOSELLE;1
54306;;Lay-Saint-Remy;LAY-SAINT-REMY;54570;54;MEURTHE ET MOSELLE;1
54307;;Lebeuville;LEBEUVILLE;54740;54;MEURTHE ET MOSELLE;1
54308;;Leintrey;LEINTREY;54450;54;MEURTHE ET MOSELLE;1
54309;;Lemainville;LEMAINVILLE;54740;54;MEURTHE ET MOSELLE;1
54310;;Leménil-Mitry;LEMENIL-MITRY;54740;54;MEURTHE ET MOSELLE;1
54311;;Lenoncourt;LENONCOURT;54110;54;MEURTHE ET MOSELLE;1
54312;;Lesménils;LESMENILS;54700;54;MEURTHE ET MOSELLE;1
54313;;Létricourt;LETRICOURT;54610;54;MEURTHE ET MOSELLE;1
54314;;Lexy;LEXY;54720;54;MEURTHE ET MOSELLE;1
54315;;Leyr;LEYR;54760;54;MEURTHE ET MOSELLE;1
54316;;Limey-Remenauville;LIMEY-REMENAUVILLE;54470;54;MEURTHE ET MOSELLE;1
54317;;Lironville;LIRONVILLE;54470;54;MEURTHE ET MOSELLE;1
54318;;Liverdun;LIVERDUN;54460;54;MEURTHE ET MOSELLE;1
54320;;Loisy;LOISY;54700;54;MEURTHE ET MOSELLE;1
54321;;Longlaville;LONGLAVILLE;54810;54;MEURTHE ET MOSELLE;1
54322;;Longuyon;LONGUYON;54260;54;MEURTHE ET MOSELLE;1
54323;;Longwy;LONGWY;54400;54;MEURTHE ET MOSELLE;1
54324;;Lorey;LOREY;54290;54;MEURTHE ET MOSELLE;1
54325;;Loromontzey;LOROMONTZEY;54290;54;MEURTHE ET MOSELLE;1
54326;;Lubey;LUBEY;54150;54;MEURTHE ET MOSELLE;1
54327;;Lucey;LUCEY;54200;54;MEURTHE ET MOSELLE;1
54328;;Ludres;LUDRES;54710;54;MEURTHE ET MOSELLE;1
54329;;Lunéville;LUNEVILLE;54300;54;MEURTHE ET MOSELLE;1
54330;;Lupcourt;LUPCOURT;54210;54;MEURTHE ET MOSELLE;1
54331;;Magnières;MAGNIERES;54129;54;MEURTHE ET MOSELLE;1
54332;;Maidières;MAIDIERES;54700;54;MEURTHE ET MOSELLE;1
54333;;Mailly-sur-Seille;MAILLY-SUR-SEILLE;54610;54;MEURTHE ET MOSELLE;1
54334;;Mairy-Mainville;MAIRY-MAINVILLE;54150;54;MEURTHE ET MOSELLE;1
54335;;Maixe;MAIXE;54370;54;MEURTHE ET MOSELLE;1
54336;;Maizières;MAIZIERES;54550;54;MEURTHE ET MOSELLE;1
54337;;Malavillers;MALAVILLERS;54560;54;MEURTHE ET MOSELLE;1
54338;;Malleloy;MALLELOY;54670;54;MEURTHE ET MOSELLE;1
54339;;Malzéville;MALZEVILLE;54220;54;MEURTHE ET MOSELLE;1
54340;;Mamey;MAMEY;54470;54;MEURTHE ET MOSELLE;1
54341;;Mance;MANCE;54150;54;MEURTHE ET MOSELLE;1
54342;;Mancieulles;MANCIEULLES;54790;54;MEURTHE ET MOSELLE;1
54343;;Mandres-aux-Quatre-Tours;MANDRES-AUX-QUATRE-TOURS;54470;54;MEURTHE ET MOSELLE;1
54344;;Mangonville;MANGONVILLE;54290;54;MEURTHE ET MOSELLE;1
54345;;Manoncourt-en-Vermois;MANONCOURT-EN-VERMOIS;54210;54;MEURTHE ET MOSELLE;1
54346;;Manoncourt-en-Woëvre;MANONCOURT-EN-WOEVRE;54385;54;MEURTHE ET MOSELLE;1
54348;;Manonville;MANONVILLE;54385;54;MEURTHE ET MOSELLE;1
54349;;Manonviller;MANONVILLER;54300;54;MEURTHE ET MOSELLE;1
54350;;Marainviller;MARAINVILLER;54300;54;MEURTHE ET MOSELLE;1
54351;;Marbache;MARBACHE;54820;54;MEURTHE ET MOSELLE;1
54352;;Maron;MARON;54230;54;MEURTHE ET MOSELLE;1
54353;;Mars-la-Tour;MARS-LA-TOUR;54800;54;MEURTHE ET MOSELLE;1
54354;;Marthemont;MARTHEMONT;54330;54;MEURTHE ET MOSELLE;1
54355;;Martincourt;MARTINCOURT;54380;54;MEURTHE ET MOSELLE;1
54356;;Mattexey;MATTEXEY;54830;54;MEURTHE ET MOSELLE;1
54357;;Maxéville;MAXEVILLE;54320;54;MEURTHE ET MOSELLE;1
54358;;Mazerulles;MAZERULLES;54280;54;MEURTHE ET MOSELLE;1
54359;;Méhoncourt;MEHONCOURT;54360;54;MEURTHE ET MOSELLE;1
54360;;Ménil-la-Tour;MENIL-LA-TOUR;54200;54;MEURTHE ET MOSELLE;1
54362;;Mercy-le-Bas;MERCY-LE-BAS;54960;54;MEURTHE ET MOSELLE;1
54363;;Mercy-le-Haut;MERCY-LE-HAUT;54560;54;MEURTHE ET MOSELLE;1
54364;;Méréville;MEREVILLE;54850;54;MEURTHE ET MOSELLE;1
54365;;Merviller;MERVILLER;54120;54;MEURTHE ET MOSELLE;1
54366;;Messein;MESSEIN;54850;54;MEURTHE ET MOSELLE;1
54367;;Mexy;MEXY;54135;54;MEURTHE ET MOSELLE;1
54368;;Mignéville;MIGNEVILLE;54540;54;MEURTHE ET MOSELLE;1
54369;;Millery;MILLERY;54670;54;MEURTHE ET MOSELLE;1
54370;;Minorville;MINORVILLE;54385;54;MEURTHE ET MOSELLE;1
54371;;Moineville;MOINEVILLE;54580;54;MEURTHE ET MOSELLE;1
54372;;Moivrons;MOIVRONS;54760;54;MEURTHE ET MOSELLE;1
54373;;Moncel-lès-Lunéville;MONCEL-LES-LUNEVILLE;54300;54;MEURTHE ET MOSELLE;1
54374;;Moncel-sur-Seille;MONCEL-SUR-SEILLE;54280;54;MEURTHE ET MOSELLE;1
54375;;Montauville;MONTAUVILLE;54700;54;MEURTHE ET MOSELLE;1
54376;;Montenoy;MONTENOY;54760;54;MEURTHE ET MOSELLE;1
54377;;Montigny;MONTIGNY;54540;54;MEURTHE ET MOSELLE;1
54378;;Montigny-sur-Chiers;MONTIGNY-SUR-CHIERS;54870;54;MEURTHE ET MOSELLE;1
54379;;Mont-l'Étroit;MONT-L'ETROIT;54170;54;MEURTHE ET MOSELLE;1
54380;;Mont-le-Vignoble;MONT-LE-VIGNOBLE;54113;54;MEURTHE ET MOSELLE;1
54381;;Montreux;MONTREUX;54450;54;MEURTHE ET MOSELLE;1
54382;;Mont-Saint-Martin;MONT-SAINT-MARTIN;54350;54;MEURTHE ET MOSELLE;1
54383;;Mont-sur-Meurthe;MONT-SUR-MEURTHE;54360;54;MEURTHE ET MOSELLE;1
54385;;Morfontaine;MORFONTAINE;54920;54;MEURTHE ET MOSELLE;1
54386;;Moriviller;MORIVILLER;54830;54;MEURTHE ET MOSELLE;1
54387;;Morville-sur-Seille;MORVILLE-SUR-SEILLE;54700;54;MEURTHE ET MOSELLE;1
54388;;Mouacourt;MOUACOURT;54370;54;MEURTHE ET MOSELLE;1
54389;;Mouaville;MOUAVILLE;54800;54;MEURTHE ET MOSELLE;1
54390;;Mousson;MOUSSON;54700;54;MEURTHE ET MOSELLE;1
54391;;Moutiers;MOUTIERS;54660;54;MEURTHE ET MOSELLE;1
54392;;Moutrot;MOUTROT;54113;54;MEURTHE ET MOSELLE;1
54393;;Moyen;MOYEN;54118;54;MEURTHE ET MOSELLE;1
54394;;Murville;MURVILLE;54490;54;MEURTHE ET MOSELLE;1
54395;;Nancy;NANCY;54000;54;MEURTHE ET MOSELLE;1
54396;;Neufmaisons;NEUFMAISONS;54540;54;MEURTHE ET MOSELLE;1
54397;;Neuves-Maisons;NEUVES-MAISONS;54230;54;MEURTHE ET MOSELLE;1
54398;;Neuviller-lès-Badonviller;NEUVILLER-LES-BADONVILLER;54540;54;MEURTHE ET MOSELLE;1
54399;;Neuviller-sur-Moselle;NEUVILLER-SUR-MOSELLE;54290;54;MEURTHE ET MOSELLE;1
54400;;Nomeny;NOMENY;54610;54;MEURTHE ET MOSELLE;1
54401;;Nonhigny;NONHIGNY;54450;54;MEURTHE ET MOSELLE;1
54402;;Norroy-le-Sec;NORROY-LE-SEC;54150;54;MEURTHE ET MOSELLE;1
54403;;Norroy-lès-Pont-à-Mousson;NORROY-LES-PONT-A-MOUSSON;54700;54;MEURTHE ET MOSELLE;1
54404;;Noviant-aux-Prés;NOVIANT-AUX-PRES;54385;54;MEURTHE ET MOSELLE;1
54405;;Ochey;OCHEY;54170;54;MEURTHE ET MOSELLE;1
54406;;Ogéviller;OGEVILLER;54450;54;MEURTHE ET MOSELLE;1
54407;;Ognéville;OGNEVILLE;54330;54;MEURTHE ET MOSELLE;1
54408;;Olley;OLLEY;54800;54;MEURTHE ET MOSELLE;1
54409;;Omelmont;OMELMONT;54330;54;MEURTHE ET MOSELLE;1
54410;;Onville;ONVILLE;54890;54;MEURTHE ET MOSELLE;1
54411;;Ormes-et-Ville;ORMES-ET-VILLE;54740;54;MEURTHE ET MOSELLE;1
54412;;Othe;OTHE;54260;54;MEURTHE ET MOSELLE;1
54413;;Ozerailles;OZERAILLES;54150;54;MEURTHE ET MOSELLE;1
54414;;Pagney-derrière-Barine;PAGNEY-DERRIERE-BARINE;54200;54;MEURTHE ET MOSELLE;1
54415;;Pagny-sur-Moselle;PAGNY-SUR-MOSELLE;54530;54;MEURTHE ET MOSELLE;1
54416;;Pannes;PANNES;54470;54;MEURTHE ET MOSELLE;1
54417;;Parey-Saint-Césaire;PAREY-SAINT-CESAIRE;54330;54;MEURTHE ET MOSELLE;1
54418;;Parroy;PARROY;54370;54;MEURTHE ET MOSELLE;1
54419;;Parux;PARUX;54480;54;MEURTHE ET MOSELLE;1
54420;;Petit-Failly;PETIT-FAILLY;54260;54;MEURTHE ET MOSELLE;1
54421;;Petitmont;PETITMONT;54480;54;MEURTHE ET MOSELLE;1
54422;;Pettonville;PETTONVILLE;54120;54;MEURTHE ET MOSELLE;1
54423;;Pexonne;PEXONNE;54540;54;MEURTHE ET MOSELLE;1
54424;;Phlin;PHLIN;54610;54;MEURTHE ET MOSELLE;1
54425;;Piennes;PIENNES;54490;54;MEURTHE ET MOSELLE;1
54426;;Pierre-la-Treiche;PIERRE-LA-TREICHE;54200;54;MEURTHE ET MOSELLE;1
54427;;Pierre-Percée;PIERRE-PERCEE;54540;54;MEURTHE ET MOSELLE;1
54428;;Pierrepont;PIERREPONT;54620;54;MEURTHE ET MOSELLE;1
54429;;Pierreville;PIERREVILLE;54160;54;MEURTHE ET MOSELLE;1
54430;;Pompey;POMPEY;54340;54;MEURTHE ET MOSELLE;1
54431;;Pont-à-Mousson;PONT-A-MOUSSON;54700;54;MEURTHE ET MOSELLE;1
54432;;Pont-Saint-Vincent;PONT-SAINT-VINCENT;54550;54;MEURTHE ET MOSELLE;1
54433;;Port-sur-Seille;PORT-SUR-SEILLE;54700;54;MEURTHE ET MOSELLE;1
54434;;Praye;PRAYE;54116;54;MEURTHE ET MOSELLE;1
54435;;Prény;PRENY;54530;54;MEURTHE ET MOSELLE;1
54436;;Preutin-Higny;PREUTIN-HIGNY;54490;54;MEURTHE ET MOSELLE;1
54437;;Pulligny;PULLIGNY;54160;54;MEURTHE ET MOSELLE;1
54438;;Pulney;PULNEY;54115;54;MEURTHE ET MOSELLE;1
54439;;Pulnoy;PULNOY;54420;54;MEURTHE ET MOSELLE;1
54440;;Puxe;PUXE;54800;54;MEURTHE ET MOSELLE;1
54441;;Puxieux;PUXIEUX;54800;54;MEURTHE ET MOSELLE;1
54442;;Quevilloncourt;QUEVILLONCOURT;54330;54;MEURTHE ET MOSELLE;1
54443;;Raon-lès-Leau;RAON-LES-LEAU;54540;54;MEURTHE ET MOSELLE;1
54444;;Raucourt;RAUCOURT;54610;54;MEURTHE ET MOSELLE;1
54445;;Raville-sur-Sânon;RAVILLE-SUR-SANON;54370;54;MEURTHE ET MOSELLE;1
54446;;Réchicourt-la-Petite;RECHICOURT-LA-PETITE;54370;54;MEURTHE ET MOSELLE;1
54447;;Réclonville;RECLONVILLE;54450;54;MEURTHE ET MOSELLE;1
54449;;Rehainviller;REHAINVILLER;54300;54;MEURTHE ET MOSELLE;1
54450;;Reherrey;REHERREY;54120;54;MEURTHE ET MOSELLE;1
54451;;Réhon;REHON;54430;54;MEURTHE ET MOSELLE;1
54452;;Reillon;REILLON;54450;54;MEURTHE ET MOSELLE;1
54453;;Rembercourt-sur-Mad;REMBERCOURT-SUR-MAD;54470;54;MEURTHE ET MOSELLE;1
54455;;Remenoville;REMENOVILLE;54830;54;MEURTHE ET MOSELLE;1
54456;;Réméréville;REMEREVILLE;54110;54;MEURTHE ET MOSELLE;1
54457;;Remoncourt;REMONCOURT;54370;54;MEURTHE ET MOSELLE;1
54458;;Repaix;REPAIX;54450;54;MEURTHE ET MOSELLE;1
54459;;Richardménil;RICHARDMENIL;54630;54;MEURTHE ET MOSELLE;1
54460;;Rogéville;ROGEVILLE;54380;54;MEURTHE ET MOSELLE;1
54461;;Romain;ROMAIN;54360;54;MEURTHE ET MOSELLE;1
54462;;Rosières-aux-Salines;ROSIERES-AUX-SALINES;54110;54;MEURTHE ET MOSELLE;1
54463;;Rosières-en-Haye;ROSIERES-EN-HAYE;54385;54;MEURTHE ET MOSELLE;1
54464;;Rouves;ROUVES;54610;54;MEURTHE ET MOSELLE;1
54465;;Roville-devant-Bayon;ROVILLE-DEVANT-BAYON;54290;54;MEURTHE ET MOSELLE;1
54466;;Royaumeix;ROYAUMEIX;54200;54;MEURTHE ET MOSELLE;1
54467;;Rozelieures;ROZELIEURES;54290;54;MEURTHE ET MOSELLE;1
54468;;Saffais;SAFFAIS;54210;54;MEURTHE ET MOSELLE;1
54469;;Saint-Ail;SAINT-AIL;54580;54;MEURTHE ET MOSELLE;1
54470;;Saint-Baussant;SAINT-BAUSSANT;54470;54;MEURTHE ET MOSELLE;1
54471;;Saint-Boingt;SAINT-BOINGT;54290;54;MEURTHE ET MOSELLE;1
54472;;Saint-Clément;SAINT-CLEMENT;54950;54;MEURTHE ET MOSELLE;1
54473;;Saint-Firmin;SAINT-FIRMIN;54930;54;MEURTHE ET MOSELLE;1
54474;;Sainte-Geneviève;SAINTE-GENEVIEVE;54700;54;MEURTHE ET MOSELLE;1
54475;;Saint-Germain;SAINT-GERMAIN;54290;54;MEURTHE ET MOSELLE;1
54476;;Saint-Jean-lès-Longuyon;SAINT-JEAN-LES-LONGUYON;54260;54;MEURTHE ET MOSELLE;1
54477;;Saint-Julien-lès-Gorze;SAINT-JULIEN-LES-GORZE;54470;54;MEURTHE ET MOSELLE;1
54478;;Saint-Marcel;SAINT-MARCEL;54800;54;MEURTHE ET MOSELLE;1
54479;;Saint-Mard;SAINT-MARD;54290;54;MEURTHE ET MOSELLE;1
54480;;Saint-Martin;SAINT-MARTIN;54450;54;MEURTHE ET MOSELLE;1
54481;;Saint-Maurice-aux-Forges;SAINT-MAURICE-AUX-FORGES;54540;54;MEURTHE ET MOSELLE;1
54482;;Saint-Max;SAINT-MAX;54130;54;MEURTHE ET MOSELLE;1
54483;;Saint-Nicolas-de-Port;SAINT-NICOLAS-DE-PORT;54210;54;MEURTHE ET MOSELLE;1
54484;;Sainte-Pôle;SAINTE-POLE;54540;54;MEURTHE ET MOSELLE;1
54485;;Saint-Pancré;SAINT-PANCRE;54730;54;MEURTHE ET MOSELLE;1
54486;;Saint-Remimont;SAINT-REMIMONT;54740;54;MEURTHE ET MOSELLE;1
54487;;Saint-Rémy-aux-Bois;SAINT-REMY-AUX-BOIS;54290;54;MEURTHE ET MOSELLE;1
54488;;Saint-Sauveur;SAINT-SAUVEUR;54480;54;MEURTHE ET MOSELLE;1
54489;;Saint-Supplet;SAINT-SUPPLET;54620;54;MEURTHE ET MOSELLE;1
54490;;Saizerais;SAIZERAIS;54380;54;MEURTHE ET MOSELLE;1
54491;;Sancy;SANCY;54560;54;MEURTHE ET MOSELLE;1
54492;;Sanzey;SANZEY;54200;54;MEURTHE ET MOSELLE;1
54493;;Saulnes;SAULNES;54650;54;MEURTHE ET MOSELLE;1
54494;;Saulxerotte;SAULXEROTTE;54115;54;MEURTHE ET MOSELLE;1
54495;;Saulxures-lès-Nancy;SAULXURES-LES-NANCY;54420;54;MEURTHE ET MOSELLE;1
54496;;Saulxures-lès-Vannes;SAULXURES-LES-VANNES;54170;54;MEURTHE ET MOSELLE;1
54497;;Saxon-Sion;SAXON-SION;54330;54;MEURTHE ET MOSELLE;1
54498;;Seichamps;SEICHAMPS;54280;54;MEURTHE ET MOSELLE;1
54499;;Seicheprey;SEICHEPREY;54470;54;MEURTHE ET MOSELLE;1
54500;;Selaincourt;SELAINCOURT;54170;54;MEURTHE ET MOSELLE;1
54501;;Seranville;SERANVILLE;54830;54;MEURTHE ET MOSELLE;1
54502;;Serres;SERRES;54370;54;MEURTHE ET MOSELLE;1
54504;;Serrouville;SERROUVILLE;54560;54;MEURTHE ET MOSELLE;1
54505;;Sexey-aux-Forges;SEXEY-AUX-FORGES;54550;54;MEURTHE ET MOSELLE;1
54506;;Sexey-les-Bois;SEXEY-LES-BOIS;54840;54;MEURTHE ET MOSELLE;1
54507;;Sionviller;SIONVILLER;54300;54;MEURTHE ET MOSELLE;1
54508;;Sivry;SIVRY;54610;54;MEURTHE ET MOSELLE;1
54509;;Sommerviller;SOMMERVILLER;54110;54;MEURTHE ET MOSELLE;1
54510;;Sornéville;SORNEVILLE;54280;54;MEURTHE ET MOSELLE;1
54511;;Sponville;SPONVILLE;54800;54;MEURTHE ET MOSELLE;1
54512;;Tanconville;TANCONVILLE;54480;54;MEURTHE ET MOSELLE;1
54513;;Tantonville;TANTONVILLE;54116;54;MEURTHE ET MOSELLE;1
54514;;Tellancourt;TELLANCOURT;54260;54;MEURTHE ET MOSELLE;1
54515;;Thélod;THELOD;54330;54;MEURTHE ET MOSELLE;1
54516;;They-sous-Vaudemont;THEY-SOUS-VAUDEMONT;54930;54;MEURTHE ET MOSELLE;1
54517;;Thézey-Saint-Martin;THEZEY-SAINT-MARTIN;54610;54;MEURTHE ET MOSELLE;1
54518;;Thiaucourt-Regniéville;THIAUCOURT-REGNIEVILLE;54470;54;MEURTHE ET MOSELLE;1
54519;;Thiaville-sur-Meurthe;THIAVILLE-SUR-MEURTHE;54120;54;MEURTHE ET MOSELLE;1
54520;;Thiébauménil;THIEBAUMENIL;54300;54;MEURTHE ET MOSELLE;1
54521;;Thil;THIL;54880;54;MEURTHE ET MOSELLE;1
54522;;Thorey-Lyautey;THOREY-LYAUTEY;54115;54;MEURTHE ET MOSELLE;1
54523;;Thuilley-aux-Groseilles;THUILLEY-AUX-GROSEILLES;54170;54;MEURTHE ET MOSELLE;1
54524;;Thumeréville;THUMEREVILLE;54800;54;MEURTHE ET MOSELLE;1
54525;;Tiercelet;TIERCELET;54190;54;MEURTHE ET MOSELLE;1
54526;;Tomblaine;TOMBLAINE;54510;54;MEURTHE ET MOSELLE;1
54527;;Tonnoy;TONNOY;54210;54;MEURTHE ET MOSELLE;1
54528;;Toul;TOUL;54200;54;MEURTHE ET MOSELLE;1
54529;;Tramont-Émy;TRAMONT-EMY;54115;54;MEURTHE ET MOSELLE;1
54530;;Tramont-Lassus;TRAMONT-LASSUS;54115;54;MEURTHE ET MOSELLE;1
54531;;Tramont-Saint-André;TRAMONT-SAINT-ANDRE;54115;54;MEURTHE ET MOSELLE;1
54532;;Tremblecourt;TREMBLECOURT;54385;54;MEURTHE ET MOSELLE;1
54533;;Trieux;TRIEUX;54750;54;MEURTHE ET MOSELLE;1
54534;;Trondes;TRONDES;54570;54;MEURTHE ET MOSELLE;1
54535;;Tronville;TRONVILLE;54800;54;MEURTHE ET MOSELLE;1
54536;;Tucquegnieux;TUCQUEGNIEUX;54640;54;MEURTHE ET MOSELLE;1
54537;;Ugny;UGNY;54870;54;MEURTHE ET MOSELLE;1
54538;;Uruffe;URUFFE;54112;54;MEURTHE ET MOSELLE;1
54539;;Vacqueville;VACQUEVILLE;54540;54;MEURTHE ET MOSELLE;1
54540;;Val-et-Châtillon;VAL-ET-CHATILLON;54480;54;MEURTHE ET MOSELLE;1
54541;;Valhey;VALHEY;54370;54;MEURTHE ET MOSELLE;1
54542;;Valleroy;VALLEROY;54910;54;MEURTHE ET MOSELLE;1
54543;;Vallois;VALLOIS;54830;54;MEURTHE ET MOSELLE;1
54544;;Vandelainville;VANDELAINVILLE;54890;54;MEURTHE ET MOSELLE;1
54545;;Vandeléville;VANDELEVILLE;54115;54;MEURTHE ET MOSELLE;1
54546;;Vandières;VANDIERES;54121;54;MEURTHE ET MOSELLE;1
54547;;Vandœuvre-lès-Nancy;VANDOEUVRE-LES-NANCY;54500;54;MEURTHE ET MOSELLE;1
54548;;Vannes-le-Châtel;VANNES-LE-CHATEL;54112;54;MEURTHE ET MOSELLE;1
54549;;Varangéville;VARANGEVILLE;54110;54;MEURTHE ET MOSELLE;1
54550;;Vathiménil;VATHIMENIL;54122;54;MEURTHE ET MOSELLE;1
54551;;Vaucourt;VAUCOURT;54370;54;MEURTHE ET MOSELLE;1
54552;;Vaudémont;VAUDEMONT;54330;54;MEURTHE ET MOSELLE;1
54553;;Vaudeville;VAUDEVILLE;54740;54;MEURTHE ET MOSELLE;1
54554;;Vaudigny;VAUDIGNY;54740;54;MEURTHE ET MOSELLE;1
54555;;Vaxainville;VAXAINVILLE;54120;54;MEURTHE ET MOSELLE;1
54556;;Vého;VEHO;54450;54;MEURTHE ET MOSELLE;1
54557;;Velaine-en-Haye;VELAINE-EN-HAYE;54840;54;MEURTHE ET MOSELLE;1
54558;;Velaine-sous-Amance;VELAINE-SOUS-AMANCE;54280;54;MEURTHE ET MOSELLE;1
54559;;Velle-sur-Moselle;VELLE-SUR-MOSELLE;54290;54;MEURTHE ET MOSELLE;1
54560;;Veney;VENEY;54540;54;MEURTHE ET MOSELLE;1
54561;;Vennezey;VENNEZEY;54830;54;MEURTHE ET MOSELLE;1
54562;;Verdenal;VERDENAL;54450;54;MEURTHE ET MOSELLE;1
54563;;Vézelise;VEZELISE;54330;54;MEURTHE ET MOSELLE;1
54564;;Viéville-en-Haye;VIEVILLE-EN-HAYE;54470;54;MEURTHE ET MOSELLE;1
54565;;Vigneulles;VIGNEULLES;54360;54;MEURTHE ET MOSELLE;1
54566;;Vilcey-sur-Trey;VILCEY-SUR-TREY;54700;54;MEURTHE ET MOSELLE;1
54567;;Villacourt;VILLACOURT;54290;54;MEURTHE ET MOSELLE;1
54568;;Ville-au-Montois;VILLE-AU-MONTOIS;54620;54;MEURTHE ET MOSELLE;1
54569;;Ville-au-Val;VILLE-AU-VAL;54380;54;MEURTHE ET MOSELLE;1
54570;;Villecey-sur-Mad;VILLECEY-SUR-MAD;54890;54;MEURTHE ET MOSELLE;1
54571;;Ville-en-Vermois;VILLE-EN-VERMOIS;54210;54;MEURTHE ET MOSELLE;1
54572;;Ville-Houdlémont;VILLE-HOUDLEMONT;54730;54;MEURTHE ET MOSELLE;1
54573;;Villers-en-Haye;VILLERS-EN-HAYE;54380;54;MEURTHE ET MOSELLE;1
54574;;Villers-la-Chèvre;VILLERS-LA-CHEVRE;54870;54;MEURTHE ET MOSELLE;1
54575;;Villers-la-Montagne;VILLERS-LA-MONTAGNE;54920;54;MEURTHE ET MOSELLE;1
54576;;Villers-le-Rond;VILLERS-LE-ROND;54260;54;MEURTHE ET MOSELLE;1
54577;;Villers-lès-Moivrons;VILLERS-LES-MOIVRONS;54760;54;MEURTHE ET MOSELLE;1
54578;;Villers-lès-Nancy;VILLERS-LES-NANCY;54600;54;MEURTHE ET MOSELLE;1
54579;;Villers-sous-Prény;VILLERS-SOUS-PRENY;54700;54;MEURTHE ET MOSELLE;1
54580;;Villerupt;VILLERUPT;54190;54;MEURTHE ET MOSELLE;1
54581;;Ville-sur-Yron;VILLE-SUR-YRON;54800;54;MEURTHE ET MOSELLE;1
54582;;Villette;VILLETTE;54260;54;MEURTHE ET MOSELLE;1
54583;;Villey-le-Sec;VILLEY-LE-SEC;54840;54;MEURTHE ET MOSELLE;1
54584;;Villey-Saint-Étienne;VILLEY-SAINT-ETIENNE;54200;54;MEURTHE ET MOSELLE;1
54585;;Virecourt;VIRECOURT;54290;54;MEURTHE ET MOSELLE;1
54586;;Viterne;VITERNE;54123;54;MEURTHE ET MOSELLE;1
54587;;Vitrey;VITREY;54330;54;MEURTHE ET MOSELLE;1
54588;;Vitrimont;VITRIMONT;54300;54;MEURTHE ET MOSELLE;1
54589;;Vittonville;VITTONVILLE;54700;54;MEURTHE ET MOSELLE;1
54590;;Viviers-sur-Chiers;VIVIERS-SUR-CHIERS;54260;54;MEURTHE ET MOSELLE;1
54591;;Voinémont;VOINEMONT;54134;54;MEURTHE ET MOSELLE;1
54592;;Vroncourt;VRONCOURT;54330;54;MEURTHE ET MOSELLE;1
54593;;Waville;WAVILLE;54890;54;MEURTHE ET MOSELLE;1
54594;;Xammes;XAMMES;54470;54;MEURTHE ET MOSELLE;1
54595;;Xermaménil;XERMAMENIL;54300;54;MEURTHE ET MOSELLE;1
54596;;Xeuilley;XEUILLEY;54990;54;MEURTHE ET MOSELLE;1
54597;;Xirocourt;XIROCOURT;54740;54;MEURTHE ET MOSELLE;1
54598;;Xivry-Circourt;XIVRY-CIRCOURT;54490;54;MEURTHE ET MOSELLE;1
54599;;Xonville;XONVILLE;54800;54;MEURTHE ET MOSELLE;1
54600;;Xousse;XOUSSE;54370;54;MEURTHE ET MOSELLE;1
54601;;Xures;XURES;54370;54;MEURTHE ET MOSELLE;1
54602;;Han-devant-Pierrepont;HAN-DEVANT-PIERREPONT;;54;;
55001;;Abainville;ABAINVILLE;55130;55;MEUSE;1
55002;;Abaucourt-Hautecourt;ABAUCOURT-HAUTECOURT;55400;55;MEUSE;1
55004;;Aincreville;AINCREVILLE;55110;55;MEUSE;1
55005;;Amanty;AMANTY;55130;55;MEUSE;1
55007;;Ambly-sur-Meuse;AMBLY-SUR-MEUSE;55300;55;MEUSE;1
55008;;Amel-sur-l'Étang;AMEL-SUR-L'ETANG;55230;55;MEUSE;1
55009;;Ancemont;ANCEMONT;55320;55;MEUSE;1
55010;;Ancerville;ANCERVILLE;55170;55;MEUSE;1
55011;;Andernay;ANDERNAY;55800;55;MEUSE;1
55012;;Apremont-la-Forêt;APREMONT-LA-FORET;55300;55;MEUSE;1
55013;;Arrancy-sur-Crusne;ARRANCY-SUR-CRUSNE;55230;55;MEUSE;1
55014;;Aubréville;AUBREVILLE;55120;55;MEUSE;1
55015;;Aulnois-en-Perthois;AULNOIS-EN-PERTHOIS;55170;55;MEUSE;1
55017;;Autrécourt-sur-Aire;AUTRECOURT-SUR-AIRE;55120;55;MEUSE;1
55018;;Autréville-Saint-Lambert;AUTREVILLE-SAINT-LAMBERT;55700;55;MEUSE;1
55021;;Avillers-Sainte-Croix;AVILLERS-SAINTE-CROIX;55210;55;MEUSE;1
55022;;Avioth;AVIOTH;55600;55;MEUSE;1
55023;;Avocourt;AVOCOURT;55270;55;MEUSE;1
55024;;Azannes-et-Soumazannes;AZANNES-ET-SOUMAZANNES;55150;55;MEUSE;1
55025;;Baâlon;BAALON;55700;55;MEUSE;1
55026;;Badonvilliers-Gérauvilliers;BADONVILLIERS-GERAUVILLIERS;55130;55;MEUSE;1
55027;;Bannoncourt;BANNONCOURT;55300;55;MEUSE;1
55028;;Bantheville;BANTHEVILLE;55110;55;MEUSE;1
55029;;Bar-le-Duc;BAR-LE-DUC;55000;55;MEUSE;1
55030;;Baudignécourt;BAUDIGNECOURT;55130;55;MEUSE;1
55031;;Baudonvilliers;BAUDONVILLIERS;55170;55;MEUSE;1
55032;;Baudrémont;BAUDREMONT;55260;55;MEUSE;1
55033;;Baulny;BAULNY;55270;55;MEUSE;1
55034;;Bazeilles-sur-Othain;BAZEILLES-SUR-OTHAIN;55600;55;MEUSE;1
55035;;Bazincourt-sur-Saulx;BAZINCOURT-SUR-SAULX;55170;55;MEUSE;1
55036;;Beauclair;BEAUCLAIR;55700;55;MEUSE;1
55037;;Beaufort-en-Argonne;BEAUFORT-EN-ARGONNE;55700;55;MEUSE;1
55038;;Beaulieu-en-Argonne;BEAULIEU-EN-ARGONNE;55250;55;MEUSE;1
55039;;Beaumont-en-Verdunois;BEAUMONT-EN-VERDUNOIS;;55;;
55040;;Beausite;BEAUSITE;55250;55;MEUSE;1
55041;;Behonne;BEHONNE;55000;55;MEUSE;1
55042;;Belleray;BELLERAY;55100;55;MEUSE;1
55043;;Belleville-sur-Meuse;BELLEVILLE-SUR-MEUSE;55430;55;MEUSE;1
55044;;Belrain;BELRAIN;55260;55;MEUSE;1
55045;;Belrupt-en-Verdunois;BELRUPT-EN-VERDUNOIS;55100;55;MEUSE;1
55046;;Beney-en-Woëvre;BENEY-EN-WOEVRE;55210;55;MEUSE;1
55047;;Béthelainville;BETHELAINVILLE;55100;55;MEUSE;1
55048;;Béthincourt;BETHINCOURT;55270;55;MEUSE;1
55049;;Beurey-sur-Saulx;BEUREY-SUR-SAULX;55000;55;MEUSE;1
55050;;Bezonvaux;BEZONVAUX;;55;;
55051;;Biencourt-sur-Orge;BIENCOURT-SUR-ORGE;55290;55;MEUSE;1
55053;;Billy-sous-Mangiennes;BILLY-SOUS-MANGIENNES;55230;55;MEUSE;1
55054;;Bislée;BISLEE;55300;55;MEUSE;1
55055;;Blanzée;BLANZEE;55400;55;MEUSE;1
55057;;Boinville-en-Woëvre;BOINVILLE-EN-WOEVRE;55400;55;MEUSE;1
55058;;Boncourt-sur-Meuse;BONCOURT-SUR-MEUSE;55200;55;MEUSE;1
55059;;Bonnet;BONNET;55130;55;MEUSE;1
55060;;Bonzée;BONZEE;55160;55;MEUSE;1
55061;Le;Bouchon-sur-Saulx;BOUCHON-SUR-SAULX;55500;55;MEUSE;1
55062;;Bouconville-sur-Madt;BOUCONVILLE-SUR-MADT;55300;55;MEUSE;1
55063;;Bouligny;BOULIGNY;55240;55;MEUSE;1
55064;;Bouquemont;BOUQUEMONT;55300;55;MEUSE;1
55065;;Boureuilles;BOUREUILLES;55270;55;MEUSE;1
55066;;Bovée-sur-Barboure;BOVEE-SUR-BARBOURE;55190;55;MEUSE;1
55067;;Boviolles;BOVIOLLES;55500;55;MEUSE;1
55068;;Brabant-en-Argonne;BRABANT-EN-ARGONNE;55120;55;MEUSE;1
55069;;Brabant-le-Roi;BRABANT-LE-ROI;55800;55;MEUSE;1
55070;;Brabant-sur-Meuse;BRABANT-SUR-MEUSE;55100;55;MEUSE;1
55071;;Brandeville;BRANDEVILLE;55150;55;MEUSE;1
55072;;Braquis;BRAQUIS;55400;55;MEUSE;1
55073;;Bras-sur-Meuse;BRAS-SUR-MEUSE;55100;55;MEUSE;1
55075;;Brauvilliers;BRAUVILLIERS;55170;55;MEUSE;1
55076;;Bréhéville;BREHEVILLE;55150;55;MEUSE;1
55077;;Breux;BREUX;55600;55;MEUSE;1
55078;;Brieulles-sur-Meuse;BRIEULLES-SUR-MEUSE;55110;55;MEUSE;1
55079;;Brillon-en-Barrois;BRILLON-EN-BARROIS;55000;55;MEUSE;1
55080;;Brixey-aux-Chanoines;BRIXEY-AUX-CHANOINES;55140;55;MEUSE;1
55081;;Brizeaux;BRIZEAUX;55250;55;MEUSE;1
55082;;Brocourt-en-Argonne;BROCOURT-EN-ARGONNE;55120;55;MEUSE;1
55083;;Brouennes;BROUENNES;55700;55;MEUSE;1
55084;;Broussey-en-Blois;BROUSSEY-EN-BLOIS;55190;55;MEUSE;1
55085;;Broussey-Raulecourt;BROUSSEY-RAULECOURT;55200;55;MEUSE;1
55087;;Bure;BURE;55290;55;MEUSE;1
55088;;Burey-en-Vaux;BUREY-EN-VAUX;55140;55;MEUSE;1
55089;;Burey-la-Côte;BUREY-LA-COTE;55140;55;MEUSE;1
55093;;Buxières-sous-les-Côtes;BUXIERES-SOUS-LES-COTES;55300;55;MEUSE;1
55094;;Buzy-Darmont;BUZY-DARMONT;55400;55;MEUSE;1
55095;;Cesse;CESSE;55700;55;MEUSE;1
55096;;Chaillon;CHAILLON;55210;55;MEUSE;1
55097;;Chalaines;CHALAINES;55140;55;MEUSE;1
55099;;Champneuville;CHAMPNEUVILLE;55100;55;MEUSE;1
55100;;Champougny;CHAMPOUGNY;55140;55;MEUSE;1
55101;;Chardogne;CHARDOGNE;55000;55;MEUSE;1
55102;;Charny-sur-Meuse;CHARNY-SUR-MEUSE;55100;55;MEUSE;1
55103;;Charpentry;CHARPENTRY;55270;55;MEUSE;1
55104;;Chassey-Beaupré;CHASSEY-BEAUPRE;55130;55;MEUSE;1
55105;;Châtillon-sous-les-Côtes;CHATILLON-SOUS-LES-COTES;55400;55;MEUSE;1
55106;;Chattancourt;CHATTANCOURT;55100;55;MEUSE;1
55107;;Chaumont-devant-Damvillers;CHAUMONT-DEVANT-DAMVILLERS;55150;55;MEUSE;1
55108;;Chaumont-sur-Aire;CHAUMONT-SUR-AIRE;55260;55;MEUSE;1
55109;;Chauvency-le-Château;CHAUVENCY-LE-CHATEAU;55600;55;MEUSE;1
55110;;Chauvency-Saint-Hubert;CHAUVENCY-SAINT-HUBERT;55600;55;MEUSE;1
55111;;Chauvoncourt;CHAUVONCOURT;55300;55;MEUSE;1
55113;;Cheppy;CHEPPY;55270;55;MEUSE;1
55114;;Chonville-Malaumont;CHONVILLE-MALAUMONT;55200;55;MEUSE;1
55115;;Cierges-sous-Montfaucon;CIERGES-SOUS-MONTFAUCON;55270;55;MEUSE;1
55116;Le;Claon;CLAON;55120;55;MEUSE;1
55117;;Clermont-en-Argonne;CLERMONT-EN-ARGONNE;55120;55;MEUSE;1
55118;;Cléry-le-Grand;CLERY-LE-GRAND;55110;55;MEUSE;1
55119;;Cléry-le-Petit;CLERY-LE-PETIT;55110;55;MEUSE;1
55120;;Combles-en-Barrois;COMBLES-EN-BARROIS;55000;55;MEUSE;1
55121;;Combres-sous-les-Côtes;COMBRES-SOUS-LES-COTES;55160;55;MEUSE;1
55122;;Commercy;COMMERCY;55200;55;MEUSE;1
55123;Les;Hauts-de-Chée;HAUTS-DE-CHEE;55000;55;MEUSE;1
55124;;Consenvoye;CONSENVOYE;55110;55;MEUSE;1
55125;;Contrisson;CONTRISSON;55800;55;MEUSE;1
55127;;Courcelles-en-Barrois;COURCELLES-EN-BARROIS;55260;55;MEUSE;1
55128;;Courcelles-sur-Aire;COURCELLES-SUR-AIRE;55260;55;MEUSE;1
55129;;Courouvre;COUROUVRE;55260;55;MEUSE;1
55132;;Cousances-les-Forges;COUSANCES-LES-FORGES;55170;55;MEUSE;1
55133;;Couvertpuis;COUVERTPUIS;55290;55;MEUSE;1
55134;;Couvonges;COUVONGES;55800;55;MEUSE;1
55137;;Cuisy;CUISY;55270;55;MEUSE;1
55139;;Cumières-le-Mort-Homme;CUMIERES-LE-MORT-HOMME;55100;55;MEUSE;1
55140;;Cunel;CUNEL;55110;55;MEUSE;1
55141;;Dagonville;DAGONVILLE;55500;55;MEUSE;1
55142;;Dainville-Bertheléville;DAINVILLE-BERTHELEVILLE;55130;55;MEUSE;1
55143;;Damloup;DAMLOUP;55400;55;MEUSE;1
55144;;Dammarie-sur-Saulx;DAMMARIE-SUR-SAULX;55500;55;MEUSE;1
55145;;Damvillers;DAMVILLERS;55150;55;MEUSE;1
55146;;Dannevoux;DANNEVOUX;55110;55;MEUSE;1
55148;;Delouze-Rosières;DELOUZE-ROSIERES;55130;55;MEUSE;1
55149;;Delut;DELUT;55150;55;MEUSE;1
55150;;Demange-aux-Eaux;DEMANGE-AUX-EAUX;55130;55;MEUSE;1
55153;;Dieppe-sous-Douaumont;DIEPPE-SOUS-DOUAUMONT;55400;55;MEUSE;1
55154;;Dieue-sur-Meuse;DIEUE-SUR-MEUSE;55320;55;MEUSE;1
55155;;Dombasle-en-Argonne;DOMBASLE-EN-ARGONNE;55120;55;MEUSE;1
55156;;Dombras;DOMBRAS;55150;55;MEUSE;1
55157;;Dommartin-la-Montagne;DOMMARTIN-LA-MONTAGNE;55160;55;MEUSE;1
55158;;Dommary-Baroncourt;DOMMARY-BARONCOURT;55240;55;MEUSE;1
55159;;Dompcevrin;DOMPCEVRIN;55300;55;MEUSE;1
55160;;Dompierre-aux-Bois;DOMPIERRE-AUX-BOIS;55300;55;MEUSE;1
55162;;Domremy-la-Canne;DOMREMY-LA-CANNE;55240;55;MEUSE;1
55163;;Doncourt-aux-Templiers;DONCOURT-AUX-TEMPLIERS;55160;55;MEUSE;1
55164;;Douaumont;DOUAUMONT;55100;55;MEUSE;1
55165;;Doulcon;DOULCON;55110;55;MEUSE;1
55166;;Dugny-sur-Meuse;DUGNY-SUR-MEUSE;55100;55;MEUSE;1
55167;;Dun-sur-Meuse;DUN-SUR-MEUSE;55110;55;MEUSE;1
55168;;Duzey;DUZEY;55230;55;MEUSE;1
55169;;Écouviez;ECOUVIEZ;55600;55;MEUSE;1
55170;;Écurey-en-Verdunois;ECUREY-EN-VERDUNOIS;55150;55;MEUSE;1
55171;;Eix;EIX;55400;55;MEUSE;1
55172;Les;Éparges;EPARGES;55160;55;MEUSE;1
55173;;Épiez-sur-Meuse;EPIEZ-SUR-MEUSE;55140;55;MEUSE;1
55174;;Épinonville;EPINONVILLE;55270;55;MEUSE;1
55175;;Érize-la-Brûlée;ERIZE-LA-BRULEE;55260;55;MEUSE;1
55177;;Érize-la-Petite;ERIZE-LA-PETITE;55260;55;MEUSE;1
55178;;Érize-Saint-Dizier;ERIZE-SAINT-DIZIER;55000;55;MEUSE;1
55179;;Erneville-aux-Bois;ERNEVILLE-AUX-BOIS;55500;55;MEUSE;1
55180;;Esnes-en-Argonne;ESNES-EN-ARGONNE;55100;55;MEUSE;1
55181;;Étain;ETAIN;55400;55;MEUSE;1
55182;;Éton;ETON;55240;55;MEUSE;1
55183;;Étraye;ETRAYE;55150;55;MEUSE;1
55184;;Euville;EUVILLE;55200;55;MEUSE;1
55185;;Èvres;EVRES;55250;55;MEUSE;1
55186;;Fains-Véel;FAINS-VEEL;55000;55;MEUSE;1
55188;;Flassigny;FLASSIGNY;55600;55;MEUSE;1
55189;;Fleury-devant-Douaumont;FLEURY-DEVANT-DOUAUMONT;55100;55;MEUSE;1
55191;;Foameix-Ornel;FOAMEIX-ORNEL;55400;55;MEUSE;1
55192;;Fontaines-Saint-Clair;FONTAINES-SAINT-CLAIR;55110;55;MEUSE;1
55193;;Forges-sur-Meuse;FORGES-SUR-MEUSE;55110;55;MEUSE;1
55194;;Foucaucourt-sur-Thabas;FOUCAUCOURT-SUR-THABAS;55250;55;MEUSE;1
55195;;Fouchères-aux-Bois;FOUCHERES-AUX-BOIS;55500;55;MEUSE;1
55196;;Frémeréville-sous-les-Côtes;FREMEREVILLE-SOUS-LES-COTES;55200;55;MEUSE;1
55197;;Fresnes-au-Mont;FRESNES-AU-MONT;55260;55;MEUSE;1
55198;;Fresnes-en-Woëvre;FRESNES-EN-WOEVRE;55160;55;MEUSE;1
55199;;Froidos;FROIDOS;55120;55;MEUSE;1
55200;;Fromeréville-les-Vallons;FROMEREVILLE-LES-VALLONS;55100;55;MEUSE;1
55201;;Fromezey;FROMEZEY;55400;55;MEUSE;1
55202;;Futeau;FUTEAU;55120;55;MEUSE;1
55204;;Génicourt-sur-Meuse;GENICOURT-SUR-MEUSE;55320;55;MEUSE;1
55206;;Gercourt-et-Drillancourt;GERCOURT-ET-DRILLANCOURT;55110;55;MEUSE;1
55207;;Géry;GERY;55000;55;MEUSE;1
55208;;Gesnes-en-Argonne;GESNES-EN-ARGONNE;55110;55;MEUSE;1
55210;;Gimécourt;GIMECOURT;55260;55;MEUSE;1
55211;;Gincrey;GINCREY;55400;55;MEUSE;1
55212;;Girauvoisin;GIRAUVOISIN;55200;55;MEUSE;1
55214;;Givrauval;GIVRAUVAL;55500;55;MEUSE;1
55215;;Gondrecourt-le-Château;GONDRECOURT-LE-CHATEAU;55130;55;MEUSE;1
55216;;Gouraincourt;GOURAINCOURT;55230;55;MEUSE;1
55217;;Goussaincourt;GOUSSAINCOURT;55140;55;MEUSE;1
55218;;Gremilly;GREMILLY;55150;55;MEUSE;1
55219;;Grimaucourt-en-Woëvre;GRIMAUCOURT-EN-WOEVRE;55400;55;MEUSE;1
55220;;Grimaucourt-près-Sampigny;GRIMAUCOURT-PRES-SAMPIGNY;55500;55;MEUSE;1
55221;;Guerpont;GUERPONT;55000;55;MEUSE;1
55222;;Gussainville;GUSSAINVILLE;55400;55;MEUSE;1
55224;;Haironville;HAIRONVILLE;55000;55;MEUSE;1
55225;;Halles-sous-les-Côtes;HALLES-SOUS-LES-COTES;55700;55;MEUSE;1
55226;;Han-lès-Juvigny;HAN-LES-JUVIGNY;55600;55;MEUSE;1
55228;;Hannonville-sous-les-Côtes;HANNONVILLE-SOUS-LES-COTES;55210;55;MEUSE;1
55229;;Han-sur-Meuse;HAN-SUR-MEUSE;55300;55;MEUSE;1
55232;;Harville;HARVILLE;55160;55;MEUSE;1
55236;;Haudainville;HAUDAINVILLE;55100;55;MEUSE;1
55237;;Haudiomont;HAUDIOMONT;55160;55;MEUSE;1
55239;;Haumont-près-Samogneux;HAUMONT-PRES-SAMOGNEUX;;55;;
55241;;Heippes;HEIPPES;55220;55;MEUSE;1
55242;;Hennemont;HENNEMONT;55160;55;MEUSE;1
55243;;Herbeuville;HERBEUVILLE;55210;55;MEUSE;1
55244;;Herméville-en-Woëvre;HERMEVILLE-EN-WOEVRE;55400;55;MEUSE;1
55245;;Heudicourt-sous-les-Côtes;HEUDICOURT-SOUS-LES-COTES;55210;55;MEUSE;1
55246;;Hévilliers;HEVILLIERS;55290;55;MEUSE;1
55247;;Horville-en-Ornois;HORVILLE-EN-ORNOIS;55130;55;MEUSE;1
55248;;Houdelaincourt;HOUDELAINCOURT;55130;55;MEUSE;1
55250;;Inor;INOR;55700;55;MEUSE;1
55251;;Ippécourt;IPPECOURT;55220;55;MEUSE;1
55252;;Iré-le-Sec;IRE-LE-SEC;55600;55;MEUSE;1
55253;Les;Islettes;ISLETTES;55120;55;MEUSE;1
55254;Les;Trois-Domaines;TROIS-DOMAINES;55220;55;MEUSE;1
55255;;Jametz;JAMETZ;55600;55;MEUSE;1
55256;;Jonville-en-Woëvre;JONVILLE-EN-WOEVRE;55160;55;MEUSE;1
55257;;Jouy-en-Argonne;JOUY-EN-ARGONNE;55120;55;MEUSE;1
55258;;Geville;GEVILLE;55200;55;MEUSE;1
55260;;Julvécourt;JULVECOURT;55120;55;MEUSE;1
55261;;Juvigny-en-Perthois;JUVIGNY-EN-PERTHOIS;55170;55;MEUSE;1
55262;;Juvigny-sur-Loison;JUVIGNY-SUR-LOISON;55600;55;MEUSE;1
55263;;Kœur-la-Grande;KOEUR-LA-GRANDE;55300;55;MEUSE;1
55264;;Kœur-la-Petite;KOEUR-LA-PETITE;55300;55;MEUSE;1
55265;;Labeuville;LABEUVILLE;55160;55;MEUSE;1
55266;;Lachalade;LACHALADE;55120;55;MEUSE;1
55267;;Lachaussée;LACHAUSSEE;55210;55;MEUSE;1
55268;;Lacroix-sur-Meuse;LACROIX-SUR-MEUSE;55300;55;MEUSE;1
55269;;Lahaymeix;LAHAYMEIX;55260;55;MEUSE;1
55270;;Lahayville;LAHAYVILLE;55300;55;MEUSE;1
55271;;Laheycourt;LAHEYCOURT;55800;55;MEUSE;1
55272;;Laimont;LAIMONT;55800;55;MEUSE;1
55274;;Lamorville;LAMORVILLE;55300;55;MEUSE;1
55275;;Lamouilly;LAMOUILLY;55700;55;MEUSE;1
55276;;Landrecourt-Lempire;LANDRECOURT-LEMPIRE;55100;55;MEUSE;1
55278;;Laneuville-au-Rupt;LANEUVILLE-AU-RUPT;55190;55;MEUSE;1
55279;;Laneuville-sur-Meuse;LANEUVILLE-SUR-MEUSE;55700;55;MEUSE;1
55280;;Lanhères;LANHERES;55400;55;MEUSE;1
55281;;Latour-en-Woëvre;LATOUR-EN-WOEVRE;55160;55;MEUSE;1
55282;;Lavallée;LAVALLEE;55260;55;MEUSE;1
55284;;Lavincourt;LAVINCOURT;55170;55;MEUSE;1
55285;;Lavoye;LAVOYE;55120;55;MEUSE;1
55286;;Lemmes;LEMMES;55220;55;MEUSE;1
55288;;Lérouville;LEROUVILLE;55200;55;MEUSE;1
55289;;Levoncourt;LEVONCOURT;55260;55;MEUSE;1
55290;;Lignières-sur-Aire;LIGNIERES-SUR-AIRE;55260;55;MEUSE;1
55291;;Ligny-en-Barrois;LIGNY-EN-BARROIS;55500;55;MEUSE;1
55292;;Liny-devant-Dun;LINY-DEVANT-DUN;55110;55;MEUSE;1
55293;;Lion-devant-Dun;LION-DEVANT-DUN;55110;55;MEUSE;1
55295;;Lisle-en-Barrois;LISLE-EN-BARROIS;55250;55;MEUSE;1
55296;;Lisle-en-Rigault;LISLE-EN-RIGAULT;55000;55;MEUSE;1
55297;;Lissey;LISSEY;55150;55;MEUSE;1
55298;;Loisey-Culey;LOISEY-CULEY;55000;55;MEUSE;1
55299;;Loison;LOISON;55230;55;MEUSE;1
55300;;Longeaux;LONGEAUX;55500;55;MEUSE;1
55301;;Longchamps-sur-Aire;LONGCHAMPS-SUR-AIRE;55260;55;MEUSE;1
55302;;Longeville-en-Barrois;LONGEVILLE-EN-BARROIS;55000;55;MEUSE;1
55303;;Loupmont;LOUPMONT;55300;55;MEUSE;1
55304;;Louppy-le-Château;LOUPPY-LE-CHATEAU;55800;55;MEUSE;1
55306;;Louppy-sur-Loison;LOUPPY-SUR-LOISON;55600;55;MEUSE;1
55307;;Louvemont-Côte-du-Poivre;LOUVEMONT-COTE-DU-POIVRE;;55;;
55310;;Luzy-Saint-Martin;LUZY-SAINT-MARTIN;55700;55;MEUSE;1
55311;;Maizeray;MAIZERAY;55160;55;MEUSE;1
55312;;Maizey;MAIZEY;55300;55;MEUSE;1
55313;;Malancourt;MALANCOURT;55270;55;MEUSE;1
55315;;Mandres-en-Barrois;MANDRES-EN-BARROIS;55290;55;MEUSE;1
55316;;Mangiennes;MANGIENNES;55150;55;MEUSE;1
55317;;Manheulles;MANHEULLES;55160;55;MEUSE;1
55320;;Marchéville-en-Woëvre;MARCHEVILLE-EN-WOEVRE;55160;55;MEUSE;1
55321;;Marre;MARRE;55100;55;MEUSE;1
55322;;Marson-sur-Barboure;MARSON-SUR-BARBOURE;55190;55;MEUSE;1
55323;;Martincourt-sur-Meuse;MARTINCOURT-SUR-MEUSE;55700;55;MEUSE;1
55324;;Marville;MARVILLE;55600;55;MEUSE;1
55325;;Maucourt-sur-Orne;MAUCOURT-SUR-ORNE;55400;55;MEUSE;1
55326;;Maulan;MAULAN;55500;55;MEUSE;1
55327;;Mauvages;MAUVAGES;55190;55;MEUSE;1
55328;;Maxey-sur-Vaise;MAXEY-SUR-VAISE;55140;55;MEUSE;1
55329;;Mécrin;MECRIN;55300;55;MEUSE;1
55330;;Méligny-le-Grand;MELIGNY-LE-GRAND;55190;55;MEUSE;1
55331;;Méligny-le-Petit;MELIGNY-LE-PETIT;55190;55;MEUSE;1
55332;;Menaucourt;MENAUCOURT;55500;55;MEUSE;1
55333;;Ménil-aux-Bois;MENIL-AUX-BOIS;55260;55;MEUSE;1
55334;;Ménil-la-Horgne;MENIL-LA-HORGNE;55190;55;MEUSE;1
55335;;Ménil-sur-Saulx;MENIL-SUR-SAULX;55500;55;MEUSE;1
55336;;Merles-sur-Loison;MERLES-SUR-LOISON;55150;55;MEUSE;1
55338;;Milly-sur-Bradon;MILLY-SUR-BRADON;55110;55;MEUSE;1
55339;;Mogeville;MOGEVILLE;55400;55;MEUSE;1
55340;;Mognéville;MOGNEVILLE;55800;55;MEUSE;1
55341;;Moirey-Flabas-Crépion;MOIREY-FLABAS-CREPION;55150;55;MEUSE;1
55343;;Montblainville;MONTBLAINVILLE;55270;55;MEUSE;1
55344;;Montbras;MONTBRAS;55140;55;MEUSE;1
55345;;Mont-devant-Sassey;MONT-DEVANT-SASSEY;55110;55;MEUSE;1
55346;;Montfaucon-d'Argonne;MONTFAUCON-D'ARGONNE;55270;55;MEUSE;1
55347;Les;Monthairons;MONTHAIRONS;55320;55;MEUSE;1
55348;;Montiers-sur-Saulx;MONTIERS-SUR-SAULX;55290;55;MEUSE;1
55349;;Montigny-devant-Sassey;MONTIGNY-DEVANT-SASSEY;55110;55;MEUSE;1
55350;;Montigny-lès-Vaucouleurs;MONTIGNY-LES-VAUCOULEURS;55140;55;MEUSE;1
55351;;Montmédy;MONTMEDY;55600;55;MEUSE;1
55352;;Montplonne;MONTPLONNE;55000;55;MEUSE;1
55353;;Montsec;MONTSEC;55300;55;MEUSE;1
55355;;Montzéville;MONTZEVILLE;55100;55;MEUSE;1
55356;;Moranville;MORANVILLE;55400;55;MEUSE;1
55357;;Morgemoulin;MORGEMOULIN;55400;55;MEUSE;1
55358;;Chanteraine;CHANTERAINE;55500;55;MEUSE;1
55359;;Morley;MORLEY;55290;55;MEUSE;1
55360;;Mouilly;MOUILLY;55320;55;MEUSE;1
55361;;Moulainville;MOULAINVILLE;55400;55;MEUSE;1
55362;;Moulins-Saint-Hubert;MOULINS-SAINT-HUBERT;55700;55;MEUSE;1
55363;;Moulotte;MOULOTTE;55160;55;MEUSE;1
55364;;Mouzay;MOUZAY;55700;55;MEUSE;1
55365;;Murvaux;MURVAUX;55110;55;MEUSE;1
55366;;Val-d'Ornain;VAL-D'ORNAIN;55000;55;MEUSE;1
55367;;Muzeray;MUZERAY;55230;55;MEUSE;1
55368;;Naives-en-Blois;NAIVES-EN-BLOIS;55190;55;MEUSE;1
55369;;Naives-Rosières;NAIVES-ROSIERES;55000;55;MEUSE;1
55370;;Naix-aux-Forges;NAIX-AUX-FORGES;55500;55;MEUSE;1
55371;;Nançois-le-Grand;NANCOIS-LE-GRAND;55500;55;MEUSE;1
55372;;Nançois-sur-Ornain;NANCOIS-SUR-ORNAIN;55500;55;MEUSE;1
55373;;Nant-le-Grand;NANT-LE-GRAND;55500;55;MEUSE;1
55374;;Nant-le-Petit;NANT-LE-PETIT;55500;55;MEUSE;1
55375;;Nantillois;NANTILLOIS;55270;55;MEUSE;1
55376;;Nantois;NANTOIS;55500;55;MEUSE;1
55377;;Nepvant;NEPVANT;55700;55;MEUSE;1
55378;;Nettancourt;NETTANCOURT;55800;55;MEUSE;1
55379;Le;Neufour;NEUFOUR;55120;55;MEUSE;1
55380;;Neuville-en-Verdunois;NEUVILLE-EN-VERDUNOIS;55260;55;MEUSE;1
55381;;Neuville-lès-Vaucouleurs;NEUVILLE-LES-VAUCOULEURS;55140;55;MEUSE;1
55382;;Neuville-sur-Ornain;NEUVILLE-SUR-ORNAIN;55800;55;MEUSE;1
55383;;Neuvilly-en-Argonne;NEUVILLY-EN-ARGONNE;55120;55;MEUSE;1
55384;;Nicey-sur-Aire;NICEY-SUR-AIRE;55260;55;MEUSE;1
55385;;Nixéville-Blercourt;NIXEVILLE-BLERCOURT;55120;55;MEUSE;1
55386;;Nonsard-Lamarche;NONSARD-LAMARCHE;55210;55;MEUSE;1
55387;;Nouillonpont;NOUILLONPONT;55230;55;MEUSE;1
55388;;Noyers-Auzécourt;NOYERS-AUZECOURT;55800;55;MEUSE;1
55389;;Nubécourt;NUBECOURT;55250;55;MEUSE;1
55391;;Olizy-sur-Chiers;OLIZY-SUR-CHIERS;55700;55;MEUSE;1
55394;;Ornes;ORNES;55150;55;MEUSE;1
55395;;Osches;OSCHES;55220;55;MEUSE;1
55396;;Ourches-sur-Meuse;OURCHES-SUR-MEUSE;55190;55;MEUSE;1
55397;;Pagny-la-Blanche-Côte;PAGNY-LA-BLANCHE-COTE;55140;55;MEUSE;1
55398;;Pagny-sur-Meuse;PAGNY-SUR-MEUSE;55190;55;MEUSE;1
55399;;Pareid;PAREID;55160;55;MEUSE;1
55400;;Parfondrupt;PARFONDRUPT;55400;55;MEUSE;1
55401;Les;Paroches;PAROCHES;55300;55;MEUSE;1
55403;;Peuvillers;PEUVILLERS;55150;55;MEUSE;1
55404;;Pierrefitte-sur-Aire;PIERREFITTE-SUR-AIRE;55260;55;MEUSE;1
55405;;Pillon;PILLON;55230;55;MEUSE;1
55406;;Pintheville;PINTHEVILLE;55160;55;MEUSE;1
55407;;Pont-sur-Meuse;PONT-SUR-MEUSE;55200;55;MEUSE;1
55408;;Pouilly-sur-Meuse;POUILLY-SUR-MEUSE;55700;55;MEUSE;1
55409;;Pretz-en-Argonne;PRETZ-EN-ARGONNE;55250;55;MEUSE;1
55410;;Quincy-Landzécourt;QUINCY-LANDZECOURT;55600;55;MEUSE;1
55411;;Rambluzin-et-Benoite-Vaux;RAMBLUZIN-ET-BENOITE-VAUX;55220;55;MEUSE;1
55412;;Rambucourt;RAMBUCOURT;55300;55;MEUSE;1
55414;;Rancourt-sur-Ornain;RANCOURT-SUR-ORNAIN;55800;55;MEUSE;1
55415;;Ranzières;RANZIERES;55300;55;MEUSE;1
55416;;Rarécourt;RARECOURT;55120;55;MEUSE;1
55419;;Récicourt;RECICOURT;55120;55;MEUSE;1
55420;;Récourt-le-Creux;RECOURT-LE-CREUX;55220;55;MEUSE;1
55421;;Reffroy;REFFROY;55190;55;MEUSE;1
55422;;Regnéville-sur-Meuse;REGNEVILLE-SUR-MEUSE;55110;55;MEUSE;1
55423;;Rembercourt-Sommaisne;REMBERCOURT-SOMMAISNE;55250;55;MEUSE;1
55424;;Remennecourt;REMENNECOURT;55800;55;MEUSE;1
55425;;Remoiville;REMOIVILLE;55600;55;MEUSE;1
55426;;Resson;RESSON;55000;55;MEUSE;1
55427;;Revigny-sur-Ornain;REVIGNY-SUR-ORNAIN;55800;55;MEUSE;1
55428;;Réville-aux-Bois;REVILLE-AUX-BOIS;55150;55;MEUSE;1
55429;;Riaville;RIAVILLE;55160;55;MEUSE;1
55430;;Ribeaucourt;RIBEAUCOURT;55290;55;MEUSE;1
55431;;Richecourt;RICHECOURT;55300;55;MEUSE;1
55433;;Rigny-la-Salle;RIGNY-LA-SALLE;55140;55;MEUSE;1
55434;;Rigny-Saint-Martin;RIGNY-SAINT-MARTIN;55140;55;MEUSE;1
55435;;Robert-Espagne;ROBERT-ESPAGNE;55000;55;MEUSE;1
55436;Les;Roises;ROISES;55130;55;MEUSE;1
55437;;Romagne-sous-les-Côtes;ROMAGNE-SOUS-LES-COTES;55150;55;MEUSE;1
55438;;Romagne-sous-Montfaucon;ROMAGNE-SOUS-MONTFAUCON;55110;55;MEUSE;1
55439;;Ronvaux;RONVAUX;55160;55;MEUSE;1
55442;;Raival;RAIVAL;55260;55;MEUSE;1
55443;;Rouvres-en-Woëvre;ROUVRES-EN-WOEVRE;55400;55;MEUSE;1
55444;;Rouvrois-sur-Meuse;ROUVROIS-SUR-MEUSE;55300;55;MEUSE;1
55445;;Rouvrois-sur-Othain;ROUVROIS-SUR-OTHAIN;55230;55;MEUSE;1
55446;;Rumont;RUMONT;55000;55;MEUSE;1
55447;;Rupt-aux-Nonains;RUPT-AUX-NONAINS;55170;55;MEUSE;1
55448;;Rupt-devant-Saint-Mihiel;RUPT-DEVANT-SAINT-MIHIEL;55260;55;MEUSE;1
55449;;Rupt-en-Woëvre;RUPT-EN-WOEVRE;55320;55;MEUSE;1
55450;;Rupt-sur-Othain;RUPT-SUR-OTHAIN;55150;55;MEUSE;1
55452;;Saint-Amand-sur-Ornain;SAINT-AMAND-SUR-ORNAIN;55500;55;MEUSE;1
55453;;Saint-André-en-Barrois;SAINT-ANDRE-EN-BARROIS;55220;55;MEUSE;1
55454;;Saint-Aubin-sur-Aire;SAINT-AUBIN-SUR-AIRE;55500;55;MEUSE;1
55456;;Saint-Germain-sur-Meuse;SAINT-GERMAIN-SUR-MEUSE;55140;55;MEUSE;1
55457;;Saint-Hilaire-en-Woëvre;SAINT-HILAIRE-EN-WOEVRE;55160;55;MEUSE;1
55458;;Saint-Jean-lès-Buzy;SAINT-JEAN-LES-BUZY;55400;55;MEUSE;1
55459;;Saint-Joire;SAINT-JOIRE;55130;55;MEUSE;1
55460;;Saint-Julien-sous-les-Côtes;SAINT-JULIEN-SOUS-LES-COTES;55200;55;MEUSE;1
55461;;Saint-Laurent-sur-Othain;SAINT-LAURENT-SUR-OTHAIN;55150;55;MEUSE;1
55462;;Saint-Maurice-sous-les-Côtes;SAINT-MAURICE-SOUS-LES-COTES;55210;55;MEUSE;1
55463;;Saint-Mihiel;SAINT-MIHIEL;55300;55;MEUSE;1
55464;;Saint-Pierrevillers;SAINT-PIERREVILLERS;55230;55;MEUSE;1
55465;;Saint-Remy-la-Calonne;SAINT-REMY-LA-CALONNE;55160;55;MEUSE;1
55466;;Salmagne;SALMAGNE;55000;55;MEUSE;1
55467;;Sampigny;SAMPIGNY;55300;55;MEUSE;1
55468;;Samogneux;SAMOGNEUX;55100;55;MEUSE;1
55469;;Sassey-sur-Meuse;SASSEY-SUR-MEUSE;55110;55;MEUSE;1
55470;;Saudrupt;SAUDRUPT;55000;55;MEUSE;1
55471;;Saulmory-et-Villefranche;SAULMORY-ET-VILLEFRANCHE;55110;55;MEUSE;1
55472;;Saulvaux;SAULVAUX;55500;55;MEUSE;1
55473;;Saulx-lès-Champlon;SAULX-LES-CHAMPLON;55160;55;MEUSE;1
55474;;Sauvigny;SAUVIGNY;55140;55;MEUSE;1
55475;;Sauvoy;SAUVOY;55190;55;MEUSE;1
55476;;Savonnières-devant-Bar;SAVONNIERES-DEVANT-BAR;55000;55;MEUSE;1
55477;;Savonnières-en-Perthois;SAVONNIERES-EN-PERTHOIS;55170;55;MEUSE;1
55479;;Seigneulles;SEIGNEULLES;55000;55;MEUSE;1
55481;;Senon;SENON;55230;55;MEUSE;1
55482;;Senoncourt-les-Maujouy;SENONCOURT-LES-MAUJOUY;55220;55;MEUSE;1
55484;;Septsarges;SEPTSARGES;55270;55;MEUSE;1
55485;;Sepvigny;SEPVIGNY;55140;55;MEUSE;1
55487;;Seuzey;SEUZEY;55300;55;MEUSE;1
55488;;Silmont;SILMONT;55000;55;MEUSE;1
55489;;Sivry-la-Perche;SIVRY-LA-PERCHE;55100;55;MEUSE;1
55490;;Sivry-sur-Meuse;SIVRY-SUR-MEUSE;55110;55;MEUSE;1
55492;;Sommedieue;SOMMEDIEUE;55320;55;MEUSE;1
55493;;Sommeilles;SOMMEILLES;55800;55;MEUSE;1
55494;;Sommelonne;SOMMELONNE;55170;55;MEUSE;1
55495;;Sorbey;SORBEY;55230;55;MEUSE;1
55496;;Sorcy-Saint-Martin;SORCY-SAINT-MARTIN;55190;55;MEUSE;1
55497;Les;Souhesmes-Rampont;SOUHESMES-RAMPONT;55220;55;MEUSE;1
55498;;Souilly;SOUILLY;55220;55;MEUSE;1
55500;;Spincourt;SPINCOURT;55230;55;MEUSE;1
55501;;Stainville;STAINVILLE;55500;55;MEUSE;1
55502;;Stenay;STENAY;55700;55;MEUSE;1
55503;;Taillancourt;TAILLANCOURT;55140;55;MEUSE;1
55504;;Tannois;TANNOIS;55000;55;MEUSE;1
55505;;Thierville-sur-Meuse;THIERVILLE-SUR-MEUSE;55840;55;MEUSE;1
55506;;Thillombois;THILLOMBOIS;55260;55;MEUSE;1
55507;;Thillot;THILLOT;55210;55;MEUSE;1
55508;;Thonne-la-Long;THONNE-LA-LONG;55600;55;MEUSE;1
55509;;Thonne-le-Thil;THONNE-LE-THIL;55600;55;MEUSE;1
55510;;Thonne-les-Près;THONNE-LES-PRES;55600;55;MEUSE;1
55511;;Thonnelle;THONNELLE;55600;55;MEUSE;1
55512;;Tilly-sur-Meuse;TILLY-SUR-MEUSE;55220;55;MEUSE;1
55514;;Trémont-sur-Saulx;TREMONT-SUR-SAULX;55000;55;MEUSE;1
55515;;Trésauvaux;TRESAUVAUX;55160;55;MEUSE;1
55516;;Tréveray;TREVERAY;55130;55;MEUSE;1
55517;;Seuil-d'Argonne;SEUIL-D'ARGONNE;55250;55;MEUSE;1
55518;;Cousances-lès-Triconville;COUSANCES-LES-TRICONVILLE;55500;55;MEUSE;1
55519;;Tronville-en-Barrois;TRONVILLE-EN-BARROIS;55310;55;MEUSE;1
55520;;Troussey;TROUSSEY;55190;55;MEUSE;1
55521;;Troyon;TROYON;55300;55;MEUSE;1
55522;;Ugny-sur-Meuse;UGNY-SUR-MEUSE;55140;55;MEUSE;1
55523;;Vacherauville;VACHERAUVILLE;55100;55;MEUSE;1
55525;;Vadelaincourt;VADELAINCOURT;55220;55;MEUSE;1
55526;;Vadonville;VADONVILLE;55200;55;MEUSE;1
55527;;Varennes-en-Argonne;VARENNES-EN-ARGONNE;55270;55;MEUSE;1
55528;;Varnéville;VARNEVILLE;55300;55;MEUSE;1
55530;;Valbois;VALBOIS;55300;55;MEUSE;1
55531;;Vassincourt;VASSINCOURT;55800;55;MEUSE;1
55532;;Vaubecourt;VAUBECOURT;55250;55;MEUSE;1
55533;;Vaucouleurs;VAUCOULEURS;55140;55;MEUSE;1
55534;;Vaudeville-le-Haut;VAUDEVILLE-LE-HAUT;55130;55;MEUSE;1
55535;;Vaudoncourt;VAUDONCOURT;55230;55;MEUSE;1
55536;;Vauquois;VAUQUOIS;55270;55;MEUSE;1
55537;;Vaux-devant-Damloup;VAUX-DEVANT-DAMLOUP;55400;55;MEUSE;1
55540;;Vaux-lès-Palameix;VAUX-LES-PALAMEIX;55300;55;MEUSE;1
55541;;Vavincourt;VAVINCOURT;55000;55;MEUSE;1
55543;;Velaines;VELAINES;55500;55;MEUSE;1
55544;;Velosnes;VELOSNES;55600;55;MEUSE;1
55545;;Verdun;VERDUN;55100;55;MEUSE;1
55546;;Verneuil-Grand;VERNEUIL-GRAND;55600;55;MEUSE;1
55547;;Verneuil-Petit;VERNEUIL-PETIT;55600;55;MEUSE;1
55549;;Véry;VERY;55270;55;MEUSE;1
55551;;Vigneulles-lès-Hattonchâtel;VIGNEULLES-LES-HATTONCHATEL;55210;55;MEUSE;1
55552;;Vigneul-sous-Montmédy;VIGNEUL-SOUS-MONTMEDY;55600;55;MEUSE;1
55553;;Vignot;VIGNOT;55200;55;MEUSE;1
55554;;Villécloye;VILLECLOYE;55600;55;MEUSE;1
55555;;Ville-devant-Belrain;VILLE-DEVANT-BELRAIN;55260;55;MEUSE;1
55556;;Ville-devant-Chaumont;VILLE-DEVANT-CHAUMONT;55150;55;MEUSE;1
55557;;Ville-en-Woëvre;VILLE-EN-WOEVRE;55160;55;MEUSE;1
55559;;Villeroy-sur-Méholle;VILLEROY-SUR-MEHOLLE;55190;55;MEUSE;1
55560;;Villers-aux-Vents;VILLERS-AUX-VENTS;55800;55;MEUSE;1
55561;;Villers-devant-Dun;VILLERS-DEVANT-DUN;55110;55;MEUSE;1
55562;;Villers-le-Sec;VILLERS-LE-SEC;55500;55;MEUSE;1
55563;;Villers-lès-Mangiennes;VILLERS-LES-MANGIENNES;55150;55;MEUSE;1
55565;;Villers-sous-Pareid;VILLERS-SOUS-PAREID;55160;55;MEUSE;1
55566;;Villers-sur-Meuse;VILLERS-SUR-MEUSE;55220;55;MEUSE;1
55567;;Ville-sur-Cousances;VILLE-SUR-COUSANCES;55120;55;MEUSE;1
55568;;Ville-sur-Saulx;VILLE-SUR-SAULX;55000;55;MEUSE;1
55569;;Villotte-devant-Louppy;VILLOTTE-DEVANT-LOUPPY;55250;55;MEUSE;1
55570;;Villotte-sur-Aire;VILLOTTE-SUR-AIRE;55260;55;MEUSE;1
55571;;Vilosnes-Haraumont;VILOSNES-HARAUMONT;55110;55;MEUSE;1
55572;;Vittarville;VITTARVILLE;55150;55;MEUSE;1
55573;;Void-Vacon;VOID-VACON;55190;55;MEUSE;1
55574;;Vouthon-Bas;VOUTHON-BAS;55130;55;MEUSE;1
55575;;Vouthon-Haut;VOUTHON-HAUT;55130;55;MEUSE;1
55577;;Waly;WALY;55250;55;MEUSE;1
55578;;Warcq;WARCQ;55400;55;MEUSE;1
55579;;Watronville;WATRONVILLE;55160;55;MEUSE;1
55580;;Wavrille;WAVRILLE;55150;55;MEUSE;1
55581;;Willeroncourt;WILLERONCOURT;55500;55;MEUSE;1
55582;;Wiseppe;WISEPPE;55700;55;MEUSE;1
55583;;Woël;WOEL;55210;55;MEUSE;1
55584;;Woimbey;WOIMBEY;55300;55;MEUSE;1
55586;;Xivray-et-Marvoisin;XIVRAY-ET-MARVOISIN;55300;55;MEUSE;1
56001;;Allaire;ALLAIRE;56350;56;MORBIHAN;1
56002;;Ambon;AMBON;56190;56;MORBIHAN;1
56003;;Arradon;ARRADON;56610;56;MORBIHAN;1
56004;;Arzal;ARZAL;56190;56;MORBIHAN;1
56005;;Arzon;ARZON;56640;56;MORBIHAN;1
56006;;Augan;AUGAN;56800;56;MORBIHAN;1
56007;;Auray;AURAY;56400;56;MORBIHAN;1
56008;;Baden;BADEN;56870;56;MORBIHAN;1
56009;;Bangor;BANGOR;56360;56;MORBIHAN;1
56010;;Baud;BAUD;56150;56;MORBIHAN;1
56011;;Béganne;BEGANNE;56350;56;MORBIHAN;1
56012;;Beignon;BEIGNON;56380;56;MORBIHAN;1
56013;;Belz;BELZ;56550;56;MORBIHAN;1
56014;;Berné;BERNE;56240;56;MORBIHAN;1
56015;;Berric;BERRIC;56230;56;MORBIHAN;1
56016;;Bieuzy;BIEUZY;56310;56;MORBIHAN;1
56017;;Bignan;BIGNAN;56500;56;MORBIHAN;1
56018;;Billiers;BILLIERS;56190;56;MORBIHAN;1
56019;;Billio;BILLIO;56420;56;MORBIHAN;1
56020;;Bohal;BOHAL;56140;56;MORBIHAN;1
56021;;Brandérion;BRANDERION;56700;56;MORBIHAN;1
56022;;Brandivy;BRANDIVY;56390;56;MORBIHAN;1
56023;;Brech;BRECH;56400;56;MORBIHAN;1
56024;;Bréhan;BREHAN;56580;56;MORBIHAN;1
56025;;Brignac;BRIGNAC;56430;56;MORBIHAN;1
56026;;Bubry;BUBRY;56310;56;MORBIHAN;1
56027;;Buléon;BULEON;56420;56;MORBIHAN;1
56028;;Caden;CADEN;56220;56;MORBIHAN;1
56029;;Calan;CALAN;56240;56;MORBIHAN;1
56030;;Camoël;CAMOEL;56130;56;MORBIHAN;1
56031;;Camors;CAMORS;56330;56;MORBIHAN;1
56032;;Campénéac;CAMPENEAC;56800;56;MORBIHAN;1
56033;;Carentoir;CARENTOIR;56910;56;MORBIHAN;1
56034;;Carnac;CARNAC;56340;56;MORBIHAN;1
56035;;Caro;CARO;56140;56;MORBIHAN;1
56036;;Caudan;CAUDAN;56850;56;MORBIHAN;1
56037;La;Chapelle-Caro;CHAPELLE-CARO;56460;56;MORBIHAN;1
56038;La;Chapelle-Gaceline;CHAPELLE-GACELINE;56200;56;MORBIHAN;1
56039;La;Chapelle-Neuve;CHAPELLE-NEUVE;56500;56;MORBIHAN;1
56040;;Cléguer;CLEGUER;56620;56;MORBIHAN;1
56041;;Cléguérec;CLEGUEREC;56480;56;MORBIHAN;1
56042;;Colpo;COLPO;56390;56;MORBIHAN;1
56043;;Concoret;CONCORET;56430;56;MORBIHAN;1
56044;;Cournon;COURNON;56200;56;MORBIHAN;1
56045;Le;Cours;COURS;56230;56;MORBIHAN;1
56046;;Crach;CRACH;56950;56;MORBIHAN;1
56047;;Crédin;CREDIN;56580;56;MORBIHAN;1
56048;Le;Croisty;CROISTY;56540;56;MORBIHAN;1
56049;;Croixanvec;CROIXANVEC;56920;56;MORBIHAN;1
56050;La;Croix-Helléan;CROIX-HELLEAN;56120;56;MORBIHAN;1
56051;;Cruguel;CRUGUEL;56420;56;MORBIHAN;1
56052;;Damgan;DAMGAN;56750;56;MORBIHAN;1
56053;;Elven;ELVEN;56250;56;MORBIHAN;1
56054;;Erdeven;ERDEVEN;56410;56;MORBIHAN;1
56055;;Étel;ETEL;56410;56;MORBIHAN;1
56056;;Évriguet;EVRIGUET;56490;56;MORBIHAN;1
56057;Le;Faouët;FAOUET;56320;56;MORBIHAN;1
56058;;Férel;FEREL;56130;56;MORBIHAN;1
56059;Les;Forges;FORGES;56120;56;MORBIHAN;1
56060;Les;Fougerêts;FOUGERETS;56200;56;MORBIHAN;1
56061;La;Gacilly;GACILLY;56200;56;MORBIHAN;1
56062;;Gâvres;GAVRES;56290;56;MORBIHAN;1
56063;;Gestel;GESTEL;56830;56;MORBIHAN;1
56064;;Glénac;GLENAC;56200;56;MORBIHAN;1
56065;;Gourhel;GOURHEL;56800;56;MORBIHAN;1
56066;;Gourin;GOURIN;56110;56;MORBIHAN;1
56067;;Grand-Champ;GRAND-CHAMP;56390;56;MORBIHAN;1
56068;La;Grée-Saint-Laurent;GREE-SAINT-LAURENT;56120;56;MORBIHAN;1
56069;;Groix;GROIX;56590;56;MORBIHAN;1
56070;;Guégon;GUEGON;56120;56;MORBIHAN;1
56071;;Guéhenno;GUEHENNO;56420;56;MORBIHAN;1
56072;;Gueltas;GUELTAS;56920;56;MORBIHAN;1
56073;;Guémené-sur-Scorff;GUEMENE-SUR-SCORFF;56160;56;MORBIHAN;1
56074;;Guénin;GUENIN;56150;56;MORBIHAN;1
56075;;Guer;GUER;56380;56;MORBIHAN;1
56076;;Guern;GUERN;56310;56;MORBIHAN;1
56077;Le;Guerno;GUERNO;56190;56;MORBIHAN;1
56078;;Guidel;GUIDEL;56520;56;MORBIHAN;1
56079;;Guillac;GUILLAC;56800;56;MORBIHAN;1
56080;;Guilliers;GUILLIERS;56490;56;MORBIHAN;1
56081;;Guiscriff;GUISCRIFF;56560;56;MORBIHAN;1
56082;;Helléan;HELLEAN;56120;56;MORBIHAN;1
56083;;Hennebont;HENNEBONT;56700;56;MORBIHAN;1
56084;Le;Hézo;HEZO;56450;56;MORBIHAN;1
56085;;Hœdic;HOEDIC;56170;56;MORBIHAN;1
56086;;Île-d'Houat;ILE-D'HOUAT;56170;56;MORBIHAN;1
56087;;Île-aux-Moines;ILE-AUX-MOINES;56780;56;MORBIHAN;1
56088;;Île-d'Arz;ILE-D'ARZ;56840;56;MORBIHAN;1
56089;;Inguiniel;INGUINIEL;56240;56;MORBIHAN;1
56090;;Inzinzac-Lochrist;INZINZAC-LOCHRIST;56650;56;MORBIHAN;1
56091;;Josselin;JOSSELIN;56120;56;MORBIHAN;1
56092;;Kerfourn;KERFOURN;56920;56;MORBIHAN;1
56093;;Kergrist;KERGRIST;56300;56;MORBIHAN;1
56094;;Kervignac;KERVIGNAC;56700;56;MORBIHAN;1
56096;;Landaul;LANDAUL;56690;56;MORBIHAN;1
56097;;Landévant;LANDEVANT;56690;56;MORBIHAN;1
56098;;Lanester;LANESTER;56600;56;MORBIHAN;1
56099;;Langoëlan;LANGOELAN;56160;56;MORBIHAN;1
56100;;Langonnet;LANGONNET;56630;56;MORBIHAN;1
56101;;Languidic;LANGUIDIC;56440;56;MORBIHAN;1
56102;;Lanouée;LANOUEE;56120;56;MORBIHAN;1
56103;;Lantillac;LANTILLAC;56120;56;MORBIHAN;1
56104;;Lanvaudan;LANVAUDAN;56240;56;MORBIHAN;1
56105;;Lanvénégen;LANVENEGEN;56320;56;MORBIHAN;1
56106;;Larmor-Baden;LARMOR-BADEN;56870;56;MORBIHAN;1
56107;;Larmor-Plage;LARMOR-PLAGE;56260;56;MORBIHAN;1
56108;;Larré;LARRE;56230;56;MORBIHAN;1
56109;;Lauzach;LAUZACH;56190;56;MORBIHAN;1
56110;;Lignol;LIGNOL;56160;56;MORBIHAN;1
56111;;Limerzel;LIMERZEL;56220;56;MORBIHAN;1
56112;;Lizio;LIZIO;56460;56;MORBIHAN;1
56113;;Locmalo;LOCMALO;56160;56;MORBIHAN;1
56114;;Locmaria;LOCMARIA;56360;56;MORBIHAN;1
56115;;Locmaria-Grand-Champ;LOCMARIA-GRAND-CHAMP;56390;56;MORBIHAN;1
56116;;Locmariaquer;LOCMARIAQUER;56740;56;MORBIHAN;1
56117;;Locminé;LOCMINE;56500;56;MORBIHAN;1
56118;;Locmiquélic;LOCMIQUELIC;56570;56;MORBIHAN;1
56119;;Locoal-Mendon;LOCOAL-MENDON;56550;56;MORBIHAN;1
56120;;Locqueltas;LOCQUELTAS;56390;56;MORBIHAN;1
56121;;Lorient;LORIENT;56100;56;MORBIHAN;1
56122;;Loyat;LOYAT;56800;56;MORBIHAN;1
56123;;Malansac;MALANSAC;56220;56;MORBIHAN;1
56124;;Malestroit;MALESTROIT;56140;56;MORBIHAN;1
56125;;Malguénac;MALGUENAC;56300;56;MORBIHAN;1
56126;;Marzan;MARZAN;56130;56;MORBIHAN;1
56127;;Mauron;MAURON;56430;56;MORBIHAN;1
56128;;Melrand;MELRAND;56310;56;MORBIHAN;1
56129;;Ménéac;MENEAC;56490;56;MORBIHAN;1
56130;;Merlevenez;MERLEVENEZ;56700;56;MORBIHAN;1
56131;;Meslan;MESLAN;56320;56;MORBIHAN;1
56132;;Meucon;MEUCON;56890;56;MORBIHAN;1
56133;;Missiriac;MISSIRIAC;56140;56;MORBIHAN;1
56134;;Mohon;MOHON;56490;56;MORBIHAN;1
56135;;Molac;MOLAC;56230;56;MORBIHAN;1
56136;;Monteneuf;MONTENEUF;56380;56;MORBIHAN;1
56137;;Monterblanc;MONTERBLANC;56250;56;MORBIHAN;1
56138;;Monterrein;MONTERREIN;56800;56;MORBIHAN;1
56139;;Montertelot;MONTERTELOT;56800;56;MORBIHAN;1
56140;;Moréac;MOREAC;56500;56;MORBIHAN;1
56141;;Moustoir-Ac;MOUSTOIR-AC;56500;56;MORBIHAN;1
56142;;Moustoir-Remungol;MOUSTOIR-REMUNGOL;56500;56;MORBIHAN;1
56143;;Muzillac;MUZILLAC;56190;56;MORBIHAN;1
56144;;Naizin;NAIZIN;56500;56;MORBIHAN;1
56145;;Néant-sur-Yvel;NEANT-SUR-YVEL;56430;56;MORBIHAN;1
56146;;Neulliac;NEULLIAC;56300;56;MORBIHAN;1
56147;;Nivillac;NIVILLAC;56130;56;MORBIHAN;1
56148;;Nostang;NOSTANG;56690;56;MORBIHAN;1
56149;;Noyal-Muzillac;NOYAL-MUZILLAC;56190;56;MORBIHAN;1
56150;;Noyalo;NOYALO;56450;56;MORBIHAN;1
56151;;Noyal-Pontivy;NOYAL-PONTIVY;56920;56;MORBIHAN;1
56152;Le;Palais;PALAIS;56360;56;MORBIHAN;1
56153;;Péaule;PEAULE;56130;56;MORBIHAN;1
56154;;Peillac;PEILLAC;56220;56;MORBIHAN;1
56155;;Pénestin;PENESTIN;56760;56;MORBIHAN;1
56156;;Persquen;PERSQUEN;56160;56;MORBIHAN;1
56157;;Plaudren;PLAUDREN;56420;56;MORBIHAN;1
56158;;Plescop;PLESCOP;56890;56;MORBIHAN;1
56159;;Pleucadeuc;PLEUCADEUC;56140;56;MORBIHAN;1
56160;;Pleugriffet;PLEUGRIFFET;56120;56;MORBIHAN;1
56161;;Ploemel;PLOEMEL;56400;56;MORBIHAN;1
56162;;Ploemeur;PLOEMEUR;56270;56;MORBIHAN;1
56163;;Ploërdut;PLOERDUT;56160;56;MORBIHAN;1
56164;;Ploeren;PLOEREN;56880;56;MORBIHAN;1
56165;;Ploërmel;PLOERMEL;56800;56;MORBIHAN;1
56166;;Plouay;PLOUAY;56240;56;MORBIHAN;1
56167;;Plougoumelen;PLOUGOUMELEN;56400;56;MORBIHAN;1
56168;;Plouharnel;PLOUHARNEL;56340;56;MORBIHAN;1
56169;;Plouhinec;PLOUHINEC;56680;56;MORBIHAN;1
56170;;Plouray;PLOURAY;56770;56;MORBIHAN;1
56171;;Pluherlin;PLUHERLIN;56220;56;MORBIHAN;1
56172;;Plumelec;PLUMELEC;56420;56;MORBIHAN;1
56173;;Pluméliau;PLUMELIAU;56930;56;MORBIHAN;1
56174;;Plumelin;PLUMELIN;56500;56;MORBIHAN;1
56175;;Plumergat;PLUMERGAT;56400;56;MORBIHAN;1
56176;;Pluneret;PLUNERET;56400;56;MORBIHAN;1
56177;;Pluvigner;PLUVIGNER;56330;56;MORBIHAN;1
56178;;Pontivy;PONTIVY;56300;56;MORBIHAN;1
56179;;Pont-Scorff;PONT-SCORFF;56620;56;MORBIHAN;1
56180;;Porcaro;PORCARO;56380;56;MORBIHAN;1
56181;;Port-Louis;PORT-LOUIS;56290;56;MORBIHAN;1
56182;;Priziac;PRIZIAC;56320;56;MORBIHAN;1
56183;;Quelneuc;QUELNEUC;56910;56;MORBIHAN;1
56184;;Questembert;QUESTEMBERT;56230;56;MORBIHAN;1
56185;;Quéven;QUEVEN;56530;56;MORBIHAN;1
56186;;Quiberon;QUIBERON;56170;56;MORBIHAN;1
56187;;Quily;QUILY;56800;56;MORBIHAN;1
56188;;Quistinic;QUISTINIC;56310;56;MORBIHAN;1
56189;;Radenac;RADENAC;56500;56;MORBIHAN;1
56190;;Réguiny;REGUINY;56500;56;MORBIHAN;1
56191;;Réminiac;REMINIAC;56140;56;MORBIHAN;1
56192;;Remungol;REMUNGOL;56500;56;MORBIHAN;1
56193;;Riantec;RIANTEC;56670;56;MORBIHAN;1
56194;;Rieux;RIEUX;56350;56;MORBIHAN;1
56195;La;Roche-Bernard;ROCHE-BERNARD;56130;56;MORBIHAN;1
56196;;Rochefort-en-Terre;ROCHEFORT-EN-TERRE;56220;56;MORBIHAN;1
56197;Le;Roc-Saint-André;ROC-SAINT-ANDRE;56460;56;MORBIHAN;1
56198;;Rohan;ROHAN;56580;56;MORBIHAN;1
56199;;Roudouallec;ROUDOUALLEC;56110;56;MORBIHAN;1
56200;;Ruffiac;RUFFIAC;56140;56;MORBIHAN;1
56201;Le;Saint;SAINT;56110;56;MORBIHAN;1
56202;;Saint-Abraham;SAINT-ABRAHAM;56140;56;MORBIHAN;1
56203;;Saint-Aignan;SAINT-AIGNAN;56480;56;MORBIHAN;1
56204;;Saint-Allouestre;SAINT-ALLOUESTRE;56500;56;MORBIHAN;1
56205;;Saint-Armel;SAINT-ARMEL;56450;56;MORBIHAN;1
56206;;Saint-Avé;SAINT-AVE;56890;56;MORBIHAN;1
56207;;Saint-Barthélemy;SAINT-BARTHELEMY;56150;56;MORBIHAN;1
56208;;Saint-Brieuc-de-Mauron;SAINT-BRIEUC-DE-MAURON;56430;56;MORBIHAN;1
56209;;Sainte-Brigitte;SAINTE-BRIGITTE;56480;56;MORBIHAN;1
56210;;Saint-Caradec-Trégomel;SAINT-CARADEC-TREGOMEL;56540;56;MORBIHAN;1
56211;;Saint-Congard;SAINT-CONGARD;56140;56;MORBIHAN;1
56212;;Saint-Dolay;SAINT-DOLAY;56130;56;MORBIHAN;1
56213;;Saint-Gérand;SAINT-GERAND;56920;56;MORBIHAN;1
56214;;Saint-Gildas-de-Rhuys;SAINT-GILDAS-DE-RHUYS;56730;56;MORBIHAN;1
56215;;Saint-Gonnery;SAINT-GONNERY;56920;56;MORBIHAN;1
56216;;Saint-Gorgon;SAINT-GORGON;56350;56;MORBIHAN;1
56218;;Saint-Gravé;SAINT-GRAVE;56220;56;MORBIHAN;1
56219;;Saint-Guyomard;SAINT-GUYOMARD;56460;56;MORBIHAN;1
56220;;Sainte-Hélène;SAINTE-HELENE;56700;56;MORBIHAN;1
56221;;Saint-Jacut-les-Pins;SAINT-JACUT-LES-PINS;56220;56;MORBIHAN;1
56222;;Saint-Jean-Brévelay;SAINT-JEAN-BREVELAY;56660;56;MORBIHAN;1
56223;;Saint-Jean-la-Poterie;SAINT-JEAN-LA-POTERIE;56350;56;MORBIHAN;1
56224;;Saint-Laurent-sur-Oust;SAINT-LAURENT-SUR-OUST;56140;56;MORBIHAN;1
56225;;Saint-Léry;SAINT-LERY;56430;56;MORBIHAN;1
56226;;Saint-Malo-de-Beignon;SAINT-MALO-DE-BEIGNON;56380;56;MORBIHAN;1
56227;;Saint-Malo-des-Trois-Fontaines;SAINT-MALO-DES-TROIS-FONTAINES;56490;56;MORBIHAN;1
56228;;Saint-Marcel;SAINT-MARCEL;56140;56;MORBIHAN;1
56229;;Saint-Martin-sur-Oust;SAINT-MARTIN-SUR-OUST;56200;56;MORBIHAN;1
56230;;Saint-Nicolas-du-Tertre;SAINT-NICOLAS-DU-TERTRE;56910;56;MORBIHAN;1
56231;;Saint-Nolff;SAINT-NOLFF;56250;56;MORBIHAN;1
56232;;Saint-Perreux;SAINT-PERREUX;56350;56;MORBIHAN;1
56233;;Saint-Philibert;SAINT-PHILIBERT;56470;56;MORBIHAN;1
56234;;Saint-Pierre-Quiberon;SAINT-PIERRE-QUIBERON;56510;56;MORBIHAN;1
56236;;Saint-Servant;SAINT-SERVANT;56120;56;MORBIHAN;1
56237;;Saint-Thuriau;SAINT-THURIAU;56300;56;MORBIHAN;1
56238;;Saint-Tugdual;SAINT-TUGDUAL;56540;56;MORBIHAN;1
56239;;Saint-Vincent-sur-Oust;SAINT-VINCENT-SUR-OUST;56350;56;MORBIHAN;1
56240;;Sarzeau;SARZEAU;56370;56;MORBIHAN;1
56241;;Sauzon;SAUZON;56360;56;MORBIHAN;1
56242;;Séglien;SEGLIEN;56160;56;MORBIHAN;1
56243;;Séné;SENE;56860;56;MORBIHAN;1
56244;;Sérent;SERENT;56460;56;MORBIHAN;1
56245;;Silfiac;SILFIAC;56480;56;MORBIHAN;1
56246;Le;Sourn;SOURN;56300;56;MORBIHAN;1
56247;;Sulniac;SULNIAC;56250;56;MORBIHAN;1
56248;;Surzur;SURZUR;56450;56;MORBIHAN;1
56249;;Taupont;TAUPONT;56800;56;MORBIHAN;1
56250;;Théhillac;THEHILLAC;56130;56;MORBIHAN;1
56251;;Theix;THEIX;56450;56;MORBIHAN;1
56252;Le;Tour-du-Parc;TOUR-DU-PARC;56370;56;MORBIHAN;1
56253;;Tréal;TREAL;56140;56;MORBIHAN;1
56254;;Trédion;TREDION;56250;56;MORBIHAN;1
56255;;Treffléan;TREFFLEAN;56250;56;MORBIHAN;1
56256;;Tréhorenteuc;TREHORENTEUC;56430;56;MORBIHAN;1
56257;La;Trinité-Porhoët;TRINITE-PORHOET;56710;56;MORBIHAN;1
56258;La;Trinité-sur-Mer;TRINITE-SUR-MER;56470;56;MORBIHAN;1
56259;La;Trinité-Surzur;TRINITE-SURZUR;56190;56;MORBIHAN;1
56260;;Vannes;VANNES;56000;56;MORBIHAN;1
56261;La;Vraie-Croix;VRAIE-CROIX;56250;56;MORBIHAN;1
56262;;Bono;BONO;56400;56;MORBIHAN;1
56263;;Sainte-Anne-d'Auray;SAINTE-ANNE-D'AURAY;56400;56;MORBIHAN;1
56264;;Kernascléden;KERNASCLEDEN;56540;56;MORBIHAN;1
57001;;Aboncourt;ABONCOURT;57920;57;MOSELLE;1
57002;;Aboncourt-sur-Seille;ABONCOURT-SUR-SEILLE;57590;57;MOSELLE;1
57003;;Abreschviller;ABRESCHVILLER;57560;57;MOSELLE;1
57004;;Achain;ACHAIN;57340;57;MOSELLE;1
57006;;Achen;ACHEN;57410;57;MOSELLE;1
57007;;Adaincourt;ADAINCOURT;57580;57;MOSELLE;1
57008;;Adelange;ADELANGE;57380;57;MOSELLE;1
57009;;Ajoncourt;AJONCOURT;57590;57;MOSELLE;1
57010;;Alaincourt-la-Côte;ALAINCOURT-LA-COTE;57590;57;MOSELLE;1
57011;;Albestroff;ALBESTROFF;57670;57;MOSELLE;1
57012;;Algrange;ALGRANGE;57440;57;MOSELLE;1
57013;;Alsting;ALSTING;57520;57;MOSELLE;1
57014;;Altrippe;ALTRIPPE;57660;57;MOSELLE;1
57015;;Altviller;ALTVILLER;57730;57;MOSELLE;1
57016;;Alzing;ALZING;57320;57;MOSELLE;1
57017;;Amanvillers;AMANVILLERS;57111;57;MOSELLE;1
57018;;Amelécourt;AMELECOURT;57170;57;MOSELLE;1
57019;;Amnéville;AMNEVILLE;57360;57;MOSELLE;1
57020;;Ancerville;ANCERVILLE;57580;57;MOSELLE;1
57021;;Ancy-sur-Moselle;ANCY-SUR-MOSELLE;57130;57;MOSELLE;1
57022;;Angevillers;ANGEVILLERS;57440;57;MOSELLE;1
57024;;Antilly;ANTILLY;57640;57;MOSELLE;1
57025;;Anzeling;ANZELING;57320;57;MOSELLE;1
57026;;Apach;APACH;57480;57;MOSELLE;1
57027;;Arraincourt;ARRAINCOURT;57380;57;MOSELLE;1
57028;;Argancy;ARGANCY;57640;57;MOSELLE;1
57029;;Arriance;ARRIANCE;57580;57;MOSELLE;1
57030;;Arry;ARRY;57680;57;MOSELLE;1
57031;;Ars-Laquenexy;ARS-LAQUENEXY;57530;57;MOSELLE;1
57032;;Ars-sur-Moselle;ARS-SUR-MOSELLE;57130;57;MOSELLE;1
57033;;Arzviller;ARZVILLER;57400;57;MOSELLE;1
57034;;Aspach;ASPACH;57790;57;MOSELLE;1
57035;;Assenoncourt;ASSENONCOURT;57810;57;MOSELLE;1
57036;;Attilloncourt;ATTILLONCOURT;57170;57;MOSELLE;1
57037;;Aube;AUBE;57580;57;MOSELLE;1
57038;;Audun-le-Tiche;AUDUN-LE-TICHE;57390;57;MOSELLE;1
57039;;Augny;AUGNY;57176;57;MOSELLE;1
57040;;Aulnois-sur-Seille;AULNOIS-SUR-SEILLE;57590;57;MOSELLE;1
57041;;Aumetz;AUMETZ;57710;57;MOSELLE;1
57042;;Avricourt;AVRICOURT;57810;57;MOSELLE;1
57043;;Ay-sur-Moselle;AY-SUR-MOSELLE;57300;57;MOSELLE;1
57044;;Azoudange;AZOUDANGE;57810;57;MOSELLE;1
57045;;Bacourt;BACOURT;57590;57;MOSELLE;1
57046;;Baerenthal;BAERENTHAL;57230;57;MOSELLE;1
57047;;Bambiderstroff;BAMBIDERSTROFF;57690;57;MOSELLE;1
57048;;Bannay;BANNAY;57220;57;MOSELLE;1
57049;Le;Ban-Saint-Martin;BAN-SAINT-MARTIN;57050;57;MOSELLE;1
57050;;Barchain;BARCHAIN;57830;57;MOSELLE;1
57051;;Baronville;BARONVILLE;57340;57;MOSELLE;1
57052;;Barst;BARST;57450;57;MOSELLE;1
57053;;Bassing;BASSING;57260;57;MOSELLE;1
57054;;Baudrecourt;BAUDRECOURT;57580;57;MOSELLE;1
57055;;Bazoncourt;BAZONCOURT;57530;57;MOSELLE;1
57056;;Bébing;BEBING;57830;57;MOSELLE;1
57057;;Béchy;BECHY;57580;57;MOSELLE;1
57058;;Behren-lès-Forbach;BEHREN-LES-FORBACH;57460;57;MOSELLE;1
57059;;Bellange;BELLANGE;57340;57;MOSELLE;1
57060;;Bénestroff;BENESTROFF;57670;57;MOSELLE;1
57061;;Béning-lès-Saint-Avold;BENING-LES-SAINT-AVOLD;57800;57;MOSELLE;1
57062;;Berg-sur-Moselle;BERG-SUR-MOSELLE;57570;57;MOSELLE;1
57063;;Bérig-Vintrange;BERIG-VINTRANGE;57660;57;MOSELLE;1
57064;;Berling;BERLING;57370;57;MOSELLE;1
57065;;Bermering;BERMERING;57340;57;MOSELLE;1
57066;;Berthelming;BERTHELMING;57930;57;MOSELLE;1
57067;;Bertrange;BERTRANGE;57310;57;MOSELLE;1
57069;;Berviller-en-Moselle;BERVILLER-EN-MOSELLE;57550;57;MOSELLE;1
57070;;Bettange;BETTANGE;57220;57;MOSELLE;1
57071;;Bettborn;BETTBORN;57930;57;MOSELLE;1
57072;;Bettelainville;BETTELAINVILLE;57640;57;MOSELLE;1
57073;;Betting;BETTING;57800;57;MOSELLE;1
57074;;Bettviller;BETTVILLER;57410;57;MOSELLE;1
57075;;Beux;BEUX;57580;57;MOSELLE;1
57076;;Beyren-lès-Sierck;BEYREN-LES-SIERCK;57570;57;MOSELLE;1
57077;;Bezange-la-Petite;BEZANGE-LA-PETITE;57630;57;MOSELLE;1
57079;;Bibiche;BIBICHE;57320;57;MOSELLE;1
57080;;Bickenholtz;BICKENHOLTZ;57370;57;MOSELLE;1
57081;;Bidestroff;BIDESTROFF;57260;57;MOSELLE;1
57082;;Biding;BIDING;57660;57;MOSELLE;1
57083;;Bining;BINING;57410;57;MOSELLE;1
57084;;Bioncourt;BIONCOURT;57170;57;MOSELLE;1
57085;;Bionville-sur-Nied;BIONVILLE-SUR-NIED;57220;57;MOSELLE;1
57086;;Belles-Forêts;BELLES-FORETS;57930;57;MOSELLE;1
57087;;Bisten-en-Lorraine;BISTEN-EN-LORRAINE;57220;57;MOSELLE;1
57088;;Bistroff;BISTROFF;57660;57;MOSELLE;1
57089;;Bitche;BITCHE;57230;57;MOSELLE;1
57090;;Blanche-Église;BLANCHE-EGLISE;57260;57;MOSELLE;1
57091;;Bliesbruck;BLIESBRUCK;57200;57;MOSELLE;1
57092;;Blies-Ébersing;BLIES-EBERSING;57200;57;MOSELLE;1
57093;;Blies-Guersviller;BLIES-GUERSVILLER;57200;57;MOSELLE;1
57095;;Boucheporn;BOUCHEPORN;57220;57;MOSELLE;1
57096;;Boulange;BOULANGE;57113;57;MOSELLE;1
57097;;Boulay-Moselle;BOULAY-MOSELLE;57220;57;MOSELLE;1
57098;;Bourgaltroff;BOURGALTROFF;57260;57;MOSELLE;1
57099;;Bourdonnay;BOURDONNAY;57810;57;MOSELLE;1
57100;;Bourscheid;BOURSCHEID;57370;57;MOSELLE;1
57101;;Bousbach;BOUSBACH;57460;57;MOSELLE;1
57102;;Bousse;BOUSSE;57310;57;MOSELLE;1
57103;;Bousseviller;BOUSSEVILLER;57230;57;MOSELLE;1
57104;;Boust;BOUST;57570;57;MOSELLE;1
57105;;Boustroff;BOUSTROFF;57380;57;MOSELLE;1
57106;;Bouzonville;BOUZONVILLE;57320;57;MOSELLE;1
57107;;Bréhain;BREHAIN;57340;57;MOSELLE;1
57108;;Breidenbach;BREIDENBACH;57720;57;MOSELLE;1
57109;;Breistroff-la-Grande;BREISTROFF-LA-GRANDE;57570;57;MOSELLE;1
57110;;Brettnach;BRETTNACH;57320;57;MOSELLE;1
57111;;Bronvaux;BRONVAUX;57159;57;MOSELLE;1
57112;;Brouck;BROUCK;57220;57;MOSELLE;1
57113;;Brouderdorff;BROUDERDORFF;57116;57;MOSELLE;1
57114;;Brouviller;BROUVILLER;57119;57;MOSELLE;1
57115;;Brulange;BRULANGE;57340;57;MOSELLE;1
57116;;Buchy;BUCHY;57420;57;MOSELLE;1
57117;;Buding;BUDING;57920;57;MOSELLE;1
57118;;Budling;BUDLING;57110;57;MOSELLE;1
57119;;Buhl-Lorraine;BUHL-LORRAINE;57400;57;MOSELLE;1
57120;;Burlioncourt;BURLIONCOURT;57170;57;MOSELLE;1
57121;;Burtoncourt;BURTONCOURT;57220;57;MOSELLE;1
57122;;Cappel;CAPPEL;57450;57;MOSELLE;1
57123;;Carling;CARLING;57490;57;MOSELLE;1
57124;;Cattenom;CATTENOM;57570;57;MOSELLE;1
57125;;Chailly-lès-Ennery;CHAILLY-LES-ENNERY;57365;57;MOSELLE;1
57126;;Chambrey;CHAMBREY;57170;57;MOSELLE;1
57127;;Chanville;CHANVILLE;57580;57;MOSELLE;1
57128;;Charleville-sous-Bois;CHARLEVILLE-SOUS-BOIS;57220;57;MOSELLE;1
57129;;Charly-Oradour;CHARLY-ORADOUR;57640;57;MOSELLE;1
57130;;Château-Bréhain;CHATEAU-BREHAIN;57340;57;MOSELLE;1
57131;;Château-Rouge;CHATEAU-ROUGE;57320;57;MOSELLE;1
57132;;Château-Salins;CHATEAU-SALINS;57170;57;MOSELLE;1
57133;;Château-Voué;CHATEAU-VOUE;57170;57;MOSELLE;1
57134;;Châtel-Saint-Germain;CHATEL-SAINT-GERMAIN;57160;57;MOSELLE;1
57136;;Chémery-les-Deux;CHEMERY-LES-DEUX;57320;57;MOSELLE;1
57137;;Cheminot;CHEMINOT;57420;57;MOSELLE;1
57138;;Chenois;CHENOIS;57580;57;MOSELLE;1
57139;;Chérisey;CHERISEY;57420;57;MOSELLE;1
57140;;Chesny;CHESNY;57245;57;MOSELLE;1
57141;;Chicourt;CHICOURT;57590;57;MOSELLE;1
57142;;Chieulles;CHIEULLES;57070;57;MOSELLE;1
57143;;Clouange;CLOUANGE;57120;57;MOSELLE;1
57144;;Cocheren;COCHEREN;57800;57;MOSELLE;1
57145;;Coincy;COINCY;57530;57;MOSELLE;1
57146;;Coin-lès-Cuvry;COIN-LES-CUVRY;57420;57;MOSELLE;1
57147;;Coin-sur-Seille;COIN-SUR-SEILLE;57420;57;MOSELLE;1
57148;;Colligny;COLLIGNY;57530;57;MOSELLE;1
57149;;Colmen;COLMEN;57320;57;MOSELLE;1
57150;;Condé-Northen;CONDE-NORTHEN;57220;57;MOSELLE;1
57151;;Conthil;CONTHIL;57340;57;MOSELLE;1
57152;;Contz-les-Bains;CONTZ-LES-BAINS;57480;57;MOSELLE;1
57153;;Corny-sur-Moselle;CORNY-SUR-MOSELLE;57680;57;MOSELLE;1
57154;;Coume;COUME;57220;57;MOSELLE;1
57155;;Courcelles-Chaussy;COURCELLES-CHAUSSY;57530;57;MOSELLE;1
57156;;Courcelles-sur-Nied;COURCELLES-SUR-NIED;57530;57;MOSELLE;1
57158;;Craincourt;CRAINCOURT;57590;57;MOSELLE;1
57159;;Créhange;CREHANGE;57690;57;MOSELLE;1
57160;;Creutzwald;CREUTZWALD;57150;57;MOSELLE;1
57161;;Cutting;CUTTING;57260;57;MOSELLE;1
57162;;Cuvry;CUVRY;57420;57;MOSELLE;1
57163;;Dabo;DABO;57850;57;MOSELLE;1
57165;;Dalem;DALEM;57550;57;MOSELLE;1
57166;;Dalhain;DALHAIN;57340;57;MOSELLE;1
57167;;Dalstein;DALSTEIN;57320;57;MOSELLE;1
57168;;Danne-et-Quatre-Vents;DANNE-ET-QUATRE-VENTS;57370;57;MOSELLE;1
57169;;Dannelbourg;DANNELBOURG;57820;57;MOSELLE;1
57171;;Delme;DELME;57590;57;MOSELLE;1
57172;;Denting;DENTING;57220;57;MOSELLE;1
57173;;Desseling;DESSELING;57930;57;MOSELLE;1
57174;;Destry;DESTRY;57340;57;MOSELLE;1
57175;;Diane-Capelle;DIANE-CAPELLE;57830;57;MOSELLE;1
57176;;Diebling;DIEBLING;57980;57;MOSELLE;1
57177;;Dieuze;DIEUZE;57260;57;MOSELLE;1
57178;;Diffembach-lès-Hellimer;DIFFEMBACH-LES-HELLIMER;57660;57;MOSELLE;1
57179;;Distroff;DISTROFF;57134;57;MOSELLE;1
57180;;Dolving;DOLVING;57400;57;MOSELLE;1
57181;;Domnom-lès-Dieuze;DOMNOM-LES-DIEUZE;57260;57;MOSELLE;1
57182;;Donjeux;DONJEUX;57590;57;MOSELLE;1
57183;;Donnelay;DONNELAY;57810;57;MOSELLE;1
57184;;Dornot;DORNOT;57130;57;MOSELLE;1
57186;;Ébersviller;EBERSVILLER;57320;57;MOSELLE;1
57187;;Éblange;EBLANGE;57220;57;MOSELLE;1
57188;;Éguelshardt;EGUELSHARDT;57230;57;MOSELLE;1
57189;;Eincheville;EINCHEVILLE;57340;57;MOSELLE;1
57190;;Elvange;ELVANGE;57690;57;MOSELLE;1
57191;;Elzange;ELZANGE;57110;57;MOSELLE;1
57192;;Enchenberg;ENCHENBERG;57410;57;MOSELLE;1
57193;;Ennery;ENNERY;57365;57;MOSELLE;1
57194;;Entrange;ENTRANGE;57330;57;MOSELLE;1
57195;;Epping;EPPING;57720;57;MOSELLE;1
57196;;Erching;ERCHING;57136;57;MOSELLE;1
57197;;Ernestviller;ERNESTVILLER;57510;57;MOSELLE;1
57198;;Erstroff;ERSTROFF;57660;57;MOSELLE;1
57199;;Escherange;ESCHERANGE;57330;57;MOSELLE;1
57200;Les;Étangs;ETANGS;57530;57;MOSELLE;1
57201;;Etting;ETTING;57410;57;MOSELLE;1
57202;;Etzling;ETZLING;57460;57;MOSELLE;1
57203;;Évrange;EVRANGE;57570;57;MOSELLE;1
57204;;Failly;FAILLY;57640;57;MOSELLE;1
57205;;Falck;FALCK;57550;57;MOSELLE;1
57206;;Fameck;FAMECK;57290;57;MOSELLE;1
57207;;Farébersviller;FAREBERSVILLER;57450;57;MOSELLE;1
57208;;Farschviller;FARSCHVILLER;57450;57;MOSELLE;1
57209;;Faulquemont;FAULQUEMONT;57380;57;MOSELLE;1
57210;;Fénétrange;FENETRANGE;57930;57;MOSELLE;1
57211;;Fèves;FEVES;57210;57;MOSELLE;1
57212;;Féy;FEY;57420;57;MOSELLE;1
57213;;Filstroff;FILSTROFF;57320;57;MOSELLE;1
57214;;Fixem;FIXEM;57570;57;MOSELLE;1
57215;;Flastroff;FLASTROFF;57320;57;MOSELLE;1
57216;;Fleisheim;FLEISHEIM;57119;57;MOSELLE;1
57217;;Flétrange;FLETRANGE;57690;57;MOSELLE;1
57218;;Fleury;FLEURY;57420;57;MOSELLE;1
57219;;Flévy;FLEVY;57365;57;MOSELLE;1
57220;;Flocourt;FLOCOURT;57580;57;MOSELLE;1
57221;;Florange;FLORANGE;57190;57;MOSELLE;1
57222;;Folkling;FOLKLING;57600;57;MOSELLE;1
57224;;Folschviller;FOLSCHVILLER;57730;57;MOSELLE;1
57225;;Fonteny;FONTENY;57590;57;MOSELLE;1
57226;;Fontoy;FONTOY;57650;57;MOSELLE;1
57227;;Forbach;FORBACH;57600;57;MOSELLE;1
57228;;Fossieux;FOSSIEUX;57590;57;MOSELLE;1
57229;;Foulcrey;FOULCREY;57830;57;MOSELLE;1
57230;;Fouligny;FOULIGNY;57220;57;MOSELLE;1
57231;;Foville;FOVILLE;57420;57;MOSELLE;1
57232;;Francaltroff;FRANCALTROFF;57670;57;MOSELLE;1
57233;;Fraquelfing;FRAQUELFING;57790;57;MOSELLE;1
57234;;Frauenberg;FRAUENBERG;57200;57;MOSELLE;1
57235;;Freistroff;FREISTROFF;57320;57;MOSELLE;1
57236;;Frémery;FREMERY;57590;57;MOSELLE;1
57237;;Frémestroff;FREMESTROFF;57660;57;MOSELLE;1
57238;;Fresnes-en-Saulnois;FRESNES-EN-SAULNOIS;57170;57;MOSELLE;1
57239;;Freybouse;FREYBOUSE;57660;57;MOSELLE;1
57240;;Freyming-Merlebach;FREYMING-MERLEBACH;57800;57;MOSELLE;1
57241;;Fribourg;FRIBOURG;57810;57;MOSELLE;1
57242;;Gandrange;GANDRANGE;57175;57;MOSELLE;1
57244;;Garrebourg;GARREBOURG;57820;57;MOSELLE;1
57245;;Gavisse;GAVISSE;57570;57;MOSELLE;1
57246;;Gelucourt;GELUCOURT;57260;57;MOSELLE;1
57247;;Gerbécourt;GERBECOURT;57170;57;MOSELLE;1
57248;;Givrycourt;GIVRYCOURT;57670;57;MOSELLE;1
57249;;Glatigny;GLATIGNY;57530;57;MOSELLE;1
57250;;Goetzenbruck;GOETZENBRUCK;57620;57;MOSELLE;1
57251;;Goin;GOIN;57420;57;MOSELLE;1
57252;;Gomelange;GOMELANGE;57220;57;MOSELLE;1
57253;;Gondrexange;GONDREXANGE;57142;57;MOSELLE;1
57254;;Gorze;GORZE;57680;57;MOSELLE;1
57255;;Gosselming;GOSSELMING;57930;57;MOSELLE;1
57256;;Gravelotte;GRAVELOTTE;57130;57;MOSELLE;1
57257;;Grémecey;GREMECEY;57170;57;MOSELLE;1
57258;;Gréning;GRENING;57660;57;MOSELLE;1
57259;;Grindorff-Bizing;GRINDORFF-BIZING;57480;57;MOSELLE;1
57260;;Grosbliederstroff;GROSBLIEDERSTROFF;57520;57;MOSELLE;1
57261;;Gros-Réderching;GROS-REDERCHING;57410;57;MOSELLE;1
57262;;Grostenquin;GROSTENQUIN;57660;57;MOSELLE;1
57263;;Grundviller;GRUNDVILLER;57510;57;MOSELLE;1
57264;;Guebenhouse;GUEBENHOUSE;57510;57;MOSELLE;1
57265;;Guébestroff;GUEBESTROFF;57260;57;MOSELLE;1
57266;;Guéblange-lès-Dieuze;GUEBLANGE-LES-DIEUZE;57260;57;MOSELLE;1
57267;Le;Val-de-Guéblange;VAL-DE-GUEBLANGE;57430;57;MOSELLE;1
57268;;Guébling;GUEBLING;57260;57;MOSELLE;1
57269;;Guénange;GUENANGE;57310;57;MOSELLE;1
57270;;Val-de-Bride;VAL-DE-BRIDE;57260;57;MOSELLE;1
57271;;Guenviller;GUENVILLER;57470;57;MOSELLE;1
57272;;Guermange;GUERMANGE;57810;57;MOSELLE;1
57273;;Guerstling;GUERSTLING;57320;57;MOSELLE;1
57274;;Guerting;GUERTING;57880;57;MOSELLE;1
57275;;Guessling-Hémering;GUESSLING-HEMERING;57380;57;MOSELLE;1
57276;;Guinglange;GUINGLANGE;57690;57;MOSELLE;1
57277;;Guinkirchen;GUINKIRCHEN;57220;57;MOSELLE;1
57278;;Guinzeling;GUINZELING;57670;57;MOSELLE;1
57280;;Guntzviller;GUNTZVILLER;57400;57;MOSELLE;1
57281;;Haboudange;HABOUDANGE;57340;57;MOSELLE;1
57282;;Hagen;HAGEN;57570;57;MOSELLE;1
57283;;Hagondange;HAGONDANGE;57300;57;MOSELLE;1
57284;;Hallering;HALLERING;57690;57;MOSELLE;1
57286;;Halstroff;HALSTROFF;57480;57;MOSELLE;1
57287;;Basse-Ham;BASSE-HAM;57110;57;MOSELLE;1
57288;;Ham-sous-Varsberg;HAM-SOUS-VARSBERG;57880;57;MOSELLE;1
57289;;Hambach;HAMBACH;57910;57;MOSELLE;1
57290;;Hampont;HAMPONT;57170;57;MOSELLE;1
57291;;Hangviller;HANGVILLER;57370;57;MOSELLE;1
57292;;Hannocourt;HANNOCOURT;57590;57;MOSELLE;1
57293;;Han-sur-Nied;HAN-SUR-NIED;57580;57;MOSELLE;1
57294;;Hanviller;HANVILLER;57230;57;MOSELLE;1
57295;;Haraucourt-sur-Seille;HARAUCOURT-SUR-SEILLE;57630;57;MOSELLE;1
57296;;Hargarten-aux-Mines;HARGARTEN-AUX-MINES;57550;57;MOSELLE;1
57297;;Harprich;HARPRICH;57340;57;MOSELLE;1
57298;;Harreberg;HARREBERG;57870;57;MOSELLE;1
57299;;Hartzviller;HARTZVILLER;57870;57;MOSELLE;1
57300;;Haselbourg;HASELBOURG;57850;57;MOSELLE;1
57301;;Haspelschiedt;HASPELSCHIEDT;57230;57;MOSELLE;1
57302;;Hattigny;HATTIGNY;57790;57;MOSELLE;1
57303;;Hauconcourt;HAUCONCOURT;57210;57;MOSELLE;1
57304;;Haut-Clocher;HAUT-CLOCHER;57400;57;MOSELLE;1
57305;;Havange;HAVANGE;57650;57;MOSELLE;1
57306;;Hayange;HAYANGE;57240;57;MOSELLE;1
57307;;Hayes;HAYES;57530;57;MOSELLE;1
57308;;Hazembourg;HAZEMBOURG;57430;57;MOSELLE;1
57309;;Heining-lès-Bouzonville;HEINING-LES-BOUZONVILLE;57320;57;MOSELLE;1
57310;;Hellering-lès-Fénétrange;HELLERING-LES-FENETRANGE;57930;57;MOSELLE;1
57311;;Hellimer;HELLIMER;57660;57;MOSELLE;1
57312;;Helstroff;HELSTROFF;57220;57;MOSELLE;1
57313;;Hémilly;HEMILLY;57690;57;MOSELLE;1
57314;;Héming;HEMING;57830;57;MOSELLE;1
57315;;Henridorff;HENRIDORFF;57820;57;MOSELLE;1
57316;;Henriville;HENRIVILLE;57450;57;MOSELLE;1
57317;;Hérange;HERANGE;57119;57;MOSELLE;1
57318;;Hermelange;HERMELANGE;57790;57;MOSELLE;1
57319;;Herny;HERNY;57580;57;MOSELLE;1
57320;;Hertzing;HERTZING;57830;57;MOSELLE;1
57321;;Hesse;HESSE;57400;57;MOSELLE;1
57322;;Hestroff;HESTROFF;57320;57;MOSELLE;1
57323;;Hettange-Grande;HETTANGE-GRANDE;57330;57;MOSELLE;1
57324;;Hilbesheim;HILBESHEIM;57400;57;MOSELLE;1
57325;;Hilsprich;HILSPRICH;57510;57;MOSELLE;1
57326;;Hinckange;HINCKANGE;57220;57;MOSELLE;1
57328;;Holacourt;HOLACOURT;57380;57;MOSELLE;1
57329;;Holling;HOLLING;57220;57;MOSELLE;1
57330;;Holving;HOLVING;57510;57;MOSELLE;1
57331;;Hombourg-Budange;HOMBOURG-BUDANGE;57920;57;MOSELLE;1
57332;;Hombourg-Haut;HOMBOURG-HAUT;57470;57;MOSELLE;1
57333;;Hommarting;HOMMARTING;57400;57;MOSELLE;1
57334;;Hommert;HOMMERT;57870;57;MOSELLE;1
57335;;Honskirch;HONSKIRCH;57670;57;MOSELLE;1
57336;L';Hôpital;HOPITAL;57490;57;MOSELLE;1
57337;;Hoste;HOSTE;57510;57;MOSELLE;1
57338;;Hottviller;HOTTVILLER;57720;57;MOSELLE;1
57339;;Hultehouse;HULTEHOUSE;57820;57;MOSELLE;1
57340;;Hundling;HUNDLING;57990;57;MOSELLE;1
57341;;Hunting;HUNTING;57480;57;MOSELLE;1
57342;;Ibigny;IBIGNY;57830;57;MOSELLE;1
57343;;Illange;ILLANGE;57110;57;MOSELLE;1
57344;;Imling;IMLING;57400;57;MOSELLE;1
57345;;Inglange;INGLANGE;57110;57;MOSELLE;1
57346;;Insming;INSMING;57670;57;MOSELLE;1
57347;;Insviller;INSVILLER;57670;57;MOSELLE;1
57348;;Ippling;IPPLING;57990;57;MOSELLE;1
57349;;Jallaucourt;JALLAUCOURT;57590;57;MOSELLE;1
57350;;Jouy-aux-Arches;JOUY-AUX-ARCHES;57130;57;MOSELLE;1
57351;;Jury;JURY;57245;57;MOSELLE;1
57352;;Jussy;JUSSY;57130;57;MOSELLE;1
57353;;Juvelize;JUVELIZE;57630;57;MOSELLE;1
57354;;Juville;JUVILLE;57590;57;MOSELLE;1
57355;;Kalhausen;KALHAUSEN;57410;57;MOSELLE;1
57356;;Kanfen;KANFEN;57330;57;MOSELLE;1
57357;;Kappelkinger;KAPPELKINGER;57430;57;MOSELLE;1
57358;;Kédange-sur-Canner;KEDANGE-SUR-CANNER;57920;57;MOSELLE;1
57359;;Kemplich;KEMPLICH;57920;57;MOSELLE;1
57360;;Kerbach;KERBACH;57460;57;MOSELLE;1
57361;;Kerling-lès-Sierck;KERLING-LES-SIERCK;57480;57;MOSELLE;1
57362;;Kerprich-aux-Bois;KERPRICH-AUX-BOIS;57830;57;MOSELLE;1
57364;;Kirsch-lès-Sierck;KIRSCH-LES-SIERCK;57480;57;MOSELLE;1
57365;;Kirschnaumen;KIRSCHNAUMEN;57480;57;MOSELLE;1
57366;;Kirviller;KIRVILLER;57430;57;MOSELLE;1
57367;;Klang;KLANG;57920;57;MOSELLE;1
57368;;Knutange;KNUTANGE;57240;57;MOSELLE;1
57370;;Kœnigsmacker;KOENIGSMACKER;57110;57;MOSELLE;1
57371;;Haute-Kontz;HAUTE-KONTZ;57480;57;MOSELLE;1
57372;;Kuntzig;KUNTZIG;57110;57;MOSELLE;1
57373;;Lachambre;LACHAMBRE;57730;57;MOSELLE;1
57374;;Lafrimbolle;LAFRIMBOLLE;57560;57;MOSELLE;1
57375;;Lagarde;LAGARDE;57810;57;MOSELLE;1
57376;;Lambach;LAMBACH;57410;57;MOSELLE;1
57377;;Landange;LANDANGE;57830;57;MOSELLE;1
57379;;Landroff;LANDROFF;57340;57;MOSELLE;1
57380;;Laneuveville-lès-Lorquin;LANEUVEVILLE-LES-LORQUIN;57790;57;MOSELLE;1
57381;;Laneuveville-en-Saulnois;LANEUVEVILLE-EN-SAULNOIS;57590;57;MOSELLE;1
57382;;Langatte;LANGATTE;57400;57;MOSELLE;1
57383;;Languimberg;LANGUIMBERG;57810;57;MOSELLE;1
57384;;Laning;LANING;57660;57;MOSELLE;1
57385;;Laquenexy;LAQUENEXY;57530;57;MOSELLE;1
57386;;Laudrefang;LAUDREFANG;57114;57;MOSELLE;1
57387;;Laumesfeld;LAUMESFELD;57480;57;MOSELLE;1
57388;;Launstroff;LAUNSTROFF;57480;57;MOSELLE;1
57389;;Lelling;LELLING;57660;57;MOSELLE;1
57390;;Lemberg;LEMBERG;57620;57;MOSELLE;1
57391;;Lemoncourt;LEMONCOURT;57590;57;MOSELLE;1
57392;;Lemud;LEMUD;57580;57;MOSELLE;1
57393;;Lengelsheim;LENGELSHEIM;57720;57;MOSELLE;1
57394;;Léning;LENING;57670;57;MOSELLE;1
57395;;Lesse;LESSE;57580;57;MOSELLE;1
57396;;Lessy;LESSY;57160;57;MOSELLE;1
57397;;Ley;LEY;57810;57;MOSELLE;1
57398;;Leyviller;LEYVILLER;57660;57;MOSELLE;1
57399;;Lezey;LEZEY;57630;57;MOSELLE;1
57401;;Lidrezing;LIDREZING;57340;57;MOSELLE;1
57402;;Liederschiedt;LIEDERSCHIEDT;57230;57;MOSELLE;1
57403;;Liéhon;LIEHON;57420;57;MOSELLE;1
57404;;Lindre-Basse;LINDRE-BASSE;57260;57;MOSELLE;1
57405;;Lindre-Haute;LINDRE-HAUTE;57260;57;MOSELLE;1
57406;;Liocourt;LIOCOURT;57590;57;MOSELLE;1
57407;;Lixheim;LIXHEIM;57119;57;MOSELLE;1
57408;;Lixing-lès-Rouhling;LIXING-LES-ROUHLING;57520;57;MOSELLE;1
57409;;Lixing-lès-Saint-Avold;LIXING-LES-SAINT-AVOLD;57660;57;MOSELLE;1
57410;;Lhor;LHOR;57670;57;MOSELLE;1
57411;;Lommerange;LOMMERANGE;57650;57;MOSELLE;1
57412;;Longeville-lès-Metz;LONGEVILLE-LES-METZ;57050;57;MOSELLE;1
57413;;Longeville-lès-Saint-Avold;LONGEVILLE-LES-SAINT-AVOLD;57740;57;MOSELLE;1
57414;;Lorquin;LORQUIN;57790;57;MOSELLE;1
57415;;Lorry-lès-Metz;LORRY-LES-METZ;57050;57;MOSELLE;1
57416;;Lorry-Mardigny;LORRY-MARDIGNY;57420;57;MOSELLE;1
57417;;Lostroff;LOSTROFF;57670;57;MOSELLE;1
57418;;Loudrefing;LOUDREFING;57670;57;MOSELLE;1
57419;;Loupershouse;LOUPERSHOUSE;57510;57;MOSELLE;1
57421;;Loutzviller;LOUTZVILLER;57720;57;MOSELLE;1
57422;;Louvigny;LOUVIGNY;57420;57;MOSELLE;1
57423;;Lubécourt;LUBECOURT;57170;57;MOSELLE;1
57424;;Lucy;LUCY;57590;57;MOSELLE;1
57425;;Luppy;LUPPY;57580;57;MOSELLE;1
57426;;Luttange;LUTTANGE;57144;57;MOSELLE;1
57427;;Lutzelbourg;LUTZELBOURG;57820;57;MOSELLE;1
57428;;Macheren;MACHEREN;57730;57;MOSELLE;1
57430;;Mainvillers;MAINVILLERS;57380;57;MOSELLE;1
57431;;Maizeroy;MAIZEROY;57530;57;MOSELLE;1
57432;;Maizery;MAIZERY;57530;57;MOSELLE;1
57433;;Maizières-lès-Metz;MAIZIERES-LES-METZ;57210;57;MOSELLE;1
57434;;Maizières-lès-Vic;MAIZIERES-LES-VIC;57810;57;MOSELLE;1
57436;;Malaucourt-sur-Seille;MALAUCOURT-SUR-SEILLE;57590;57;MOSELLE;1
57437;;Malling;MALLING;57480;57;MOSELLE;1
57438;;Malroy;MALROY;57640;57;MOSELLE;1
57439;;Manderen;MANDEREN;57480;57;MOSELLE;1
57440;;Manhoué;MANHOUE;57590;57;MOSELLE;1
57441;;Manom;MANOM;57100;57;MOSELLE;1
57442;;Many;MANY;57380;57;MOSELLE;1
57443;;Marange-Silvange;MARANGE-SILVANGE;57159;57;MOSELLE;1
57444;;Marange-Zondrange;MARANGE-ZONDRANGE;57690;57;MOSELLE;1
57445;;Marieulles;MARIEULLES;57420;57;MOSELLE;1
57446;;Marimont-lès-Bénestroff;MARIMONT-LES-BENESTROFF;57670;57;MOSELLE;1
57447;;Marly;MARLY;57157;57;MOSELLE;1
57448;;Marsal;MARSAL;57630;57;MOSELLE;1
57449;;Marsilly;MARSILLY;57530;57;MOSELLE;1
57451;;Marthille;MARTHILLE;57340;57;MOSELLE;1
57452;La;Maxe;MAXE;57140;57;MOSELLE;1
57453;;Maxstadt;MAXSTADT;57660;57;MOSELLE;1
57454;;Mécleuves;MECLEUVES;57245;57;MOSELLE;1
57455;;Mégange;MEGANGE;57220;57;MOSELLE;1
57456;;Meisenthal;MEISENTHAL;57960;57;MOSELLE;1
57457;;Menskirch;MENSKIRCH;57320;57;MOSELLE;1
57459;;Merschweiller;MERSCHWEILLER;57480;57;MOSELLE;1
57460;;Merten;MERTEN;57550;57;MOSELLE;1
57461;;Métairies-Saint-Quirin;METAIRIES-SAINT-QUIRIN;57560;57;MOSELLE;1
57462;;Metting;METTING;57370;57;MOSELLE;1
57463;;Metz;METZ;57000;57;MOSELLE;1
57464;;Metzeresche;METZERESCHE;57920;57;MOSELLE;1
57465;;Metzervisse;METZERVISSE;57940;57;MOSELLE;1
57466;;Metzing;METZING;57980;57;MOSELLE;1
57467;;Mey;MEY;57070;57;MOSELLE;1
57468;;Mittelbronn;MITTELBRONN;57370;57;MOSELLE;1
57469;;Mittersheim;MITTERSHEIM;57930;57;MOSELLE;1
57470;;Molring;MOLRING;57670;57;MOSELLE;1
57471;;Momerstroff;MOMERSTROFF;57220;57;MOSELLE;1
57472;;Moncheux;MONCHEUX;57420;57;MOSELLE;1
57473;;Moncourt;MONCOURT;57810;57;MOSELLE;1
57474;;Mondelange;MONDELANGE;57300;57;MOSELLE;1
57475;;Mondorff;MONDORFF;57570;57;MOSELLE;1
57476;;Monneren;MONNEREN;57920;57;MOSELLE;1
57477;;Montbronn;MONTBRONN;57410;57;MOSELLE;1
57478;;Montdidier;MONTDIDIER;57670;57;MOSELLE;1
57479;;Montenach;MONTENACH;57480;57;MOSELLE;1
57480;;Montigny-lès-Metz;MONTIGNY-LES-METZ;57158;57;MOSELLE;1
57481;;Montois-la-Montagne;MONTOIS-LA-MONTAGNE;57860;57;MOSELLE;1
57482;;Montoy-Flanville;MONTOY-FLANVILLE;57117;57;MOSELLE;1
57483;;Morhange;MORHANGE;57340;57;MOSELLE;1
57484;;Morsbach;MORSBACH;57600;57;MOSELLE;1
57485;;Morville-lès-Vic;MORVILLE-LES-VIC;57170;57;MOSELLE;1
57486;;Morville-sur-Nied;MORVILLE-SUR-NIED;57590;57;MOSELLE;1
57487;;Moulins-lès-Metz;MOULINS-LES-METZ;57160;57;MOSELLE;1
57488;;Moussey;MOUSSEY;57770;57;MOSELLE;1
57489;;Mouterhouse;MOUTERHOUSE;57620;57;MOSELLE;1
57490;;Moyenvic;MOYENVIC;57630;57;MOSELLE;1
57491;;Moyeuvre-Grande;MOYEUVRE-GRANDE;57250;57;MOSELLE;1
57492;;Moyeuvre-Petite;MOYEUVRE-PETITE;57250;57;MOSELLE;1
57493;;Mulcey;MULCEY;57260;57;MOSELLE;1
57494;;Munster;MUNSTER;57670;57;MOSELLE;1
57495;;Narbéfontaine;NARBEFONTAINE;57220;57;MOSELLE;1
57496;;Nébing;NEBING;57670;57;MOSELLE;1
57497;;Nelling;NELLING;57670;57;MOSELLE;1
57498;;Neufchef;NEUFCHEF;57700;57;MOSELLE;1
57499;;Neufgrange;NEUFGRANGE;57910;57;MOSELLE;1
57500;;Neufmoulins;NEUFMOULINS;57830;57;MOSELLE;1
57501;;Neufvillage;NEUFVILLAGE;57670;57;MOSELLE;1
57502;;Neunkirchen-lès-Bouzonville;NEUNKIRCHEN-LES-BOUZONVILLE;57320;57;MOSELLE;1
57504;;Niderhoff;NIDERHOFF;57560;57;MOSELLE;1
57505;;Niderviller;NIDERVILLER;57116;57;MOSELLE;1
57506;;Niederstinzel;NIEDERSTINZEL;57930;57;MOSELLE;1
57507;;Niedervisse;NIEDERVISSE;57220;57;MOSELLE;1
57508;;Nilvange;NILVANGE;57240;57;MOSELLE;1
57509;;Nitting;NITTING;57790;57;MOSELLE;1
57510;;Noisseville;NOISSEVILLE;57117;57;MOSELLE;1
57511;;Norroy-le-Veneur;NORROY-LE-VENEUR;57140;57;MOSELLE;1
57512;;Nouilly;NOUILLY;57117;57;MOSELLE;1
57513;;Nousseviller-lès-Bitche;NOUSSEVILLER-LES-BITCHE;57720;57;MOSELLE;1
57514;;Nousseviller-Saint-Nabor;NOUSSEVILLER-SAINT-NABOR;57990;57;MOSELLE;1
57515;;Novéant-sur-Moselle;NOVEANT-SUR-MOSELLE;57680;57;MOSELLE;1
57516;;Oberdorff;OBERDORFF;57320;57;MOSELLE;1
57517;;Obergailbach;OBERGAILBACH;57720;57;MOSELLE;1
57518;;Oberstinzel;OBERSTINZEL;57930;57;MOSELLE;1
57519;;Obervisse;OBERVISSE;57220;57;MOSELLE;1
57520;;Obreck;OBRECK;57170;57;MOSELLE;1
57521;;Œting;OETING;57600;57;MOSELLE;1
57523;;Ogy;OGY;57530;57;MOSELLE;1
57524;;Ommeray;OMMERAY;57810;57;MOSELLE;1
57525;;Oriocourt;ORIOCOURT;57590;57;MOSELLE;1
57526;;Ormersviller;ORMERSVILLER;57720;57;MOSELLE;1
57527;;Orny;ORNY;57420;57;MOSELLE;1
57528;;Oron;ORON;57590;57;MOSELLE;1
57529;;Ottange;OTTANGE;57840;57;MOSELLE;1
57530;;Ottonville;OTTONVILLE;57220;57;MOSELLE;1
57531;;Oudrenne;OUDRENNE;57110;57;MOSELLE;1
57532;;Pagny-lès-Goin;PAGNY-LES-GOIN;57420;57;MOSELLE;1
57533;;Pange;PANGE;57530;57;MOSELLE;1
57534;;Peltre;PELTRE;57245;57;MOSELLE;1
57535;;Petit-Réderching;PETIT-REDERCHING;57410;57;MOSELLE;1
57536;;Petit-Tenquin;PETIT-TENQUIN;57660;57;MOSELLE;1
57537;;Petite-Rosselle;PETITE-ROSSELLE;57540;57;MOSELLE;1
57538;;Pettoncourt;PETTONCOURT;57170;57;MOSELLE;1
57539;;Pévange;PEVANGE;57340;57;MOSELLE;1
57540;;Phalsbourg;PHALSBOURG;57370;57;MOSELLE;1
57541;;Philippsbourg;PHILIPPSBOURG;57230;57;MOSELLE;1
57542;;Piblange;PIBLANGE;57220;57;MOSELLE;1
57543;;Pierrevillers;PIERREVILLERS;57120;57;MOSELLE;1
57544;;Plaine-de-Walsch;PLAINE-DE-WALSCH;57870;57;MOSELLE;1
57545;;Plappeville;PLAPPEVILLE;57050;57;MOSELLE;1
57546;;Plesnois;PLESNOIS;57140;57;MOSELLE;1
57547;;Pommérieux;POMMERIEUX;57420;57;MOSELLE;1
57548;;Pontoy;PONTOY;57420;57;MOSELLE;1
57549;;Pontpierre;PONTPIERRE;57380;57;MOSELLE;1
57550;;Porcelette;PORCELETTE;57890;57;MOSELLE;1
57551;;Postroff;POSTROFF;57930;57;MOSELLE;1
57552;;Pouilly;POUILLY;57420;57;MOSELLE;1
57553;;Pournoy-la-Chétive;POURNOY-LA-CHETIVE;57420;57;MOSELLE;1
57554;;Pournoy-la-Grasse;POURNOY-LA-GRASSE;57420;57;MOSELLE;1
57555;;Prévocourt;PREVOCOURT;57590;57;MOSELLE;1
57556;;Puttelange-aux-Lacs;PUTTELANGE-AUX-LACS;57510;57;MOSELLE;1
57557;;Puttelange-lès-Thionville;PUTTELANGE-LES-THIONVILLE;57570;57;MOSELLE;1
57558;;Puttigny;PUTTIGNY;57170;57;MOSELLE;1
57559;;Puzieux;PUZIEUX;57590;57;MOSELLE;1
57560;;Racrange;RACRANGE;57340;57;MOSELLE;1
57561;;Rahling;RAHLING;57410;57;MOSELLE;1
57562;;Ranguevaux;RANGUEVAUX;57700;57;MOSELLE;1
57563;;Raville;RAVILLE;57530;57;MOSELLE;1
57564;;Réchicourt-le-Château;RECHICOURT-LE-CHATEAU;57810;57;MOSELLE;1
57565;;Rédange;REDANGE;57390;57;MOSELLE;1
57566;;Réding;REDING;57444;57;MOSELLE;1
57567;;Rémelfang;REMELFANG;57320;57;MOSELLE;1
57568;;Rémelfing;REMELFING;57200;57;MOSELLE;1
57569;;Rémeling;REMELING;57480;57;MOSELLE;1
57570;;Rémering;REMERING;57550;57;MOSELLE;1
57571;;Rémering-lès-Puttelange;REMERING-LES-PUTTELANGE;57510;57;MOSELLE;1
57572;;Rémilly;REMILLY;57580;57;MOSELLE;1
57573;;Réning;RENING;57670;57;MOSELLE;1
57574;;Basse-Rentgen;BASSE-RENTGEN;57570;57;MOSELLE;1
57575;;Retonfey;RETONFEY;57117;57;MOSELLE;1
57576;;Rettel;RETTEL;57480;57;MOSELLE;1
57577;;Reyersviller;REYERSVILLER;57230;57;MOSELLE;1
57578;;Rezonville;REZONVILLE;57130;57;MOSELLE;1
57579;;Rhodes;RHODES;57810;57;MOSELLE;1
57580;;Riche;RICHE;57340;57;MOSELLE;1
57581;;Richeling;RICHELING;57510;57;MOSELLE;1
57582;;Richemont;RICHEMONT;57270;57;MOSELLE;1
57583;;Richeval;RICHEVAL;57830;57;MOSELLE;1
57584;;Rimling;RIMLING;57136;57;MOSELLE;1
57585;;Ritzing;RITZING;57480;57;MOSELLE;1
57586;;Rochonvillers;ROCHONVILLERS;57840;57;MOSELLE;1
57587;;Rodalbe;RODALBE;57340;57;MOSELLE;1
57588;;Rodemack;RODEMACK;57570;57;MOSELLE;1
57589;;Rohrbach-lès-Bitche;ROHRBACH-LES-BITCHE;57410;57;MOSELLE;1
57590;;Rolbing;ROLBING;57720;57;MOSELLE;1
57591;;Rombas;ROMBAS;57120;57;MOSELLE;1
57592;;Romelfing;ROMELFING;57930;57;MOSELLE;1
57593;;Roncourt;RONCOURT;57860;57;MOSELLE;1
57594;;Roppeviller;ROPPEVILLER;57230;57;MOSELLE;1
57595;;Rorbach-lès-Dieuze;RORBACH-LES-DIEUZE;57260;57;MOSELLE;1
57596;;Rosbruck;ROSBRUCK;57800;57;MOSELLE;1
57597;;Rosselange;ROSSELANGE;57780;57;MOSELLE;1
57598;;Rouhling;ROUHLING;57520;57;MOSELLE;1
57599;;Roupeldange;ROUPELDANGE;57220;57;MOSELLE;1
57600;;Roussy-le-Village;ROUSSY-LE-VILLAGE;57330;57;MOSELLE;1
57601;;Rozérieulles;ROZERIEULLES;57160;57;MOSELLE;1
57602;;Rurange-lès-Thionville;RURANGE-LES-THIONVILLE;57310;57;MOSELLE;1
57603;;Russange;RUSSANGE;57390;57;MOSELLE;1
57604;;Rustroff;RUSTROFF;57480;57;MOSELLE;1
57605;;Sailly-Achâtel;SAILLY-ACHATEL;57420;57;MOSELLE;1
57606;;Saint-Avold;SAINT-AVOLD;57500;57;MOSELLE;1
57607;;Sainte-Barbe;SAINTE-BARBE;57640;57;MOSELLE;1
57609;;Saint-Epvre;SAINT-EPVRE;57580;57;MOSELLE;1
57610;;Saint-François-Lacroix;SAINT-FRANCOIS-LACROIX;57320;57;MOSELLE;1
57611;;Saint-Georges;SAINT-GEORGES;57830;57;MOSELLE;1
57612;;Saint-Hubert;SAINT-HUBERT;57640;57;MOSELLE;1
57613;;Saint-Jean-de-Bassel;SAINT-JEAN-DE-BASSEL;57930;57;MOSELLE;1
57614;;Saint-Jean-Kourtzerode;SAINT-JEAN-KOURTZERODE;57370;57;MOSELLE;1
57615;;Saint-Jean-Rohrbach;SAINT-JEAN-ROHRBACH;57510;57;MOSELLE;1
57616;;Saint-Julien-lès-Metz;SAINT-JULIEN-LES-METZ;57070;57;MOSELLE;1
57617;;Saint-Jure;SAINT-JURE;57420;57;MOSELLE;1
57618;;Saint-Louis;SAINT-LOUIS;57820;57;MOSELLE;1
57619;;Saint-Louis-lès-Bitche;SAINT-LOUIS-LES-BITCHE;57620;57;MOSELLE;1
57620;;Sainte-Marie-aux-Chênes;SAINTE-MARIE-AUX-CHENES;57118;57;MOSELLE;1
57621;;Saint-Médard;SAINT-MEDARD;57260;57;MOSELLE;1
57622;;Saint-Privat-la-Montagne;SAINT-PRIVAT-LA-MONTAGNE;57124;57;MOSELLE;1
57623;;Saint-Quirin;SAINT-QUIRIN;57560;57;MOSELLE;1
57624;;Sainte-Ruffine;SAINTE-RUFFINE;57130;57;MOSELLE;1
57625;;Salonnes;SALONNES;57170;57;MOSELLE;1
57626;;Sanry-lès-Vigy;SANRY-LES-VIGY;57640;57;MOSELLE;1
57627;;Sanry-sur-Nied;SANRY-SUR-NIED;57530;57;MOSELLE;1
57628;;Sarralbe;SARRALBE;57430;57;MOSELLE;1
57629;;Sarraltroff;SARRALTROFF;57400;57;MOSELLE;1
57630;;Sarrebourg;SARREBOURG;57400;57;MOSELLE;1
57631;;Sarreguemines;SARREGUEMINES;57200;57;MOSELLE;1
57633;;Sarreinsming;SARREINSMING;57115;57;MOSELLE;1
57634;;Saulny;SAULNY;57140;57;MOSELLE;1
57635;;Schalbach;SCHALBACH;57370;57;MOSELLE;1
57636;;Schmittviller;SCHMITTVILLER;57410;57;MOSELLE;1
57637;;Schneckenbusch;SCHNECKENBUSCH;57400;57;MOSELLE;1
57638;;Schœneck;SCHOENECK;57350;57;MOSELLE;1
57639;;Schorbach;SCHORBACH;57230;57;MOSELLE;1
57640;;Schwerdorff;SCHWERDORFF;57320;57;MOSELLE;1
57641;;Schweyen;SCHWEYEN;57720;57;MOSELLE;1
57642;;Scy-Chazelles;SCY-CHAZELLES;57160;57;MOSELLE;1
57643;;Secourt;SECOURT;57420;57;MOSELLE;1
57644;;Seingbouse;SEINGBOUSE;57450;57;MOSELLE;1
57645;;Semécourt;SEMECOURT;57210;57;MOSELLE;1
57647;;Serémange-Erzange;SEREMANGE-ERZANGE;57290;57;MOSELLE;1
57648;;Servigny-lès-Raville;SERVIGNY-LES-RAVILLE;57530;57;MOSELLE;1
57649;;Servigny-lès-Sainte-Barbe;SERVIGNY-LES-SAINTE-BARBE;57640;57;MOSELLE;1
57650;;Sierck-les-Bains;SIERCK-LES-BAINS;57480;57;MOSELLE;1
57651;;Siersthal;SIERSTHAL;57410;57;MOSELLE;1
57652;;Sillegny;SILLEGNY;57420;57;MOSELLE;1
57653;;Silly-en-Saulnois;SILLY-EN-SAULNOIS;57420;57;MOSELLE;1
57654;;Silly-sur-Nied;SILLY-SUR-NIED;57530;57;MOSELLE;1
57655;;Solgne;SOLGNE;57420;57;MOSELLE;1
57656;;Sorbey;SORBEY;57580;57;MOSELLE;1
57657;;Sotzeling;SOTZELING;57170;57;MOSELLE;1
57658;;Soucht;SOUCHT;57960;57;MOSELLE;1
57659;;Spicheren;SPICHEREN;57350;57;MOSELLE;1
57660;;Stiring-Wendel;STIRING-WENDEL;57350;57;MOSELLE;1
57661;;Sturzelbronn;STURZELBRONN;57230;57;MOSELLE;1
57662;;Suisse;SUISSE;57340;57;MOSELLE;1
57663;;Talange;TALANGE;57525;57;MOSELLE;1
57664;;Tarquimpol;TARQUIMPOL;57260;57;MOSELLE;1
57665;;Tenteling;TENTELING;57980;57;MOSELLE;1
57666;;Terville;TERVILLE;57180;57;MOSELLE;1
57667;;Téterchen;TETERCHEN;57220;57;MOSELLE;1
57668;;Teting-sur-Nied;TETING-SUR-NIED;57114;57;MOSELLE;1
57669;;Théding;THEDING;57450;57;MOSELLE;1
57670;;Thicourt;THICOURT;57380;57;MOSELLE;1
57671;;Thimonville;THIMONVILLE;57580;57;MOSELLE;1
57672;;Thionville;THIONVILLE;57100;57;MOSELLE;1
57673;;Thonville;THONVILLE;57380;57;MOSELLE;1
57674;;Tincry;TINCRY;57590;57;MOSELLE;1
57675;;Torcheville;TORCHEVILLE;57670;57;MOSELLE;1
57676;;Tragny;TRAGNY;57580;57;MOSELLE;1
57677;;Trémery;TREMERY;57300;57;MOSELLE;1
57678;;Tressange;TRESSANGE;57710;57;MOSELLE;1
57679;;Tritteling-Redlach;TRITTELING-REDLACH;57114;57;MOSELLE;1
57680;;Troisfontaines;TROISFONTAINES;57870;57;MOSELLE;1
57681;;Tromborn;TROMBORN;57320;57;MOSELLE;1
57682;;Turquestein-Blancrupt;TURQUESTEIN-BLANCRUPT;57560;57;MOSELLE;1
57683;;Uckange;UCKANGE;57270;57;MOSELLE;1
57684;;Vahl-Ebersing;VAHL-EBERSING;57660;57;MOSELLE;1
57685;;Vahl-lès-Bénestroff;VAHL-LES-BENESTROFF;57670;57;MOSELLE;1
57686;;Vahl-lès-Faulquemont;VAHL-LES-FAULQUEMONT;57380;57;MOSELLE;1
57687;;Vallerange;VALLERANGE;57340;57;MOSELLE;1
57689;;Valmestroff;VALMESTROFF;57110;57;MOSELLE;1
57690;;Valmont;VALMONT;57730;57;MOSELLE;1
57691;;Valmunster;VALMUNSTER;57220;57;MOSELLE;1
57692;;Vannecourt;VANNECOURT;57340;57;MOSELLE;1
57693;;Vantoux;VANTOUX;57070;57;MOSELLE;1
57694;;Vany;VANY;57070;57;MOSELLE;1
57695;;Varize;VARIZE;57220;57;MOSELLE;1
57696;;Varsberg;VARSBERG;57880;57;MOSELLE;1
57697;;Vasperviller;VASPERVILLER;57560;57;MOSELLE;1
57698;;Vatimont;VATIMONT;57580;57;MOSELLE;1
57700;;Vaudreching;VAUDRECHING;57320;57;MOSELLE;1
57701;;Vaux;VAUX;57130;57;MOSELLE;1
57702;;Vaxy;VAXY;57170;57;MOSELLE;1
57703;;Veckersviller;VECKERSVILLER;57370;57;MOSELLE;1
57704;;Veckring;VECKRING;57920;57;MOSELLE;1
57705;;Velving;VELVING;57220;57;MOSELLE;1
57706;;Vergaville;VERGAVILLE;57260;57;MOSELLE;1
57707;;Vernéville;VERNEVILLE;57130;57;MOSELLE;1
57708;;Verny;VERNY;57420;57;MOSELLE;1
57709;;Vescheim;VESCHEIM;57370;57;MOSELLE;1
57711;;Vibersviller;VIBERSVILLER;57670;57;MOSELLE;1
57712;;Vic-sur-Seille;VIC-SUR-SEILLE;57630;57;MOSELLE;1
57713;;Vieux-Lixheim;VIEUX-LIXHEIM;57119;57;MOSELLE;1
57714;;Haute-Vigneulles;HAUTE-VIGNEULLES;57690;57;MOSELLE;1
57715;;Vigny;VIGNY;57420;57;MOSELLE;1
57716;;Vigy;VIGY;57640;57;MOSELLE;1
57717;;Viller;VILLER;57340;57;MOSELLE;1
57718;;Villers-Stoncourt;VILLERS-STONCOURT;57530;57;MOSELLE;1
57719;;Villers-sur-Nied;VILLERS-SUR-NIED;57340;57;MOSELLE;1
57720;;Villing;VILLING;57550;57;MOSELLE;1
57721;;Vilsberg;VILSBERG;57370;57;MOSELLE;1
57722;;Vionville;VIONVILLE;57130;57;MOSELLE;1
57723;;Virming;VIRMING;57340;57;MOSELLE;1
57724;;Vitry-sur-Orne;VITRY-SUR-ORNE;57120;57;MOSELLE;1
57725;;Vittersbourg;VITTERSBOURG;57670;57;MOSELLE;1
57726;;Vittoncourt;VITTONCOURT;57580;57;MOSELLE;1
57727;;Viviers;VIVIERS;57590;57;MOSELLE;1
57728;;Voimhaut;VOIMHAUT;57580;57;MOSELLE;1
57730;;Volmerange-lès-Boulay;VOLMERANGE-LES-BOULAY;57220;57;MOSELLE;1
57731;;Volmerange-les-Mines;VOLMERANGE-LES-MINES;57330;57;MOSELLE;1
57732;;Volmunster;VOLMUNSTER;57720;57;MOSELLE;1
57733;;Volstroff;VOLSTROFF;57940;57;MOSELLE;1
57734;;Voyer;VOYER;57560;57;MOSELLE;1
57736;;Vry;VRY;57640;57;MOSELLE;1
57737;;Vulmont;VULMONT;57420;57;MOSELLE;1
57738;;Waldhouse;WALDHOUSE;57720;57;MOSELLE;1
57739;;Waldweistroff;WALDWEISTROFF;57320;57;MOSELLE;1
57740;;Waldwisse;WALDWISSE;57480;57;MOSELLE;1
57741;;Walschbronn;WALSCHBRONN;57720;57;MOSELLE;1
57742;;Walscheid;WALSCHEID;57870;57;MOSELLE;1
57743;;Waltembourg;WALTEMBOURG;57370;57;MOSELLE;1
57745;;Wiesviller;WIESVILLER;57200;57;MOSELLE;1
57746;;Willerwald;WILLERWALD;57430;57;MOSELLE;1
57747;;Wintersbourg;WINTERSBOURG;57119;57;MOSELLE;1
57748;;Wittring;WITTRING;57137;57;MOSELLE;1
57749;;Vœlfling-lès-Bouzonville;VOELFLING-LES-BOUZONVILLE;57320;57;MOSELLE;1
57750;;Wœlfling-lès-Sarreguemines;WOELFLING-LES-SARREGUEMINES;57200;57;MOSELLE;1
57751;;Woippy;WOIPPY;57140;57;MOSELLE;1
57752;;Woustviller;WOUSTVILLER;57145;57;MOSELLE;1
57753;;Wuisse;WUISSE;57170;57;MOSELLE;1
57754;;Xanrey;XANREY;57630;57;MOSELLE;1
57755;;Xocourt;XOCOURT;57590;57;MOSELLE;1
57756;;Xouaxange;XOUAXANGE;57830;57;MOSELLE;1
57757;;Yutz;YUTZ;57110;57;MOSELLE;1
57759;;Zarbeling;ZARBELING;57340;57;MOSELLE;1
57760;;Zetting;ZETTING;57115;57;MOSELLE;1
57761;;Zilling;ZILLING;57370;57;MOSELLE;1
57762;;Zimming;ZIMMING;57690;57;MOSELLE;1
57763;;Zommange;ZOMMANGE;57260;57;MOSELLE;1
57764;;Zoufftgen;ZOUFFTGEN;57330;57;MOSELLE;1
57765;;Diesen;DIESEN;57890;57;MOSELLE;1
57767;;Stuckange;STUCKANGE;57110;57;MOSELLE;1
58001;;Achun;ACHUN;58110;58;NIEVRE;1
58002;;Alligny-Cosne;ALLIGNY-COSNE;58200;58;NIEVRE;1
58003;;Alligny-en-Morvan;ALLIGNY-EN-MORVAN;58230;58;NIEVRE;1
58004;;Alluy;ALLUY;58110;58;NIEVRE;1
58005;;Amazy;AMAZY;58190;58;NIEVRE;1
58006;;Anlezy;ANLEZY;58270;58;NIEVRE;1
58007;;Annay;ANNAY;58450;58;NIEVRE;1
58008;;Anthien;ANTHIEN;58800;58;NIEVRE;1
58009;;Arbourse;ARBOURSE;58350;58;NIEVRE;1
58010;;Arleuf;ARLEUF;58430;58;NIEVRE;1
58011;;Armes;ARMES;58500;58;NIEVRE;1
58012;;Arquian;ARQUIAN;58310;58;NIEVRE;1
58013;;Arthel;ARTHEL;58700;58;NIEVRE;1
58014;;Arzembouy;ARZEMBOUY;58700;58;NIEVRE;1
58015;;Asnan;ASNAN;58420;58;NIEVRE;1
58016;;Asnois;ASNOIS;58190;58;NIEVRE;1
58017;;Aunay-en-Bazois;AUNAY-EN-BAZOIS;58110;58;NIEVRE;1
58018;;Authiou;AUTHIOU;58700;58;NIEVRE;1
58019;;Avrée;AVREE;58170;58;NIEVRE;1
58020;;Avril-sur-Loire;AVRIL-SUR-LOIRE;58300;58;NIEVRE;1
58021;;Azy-le-Vif;AZY-LE-VIF;58240;58;NIEVRE;1
58022;;Balleray;BALLERAY;58130;58;NIEVRE;1
58023;;Bazoches;BAZOCHES;58190;58;NIEVRE;1
58024;;Bazolles;BAZOLLES;58110;58;NIEVRE;1
58025;;Béard;BEARD;58160;58;NIEVRE;1
58026;;Beaulieu;BEAULIEU;58420;58;NIEVRE;1
58027;;Beaumont-la-Ferrière;BEAUMONT-LA-FERRIERE;58700;58;NIEVRE;1
58028;;Beaumont-Sardolles;BEAUMONT-SARDOLLES;58270;58;NIEVRE;1
58029;;Beuvron;BEUVRON;58210;58;NIEVRE;1
58030;;Biches;BICHES;58110;58;NIEVRE;1
58031;;Billy-Chevannes;BILLY-CHEVANNES;58270;58;NIEVRE;1
58032;;Billy-sur-Oisy;BILLY-SUR-OISY;58500;58;NIEVRE;1
58033;;Bitry;BITRY;58310;58;NIEVRE;1
58034;;Blismes;BLISMES;58120;58;NIEVRE;1
58035;;Bona;BONA;58330;58;NIEVRE;1
58036;;Bouhy;BOUHY;58310;58;NIEVRE;1
58037;;Brassy;BRASSY;58140;58;NIEVRE;1
58038;;Breugnon;BREUGNON;58460;58;NIEVRE;1
58039;;Brèves;BREVES;58530;58;NIEVRE;1
58040;;Brinay;BRINAY;58110;58;NIEVRE;1
58041;;Brinon-sur-Beuvron;BRINON-SUR-BEUVRON;58420;58;NIEVRE;1
58042;;Bulcy;BULCY;58400;58;NIEVRE;1
58043;;Bussy-la-Pesle;BUSSY-LA-PESLE;58420;58;NIEVRE;1
58044;La;Celle-sur-Loire;CELLE-SUR-LOIRE;58440;58;NIEVRE;1
58045;La;Celle-sur-Nièvre;CELLE-SUR-NIEVRE;58700;58;NIEVRE;1
58046;;Cercy-la-Tour;CERCY-LA-TOUR;58340;58;NIEVRE;1
58047;;Cervon;CERVON;58800;58;NIEVRE;1
58048;;Cessy-les-Bois;CESSY-LES-BOIS;58220;58;NIEVRE;1
58049;;Chalaux;CHALAUX;58140;58;NIEVRE;1
58050;;Challement;CHALLEMENT;58420;58;NIEVRE;1
58051;;Challuy;CHALLUY;58000;58;NIEVRE;1
58052;;Champallement;CHAMPALLEMENT;58420;58;NIEVRE;1
58053;;Champlemy;CHAMPLEMY;58210;58;NIEVRE;1
58054;;Champlin;CHAMPLIN;58700;58;NIEVRE;1
58055;;Champvert;CHAMPVERT;58300;58;NIEVRE;1
58056;;Champvoux;CHAMPVOUX;58400;58;NIEVRE;1
58057;;Chantenay-Saint-Imbert;CHANTENAY-SAINT-IMBERT;58240;58;NIEVRE;1
58058;La;Chapelle-Saint-André;CHAPELLE-SAINT-ANDRE;58210;58;NIEVRE;1
58059;La;Charité-sur-Loire;CHARITE-SUR-LOIRE;58400;58;NIEVRE;1
58060;;Charrin;CHARRIN;58300;58;NIEVRE;1
58061;;Chasnay;CHASNAY;58350;58;NIEVRE;1
58062;;(VILLE);CHATEAU-CHINON;58120;58;NIEVRE;1
58063;;(CAMPAGNE);CHATEAU-CHINON;58120;58;NIEVRE;1
58064;;Châteauneuf-Val-de-Bargis;CHATEAUNEUF-VAL-DE-BARGIS;58350;58;NIEVRE;1
58065;;Châtillon-en-Bazois;CHATILLON-EN-BAZOIS;58110;58;NIEVRE;1
58066;;Châtin;CHATIN;58120;58;NIEVRE;1
58067;;Chaulgnes;CHAULGNES;58400;58;NIEVRE;1
58068;;Chaumard;CHAUMARD;58120;58;NIEVRE;1
58069;;Chaumot;CHAUMOT;58800;58;NIEVRE;1
58070;;Chazeuil;CHAZEUIL;58700;58;NIEVRE;1
58071;;Chevannes-Changy;CHEVANNES-CHANGY;58420;58;NIEVRE;1
58072;;Chevenon;CHEVENON;58160;58;NIEVRE;1
58073;;Chevroches;CHEVROCHES;58500;58;NIEVRE;1
58074;;Chiddes;CHIDDES;58170;58;NIEVRE;1
58075;;Chitry-les-Mines;CHITRY-LES-MINES;58800;58;NIEVRE;1
58076;;Chougny;CHOUGNY;58110;58;NIEVRE;1
58077;;Ciez;CIEZ;58220;58;NIEVRE;1
58078;;Cizely;CIZELY;58270;58;NIEVRE;1
58079;;Clamecy;CLAMECY;58500;58;NIEVRE;1
58080;La;Collancelle;COLLANCELLE;58800;58;NIEVRE;1
58081;;Colméry;COLMERY;58350;58;NIEVRE;1
58082;;Corancy;CORANCY;58120;58;NIEVRE;1
58083;;Corbigny;CORBIGNY;58800;58;NIEVRE;1
58084;;Corvol-d'Embernard;CORVOL-D'EMBERNARD;58210;58;NIEVRE;1
58085;;Corvol-l'Orgueilleux;CORVOL-L'ORGUEILLEUX;58460;58;NIEVRE;1
58086;;Cosne-Cours-sur-Loire;COSNE-COURS-SUR-LOIRE;58200;58;NIEVRE;1
58087;;Cossaye;COSSAYE;58300;58;NIEVRE;1
58088;;Coulanges-lès-Nevers;COULANGES-LES-NEVERS;58660;58;NIEVRE;1
58089;;Couloutre;COULOUTRE;58220;58;NIEVRE;1
58090;;Courcelles;COURCELLES;58210;58;NIEVRE;1
58092;;Crux-la-Ville;CRUX-LA-VILLE;58330;58;NIEVRE;1
58093;;Cuncy-lès-Varzy;CUNCY-LES-VARZY;58210;58;NIEVRE;1
58094;;Dampierre-sous-Bouhy;DAMPIERRE-SOUS-BOUHY;58310;58;NIEVRE;1
58095;;Decize;DECIZE;58300;58;NIEVRE;1
58096;;Devay;DEVAY;58300;58;NIEVRE;1
58097;;Diennes-Aubigny;DIENNES-AUBIGNY;58340;58;NIEVRE;1
58098;;Dirol;DIROL;58190;58;NIEVRE;1
58099;;Dommartin;DOMMARTIN;58120;58;NIEVRE;1
58100;;Dompierre-sur-Héry;DOMPIERRE-SUR-HERY;58420;58;NIEVRE;1
58101;;Dompierre-sur-Nièvre;DOMPIERRE-SUR-NIEVRE;58350;58;NIEVRE;1
58102;;Donzy;DONZY;58220;58;NIEVRE;1
58103;;Dornecy;DORNECY;58530;58;NIEVRE;1
58104;;Dornes;DORNES;58390;58;NIEVRE;1
58105;;Druy-Parigny;DRUY-PARIGNY;58160;58;NIEVRE;1
58106;;Dun-les-Places;DUN-LES-PLACES;58230;58;NIEVRE;1
58107;;Dun-sur-Grandry;DUN-SUR-GRANDRY;58110;58;NIEVRE;1
58108;;Empury;EMPURY;58140;58;NIEVRE;1
58109;;Entrains-sur-Nohain;ENTRAINS-SUR-NOHAIN;58410;58;NIEVRE;1
58110;;Epiry;EPIRY;58800;58;NIEVRE;1
58111;;Fâchin;FACHIN;58430;58;NIEVRE;1
58112;La;Fermeté;FERMETE;58160;58;NIEVRE;1
58113;;Fertrève;FERTREVE;58270;58;NIEVRE;1
58114;;Fléty;FLETY;58170;58;NIEVRE;1
58115;;Fleury-sur-Loire;FLEURY-SUR-LOIRE;58240;58;NIEVRE;1
58116;;Flez-Cuzy;FLEZ-CUZY;58190;58;NIEVRE;1
58117;;Fourchambault;FOURCHAMBAULT;58600;58;NIEVRE;1
58118;;Fours;FOURS;58250;58;NIEVRE;1
58119;;Frasnay-Reugny;FRASNAY-REUGNY;58270;58;NIEVRE;1
58120;;Gâcogne;GACOGNE;58140;58;NIEVRE;1
58121;;Garchizy;GARCHIZY;58600;58;NIEVRE;1
58122;;Garchy;GARCHY;58150;58;NIEVRE;1
58123;;Germenay;GERMENAY;58800;58;NIEVRE;1
58124;;Germigny-sur-Loire;GERMIGNY-SUR-LOIRE;58320;58;NIEVRE;1
58125;;Gien-sur-Cure;GIEN-SUR-CURE;58230;58;NIEVRE;1
58126;;Gimouille;GIMOUILLE;58470;58;NIEVRE;1
58127;;Giry;GIRY;58700;58;NIEVRE;1
58128;;Glux-en-Glenne;GLUX-EN-GLENNE;58370;58;NIEVRE;1
58129;;Gouloux;GOULOUX;58230;58;NIEVRE;1
58130;;Grenois;GRENOIS;58420;58;NIEVRE;1
58131;;Guérigny;GUERIGNY;58130;58;NIEVRE;1
58132;;Guipy;GUIPY;58420;58;NIEVRE;1
58133;;Héry;HERY;58800;58;NIEVRE;1
58134;;Imphy;IMPHY;58160;58;NIEVRE;1
58135;;Isenay;ISENAY;58290;58;NIEVRE;1
58136;;Jailly;JAILLY;58330;58;NIEVRE;1
58137;;Lamenay-sur-Loire;LAMENAY-SUR-LOIRE;58300;58;NIEVRE;1
58138;;Langeron;LANGERON;58240;58;NIEVRE;1
58139;;Lanty;LANTY;58250;58;NIEVRE;1
58140;;Larochemillay;LAROCHEMILLAY;58370;58;NIEVRE;1
58141;;Lavault-de-Frétoy;LAVAULT-DE-FRETOY;58230;58;NIEVRE;1
58142;;Limanton;LIMANTON;58290;58;NIEVRE;1
58143;;Limon;LIMON;58270;58;NIEVRE;1
58144;;Livry;LIVRY;58240;58;NIEVRE;1
58145;;Lormes;LORMES;58140;58;NIEVRE;1
58146;;Lucenay-lès-Aix;LUCENAY-LES-AIX;58380;58;NIEVRE;1
58147;;Lurcy-le-Bourg;LURCY-LE-BOURG;58700;58;NIEVRE;1
58148;;Luthenay-Uxeloup;LUTHENAY-UXELOUP;58240;58;NIEVRE;1
58149;;Luzy;LUZY;58170;58;NIEVRE;1
58150;;Lys;LYS;58190;58;NIEVRE;1
58151;La;Machine;MACHINE;58260;58;NIEVRE;1
58152;;Magny-Cours;MAGNY-COURS;58470;58;NIEVRE;1
58153;;Magny-Lormes;MAGNY-LORMES;58800;58;NIEVRE;1
58154;La;Maison-Dieu;MAISON-DIEU;58190;58;NIEVRE;1
58155;La;Marche;MARCHE;58400;58;NIEVRE;1
58156;;Marcy;MARCY;58210;58;NIEVRE;1
58157;;Marigny-l'Église;MARIGNY-L'EGLISE;58140;58;NIEVRE;1
58158;;Mars-sur-Allier;MARS-SUR-ALLIER;58240;58;NIEVRE;1
58159;;Marigny-sur-Yonne;MARIGNY-SUR-YONNE;58800;58;NIEVRE;1
58160;;Marzy;MARZY;58180;58;NIEVRE;1
58161;;Maux;MAUX;58290;58;NIEVRE;1
58162;;Menestreau;MENESTREAU;58410;58;NIEVRE;1
58163;;Menou;MENOU;58210;58;NIEVRE;1
58164;;Mesves-sur-Loire;MESVES-SUR-LOIRE;58400;58;NIEVRE;1
58165;;Metz-le-Comte;METZ-LE-COMTE;58190;58;NIEVRE;1
58166;;Mhère;MHERE;58140;58;NIEVRE;1
58167;;Michaugues;MICHAUGUES;58420;58;NIEVRE;1
58168;;Millay;MILLAY;58170;58;NIEVRE;1
58169;;Moissy-Moulinot;MOISSY-MOULINOT;58190;58;NIEVRE;1
58170;;Monceaux-le-Comte;MONCEAUX-LE-COMTE;58190;58;NIEVRE;1
58171;;Montapas;MONTAPAS;58110;58;NIEVRE;1
58172;;Montambert;MONTAMBERT;58250;58;NIEVRE;1
58173;;Montaron;MONTARON;58250;58;NIEVRE;1
58174;;Montenoison;MONTENOISON;58700;58;NIEVRE;1
58175;;Mont-et-Marré;MONT-ET-MARRE;58110;58;NIEVRE;1
58176;;Montigny-aux-Amognes;MONTIGNY-AUX-AMOGNES;58130;58;NIEVRE;1
58177;;Montigny-en-Morvan;MONTIGNY-EN-MORVAN;58120;58;NIEVRE;1
58178;;Montigny-sur-Canne;MONTIGNY-SUR-CANNE;58340;58;NIEVRE;1
58179;;Montreuillon;MONTREUILLON;58800;58;NIEVRE;1
58180;;Montsauche-les-Settons;MONTSAUCHE-LES-SETTONS;58230;58;NIEVRE;1
58181;;Moraches;MORACHES;58420;58;NIEVRE;1
58182;;Moulins-Engilbert;MOULINS-ENGILBERT;58290;58;NIEVRE;1
58183;;Mouron-sur-Yonne;MOURON-SUR-YONNE;58800;58;NIEVRE;1
58184;;Moussy;MOUSSY;58700;58;NIEVRE;1
58185;;Moux-en-Morvan;MOUX-EN-MORVAN;58230;58;NIEVRE;1
58186;;Murlin;MURLIN;58700;58;NIEVRE;1
58187;;Myennes;MYENNES;58440;58;NIEVRE;1
58188;;Nannay;NANNAY;58350;58;NIEVRE;1
58189;;Narcy;NARCY;58400;58;NIEVRE;1
58190;;Neuffontaines;NEUFFONTAINES;58190;58;NIEVRE;1
58191;;Neuilly;NEUILLY;58420;58;NIEVRE;1
58192;;Neuville-lès-Decize;NEUVILLE-LES-DECIZE;58300;58;NIEVRE;1
58193;;Neuvy-sur-Loire;NEUVY-SUR-LOIRE;58450;58;NIEVRE;1
58194;;Nevers;NEVERS;58000;58;NIEVRE;1
58195;La;Nocle-Maulaix;NOCLE-MAULAIX;58250;58;NIEVRE;1
58196;;Nolay;NOLAY;58700;58;NIEVRE;1
58197;;Nuars;NUARS;58190;58;NIEVRE;1
58198;;Oisy;OISY;58500;58;NIEVRE;1
58199;;Onlay;ONLAY;58370;58;NIEVRE;1
58200;;Ouagne;OUAGNE;58500;58;NIEVRE;1
58201;;Oudan;OUDAN;58210;58;NIEVRE;1
58202;;Ougny;OUGNY;58110;58;NIEVRE;1
58203;;Oulon;OULON;58700;58;NIEVRE;1
58204;;Ourouër;OUROUER;58130;58;NIEVRE;1
58205;;Ouroux-en-Morvan;OUROUX-EN-MORVAN;58230;58;NIEVRE;1
58206;;Parigny-la-Rose;PARIGNY-LA-ROSE;58210;58;NIEVRE;1
58207;;Parigny-les-Vaux;PARIGNY-LES-VAUX;58320;58;NIEVRE;1
58208;;Pazy;PAZY;58800;58;NIEVRE;1
58209;;Perroy;PERROY;58220;58;NIEVRE;1
58210;;Planchez;PLANCHEZ;58230;58;NIEVRE;1
58211;;Poil;POIL;58170;58;NIEVRE;1
58212;;Poiseux;POISEUX;58130;58;NIEVRE;1
58213;;Pougny;POUGNY;58200;58;NIEVRE;1
58214;;Pougues-les-Eaux;POUGUES-LES-EAUX;58320;58;NIEVRE;1
58215;;Pouilly-sur-Loire;POUILLY-SUR-LOIRE;58150;58;NIEVRE;1
58216;;Pouques-Lormes;POUQUES-LORMES;58140;58;NIEVRE;1
58217;;Pousseaux;POUSSEAUX;58500;58;NIEVRE;1
58218;;Prémery;PREMERY;58700;58;NIEVRE;1
58219;;Préporché;PREPORCHE;58360;58;NIEVRE;1
58220;;Raveau;RAVEAU;58400;58;NIEVRE;1
58221;;Rémilly;REMILLY;58250;58;NIEVRE;1
58222;;Rix;RIX;58500;58;NIEVRE;1
58223;;Rouy;ROUY;58110;58;NIEVRE;1
58224;;Ruages;RUAGES;58190;58;NIEVRE;1
58225;;Saincaize-Meauce;SAINCAIZE-MEAUCE;58470;58;NIEVRE;1
58226;;Saint-Agnan;SAINT-AGNAN;58230;58;NIEVRE;1
58227;;Saint-Amand-en-Puisaye;SAINT-AMAND-EN-PUISAYE;58310;58;NIEVRE;1
58228;;Saint-Andelain;SAINT-ANDELAIN;58150;58;NIEVRE;1
58229;;Saint-André-en-Morvan;SAINT-ANDRE-EN-MORVAN;58140;58;NIEVRE;1
58230;;Saint-Aubin-des-Chaumes;SAINT-AUBIN-DES-CHAUMES;58190;58;NIEVRE;1
58231;;Saint-Aubin-les-Forges;SAINT-AUBIN-LES-FORGES;58130;58;NIEVRE;1
58232;;Saint-Benin-d'Azy;SAINT-BENIN-D'AZY;58270;58;NIEVRE;1
58233;;Saint-Benin-des-Bois;SAINT-BENIN-DES-BOIS;58330;58;NIEVRE;1
58234;;Saint-Bonnot;SAINT-BONNOT;58700;58;NIEVRE;1
58235;;Saint-Brisson;SAINT-BRISSON;58230;58;NIEVRE;1
58236;;Sainte-Colombe-des-Bois;SAINTE-COLOMBE-DES-BOIS;58220;58;NIEVRE;1
58237;;Saint-Didier;SAINT-DIDIER;58190;58;NIEVRE;1
58238;;Saint-Éloi;SAINT-ELOI;58000;58;NIEVRE;1
58239;;Saint-Firmin;SAINT-FIRMIN;58270;58;NIEVRE;1
58240;;Saint-Franchy;SAINT-FRANCHY;58330;58;NIEVRE;1
58241;;Saint-Germain-Chassenay;SAINT-GERMAIN-CHASSENAY;58300;58;NIEVRE;1
58242;;Saint-Germain-des-Bois;SAINT-GERMAIN-DES-BOIS;58210;58;NIEVRE;1
58243;;Saint-Gratien-Savigny;SAINT-GRATIEN-SAVIGNY;58340;58;NIEVRE;1
58244;;Saint-Hilaire-en-Morvan;SAINT-HILAIRE-EN-MORVAN;58120;58;NIEVRE;1
58245;;Saint-Hilaire-Fontaine;SAINT-HILAIRE-FONTAINE;58300;58;NIEVRE;1
58246;;Saint-Honoré-les-Bains;SAINT-HONORE-LES-BAINS;58360;58;NIEVRE;1
58247;;Saint-Jean-aux-Amognes;SAINT-JEAN-AUX-AMOGNES;58270;58;NIEVRE;1
58248;;Saint-Laurent-l'Abbaye;SAINT-LAURENT-L'ABBAYE;58150;58;NIEVRE;1
58249;;Saint-Léger-de-Fougeret;SAINT-LEGER-DE-FOUGERET;58120;58;NIEVRE;1
58250;;Saint-Léger-des-Vignes;SAINT-LEGER-DES-VIGNES;58300;58;NIEVRE;1
58251;;Saint-Loup;SAINT-LOUP;58200;58;NIEVRE;1
58252;;Saint-Malo-en-Donziois;SAINT-MALO-EN-DONZIOIS;58350;58;NIEVRE;1
58253;;Sainte-Marie;SAINTE-MARIE;58330;58;NIEVRE;1
58254;;Saint-Martin-d'Heuille;SAINT-MARTIN-D'HEUILLE;58130;58;NIEVRE;1
58255;;Saint-Martin-du-Puy;SAINT-MARTIN-DU-PUY;58140;58;NIEVRE;1
58256;;Saint-Martin-sur-Nohain;SAINT-MARTIN-SUR-NOHAIN;58150;58;NIEVRE;1
58257;;Saint-Maurice;SAINT-MAURICE;58330;58;NIEVRE;1
58258;;Saint-Ouen-sur-Loire;SAINT-OUEN-SUR-LOIRE;58160;58;NIEVRE;1
58259;;Saint-Parize-en-Viry;SAINT-PARIZE-EN-VIRY;58300;58;NIEVRE;1
58260;;Saint-Parize-le-Châtel;SAINT-PARIZE-LE-CHATEL;58490;58;NIEVRE;1
58261;;Saint-Père;SAINT-PERE;58200;58;NIEVRE;1
58262;;Saint-Péreuse;SAINT-PEREUSE;58110;58;NIEVRE;1
58263;;Saint-Pierre-du-Mont;SAINT-PIERRE-DU-MONT;58210;58;NIEVRE;1
58264;;Saint-Pierre-le-Moûtier;SAINT-PIERRE-LE-MOUTIER;58240;58;NIEVRE;1
58265;;Saint-Quentin-sur-Nohain;SAINT-QUENTIN-SUR-NOHAIN;58150;58;NIEVRE;1
58266;;Saint-Révérien;SAINT-REVERIEN;58420;58;NIEVRE;1
58267;;Saint-Saulge;SAINT-SAULGE;58330;58;NIEVRE;1
58268;;Saint-Seine;SAINT-SEINE;58250;58;NIEVRE;1
58269;;Saint-Sulpice;SAINT-SULPICE;58270;58;NIEVRE;1
58270;;Saint-Vérain;SAINT-VERAIN;58310;58;NIEVRE;1
58271;;Saizy;SAIZY;58190;58;NIEVRE;1
58272;;Sardy-lès-Épiry;SARDY-LES-EPIRY;58800;58;NIEVRE;1
58273;;Sauvigny-les-Bois;SAUVIGNY-LES-BOIS;58160;58;NIEVRE;1
58274;;Savigny-Poil-Fol;SAVIGNY-POIL-FOL;58170;58;NIEVRE;1
58275;;Saxi-Bourdon;SAXI-BOURDON;58330;58;NIEVRE;1
58276;;Sémelay;SEMELAY;58360;58;NIEVRE;1
58277;;Sermages;SERMAGES;58290;58;NIEVRE;1
58278;;Sermoise-sur-Loire;SERMOISE-SUR-LOIRE;58000;58;NIEVRE;1
58279;;Sichamps;SICHAMPS;58700;58;NIEVRE;1
58280;;Sougy-sur-Loire;SOUGY-SUR-LOIRE;58300;58;NIEVRE;1
58281;;Suilly-la-Tour;SUILLY-LA-TOUR;58150;58;NIEVRE;1
58282;;Surgy;SURGY;58500;58;NIEVRE;1
58283;;Taconnay;TACONNAY;58420;58;NIEVRE;1
58284;;Talon;TALON;58190;58;NIEVRE;1
58285;;Tamnay-en-Bazois;TAMNAY-EN-BAZOIS;58110;58;NIEVRE;1
58286;;Tannay;TANNAY;58190;58;NIEVRE;1
58287;;Tazilly;TAZILLY;58170;58;NIEVRE;1
58288;;Teigny;TEIGNY;58190;58;NIEVRE;1
58289;;Ternant;TERNANT;58250;58;NIEVRE;1
58290;;Thaix;THAIX;58250;58;NIEVRE;1
58291;;Thianges;THIANGES;58260;58;NIEVRE;1
58292;;Tintury;TINTURY;58110;58;NIEVRE;1
58293;;Toury-Lurcy;TOURY-LURCY;58300;58;NIEVRE;1
58294;;Toury-sur-Jour;TOURY-SUR-JOUR;58240;58;NIEVRE;1
58295;;Tracy-sur-Loire;TRACY-SUR-LOIRE;58150;58;NIEVRE;1
58296;;Tresnay;TRESNAY;58240;58;NIEVRE;1
58297;;Trois-Vèvres;TROIS-VEVRES;58260;58;NIEVRE;1
58298;;Tronsanges;TRONSANGES;58400;58;NIEVRE;1
58299;;Trucy-l'Orgueilleux;TRUCY-L'ORGUEILLEUX;58460;58;NIEVRE;1
58300;;Urzy;URZY;58130;58;NIEVRE;1
58301;;Vandenesse;VANDENESSE;58290;58;NIEVRE;1
58302;;Varennes-lès-Narcy;VARENNES-LES-NARCY;58400;58;NIEVRE;1
58303;;Varennes-Vauzelles;VARENNES-VAUZELLES;58640;58;NIEVRE;1
58304;;Varzy;VARZY;58210;58;NIEVRE;1
58305;;Vauclaix;VAUCLAIX;58140;58;NIEVRE;1
58306;;Verneuil;VERNEUIL;58300;58;NIEVRE;1
58307;;Vielmanay;VIELMANAY;58150;58;NIEVRE;1
58308;;Vignol;VIGNOL;58190;58;NIEVRE;1
58309;;Villapourçon;VILLAPOURCON;58370;58;NIEVRE;1
58310;;Villiers-le-Sec;VILLIERS-LE-SEC;58210;58;NIEVRE;1
58311;;Ville-Langy;VILLE-LANGY;58270;58;NIEVRE;1
58312;;Villiers-sur-Yonne;VILLIERS-SUR-YONNE;58500;58;NIEVRE;1
58313;;Vitry-Laché;VITRY-LACHE;58420;58;NIEVRE;1
59001;;Abancourt;ABANCOURT;59265;59;NORD;1
59002;;Abscon;ABSCON;59215;59;NORD;1
59003;;Aibes;AIBES;59149;59;NORD;1
59004;;Aix;AIX;59310;59;NORD;1
59005;;Allennes-les-Marais;ALLENNES-LES-MARAIS;59251;59;NORD;1
59006;;Amfroipret;AMFROIPRET;59144;59;NORD;1
59007;;Anhiers;ANHIERS;59194;59;NORD;1
59008;;Aniche;ANICHE;59580;59;NORD;1
59009;;Villeneuve-d'Ascq;VILLENEUVE-D'ASCQ;59491;59;NORD;1
59010;;Anneux;ANNEUX;59400;59;NORD;1
59011;;Annœullin;ANNOEULLIN;59112;59;NORD;1
59012;;Anor;ANOR;59186;59;NORD;1
59013;;Anstaing;ANSTAING;59152;59;NORD;1
59014;;Anzin;ANZIN;59410;59;NORD;1
59015;;Arleux;ARLEUX;59151;59;NORD;1
59016;;Armbouts-Cappel;ARMBOUTS-CAPPEL;59380;59;NORD;1
59017;;Armentières;ARMENTIERES;59280;59;NORD;1
59018;;Arnèke;ARNEKE;59285;59;NORD;1
59019;;Artres;ARTRES;59269;59;NORD;1
59021;;Assevent;ASSEVENT;59600;59;NORD;1
59022;;Attiches;ATTICHES;59551;59;NORD;1
59023;;Aubencheul-au-Bac;AUBENCHEUL-AU-BAC;59265;59;NORD;1
59024;;Auberchicourt;AUBERCHICOURT;59165;59;NORD;1
59025;;Aubers;AUBERS;59249;59;NORD;1
59026;;Aubigny-au-Bac;AUBIGNY-AU-BAC;59265;59;NORD;1
59027;;Aubry-du-Hainaut;AUBRY-DU-HAINAUT;59494;59;NORD;1
59028;;Auby;AUBY;59950;59;NORD;1
59029;;Auchy-lez-Orchies;AUCHY-LEZ-ORCHIES;59310;59;NORD;1
59031;;Audignies;AUDIGNIES;59570;59;NORD;1
59032;;Aulnoy-lez-Valenciennes;AULNOY-LEZ-VALENCIENNES;59300;59;NORD;1
59033;;Aulnoye-Aymeries;AULNOYE-AYMERIES;59620;59;NORD;1
59034;;Avelin;AVELIN;59710;59;NORD;1
59035;;Avesnelles;AVESNELLES;59440;59;NORD;1
59036;;Avesnes-sur-Helpe;AVESNES-SUR-HELPE;59440;59;NORD;1
59037;;Avesnes-les-Aubert;AVESNES-LES-AUBERT;59129;59;NORD;1
59038;;Avesnes-le-Sec;AVESNES-LE-SEC;59296;59;NORD;1
59039;;Awoingt;AWOINGT;59400;59;NORD;1
59041;;Bachant;BACHANT;59138;59;NORD;1
59042;;Bachy;BACHY;59830;59;NORD;1
59043;;Bailleul;BAILLEUL;59270;59;NORD;1
59044;;Baisieux;BAISIEUX;59780;59;NORD;1
59045;;Baives;BAIVES;59132;59;NORD;1
59046;;Bambecque;BAMBECQUE;59470;59;NORD;1
59047;;Banteux;BANTEUX;59266;59;NORD;1
59048;;Bantigny;BANTIGNY;59554;59;NORD;1
59049;;Bantouzelle;BANTOUZELLE;59266;59;NORD;1
59050;;Bas-Lieu;BAS-LIEU;59440;59;NORD;1
59051;La;Bassée;BASSEE;59480;59;NORD;1
59052;;Bauvin;BAUVIN;59221;59;NORD;1
59053;;Bavay;BAVAY;59570;59;NORD;1
59054;;Bavinchove;BAVINCHOVE;59670;59;NORD;1
59055;;Bazuel;BAZUEL;59360;59;NORD;1
59056;;Beaucamps-Ligny;BEAUCAMPS-LIGNY;59134;59;NORD;1
59057;;Beaudignies;BEAUDIGNIES;59530;59;NORD;1
59058;;Beaufort;BEAUFORT;59330;59;NORD;1
59059;;Beaumont-en-Cambrésis;BEAUMONT-EN-CAMBRESIS;59540;59;NORD;1
59060;;Beaurain;BEAURAIN;59730;59;NORD;1
59061;;Beaurepaire-sur-Sambre;BEAUREPAIRE-SUR-SAMBRE;59550;59;NORD;1
59062;;Beaurieux;BEAURIEUX;59740;59;NORD;1
59063;;Beauvois-en-Cambrésis;BEAUVOIS-EN-CAMBRESIS;59157;59;NORD;1
59064;;Bellaing;BELLAING;59135;59;NORD;1
59065;;Bellignies;BELLIGNIES;59570;59;NORD;1
59066;;Bérelles;BERELLES;59740;59;NORD;1
59067;;Bergues;BERGUES;59380;59;NORD;1
59068;;Berlaimont;BERLAIMONT;59145;59;NORD;1
59069;;Bermerain;BERMERAIN;59213;59;NORD;1
59070;;Bermeries;BERMERIES;59570;59;NORD;1
59071;;Bersée;BERSEE;59235;59;NORD;1
59072;;Bersillies;BERSILLIES;59600;59;NORD;1
59073;;Berthen;BERTHEN;59270;59;NORD;1
59074;;Bertry;BERTRY;59980;59;NORD;1
59075;;Béthencourt;BETHENCOURT;59540;59;NORD;1
59076;;Bettignies;BETTIGNIES;59600;59;NORD;1
59077;;Bettrechies;BETTRECHIES;59570;59;NORD;1
59078;;Beugnies;BEUGNIES;59216;59;NORD;1
59079;;Beuvrages;BEUVRAGES;59192;59;NORD;1
59080;;Beuvry-la-Forêt;BEUVRY-LA-FORET;59310;59;NORD;1
59081;;Bévillers;BEVILLERS;59217;59;NORD;1
59082;;Bierne;BIERNE;59380;59;NORD;1
59083;;Bissezeele;BISSEZEELE;59380;59;NORD;1
59084;;Blaringhem;BLARINGHEM;59173;59;NORD;1
59085;;Blécourt;BLECOURT;59554;59;NORD;1
59086;;Boeschepe;BOESCHEPE;59299;59;NORD;1
59087;;Boëseghem;BOESEGHEM;59189;59;NORD;1
59088;;Bois-Grenier;BOIS-GRENIER;59280;59;NORD;1
59089;;Bollezeele;BOLLEZEELE;59470;59;NORD;1
59090;;Bondues;BONDUES;59910;59;NORD;1
59091;;Borre;BORRE;59190;59;NORD;1
59092;;Bouchain;BOUCHAIN;59111;59;NORD;1
59093;;Boulogne-sur-Helpe;BOULOGNE-SUR-HELPE;59440;59;NORD;1
59094;;Bourbourg;BOURBOURG;59630;59;NORD;1
59096;;Bourghelles;BOURGHELLES;59830;59;NORD;1
59097;;Boursies;BOURSIES;62147;59;PAS DE CALAIS;1
59098;;Bousbecque;BOUSBECQUE;59166;59;NORD;1
59099;;Bousies;BOUSIES;59222;59;NORD;1
59100;;Bousignies;BOUSIGNIES;59178;59;NORD;1
59101;;Bousignies-sur-Roc;BOUSIGNIES-SUR-ROC;59149;59;NORD;1
59102;;Boussières-en-Cambrésis;BOUSSIERES-EN-CAMBRESIS;59217;59;NORD;1
59103;;Boussières-sur-Sambre;BOUSSIERES-SUR-SAMBRE;59330;59;NORD;1
59104;;Boussois;BOUSSOIS;59168;59;NORD;1
59105;;Bouvignies;BOUVIGNIES;59870;59;NORD;1
59106;;Bouvines;BOUVINES;59830;59;NORD;1
59107;;Bray-Dunes;BRAY-DUNES;59123;59;NORD;1
59108;;Briastre;BRIASTRE;59730;59;NORD;1
59109;;Brillon;BRILLON;59178;59;NORD;1
59110;;Brouckerque;BROUCKERQUE;59630;59;NORD;1
59111;;Broxeele;BROXEELE;59470;59;NORD;1
59112;;Bruay-sur-l'Escaut;BRUAY-SUR-L'ESCAUT;59860;59;NORD;1
59113;;Bruille-lez-Marchiennes;BRUILLE-LEZ-MARCHIENNES;59490;59;NORD;1
59114;;Bruille-Saint-Amand;BRUILLE-SAINT-AMAND;59199;59;NORD;1
59115;;Brunémont;BRUNEMONT;59151;59;NORD;1
59116;;Bry;BRY;59144;59;NORD;1
59117;;Bugnicourt;BUGNICOURT;59151;59;NORD;1
59118;;Busigny;BUSIGNY;59137;59;NORD;1
59119;;Buysscheure;BUYSSCHEURE;59285;59;NORD;1
59120;;Caëstre;CAESTRE;59190;59;NORD;1
59121;;Cagnoncles;CAGNONCLES;59161;59;NORD;1
59122;;Cambrai;CAMBRAI;59400;59;NORD;1
59123;;Camphin-en-Carembault;CAMPHIN-EN-CAREMBAULT;59133;59;NORD;1
59124;;Camphin-en-Pévèle;CAMPHIN-EN-PEVELE;59780;59;NORD;1
59125;;Cantaing-sur-Escaut;CANTAING-SUR-ESCAUT;59267;59;NORD;1
59126;;Cantin;CANTIN;59169;59;NORD;1
59127;;Capelle;CAPELLE;59213;59;NORD;1
59128;;Capinghem;CAPINGHEM;59160;59;NORD;1
59129;;Cappelle-en-Pévèle;CAPPELLE-EN-PEVELE;59242;59;NORD;1
59130;;Cappelle-Brouck;CAPPELLE-BROUCK;59630;59;NORD;1
59131;;Cappelle-la-Grande;CAPPELLE-LA-GRANDE;59180;59;NORD;1
59132;;Carnières;CARNIERES;59217;59;NORD;1
59133;;Carnin;CARNIN;59112;59;NORD;1
59134;;Cartignies;CARTIGNIES;59244;59;NORD;1
59135;;Cassel;CASSEL;59670;59;NORD;1
59136;Le;Cateau-Cambrésis;CATEAU-CAMBRESIS;59360;59;NORD;1
59137;;Catillon-sur-Sambre;CATILLON-SUR-SAMBRE;59360;59;NORD;1
59138;;Cattenières;CATTENIERES;59217;59;NORD;1
59139;;Caudry;CAUDRY;59540;59;NORD;1
59140;;Caullery;CAULLERY;59191;59;NORD;1
59141;;Cauroir;CAUROIR;59400;59;NORD;1
59142;;Cerfontaine;CERFONTAINE;59680;59;NORD;1
59143;La;Chapelle-d'Armentières;CHAPELLE-D'ARMENTIERES;59930;59;NORD;1
59144;;Château-l'Abbaye;CHATEAU-L'ABBAYE;59230;59;NORD;1
59145;;Chemy;CHEMY;59147;59;NORD;1
59146;;Chéreng;CHERENG;59152;59;NORD;1
59147;;Choisies;CHOISIES;59740;59;NORD;1
59148;;Clairfayts;CLAIRFAYTS;59740;59;NORD;1
59149;;Clary;CLARY;59225;59;NORD;1
59150;;Cobrieux;COBRIEUX;59830;59;NORD;1
59151;;Colleret;COLLERET;59680;59;NORD;1
59152;;Comines;COMINES;59560;59;NORD;1
59153;;Condé-sur-l'Escaut;CONDE-SUR-L'ESCAUT;59163;59;NORD;1
59154;;Coudekerque-Village;COUDEKERQUE-VILLAGE;59380;59;NORD;1
59155;;Coudekerque-Branche;COUDEKERQUE-BRANCHE;59210;59;NORD;1
59156;;Courchelettes;COURCHELETTES;59552;59;NORD;1
59157;;Cousolre;COUSOLRE;59149;59;NORD;1
59158;;Coutiches;COUTICHES;59310;59;NORD;1
59159;;Craywick;CRAYWICK;59279;59;NORD;1
59160;;Crespin;CRESPIN;59154;59;NORD;1
59161;;Crèvecœur-sur-l'Escaut;CREVECOEUR-SUR-L'ESCAUT;59258;59;NORD;1
59162;;Crochte;CROCHTE;59380;59;NORD;1
59163;;Croix;CROIX;59170;59;NORD;1
59164;;Croix-Caluyau;CROIX-CALUYAU;59222;59;NORD;1
59165;;Cuincy;CUINCY;59553;59;NORD;1
59166;;Curgies;CURGIES;59990;59;NORD;1
59167;;Cuvillers;CUVILLERS;59554;59;NORD;1
59168;;Cysoing;CYSOING;59830;59;NORD;1
59169;;Damousies;DAMOUSIES;59680;59;NORD;1
59170;;Dechy;DECHY;59187;59;NORD;1
59171;;Dehéries;DEHERIES;59127;59;NORD;1
59172;;Denain;DENAIN;59220;59;NORD;1
59173;;Deûlémont;DEULEMONT;59890;59;NORD;1
59174;;Dimechaux;DIMECHAUX;59740;59;NORD;1
59175;;Dimont;DIMONT;59216;59;NORD;1
59176;;Doignies;DOIGNIES;62147;59;PAS DE CALAIS;1
59177;;Dompierre-sur-Helpe;DOMPIERRE-SUR-HELPE;59440;59;NORD;1
59178;;Douai;DOUAI;59500;59;NORD;1
59179;;Douchy-les-Mines;DOUCHY-LES-MINES;59282;59;NORD;1
59180;Le;Doulieu;DOULIEU;59940;59;NORD;1
59181;;Dourlers;DOURLERS;59440;59;NORD;1
59182;;Drincham;DRINCHAM;59630;59;NORD;1
59183;;Dunkerque;DUNKERQUE;59140;59;NORD;1
59184;;Ebblinghem;EBBLINGHEM;59173;59;NORD;1
59185;;Écaillon;ECAILLON;59176;59;NORD;1
59186;;Eccles;ECCLES;59740;59;NORD;1
59187;;Éclaibes;ECLAIBES;59330;59;NORD;1
59188;;Écuélin;ECUELIN;59620;59;NORD;1
59189;;Eecke;EECKE;59114;59;NORD;1
59190;;Élesmes;ELESMES;59600;59;NORD;1
59191;;Élincourt;ELINCOURT;59127;59;NORD;1
59192;;Émerchicourt;EMERCHICOURT;59580;59;NORD;1
59193;;Emmerin;EMMERIN;59320;59;NORD;1
59194;;Englefontaine;ENGLEFONTAINE;59530;59;NORD;1
59195;;Englos;ENGLOS;59320;59;NORD;1
59196;;Ennetières-en-Weppes;ENNETIERES-EN-WEPPES;59320;59;NORD;1
59197;;Ennevelin;ENNEVELIN;59710;59;NORD;1
59198;;Eppe-Sauvage;EPPE-SAUVAGE;59132;59;NORD;1
59199;;Erchin;ERCHIN;59169;59;NORD;1
59200;;Eringhem;ERINGHEM;59470;59;NORD;1
59201;;Erquinghem-le-Sec;ERQUINGHEM-LE-SEC;59320;59;NORD;1
59202;;Erquinghem-Lys;ERQUINGHEM-LYS;59193;59;NORD;1
59203;;Erre;ERRE;59171;59;NORD;1
59204;;Escarmain;ESCARMAIN;59213;59;NORD;1
59205;;Escaudain;ESCAUDAIN;59124;59;NORD;1
59206;;Escaudœuvres;ESCAUDOEUVRES;59161;59;NORD;1
59207;;Escautpont;ESCAUTPONT;59278;59;NORD;1
59208;;Escobecques;ESCOBECQUES;59320;59;NORD;1
59209;;Esnes;ESNES;59127;59;NORD;1
59210;;Esquelbecq;ESQUELBECQ;59470;59;NORD;1
59211;;Esquerchin;ESQUERCHIN;59553;59;NORD;1
59212;;Estaires;ESTAIRES;59940;59;NORD;1
59213;;Estourmel;ESTOURMEL;59400;59;NORD;1
59214;;Estrées;ESTREES;59151;59;NORD;1
59215;;Estreux;ESTREUX;59990;59;NORD;1
59216;;Eswars;ESWARS;59400;59;NORD;1
59217;;Eth;ETH;59144;59;NORD;1
59218;;Étrœungt;ETROEUNGT;59219;59;NORD;1
59219;;Estrun;ESTRUN;59295;59;NORD;1
59220;;Faches-Thumesnil;FACHES-THUMESNIL;59155;59;NORD;1
59221;;Famars;FAMARS;59300;59;NORD;1
59222;;Faumont;FAUMONT;59310;59;NORD;1
59223;Le;Favril;FAVRIL;59550;59;NORD;1
59224;;Féchain;FECHAIN;59247;59;NORD;1
59225;;Feignies;FEIGNIES;59750;59;NORD;1
59226;;Felleries;FELLERIES;59740;59;NORD;1
59227;;Fenain;FENAIN;59179;59;NORD;1
59228;;Férin;FERIN;59169;59;NORD;1
59229;;Féron;FERON;59610;59;NORD;1
59230;;Ferrière-la-Grande;FERRIERE-LA-GRANDE;59680;59;NORD;1
59231;;Ferrière-la-Petite;FERRIERE-LA-PETITE;59680;59;NORD;1
59232;La;Flamengrie;FLAMENGRIE;59570;59;NORD;1
59233;;Flaumont-Waudrechies;FLAUMONT-WAUDRECHIES;59440;59;NORD;1
59234;;Flers-en-Escrebieux;FLERS-EN-ESCREBIEUX;59128;59;NORD;1
59236;;Flesquières;FLESQUIERES;59267;59;NORD;1
59237;;Flêtre;FLETRE;59270;59;NORD;1
59238;;Flines-lès-Mortagne;FLINES-LES-MORTAGNE;59158;59;NORD;1
59239;;Flines-lez-Raches;FLINES-LEZ-RACHES;59148;59;NORD;1
59240;;Floursies;FLOURSIES;59440;59;NORD;1
59241;;Floyon;FLOYON;59219;59;NORD;1
59242;;Fontaine-au-Bois;FONTAINE-AU-BOIS;59550;59;NORD;1
59243;;Fontaine-au-Pire;FONTAINE-AU-PIRE;59157;59;NORD;1
59244;;Fontaine-Notre-Dame;FONTAINE-NOTRE-DAME;59400;59;NORD;1
59246;;Forest-en-Cambrésis;FOREST-EN-CAMBRESIS;59222;59;NORD;1
59247;;Forest-sur-Marque;FOREST-SUR-MARQUE;59510;59;NORD;1
59249;;Fourmies;FOURMIES;59610;59;NORD;1
59250;;Fournes-en-Weppes;FOURNES-EN-WEPPES;59134;59;NORD;1
59251;;Frasnoy;FRASNOY;59530;59;NORD;1
59252;;Frelinghien;FRELINGHIEN;59236;59;NORD;1
59253;;Fresnes-sur-Escaut;FRESNES-SUR-ESCAUT;59970;59;NORD;1
59254;;Fressain;FRESSAIN;59234;59;NORD;1
59255;;Fressies;FRESSIES;59247;59;NORD;1
59256;;Fretin;FRETIN;59273;59;NORD;1
59257;;Fromelles;FROMELLES;59249;59;NORD;1
59258;;Genech;GENECH;59242;59;NORD;1
59259;;Ghissignies;GHISSIGNIES;59530;59;NORD;1
59260;;Ghyvelde;GHYVELDE;59254;59;NORD;1
59261;;Glageon;GLAGEON;59132;59;NORD;1
59262;;Godewaersvelde;GODEWAERSVELDE;59270;59;NORD;1
59263;;Gœulzin;GOEULZIN;59169;59;NORD;1
59264;;Gognies-Chaussée;GOGNIES-CHAUSSEE;59600;59;NORD;1
59265;;Gommegnies;GOMMEGNIES;59144;59;NORD;1
59266;;Gondecourt;GONDECOURT;59147;59;NORD;1
59267;;Gonnelieu;GONNELIEU;59231;59;NORD;1
59268;La;Gorgue;GORGUE;59253;59;NORD;1
59269;;Gouzeaucourt;GOUZEAUCOURT;59231;59;NORD;1
59270;;Grand-Fayt;GRAND-FAYT;59244;59;NORD;1
59271;;Grande-Synthe;GRANDE-SYNTHE;59760;59;NORD;1
59272;;Grand-Fort-Philippe;GRAND-FORT-PHILIPPE;59153;59;NORD;1
59273;;Gravelines;GRAVELINES;59820;59;NORD;1
59274;La;Groise;GROISE;59360;59;NORD;1
59275;;Gruson;GRUSON;59152;59;NORD;1
59276;;Guesnain;GUESNAIN;59287;59;NORD;1
59277;;Gussignies;GUSSIGNIES;59570;59;NORD;1
59278;;Hallennes-lez-Haubourdin;HALLENNES-LEZ-HAUBOURDIN;59320;59;NORD;1
59279;;Halluin;HALLUIN;59250;59;NORD;1
59280;;Hamel;HAMEL;59151;59;NORD;1
59281;;Hantay;HANTAY;59496;59;NORD;1
59282;;Hardifort;HARDIFORT;59670;59;NORD;1
59283;;Hargnies;HARGNIES;59138;59;NORD;1
59284;;Hasnon;HASNON;59178;59;NORD;1
59285;;Haspres;HASPRES;59198;59;NORD;1
59286;;Haubourdin;HAUBOURDIN;59320;59;NORD;1
59287;;Haucourt-en-Cambrésis;HAUCOURT-EN-CAMBRESIS;59191;59;NORD;1
59288;;Haulchin;HAULCHIN;59121;59;NORD;1
59289;;Haussy;HAUSSY;59294;59;NORD;1
59290;;Haut-Lieu;HAUT-LIEU;59440;59;NORD;1
59291;;Hautmont;HAUTMONT;59330;59;NORD;1
59292;;Haveluy;HAVELUY;59255;59;NORD;1
59293;;Haverskerque;HAVERSKERQUE;62350;59;PAS DE CALAIS;1
59294;;Haynecourt;HAYNECOURT;59265;59;NORD;1
59295;;Hazebrouck;HAZEBROUCK;59190;59;NORD;1
59296;;Hecq;HECQ;59530;59;NORD;1
59297;;Hélesmes;HELESMES;59171;59;NORD;1
59299;;Hem;HEM;59510;59;NORD;1
59300;;Hem-Lenglet;HEM-LENGLET;59247;59;NORD;1
59301;;Hergnies;HERGNIES;59199;59;NORD;1
59302;;Hérin;HERIN;59195;59;NORD;1
59303;;Herlies;HERLIES;59134;59;NORD;1
59304;;Herrin;HERRIN;59147;59;NORD;1
59305;;Herzeele;HERZEELE;59470;59;NORD;1
59306;;Hestrud;HESTRUD;59740;59;NORD;1
59307;;Holque;HOLQUE;59143;59;NORD;1
59308;;Hondeghem;HONDEGHEM;59190;59;NORD;1
59309;;Hondschoote;HONDSCHOOTE;59122;59;NORD;1
59310;;Hon-Hergies;HON-HERGIES;59570;59;NORD;1
59311;;Honnechy;HONNECHY;59980;59;NORD;1
59312;;Honnecourt-sur-Escaut;HONNECOURT-SUR-ESCAUT;59266;59;NORD;1
59313;;Hordain;HORDAIN;59111;59;NORD;1
59314;;Hornaing;HORNAING;59171;59;NORD;1
59315;;Houdain-lez-Bavay;HOUDAIN-LEZ-BAVAY;59570;59;NORD;1
59316;;Houplin-Ancoisne;HOUPLIN-ANCOISNE;59263;59;NORD;1
59317;;Houplines;HOUPLINES;59116;59;NORD;1
59318;;Houtkerque;HOUTKERQUE;59470;59;NORD;1
59319;;Hoymille;HOYMILLE;59492;59;NORD;1
59320;;Illies;ILLIES;59480;59;NORD;1
59321;;Inchy;INCHY;59540;59;NORD;1
59322;;Iwuy;IWUY;59141;59;NORD;1
59323;;Jenlain;JENLAIN;59144;59;NORD;1
59324;;Jeumont;JEUMONT;59460;59;NORD;1
59325;;Jolimetz;JOLIMETZ;59530;59;NORD;1
59326;;Killem;KILLEM;59122;59;NORD;1
59327;;Lallaing;LALLAING;59167;59;NORD;1
59328;;Lambersart;LAMBERSART;59130;59;NORD;1
59329;;Lambres-lez-Douai;LAMBRES-LEZ-DOUAI;59552;59;NORD;1
59330;;Landas;LANDAS;59310;59;NORD;1
59331;;Landrecies;LANDRECIES;59550;59;NORD;1
59332;;Lannoy;LANNOY;59390;59;NORD;1
59333;;Larouillies;LAROUILLIES;59219;59;NORD;1
59334;;Lauwin-Planque;LAUWIN-PLANQUE;59553;59;NORD;1
59335;;Lecelles;LECELLES;59226;59;NORD;1
59336;;Lécluse;LECLUSE;59259;59;NORD;1
59337;;Lederzeele;LEDERZEELE;59143;59;NORD;1
59338;;Ledringhem;LEDRINGHEM;59470;59;NORD;1
59339;;Leers;LEERS;59115;59;NORD;1
59340;;Leffrinckoucke;LEFFRINCKOUCKE;59495;59;NORD;1
59341;;Lesdain;LESDAIN;59258;59;NORD;1
59342;;Lez-Fontaine;LEZ-FONTAINE;59740;59;NORD;1
59343;;Lesquin;LESQUIN;59810;59;NORD;1
59344;;Leval;LEVAL;59620;59;NORD;1
59345;;Lewarde;LEWARDE;59287;59;NORD;1
59346;;Lezennes;LEZENNES;59260;59;NORD;1
59347;;Liessies;LIESSIES;59740;59;NORD;1
59348;;Lieu-Saint-Amand;LIEU-SAINT-AMAND;59111;59;NORD;1
59349;;Ligny-en-Cambrésis;LIGNY-EN-CAMBRESIS;59191;59;NORD;1
59350;;Lille;LILLE;59000;59;NORD;1
59351;;Limont-Fontaine;LIMONT-FONTAINE;59330;59;NORD;1
59352;;Linselles;LINSELLES;59126;59;NORD;1
59353;;Locquignol;LOCQUIGNOL;59530;59;NORD;1
59354;;Loffre;LOFFRE;59182;59;NORD;1
59356;;Lompret;LOMPRET;59840;59;NORD;1
59357;La;Longueville;LONGUEVILLE;59570;59;NORD;1
59358;;Looberghe;LOOBERGHE;59630;59;NORD;1
59359;;Loon-Plage;LOON-PLAGE;59279;59;NORD;1
59360;;Loos;LOOS;59120;59;NORD;1
59361;;Lourches;LOURCHES;59156;59;NORD;1
59363;;Louvignies-Quesnoy;LOUVIGNIES-QUESNOY;59530;59;NORD;1
59364;;Louvil;LOUVIL;59830;59;NORD;1
59365;;Louvroil;LOUVROIL;59720;59;NORD;1
59366;;Lynde;LYNDE;59173;59;NORD;1
59367;;Lys-lez-Lannoy;LYS-LEZ-LANNOY;59390;59;NORD;1
59368;La;Madeleine;MADELEINE;59110;59;NORD;1
59369;;Maing;MAING;59233;59;NORD;1
59370;;Mairieux;MAIRIEUX;59600;59;NORD;1
59371;Le;Maisnil;MAISNIL;59134;59;NORD;1
59372;;Malincourt;MALINCOURT;59127;59;NORD;1
59374;;Marbaix;MARBAIX;59440;59;NORD;1
59375;;Marchiennes;MARCHIENNES;59870;59;NORD;1
59377;;Marcoing;MARCOING;59159;59;NORD;1
59378;;Marcq-en-Barœul;MARCQ-EN-BAROEUL;59700;59;NORD;1
59379;;Marcq-en-Ostrevent;MARCQ-EN-OSTREVENT;59252;59;NORD;1
59381;;Maresches;MARESCHES;59990;59;NORD;1
59382;;Maretz;MARETZ;59238;59;NORD;1
59383;;Marly;MARLY;59770;59;NORD;1
59384;;Maroilles;MAROILLES;59550;59;NORD;1
59385;;Marpent;MARPENT;59164;59;NORD;1
59386;;Marquette-lez-Lille;MARQUETTE-LEZ-LILLE;59520;59;NORD;1
59387;;Marquette-en-Ostrevant;MARQUETTE-EN-OSTREVANT;59252;59;NORD;1
59388;;Marquillies;MARQUILLIES;59274;59;NORD;1
59389;;Masnières;MASNIERES;59241;59;NORD;1
59390;;Masny;MASNY;59176;59;NORD;1
59391;;Mastaing;MASTAING;59172;59;NORD;1
59392;;Maubeuge;MAUBEUGE;59600;59;NORD;1
59393;;Maulde;MAULDE;59158;59;NORD;1
59394;;Maurois;MAUROIS;59980;59;NORD;1
59395;;Mazinghien;MAZINGHIEN;59360;59;NORD;1
59396;;Mecquignies;MECQUIGNIES;59570;59;NORD;1
59397;;Merckeghem;MERCKEGHEM;59470;59;NORD;1
59398;;Mérignies;MERIGNIES;59710;59;NORD;1
59399;;Merris;MERRIS;59270;59;NORD;1
59400;;Merville;MERVILLE;59660;59;NORD;1
59401;;Méteren;METEREN;59270;59;NORD;1
59402;;Millam;MILLAM;59143;59;NORD;1
59403;;Millonfosse;MILLONFOSSE;59178;59;NORD;1
59404;Les;Moëres;MOERES;59122;59;NORD;1
59405;;Mœuvres;MOEUVRES;62147;59;PAS DE CALAIS;1
59406;;Monceau-Saint-Waast;MONCEAU-SAINT-WAAST;59620;59;NORD;1
59407;;Monchaux-sur-Écaillon;MONCHAUX-SUR-ECAILLON;59224;59;NORD;1
59408;;Moncheaux;MONCHEAUX;59283;59;NORD;1
59409;;Monchecourt;MONCHECOURT;59234;59;NORD;1
59410;;Mons-en-Barœul;MONS-EN-BAROEUL;59370;59;NORD;1
59411;;Mons-en-Pévèle;MONS-EN-PEVELE;59246;59;NORD;1
59412;;Montay;MONTAY;59360;59;NORD;1
59413;;Montigny-en-Cambrésis;MONTIGNY-EN-CAMBRESIS;59225;59;NORD;1
59414;;Montigny-en-Ostrevent;MONTIGNY-EN-OSTREVENT;59182;59;NORD;1
59415;;Montrécourt;MONTRECOURT;59227;59;NORD;1
59416;;Morbecque;MORBECQUE;59190;59;NORD;1
59418;;Mortagne-du-Nord;MORTAGNE-DU-NORD;59158;59;NORD;1
59419;;Mouchin;MOUCHIN;59310;59;NORD;1
59420;;Moustier-en-Fagne;MOUSTIER-EN-FAGNE;59132;59;NORD;1
59421;;Mouvaux;MOUVAUX;59420;59;NORD;1
59422;;Naves;NAVES;59161;59;NORD;1
59423;;Neuf-Berquin;NEUF-BERQUIN;59940;59;NORD;1
59424;;Neuf-Mesnil;NEUF-MESNIL;59330;59;NORD;1
59425;;Neuville-en-Avesnois;NEUVILLE-EN-AVESNOIS;59218;59;NORD;1
59426;;Neuville-en-Ferrain;NEUVILLE-EN-FERRAIN;59960;59;NORD;1
59427;La;Neuville;NEUVILLE;59239;59;NORD;1
59428;;Neuville-Saint-Rémy;NEUVILLE-SAINT-REMY;59554;59;NORD;1
59429;;Neuville-sur-Escaut;NEUVILLE-SUR-ESCAUT;59293;59;NORD;1
59430;;Neuvilly;NEUVILLY;59360;59;NORD;1
59431;;Nieppe;NIEPPE;59850;59;NORD;1
59432;;Niergnies;NIERGNIES;59400;59;NORD;1
59433;;Nieurlet;NIEURLET;59143;59;NORD;1
59434;;Nivelle;NIVELLE;59230;59;NORD;1
59435;;Nomain;NOMAIN;59310;59;NORD;1
59436;;Noordpeene;NOORDPEENE;59670;59;NORD;1
59437;;Noyelles-lès-Seclin;NOYELLES-LES-SECLIN;59139;59;NORD;1
59438;;Noyelles-sur-Escaut;NOYELLES-SUR-ESCAUT;59159;59;NORD;1
59439;;Noyelles-sur-Sambre;NOYELLES-SUR-SAMBRE;59550;59;NORD;1
59440;;Noyelles-sur-Selle;NOYELLES-SUR-SELLE;59282;59;NORD;1
59441;;Obies;OBIES;59570;59;NORD;1
59442;;Obrechies;OBRECHIES;59680;59;NORD;1
59443;;Ochtezeele;OCHTEZEELE;59670;59;NORD;1
59444;;Odomez;ODOMEZ;59970;59;NORD;1
59445;;Ohain;OHAIN;59132;59;NORD;1
59446;;Oisy;OISY;59195;59;NORD;1
59447;;Onnaing;ONNAING;59264;59;NORD;1
59448;;Oost-Cappel;OOST-CAPPEL;59122;59;NORD;1
59449;;Orchies;ORCHIES;59310;59;NORD;1
59450;;Ors;ORS;59360;59;NORD;1
59451;;Orsinval;ORSINVAL;59530;59;NORD;1
59452;;Ostricourt;OSTRICOURT;59162;59;NORD;1
59453;;Oudezeele;OUDEZEELE;59670;59;NORD;1
59454;;Oxelaëre;OXELAERE;59670;59;NORD;1
59455;;Paillencourt;PAILLENCOURT;59295;59;NORD;1
59456;;Pecquencourt;PECQUENCOURT;59146;59;NORD;1
59457;;Pérenchies;PERENCHIES;59840;59;NORD;1
59458;;Péronne-en-Mélantois;PERONNE-EN-MELANTOIS;59273;59;NORD;1
59459;;Petite-Forêt;PETITE-FORET;59494;59;NORD;1
59461;;Petit-Fayt;PETIT-FAYT;59244;59;NORD;1
59462;;Phalempin;PHALEMPIN;59133;59;NORD;1
59463;;Pitgam;PITGAM;59284;59;NORD;1
59464;;Poix-du-Nord;POIX-DU-NORD;59218;59;NORD;1
59465;;Pommereuil;POMMEREUIL;59360;59;NORD;1
59466;;Pont-à-Marcq;PONT-A-MARCQ;59710;59;NORD;1
59467;;Pont-sur-Sambre;PONT-SUR-SAMBRE;59138;59;NORD;1
59468;;Potelle;POTELLE;59530;59;NORD;1
59469;;Pradelles;PRADELLES;59190;59;NORD;1
59470;;Prémesques;PREMESQUES;59840;59;NORD;1
59471;;Préseau;PRESEAU;59990;59;NORD;1
59472;;Preux-au-Bois;PREUX-AU-BOIS;59288;59;NORD;1
59473;;Preux-au-Sart;PREUX-AU-SART;59144;59;NORD;1
59474;;Prisches;PRISCHES;59550;59;NORD;1
59475;;Prouvy;PROUVY;59121;59;NORD;1
59476;;Proville;PROVILLE;59267;59;NORD;1
59477;;Provin;PROVIN;59185;59;NORD;1
59478;;Quaëdypre;QUAEDYPRE;59380;59;NORD;1
59479;;Quarouble;QUAROUBLE;59243;59;NORD;1
59480;;Quérénaing;QUERENAING;59269;59;NORD;1
59481;Le;Quesnoy;QUESNOY;59530;59;NORD;1
59482;;Quesnoy-sur-Deûle;QUESNOY-SUR-DEULE;59890;59;NORD;1
59483;;Quiévelon;QUIEVELON;59680;59;NORD;1
59484;;Quiévrechain;QUIEVRECHAIN;59920;59;NORD;1
59485;;Quiévy;QUIEVY;59214;59;NORD;1
59486;;Râches;RACHES;59194;59;NORD;1
59487;;Radinghem-en-Weppes;RADINGHEM-EN-WEPPES;59320;59;NORD;1
59488;;Raillencourt-Sainte-Olle;RAILLENCOURT-SAINTE-OLLE;59554;59;NORD;1
59489;;Raimbeaucourt;RAIMBEAUCOURT;59283;59;NORD;1
59490;;Rainsars;RAINSARS;59177;59;NORD;1
59491;;Raismes;RAISMES;59590;59;NORD;1
59492;;Ramillies;RAMILLIES;59161;59;NORD;1
59493;;Ramousies;RAMOUSIES;59177;59;NORD;1
59494;;Raucourt-au-Bois;RAUCOURT-AU-BOIS;59530;59;NORD;1
59495;;Recquignies;RECQUIGNIES;59245;59;NORD;1
59496;;Rejet-de-Beaulieu;REJET-DE-BEAULIEU;59360;59;NORD;1
59497;;Renescure;RENESCURE;59173;59;NORD;1
59498;;Reumont;REUMONT;59980;59;NORD;1
59499;;Rexpoëde;REXPOEDE;59122;59;NORD;1
59500;;Ribécourt-la-Tour;RIBECOURT-LA-TOUR;59159;59;NORD;1
59501;;Rieulay;RIEULAY;59870;59;NORD;1
59502;;Rieux-en-Cambrésis;RIEUX-EN-CAMBRESIS;59277;59;NORD;1
59503;;Robersart;ROBERSART;59550;59;NORD;1
59504;;Rœulx;ROEULX;59172;59;NORD;1
59505;;Rombies-et-Marchipont;ROMBIES-ET-MARCHIPONT;59990;59;NORD;1
59506;;Romeries;ROMERIES;59730;59;NORD;1
59507;;Ronchin;RONCHIN;59790;59;NORD;1
59508;;Roncq;RONCQ;59223;59;NORD;1
59509;;Roost-Warendin;ROOST-WARENDIN;59286;59;NORD;1
59511;;Rosult;ROSULT;59230;59;NORD;1
59512;;Roubaix;ROUBAIX;59100;59;NORD;1
59513;;Roucourt;ROUCOURT;59169;59;NORD;1
59514;;Rousies;ROUSIES;59131;59;NORD;1
59515;;Rouvignies;ROUVIGNIES;59220;59;NORD;1
59516;;Rubrouck;RUBROUCK;59285;59;NORD;1
59517;Les;Rues-des-Vignes;RUES-DES-VIGNES;59258;59;NORD;1
59518;;Ruesnes;RUESNES;59530;59;NORD;1
59519;;Rumegies;RUMEGIES;59226;59;NORD;1
59520;;Rumilly-en-Cambrésis;RUMILLY-EN-CAMBRESIS;59281;59;NORD;1
59521;;Sailly-lez-Cambrai;SAILLY-LEZ-CAMBRAI;59554;59;NORD;1
59522;;Sailly-lez-Lannoy;SAILLY-LEZ-LANNOY;59390;59;NORD;1
59523;;Sainghin-en-Mélantois;SAINGHIN-EN-MELANTOIS;59262;59;NORD;1
59524;;Sainghin-en-Weppes;SAINGHIN-EN-WEPPES;59184;59;NORD;1
59525;;Sains-du-Nord;SAINS-DU-NORD;59177;59;NORD;1
59526;;Saint-Amand-les-Eaux;SAINT-AMAND-LES-EAUX;59230;59;NORD;1
59527;;Saint-André-lez-Lille;SAINT-ANDRE-LEZ-LILLE;59350;59;NORD;1
59528;;Saint-Aubert;SAINT-AUBERT;59188;59;NORD;1
59529;;Saint-Aubin;SAINT-AUBIN;59440;59;NORD;1
59530;;Saint-Aybert;SAINT-AYBERT;59163;59;NORD;1
59531;;Saint-Benin;SAINT-BENIN;59360;59;NORD;1
59532;;Saint-Georges-sur-l'Aa;SAINT-GEORGES-SUR-L'AA;59820;59;NORD;1
59533;;Saint-Hilaire-lez-Cambrai;SAINT-HILAIRE-LEZ-CAMBRAI;59292;59;NORD;1
59534;;Saint-Hilaire-sur-Helpe;SAINT-HILAIRE-SUR-HELPE;59440;59;NORD;1
59535;;Saint-Jans-Cappel;SAINT-JANS-CAPPEL;59270;59;NORD;1
59536;;Sainte-Marie-Cappel;SAINTE-MARIE-CAPPEL;59670;59;NORD;1
59537;;Saint-Martin-sur-Écaillon;SAINT-MARTIN-SUR-ECAILLON;59213;59;NORD;1
59538;;Saint-Momelin;SAINT-MOMELIN;59143;59;NORD;1
59539;;Saint-Pierre-Brouck;SAINT-PIERRE-BROUCK;59630;59;NORD;1
59541;;Saint-Python;SAINT-PYTHON;59730;59;NORD;1
59542;;Saint-Remy-Chaussée;SAINT-REMY-CHAUSSEE;59620;59;NORD;1
59543;;Saint-Remy-du-Nord;SAINT-REMY-DU-NORD;59330;59;NORD;1
59544;;Saint-Saulve;SAINT-SAULVE;59880;59;NORD;1
59545;;Saint-Souplet;SAINT-SOUPLET;59360;59;NORD;1
59546;;Saint-Sylvestre-Cappel;SAINT-SYLVESTRE-CAPPEL;59114;59;NORD;1
59547;;Saint-Vaast-en-Cambrésis;SAINT-VAAST-EN-CAMBRESIS;59188;59;NORD;1
59548;;Saint-Waast;SAINT-WAAST;59570;59;NORD;1
59549;;Salesches;SALESCHES;59218;59;NORD;1
59550;;Salomé;SALOME;59496;59;NORD;1
59551;;Saméon;SAMEON;59310;59;NORD;1
59552;;Sancourt;SANCOURT;59265;59;NORD;1
59553;;Santes;SANTES;59211;59;NORD;1
59554;;Sars-et-Rosières;SARS-ET-ROSIERES;59230;59;NORD;1
59555;;Sars-Poteries;SARS-POTERIES;59216;59;NORD;1
59556;;Sassegnies;SASSEGNIES;59145;59;NORD;1
59557;;Saultain;SAULTAIN;59990;59;NORD;1
59558;;Saulzoir;SAULZOIR;59227;59;NORD;1
59559;;Sebourg;SEBOURG;59990;59;NORD;1
59560;;Seclin;SECLIN;59113;59;NORD;1
59562;;Sémeries;SEMERIES;59440;59;NORD;1
59563;;Semousies;SEMOUSIES;59440;59;NORD;1
59564;La;Sentinelle;SENTINELLE;59174;59;NORD;1
59565;;Sepmeries;SEPMERIES;59269;59;NORD;1
59566;;Sequedin;SEQUEDIN;59320;59;NORD;1
59567;;Séranvillers-Forenville;SERANVILLERS-FORENVILLE;59400;59;NORD;1
59568;;Sercus;SERCUS;59173;59;NORD;1
59569;;Sin-le-Noble;SIN-LE-NOBLE;59450;59;NORD;1
59570;;Socx;SOCX;59380;59;NORD;1
59571;;Solesmes;SOLESMES;59730;59;NORD;1
59572;;Solre-le-Château;SOLRE-LE-CHATEAU;59740;59;NORD;1
59573;;Solrinnes;SOLRINNES;59740;59;NORD;1
59574;;Somain;SOMAIN;59490;59;NORD;1
59575;;Sommaing;SOMMAING;59213;59;NORD;1
59576;;Spycker;SPYCKER;59380;59;NORD;1
59577;;Staple;STAPLE;59190;59;NORD;1
59578;;Steenbecque;STEENBECQUE;59189;59;NORD;1
59579;;Steene;STEENE;59380;59;NORD;1
59580;;Steenvoorde;STEENVOORDE;59114;59;NORD;1
59581;;Steenwerck;STEENWERCK;59181;59;NORD;1
59582;;Strazeele;STRAZEELE;59270;59;NORD;1
59583;;Taisnières-en-Thiérache;TAISNIERES-EN-THIERACHE;59550;59;NORD;1
59584;;Taisnières-sur-Hon;TAISNIERES-SUR-HON;59570;59;NORD;1
59585;;Templemars;TEMPLEMARS;59175;59;NORD;1
59586;;Templeuve;TEMPLEUVE;59242;59;NORD;1
59587;;Terdeghem;TERDEGHEM;59114;59;NORD;1
59588;;Téteghem;TETEGHEM;59229;59;NORD;1
59589;;Thiant;THIANT;59224;59;NORD;1
59590;;Thiennes;THIENNES;59189;59;NORD;1
59591;;Thivencelle;THIVENCELLE;59163;59;NORD;1
59592;;Thumeries;THUMERIES;59239;59;NORD;1
59593;;Thun-l'Évêque;THUN-L'EVEQUE;59141;59;NORD;1
59594;;Thun-Saint-Amand;THUN-SAINT-AMAND;59158;59;NORD;1
59595;;Thun-Saint-Martin;THUN-SAINT-MARTIN;59141;59;NORD;1
59596;;Tilloy-lez-Marchiennes;TILLOY-LEZ-MARCHIENNES;59870;59;NORD;1
59597;;Tilloy-lez-Cambrai;TILLOY-LEZ-CAMBRAI;59554;59;NORD;1
59598;;Toufflers;TOUFFLERS;59390;59;NORD;1
59599;;Tourcoing;TOURCOING;59200;59;NORD;1
59600;;Tourmignies;TOURMIGNIES;59551;59;NORD;1
59601;;Trélon;TRELON;59132;59;NORD;1
59602;;Tressin;TRESSIN;59152;59;NORD;1
59603;;Trith-Saint-Léger;TRITH-SAINT-LEGER;59125;59;NORD;1
59604;;Troisvilles;TROISVILLES;59980;59;NORD;1
59605;;Uxem;UXEM;59229;59;NORD;1
59606;;Valenciennes;VALENCIENNES;59300;59;NORD;1
59607;;Vendegies-au-Bois;VENDEGIES-AU-BOIS;59218;59;NORD;1
59608;;Vendegies-sur-Écaillon;VENDEGIES-SUR-ECAILLON;59213;59;NORD;1
59609;;Vendeville;VENDEVILLE;59175;59;NORD;1
59610;;Verchain-Maugré;VERCHAIN-MAUGRE;59227;59;NORD;1
59611;;Verlinghem;VERLINGHEM;59237;59;NORD;1
59612;;Vertain;VERTAIN;59730;59;NORD;1
59613;;Vicq;VICQ;59970;59;NORD;1
59614;;Viesly;VIESLY;59271;59;NORD;1
59615;;Vieux-Berquin;VIEUX-BERQUIN;59232;59;NORD;1
59616;;Vieux-Condé;VIEUX-CONDE;59690;59;NORD;1
59617;;Vieux-Mesnil;VIEUX-MESNIL;59138;59;NORD;1
59618;;Vieux-Reng;VIEUX-RENG;59600;59;NORD;1
59619;;Villereau;VILLEREAU;59530;59;NORD;1
59620;;Villers-au-Tertre;VILLERS-AU-TERTRE;59234;59;NORD;1
59622;;Villers-en-Cauchies;VILLERS-EN-CAUCHIES;59188;59;NORD;1
59623;;Villers-Guislain;VILLERS-GUISLAIN;59297;59;NORD;1
59624;;Villers-Outréaux;VILLERS-OUTREAUX;59142;59;NORD;1
59625;;Villers-Plouich;VILLERS-PLOUICH;59231;59;NORD;1
59626;;Villers-Pol;VILLERS-POL;59530;59;NORD;1
59627;;Villers-Sire-Nicole;VILLERS-SIRE-NICOLE;59600;59;NORD;1
59628;;Volckerinckhove;VOLCKERINCKHOVE;59470;59;NORD;1
59629;;Vred;VRED;59870;59;NORD;1
59630;;Wahagnies;WAHAGNIES;59261;59;NORD;1
59631;;Walincourt-Selvigny;WALINCOURT-SELVIGNY;59127;59;NORD;1
59632;;Wallers;WALLERS;59135;59;NORD;1
59633;;Wallers-en-Fagne;WALLERS-EN-FAGNE;59132;59;NORD;1
59634;;Wallon-Cappel;WALLON-CAPPEL;59190;59;NORD;1
59635;;Wambaix;WAMBAIX;59400;59;NORD;1
59636;;Wambrechies;WAMBRECHIES;59118;59;NORD;1
59637;;Wandignies-Hamage;WANDIGNIES-HAMAGE;59870;59;NORD;1
59638;;Wannehain;WANNEHAIN;59830;59;NORD;1
59639;;Wargnies-le-Grand;WARGNIES-LE-GRAND;59144;59;NORD;1
59640;;Wargnies-le-Petit;WARGNIES-LE-PETIT;59144;59;NORD;1
59641;;Warhem;WARHEM;59380;59;NORD;1
59642;;Warlaing;WARLAING;59870;59;NORD;1
59643;;Warneton;WARNETON;59560;59;NORD;1
59645;;Wasnes-au-Bac;WASNES-AU-BAC;59252;59;NORD;1
59646;;Wasquehal;WASQUEHAL;59290;59;NORD;1
59647;;Watten;WATTEN;59143;59;NORD;1
59648;;Wattignies;WATTIGNIES;59139;59;NORD;1
59649;;Wattignies-la-Victoire;WATTIGNIES-LA-VICTOIRE;59680;59;NORD;1
59650;;Wattrelos;WATTRELOS;59150;59;NORD;1
59651;;Wavrechain-sous-Denain;WAVRECHAIN-SOUS-DENAIN;59220;59;NORD;1
59652;;Wavrechain-sous-Faulx;WAVRECHAIN-SOUS-FAULX;59111;59;NORD;1
59653;;Wavrin;WAVRIN;59136;59;NORD;1
59654;;Waziers;WAZIERS;59119;59;NORD;1
59655;;Wemaers-Cappel;WEMAERS-CAPPEL;59670;59;NORD;1
59656;;Wervicq-Sud;WERVICQ-SUD;59117;59;NORD;1
59657;;West-Cappel;WEST-CAPPEL;59380;59;NORD;1
59658;;Wicres;WICRES;59134;59;NORD;1
59659;;Wignehies;WIGNEHIES;59212;59;NORD;1
59660;;Willems;WILLEMS;59780;59;NORD;1
59661;;Willies;WILLIES;59740;59;NORD;1
59662;;Winnezeele;WINNEZEELE;59670;59;NORD;1
59663;;Wormhout;WORMHOUT;59470;59;NORD;1
59664;;Wulverdinghe;WULVERDINGHE;59143;59;NORD;1
59665;;Wylder;WYLDER;59380;59;NORD;1
59666;;Zegerscappel;ZEGERSCAPPEL;59470;59;NORD;1
59667;;Zermezeele;ZERMEZEELE;59670;59;NORD;1
59668;;Zuydcoote;ZUYDCOOTE;59123;59;NORD;1
59669;;Zuytpeene;ZUYTPEENE;59670;59;NORD;1
59670;;Don;DON;59272;59;NORD;1
60001;;Abancourt;ABANCOURT;60220;60;OISE;1
60002;;Abbecourt;ABBECOURT;60430;60;OISE;1
60003;;Abbeville-Saint-Lucien;ABBEVILLE-SAINT-LUCIEN;60480;60;OISE;1
60004;;Achy;ACHY;60690;60;OISE;1
60005;;Acy-en-Multien;ACY-EN-MULTIEN;60620;60;OISE;1
60006;Les;Ageux;AGEUX;60700;60;OISE;1
60007;;Agnetz;AGNETZ;60600;60;OISE;1
60008;;Airion;AIRION;60600;60;OISE;1
60009;;Allonne;ALLONNE;60000;60;OISE;1
60010;;Amblainville;AMBLAINVILLE;60110;60;OISE;1
60011;;Amy;AMY;60310;60;OISE;1
60012;;Andeville;ANDEVILLE;60570;60;OISE;1
60013;;Angicourt;ANGICOURT;60940;60;OISE;1
60014;;Angivillers;ANGIVILLERS;60130;60;OISE;1
60015;;Angy;ANGY;60250;60;OISE;1
60016;;Ansacq;ANSACQ;60250;60;OISE;1
60017;;Ansauvillers;ANSAUVILLERS;60120;60;OISE;1
60018;;Anserville;ANSERVILLE;60540;60;OISE;1
60019;;Antheuil-Portes;ANTHEUIL-PORTES;60162;60;OISE;1
60020;;Antilly;ANTILLY;60620;60;OISE;1
60021;;Appilly;APPILLY;60400;60;OISE;1
60022;;Apremont;APREMONT;60300;60;OISE;1
60023;;Armancourt;ARMANCOURT;60880;60;OISE;1
60024;;Arsy;ARSY;60190;60;OISE;1
60025;;Attichy;ATTICHY;60350;60;OISE;1
60026;;Auchy-la-Montagne;AUCHY-LA-MONTAGNE;60360;60;OISE;1
60027;;Auger-Saint-Vincent;AUGER-SAINT-VINCENT;60800;60;OISE;1
60028;;Aumont-en-Halatte;AUMONT-EN-HALATTE;60300;60;OISE;1
60029;;Auneuil;AUNEUIL;60390;60;OISE;1
60030;;Auteuil;AUTEUIL;60390;60;OISE;1
60031;;Autheuil-en-Valois;AUTHEUIL-EN-VALOIS;60890;60;OISE;1
60032;;Autrêches;AUTRECHES;60350;60;OISE;1
60033;;Avilly-Saint-Léonard;AVILLY-SAINT-LEONARD;60300;60;OISE;1
60034;;Avrechy;AVRECHY;60130;60;OISE;1
60035;;Avricourt;AVRICOURT;60310;60;OISE;1
60036;;Avrigny;AVRIGNY;60190;60;OISE;1
60037;;Babœuf;BABOEUF;60400;60;OISE;1
60038;;Bachivillers;BACHIVILLERS;60240;60;OISE;1
60039;;Bacouël;BACOUEL;60120;60;OISE;1
60040;;Bailleul-le-Soc;BAILLEUL-LE-SOC;60190;60;OISE;1
60041;;Bailleul-sur-Thérain;BAILLEUL-SUR-THERAIN;60930;60;OISE;1
60042;;Bailleval;BAILLEVAL;60140;60;OISE;1
60043;;Bailly;BAILLY;60170;60;OISE;1
60044;;Balagny-sur-Thérain;BALAGNY-SUR-THERAIN;60250;60;OISE;1
60045;;Barbery;BARBERY;60810;60;OISE;1
60046;;Bargny;BARGNY;60620;60;OISE;1
60047;;Baron;BARON;60300;60;OISE;1
60048;;Baugy;BAUGY;60113;60;OISE;1
60049;;Bazancourt;BAZANCOURT;60380;60;OISE;1
60050;;Bazicourt;BAZICOURT;60700;60;OISE;1
60051;;Beaudéduit;BEAUDEDUIT;60210;60;OISE;1
60052;;Beaugies-sous-Bois;BEAUGIES-SOUS-BOIS;60640;60;OISE;1
60053;;Beaulieu-les-Fontaines;BEAULIEU-LES-FONTAINES;60310;60;OISE;1
60054;;Beaumont-les-Nonains;BEAUMONT-LES-NONAINS;60390;60;OISE;1
60055;;Beaurains-lès-Noyon;BEAURAINS-LES-NOYON;60400;60;OISE;1
60056;;Beaurepaire;BEAUREPAIRE;60700;60;OISE;1
60057;;Beauvais;BEAUVAIS;60000;60;OISE;1
60058;;Beauvoir;BEAUVOIR;60120;60;OISE;1
60059;;Béhéricourt;BEHERICOURT;60400;60;OISE;1
60060;;Belle-Église;BELLE-EGLISE;60540;60;OISE;1
60061;;Belloy;BELLOY;60490;60;OISE;1
60062;;Berlancourt;BERLANCOURT;60640;60;OISE;1
60063;;Berneuil-en-Bray;BERNEUIL-EN-BRAY;60390;60;OISE;1
60064;;Berneuil-sur-Aisne;BERNEUIL-SUR-AISNE;60350;60;OISE;1
60065;;Berthecourt;BERTHECOURT;60370;60;OISE;1
60066;;Béthancourt-en-Valois;BETHANCOURT-EN-VALOIS;60129;60;OISE;1
60067;;Béthisy-Saint-Martin;BETHISY-SAINT-MARTIN;60320;60;OISE;1
60068;;Béthisy-Saint-Pierre;BETHISY-SAINT-PIERRE;60320;60;OISE;1
60069;;Betz;BETZ;60620;60;OISE;1
60070;;Bienville;BIENVILLE;60200;60;OISE;1
60071;;Biermont;BIERMONT;60490;60;OISE;1
60072;;Bitry;BITRY;60350;60;OISE;1
60073;;Blacourt;BLACOURT;60650;60;OISE;1
60074;;Blaincourt-lès-Précy;BLAINCOURT-LES-PRECY;60460;60;OISE;1
60075;;Blancfossé;BLANCFOSSE;60120;60;OISE;1
60076;;Blargies;BLARGIES;60220;60;OISE;1
60077;;Blicourt;BLICOURT;60860;60;OISE;1
60078;;Blincourt;BLINCOURT;60190;60;OISE;1
60079;;Boissy-Fresnoy;BOISSY-FRESNOY;60440;60;OISE;1
60080;;Boissy-le-Bois;BOISSY-LE-BOIS;60240;60;OISE;1
60081;;Bonlier;BONLIER;60510;60;OISE;1
60082;;Bonneuil-les-Eaux;BONNEUIL-LES-EAUX;60120;60;OISE;1
60083;;Bonneuil-en-Valois;BONNEUIL-EN-VALOIS;60123;60;OISE;1
60084;;Bonnières;BONNIERES;60112;60;OISE;1
60085;;Bonvillers;BONVILLERS;60120;60;OISE;1
60086;;Boran-sur-Oise;BORAN-SUR-OISE;60820;60;OISE;1
60087;;Borest;BOREST;60300;60;OISE;1
60088;;Bornel;BORNEL;60540;60;OISE;1
60089;;Boubiers;BOUBIERS;60240;60;OISE;1
60090;;Bouconvillers;BOUCONVILLERS;60240;60;OISE;1
60091;;Bouillancy;BOUILLANCY;60620;60;OISE;1
60092;;Boullarre;BOULLARRE;60620;60;OISE;1
60093;;Boulogne-la-Grasse;BOULOGNE-LA-GRASSE;60490;60;OISE;1
60094;;Boursonne;BOURSONNE;60141;60;OISE;1
60095;;Boury-en-Vexin;BOURY-EN-VEXIN;60240;60;OISE;1
60096;;Boutavent;BOUTAVENT;60220;60;OISE;1
60097;;Boutencourt;BOUTENCOURT;60590;60;OISE;1
60098;;Bouvresse;BOUVRESSE;60220;60;OISE;1
60099;;Braisnes;BRAISNES;60113;60;OISE;1
60100;;Brasseuse;BRASSEUSE;60810;60;OISE;1
60101;;Brégy;BREGY;60440;60;OISE;1
60102;;Brenouille;BRENOUILLE;60870;60;OISE;1
60103;;Bresles;BRESLES;60510;60;OISE;1
60104;;Breteuil;BRETEUIL;60120;60;OISE;1
60105;;Brétigny;BRETIGNY;60400;60;OISE;1
60106;;Breuil-le-Sec;BREUIL-LE-SEC;60600;60;OISE;1
60107;;Breuil-le-Vert;BREUIL-LE-VERT;60600;60;OISE;1
60108;;Briot;BRIOT;60210;60;OISE;1
60109;;Brombos;BROMBOS;60210;60;OISE;1
60110;;Broquiers;BROQUIERS;60220;60;OISE;1
60111;;Broyes;BROYES;60120;60;OISE;1
60112;;Brunvillers-la-Motte;BRUNVILLERS-LA-MOTTE;60130;60;OISE;1
60113;;Bucamps;BUCAMPS;60480;60;OISE;1
60114;;Buicourt;BUICOURT;60380;60;OISE;1
60115;;Bulles;BULLES;60130;60;OISE;1
60116;;Bury;BURY;60250;60;OISE;1
60117;;Bussy;BUSSY;60400;60;OISE;1
60118;;Caisnes;CAISNES;60400;60;OISE;1
60119;;Cambronne-lès-Ribécourt;CAMBRONNE-LES-RIBECOURT;60170;60;OISE;1
60120;;Cambronne-lès-Clermont;CAMBRONNE-LES-CLERMONT;60290;60;OISE;1
60121;;Campagne;CAMPAGNE;60640;60;OISE;1
60122;;Campeaux;CAMPEAUX;60220;60;OISE;1
60123;;Campremy;CAMPREMY;60480;60;OISE;1
60124;;Candor;CANDOR;60310;60;OISE;1
60125;;Canly;CANLY;60680;60;OISE;1
60126;;Cannectancourt;CANNECTANCOURT;60310;60;OISE;1
60127;;Canny-sur-Matz;CANNY-SUR-MATZ;60310;60;OISE;1
60128;;Canny-sur-Thérain;CANNY-SUR-THERAIN;60220;60;OISE;1
60129;;Carlepont;CARLEPONT;60170;60;OISE;1
60130;;Catenoy;CATENOY;60600;60;OISE;1
60131;;Catheux;CATHEUX;60360;60;OISE;1
60132;;Catigny;CATIGNY;60640;60;OISE;1
60133;;Catillon-Fumechon;CATILLON-FUMECHON;60130;60;OISE;1
60134;;Cauffry;CAUFFRY;60290;60;OISE;1
60135;;Cauvigny;CAUVIGNY;60730;60;OISE;1
60136;;Cempuis;CEMPUIS;60210;60;OISE;1
60137;;Cernoy;CERNOY;60190;60;OISE;1
60138;;Chamant;CHAMANT;60300;60;OISE;1
60139;;Chambly;CHAMBLY;60230;60;OISE;1
60140;;Chambors;CHAMBORS;60240;60;OISE;1
60141;;Chantilly;CHANTILLY;60500;60;OISE;1
60142;La;Chapelle-en-Serval;CHAPELLE-EN-SERVAL;60520;60;OISE;1
60143;;Chaumont-en-Vexin;CHAUMONT-EN-VEXIN;60240;60;OISE;1
60144;;Chavençon;CHAVENCON;60240;60;OISE;1
60145;;Chelles;CHELLES;60350;60;OISE;1
60146;;Chepoix;CHEPOIX;60120;60;OISE;1
60147;;Chevincourt;CHEVINCOURT;60150;60;OISE;1
60148;;Chèvreville;CHEVREVILLE;60440;60;OISE;1
60149;;Chevrières;CHEVRIERES;60710;60;OISE;1
60150;;Chiry-Ourscamp;CHIRY-OURSCAMP;60138;60;OISE;1
60151;;Choisy-au-Bac;CHOISY-AU-BAC;60750;60;OISE;1
60152;;Choisy-la-Victoire;CHOISY-LA-VICTOIRE;60190;60;OISE;1
60153;;Choqueuse-les-Bénards;CHOQUEUSE-LES-BENARDS;60360;60;OISE;1
60154;;Cinqueux;CINQUEUX;60940;60;OISE;1
60155;;Cires-lès-Mello;CIRES-LES-MELLO;60660;60;OISE;1
60156;;Clairoix;CLAIROIX;60200;60;OISE;1
60157;;Clermont;CLERMONT;60600;60;OISE;1
60158;;Coivrel;COIVREL;60420;60;OISE;1
60159;;Compiègne;COMPIEGNE;60200;60;OISE;1
60160;;Conchy-les-Pots;CONCHY-LES-POTS;60490;60;OISE;1
60161;;Conteville;CONTEVILLE;60360;60;OISE;1
60162;;Corbeil-Cerf;CORBEIL-CERF;60110;60;OISE;1
60163;;Cormeilles;CORMEILLES;60120;60;OISE;1
60164;Le;Coudray-Saint-Germer;COUDRAY-SAINT-GERMER;60850;60;OISE;1
60165;Le;Coudray-sur-Thelle;COUDRAY-SUR-THELLE;60430 ;60;OISE;1
60166;;Coudun;COUDUN;60150;60;OISE;1
60167;;Couloisy;COULOISY;60350;60;OISE;1
60168;;Courcelles-Epayelles;COURCELLES-EPAYELLES;60420;60;OISE;1
60169;;Courcelles-lès-Gisors;COURCELLES-LES-GISORS;60240;60;OISE;1
60170;;Courteuil;COURTEUIL;60300;60;OISE;1
60171;;Courtieux;COURTIEUX;60350;60;OISE;1
60172;;Coye-la-Forêt;COYE-LA-FORET;60580;60;OISE;1
60173;;Cramoisy;CRAMOISY;60660;60;OISE;1
60174;;Crapeaumesnil;CRAPEAUMESNIL;60310;60;OISE;1
60175;;Creil;CREIL;60100;60;OISE;1
60176;;Crépy-en-Valois;CREPY-EN-VALOIS;60800;60;OISE;1
60177;;Cressonsacq;CRESSONSACQ;60190;60;OISE;1
60178;;Crèvecœur-le-Grand;CREVECOEUR-LE-GRAND;60360;60;OISE;1
60179;;Crèvecœur-le-Petit;CREVECOEUR-LE-PETIT;60420;60;OISE;1
60180;;Crillon;CRILLON;60112;60;OISE;1
60181;;Crisolles;CRISOLLES;60400;60;OISE;1
60182;Le;Crocq;CROCQ;60120;60;OISE;1
60183;;Croissy-sur-Celle;CROISSY-SUR-CELLE;60120;60;OISE;1
60184;;Croutoy;CROUTOY;60350;60;OISE;1
60185;;Crouy-en-Thelle;CROUY-EN-THELLE;60530;60;OISE;1
60186;;Cuignières;CUIGNIERES;60130;60;OISE;1
60187;;Cuigy-en-Bray;CUIGY-EN-BRAY;60850;60;OISE;1
60188;;Cuise-la-Motte;CUISE-LA-MOTTE;60350;60;OISE;1
60189;;Cuts;CUTS;60400;60;OISE;1
60190;;Cuvergnon;CUVERGNON;60620;60;OISE;1
60191;;Cuvilly;CUVILLY;60490;60;OISE;1
60192;;Cuy;CUY;60310;60;OISE;1
60193;;Daméraucourt;DAMERAUCOURT;60210;60;OISE;1
60194;;Dargies;DARGIES;60210;60;OISE;1
60195;;Delincourt;DELINCOURT;60240;60;OISE;1
60196;Le;Déluge;DELUGE;60790;60;OISE;1
60197;;Dieudonné;DIEUDONNE;60530;60;OISE;1
60198;;Dives;DIVES;60310;60;OISE;1
60199;;Doméliers;DOMELIERS;60360;60;OISE;1
60200;;Domfront;DOMFRONT;60420;60;OISE;1
60201;;Dompierre;DOMPIERRE;60420;60;OISE;1
60203;;Duvy;DUVY;60800;60;OISE;1
60204;;Écuvilly;ECUVILLY;60310;60;OISE;1
60205;;Élencourt;ELENCOURT;60210;60;OISE;1
60206;;Élincourt-Sainte-Marguerite;ELINCOURT-SAINTE-MARGUERITE;60157;60;OISE;1
60207;;Éméville;EMEVILLE;60123;60;OISE;1
60208;;Énencourt-Léage;ENENCOURT-LEAGE;60590;60;OISE;1
60209;;Énencourt-le-Sec;ENENCOURT-LE-SEC;60240;60;OISE;1
60210;;Épineuse;EPINEUSE;60190;60;OISE;1
60211;;Éragny-sur-Epte;ERAGNY-SUR-EPTE;60590;60;OISE;1
60212;;Ercuis;ERCUIS;60530;60;OISE;1
60213;;Ermenonville;ERMENONVILLE;60950;60;OISE;1
60214;;Ernemont-Boutavent;ERNEMONT-BOUTAVENT;60380;60;OISE;1
60215;;Erquery;ERQUERY;60600;60;OISE;1
60216;;Erquinvillers;ERQUINVILLERS;60130;60;OISE;1
60217;;Escames;ESCAMES;60380;60;OISE;1
60218;;Esches;ESCHES;60110;60;OISE;1
60219;;Escles-Saint-Pierre;ESCLES-SAINT-PIERRE;60220;60;OISE;1
60220;;Espaubourg;ESPAUBOURG;60650;60;OISE;1
60221;;Esquennoy;ESQUENNOY;60120;60;OISE;1
60222;;Essuiles;ESSUILES;60510;60;OISE;1
60223;;Estrées-Saint-Denis;ESTREES-SAINT-DENIS;60190;60;OISE;1
60224;;Étavigny;ETAVIGNY;60620;60;OISE;1
60225;;Étouy;ETOUY;60600;60;OISE;1
60226;;Ève;EVE;60330;60;OISE;1
60227;;Évricourt;EVRICOURT;60310;60;OISE;1
60228;;Fay-les-Étangs;FAY-LES-ETANGS;60240;60;OISE;1
60229;Le;Fayel;FAYEL;60680;60;OISE;1
60230;Le;Fay-Saint-Quentin;FAY-SAINT-QUENTIN;60510;60;OISE;1
60231;;Feigneux;FEIGNEUX;60800;60;OISE;1
60232;;Ferrières;FERRIERES;60420;60;OISE;1
60233;;Feuquières;FEUQUIERES;60960;60;OISE;1
60234;;Fitz-James;FITZ-JAMES;60600;60;OISE;1
60235;;Flavacourt;FLAVACOURT;60590;60;OISE;1
60236;;Flavy-le-Meldeux;FLAVY-LE-MELDEUX;60640;60;OISE;1
60237;;Fléchy;FLECHY;60120;60;OISE;1
60238;;Fleurines;FLEURINES;60700;60;OISE;1
60239;;Fleury;FLEURY;60240;60;OISE;1
60240;;Fontaine-Bonneleau;FONTAINE-BONNELEAU;60360;60;OISE;1
60241;;Fontaine-Chaalis;FONTAINE-CHAALIS;60300;60;OISE;1
60242;;Fontaine-Lavaganne;FONTAINE-LAVAGANNE;60690;60;OISE;1
60243;;Fontaine-Saint-Lucien;FONTAINE-SAINT-LUCIEN;60480;60;OISE;1
60244;;Fontenay-Torcy;FONTENAY-TORCY;60380;60;OISE;1
60245;;Formerie;FORMERIE;60220;60;OISE;1
60246;;Fosseuse;FOSSEUSE;60540;60;OISE;1
60247;;Fouilleuse;FOUILLEUSE;60190;60;OISE;1
60248;;Fouilloy;FOUILLOY;60220;60;OISE;1
60249;;Foulangues;FOULANGUES;60250;60;OISE;1
60250;;Fouquenies;FOUQUENIES;60000;60;OISE;1
60251;;Fouquerolles;FOUQUEROLLES;60510;60;OISE;1
60252;;Fournival;FOURNIVAL;60130;60;OISE;1
60253;;Francastel;FRANCASTEL;60480;60;OISE;1
60254;;Francières;FRANCIERES;60190;60;OISE;1
60255;;Fréniches;FRENICHES;60640;60;OISE;1
60256;;Fresneaux-Montchevreuil;FRESNEAUX-MONTCHEVREUIL;60240;60;OISE;1
60257;;Fresne-Léguillon;FRESNE-LEGUILLON;60240;60;OISE;1
60258;;Fresnières;FRESNIERES;60310;60;OISE;1
60259;;Fresnoy-en-Thelle;FRESNOY-EN-THELLE;60530;60;OISE;1
60260;;Fresnoy-la-Rivière;FRESNOY-LA-RIVIERE;60127;60;OISE;1
60261;;Fresnoy-le-Luat;FRESNOY-LE-LUAT;60800;60;OISE;1
60262;Le;Frestoy-Vaux;FRESTOY-VAUX;60420;60;OISE;1
60263;;Frétoy-le-Château;FRETOY-LE-CHATEAU;60640;60;OISE;1
60264;;Frocourt;FROCOURT;60000;60;OISE;1
60265;;Froissy;FROISSY;60480;60;OISE;1
60267;Le;Gallet;GALLET;60360;60;OISE;1
60268;;Gannes;GANNES;60120;60;OISE;1
60269;;Gaudechart;GAUDECHART;60210;60;OISE;1
60270;;Genvry;GENVRY;60400;60;OISE;1
60271;;Gerberoy;GERBEROY;60380;60;OISE;1
60272;;Gilocourt;GILOCOURT;60129;60;OISE;1
60273;;Giraumont;GIRAUMONT;60150;60;OISE;1
60274;;Glaignes;GLAIGNES;60129;60;OISE;1
60275;;Glatigny;GLATIGNY;60650;60;OISE;1
60276;;Godenvillers;GODENVILLERS;60420;60;OISE;1
60277;;Goincourt;GOINCOURT;60000;60;OISE;1
60278;;Golancourt;GOLANCOURT;60640;60;OISE;1
60279;;Gondreville;GONDREVILLE;60117;60;OISE;1
60280;;Gourchelles;GOURCHELLES;60220;60;OISE;1
60281;;Gournay-sur-Aronde;GOURNAY-SUR-ARONDE;60190;60;OISE;1
60282;;Gouvieux;GOUVIEUX;60270;60;OISE;1
60283;;Gouy-les-Groseillers;GOUY-LES-GROSEILLERS;60120;60;OISE;1
60284;;Grandfresnoy;GRANDFRESNOY;60680;60;OISE;1
60285;;Grandvillers-aux-Bois;GRANDVILLERS-AUX-BOIS;60190;60;OISE;1
60286;;Grandvilliers;GRANDVILLIERS;60210;60;OISE;1
60287;;Grandrû;GRANDRU;60400;60;OISE;1
60288;;Grémévillers;GREMEVILLERS;60380;60;OISE;1
60289;;Grez;GREZ;60210;60;OISE;1
60290;;Guignecourt;GUIGNECOURT;60480;60;OISE;1
60291;;Guiscard;GUISCARD;60640;60;OISE;1
60292;;Gury;GURY;60310;60;OISE;1
60293;;Hadancourt-le-Haut-Clocher;HADANCOURT-LE-HAUT-CLOCHER;60240;60;OISE;1
60294;;Hainvillers;HAINVILLERS;60490;60;OISE;1
60295;;Halloy;HALLOY;60210;60;OISE;1
60296;;Hannaches;HANNACHES;60650;60;OISE;1
60297;Le;Hamel;HAMEL;60210;60;OISE;1
60298;;Hanvoile;HANVOILE;60650;60;OISE;1
60299;;Hardivillers;HARDIVILLERS;60120;60;OISE;1
60300;;Hardivillers-en-Vexin;HARDIVILLERS-EN-VEXIN;60240;60;OISE;1
60301;;Haucourt;HAUCOURT;60112;60;OISE;1
60302;;Haudivillers;HAUDIVILLERS;60510;60;OISE;1
60303;;Hautbos;HAUTBOS;60210;60;OISE;1
60304;;Haute-Épine;HAUTE-EPINE;60690;60;OISE;1
60305;;Hautefontaine;HAUTEFONTAINE;60350;60;OISE;1
60306;;Hécourt;HECOURT;60380;60;OISE;1
60307;;Heilles;HEILLES;60250;60;OISE;1
60308;;Hémévillers;HEMEVILLERS;60190;60;OISE;1
60309;;Hénonville;HENONVILLE;60119;60;OISE;1
60310;;Herchies;HERCHIES;60112;60;OISE;1
60311;La;Hérelle;HERELLE;60120;60;OISE;1
60312;;Héricourt-sur-Thérain;HERICOURT-SUR-THERAIN;60380;60;OISE;1
60313;;Hermes;HERMES;60370;60;OISE;1
60314;;Hétomesnil;HETOMESNIL;60360;60;OISE;1
60315;;Hodenc-en-Bray;HODENC-EN-BRAY;60650;60;OISE;1
60316;;Hodenc-l'Évêque;HODENC-L'EVEQUE;60430;60;OISE;1
60317;;Hondainville;HONDAINVILLE;60250;60;OISE;1
60318;;Houdancourt;HOUDANCOURT;60710;60;OISE;1
60319;La;Houssoye;HOUSSOYE;60390;60;OISE;1
60320;;Ivors;IVORS;60141;60;OISE;1
60321;;Ivry-le-Temple;IVRY-LE-TEMPLE;60173;60;OISE;1
60322;;Jaméricourt;JAMERICOURT;60240;60;OISE;1
60323;;Janville;JANVILLE;60150;60;OISE;1
60324;;Jaulzy;JAULZY;60350;60;OISE;1
60325;;Jaux;JAUX;60880;60;OISE;1
60326;;Jonquières;JONQUIERES;60680;60;OISE;1
60327;;Jouy-sous-Thelle;JOUY-SOUS-THELLE;60240;60;OISE;1
60328;;Juvignies;JUVIGNIES;60112;60;OISE;1
60329;;Laberlière;LABERLIERE;60310;60;OISE;1
60330;;Laboissière-en-Thelle;LABOISSIERE-EN-THELLE;60570;60;OISE;1
60331;;Labosse;LABOSSE;60590;60;OISE;1
60332;;Labruyère;LABRUYERE;60140;60;OISE;1
60333;;Lachapelle-aux-Pots;LACHAPELLE-AUX-POTS;60650;60;OISE;1
60334;;Lachapelle-Saint-Pierre;LACHAPELLE-SAINT-PIERRE;60730;60;OISE;1
60335;;Lachapelle-sous-Gerberoy;LACHAPELLE-SOUS-GERBEROY;60380;60;OISE;1
60336;;Lachaussée-du-Bois-d'Écu;LACHAUSSEE-DU-BOIS-D'ECU;60480;60;OISE;1
60337;;Lachelle;LACHELLE;60190;60;OISE;1
60338;;Lacroix-Saint-Ouen;LACROIX-SAINT-OUEN;60610;60;OISE;1
60339;;Lafraye;LAFRAYE;60510;60;OISE;1
60340;;Lagny;LAGNY;60310;60;OISE;1
60341;;Lagny-le-Sec;LAGNY-LE-SEC;60330;60;OISE;1
60342;;Laigneville;LAIGNEVILLE;60290;60;OISE;1
60343;;Lalande-en-Son;LALANDE-EN-SON;60590;60;OISE;1
60344;;Lalandelle;LALANDELLE;60850;60;OISE;1
60345;;Lamécourt;LAMECOURT;60600;60;OISE;1
60346;;Lamorlaye;LAMORLAYE;60260;60;OISE;1
60347;;Lannoy-Cuillère;LANNOY-CUILLERE;60220;60;OISE;1
60348;;Larbroye;LARBROYE;60400;60;OISE;1
60350;;Lassigny;LASSIGNY;60310;60;OISE;1
60351;;Lataule;LATAULE;60490;60;OISE;1
60352;;Lattainville;LATTAINVILLE;60240;60;OISE;1
60353;;Lavacquerie;LAVACQUERIE;60120;60;OISE;1
60354;;Laverrière;LAVERRIERE;60210;60;OISE;1
60355;;Laversines;LAVERSINES;60510;60;OISE;1
60356;;Lavilletertre;LAVILLETERTRE;60240;60;OISE;1
60357;;Léglantiers;LEGLANTIERS;60420;60;OISE;1
60358;;Lévignen;LEVIGNEN;60800;60;OISE;1
60359;;Lhéraule;LHERAULE;60650;60;OISE;1
60360;;Liancourt;LIANCOURT;60140;60;OISE;1
60361;;Liancourt-Saint-Pierre;LIANCOURT-SAINT-PIERRE;60240;60;OISE;1
60362;;Libermont;LIBERMONT;60640;60;OISE;1
60363;;Lierville;LIERVILLE;60240;60;OISE;1
60364;;Lieuvillers;LIEUVILLERS;60130;60;OISE;1
60365;;Lihus;LIHUS;60360;60;OISE;1
60366;;Litz;LITZ;60510;60;OISE;1
60367;;Loconville;LOCONVILLE;60240;60;OISE;1
60368;;Longueil-Annel;LONGUEIL-ANNEL;60150;60;OISE;1
60369;;Longueil-Sainte-Marie;LONGUEIL-SAINTE-MARIE;60126;60;OISE;1
60370;;Lormaison;LORMAISON;60110;60;OISE;1
60371;;Loueuse;LOUEUSE;60380;60;OISE;1
60372;;Luchy;LUCHY;60360;60;OISE;1
60373;;Machemont;MACHEMONT;60150;60;OISE;1
60374;;Maignelay-Montigny;MAIGNELAY-MONTIGNY;60420;60;OISE;1
60375;;Maimbeville;MAIMBEVILLE;60600;60;OISE;1
60376;;Maisoncelle-Saint-Pierre;MAISONCELLE-SAINT-PIERRE;60112;60;OISE;1
60377;;Maisoncelle-Tuilerie;MAISONCELLE-TUILERIE;60480;60;OISE;1
60378;;Marest-sur-Matz;MAREST-SUR-MATZ;60490;60;OISE;1
60379;;Mareuil-la-Motte;MAREUIL-LA-MOTTE;60490;60;OISE;1
60380;;Mareuil-sur-Ourcq;MAREUIL-SUR-OURCQ;60890;60;OISE;1
60381;;Margny-aux-Cerises;MARGNY-AUX-CERISES;60310;60;OISE;1
60382;;Margny-lès-Compiègne;MARGNY-LES-COMPIEGNE;60280;60;OISE;1
60383;;Margny-sur-Matz;MARGNY-SUR-MATZ;60490;60;OISE;1
60385;;Marolles;MAROLLES;60890;60;OISE;1
60386;;Marquéglise;MARQUEGLISE;60490;60;OISE;1
60387;;Marseille-en-Beauvaisis;MARSEILLE-EN-BEAUVAISIS;60690;60;OISE;1
60388;;Martincourt;MARTINCOURT;60112;60;OISE;1
60389;;Maucourt;MAUCOURT;60640;60;OISE;1
60390;;Maulers;MAULERS;60480;60;OISE;1
60391;;Maysel;MAYSEL;60660;60;OISE;1
60392;;Mélicocq;MELICOCQ;60150;60;OISE;1
60393;;Mello;MELLO;60660;60;OISE;1
60394;;Ménévillers;MENEVILLERS;60420;60;OISE;1
60395;;Méru;MERU;60110;60;OISE;1
60396;;Méry-la-Bataille;MERY-LA-BATAILLE;60420;60;OISE;1
60397;Le;Mesnil-Conteville;MESNIL-CONTEVILLE;60210;60;OISE;1
60398;Le;Mesnil-en-Thelle;MESNIL-EN-THELLE;60530;60;OISE;1
60399;Le;Mesnil-Saint-Firmin;MESNIL-SAINT-FIRMIN;60120;60;OISE;1
60400;Le;Mesnil-sur-Bulles;MESNIL-SUR-BULLES;60130;60;OISE;1
60401;Le;Mesnil-Théribus;MESNIL-THERIBUS;60240;60;OISE;1
60402;Le;Meux;MEUX;60880;60;OISE;1
60403;;Milly-sur-Thérain;MILLY-SUR-THERAIN;60112;60;OISE;1
60404;;Mogneville;MOGNEVILLE;60140;60;OISE;1
60405;;Moliens;MOLIENS;60220;60;OISE;1
60406;;Monceaux;MONCEAUX;60940;60;OISE;1
60407;;Monceaux-l'Abbaye;MONCEAUX-L'ABBAYE;60220;60;OISE;1
60408;;Monchy-Humières;MONCHY-HUMIERES;60113;60;OISE;1
60409;;Monchy-Saint-Éloi;MONCHY-SAINT-ELOI;60290;60;OISE;1
60410;;Mondescourt;MONDESCOURT;60400;60;OISE;1
60411;;Monneville;MONNEVILLE;60240;60;OISE;1
60412;;Montagny-en-Vexin;MONTAGNY-EN-VEXIN;60240;60;OISE;1
60413;;Montagny-Sainte-Félicité;MONTAGNY-SAINTE-FELICITE;60950;60;OISE;1
60414;;Montataire;MONTATAIRE;60160;60;OISE;1
60415;;Montépilloy;MONTEPILLOY;60810;60;OISE;1
60416;;Montgérain;MONTGERAIN;60420;60;OISE;1
60417;;Montherlant;MONTHERLANT;60790;60;OISE;1
60418;;Montiers;MONTIERS;60190;60;OISE;1
60420;;Montjavoult;MONTJAVOULT;60240;60;OISE;1
60421;;Mont-l'Évêque;MONT-L'EVEQUE;60300;60;OISE;1
60422;;Montlognon;MONTLOGNON;60300;60;OISE;1
60423;;Montmacq;MONTMACQ;60150;60;OISE;1
60424;;Montmartin;MONTMARTIN;60190;60;OISE;1
60425;;Montreuil-sur-Brêche;MONTREUIL-SUR-BRECHE;60480;60;OISE;1
60426;;Montreuil-sur-Thérain;MONTREUIL-SUR-THERAIN;60134;60;OISE;1
60427;;Monts;MONTS;60119;60;OISE;1
60428;Le;Mont-Saint-Adrien;MONT-SAINT-ADRIEN;60650;60;OISE;1
60429;;Morangles;MORANGLES;60530;60;OISE;1
60430;;Morienval;MORIENVAL;60127;60;OISE;1
60431;;Morlincourt;MORLINCOURT;60400;60;OISE;1
60432;;Mortefontaine;MORTEFONTAINE;60128;60;OISE;1
60433;;Mortefontaine-en-Thelle;MORTEFONTAINE-EN-THELLE;60570;60;OISE;1
60434;;Mortemer;MORTEMER;60490;60;OISE;1
60435;;Morvillers;MORVILLERS;60380;60;OISE;1
60436;;Mory-Montcrux;MORY-MONTCRUX;60120;60;OISE;1
60437;;Mouchy-le-Châtel;MOUCHY-LE-CHATEL;60250;60;OISE;1
60438;;Moulin-sous-Touvent;MOULIN-SOUS-TOUVENT;60350;60;OISE;1
60439;;Mouy;MOUY;60250;60;OISE;1
60440;;Moyenneville;MOYENNEVILLE;60190;60;OISE;1
60441;;Moyvillers;MOYVILLERS;60190;60;OISE;1
60442;;Muidorge;MUIDORGE;60480;60;OISE;1
60443;;Muirancourt;MUIRANCOURT;60640;60;OISE;1
60444;;Mureaumont;MUREAUMONT;60220;60;OISE;1
60445;;Nampcel;NAMPCEL;60400;60;OISE;1
60446;;Nanteuil-le-Haudouin;NANTEUIL-LE-HAUDOUIN;60440;60;OISE;1
60447;;Néry;NERY;60320;60;OISE;1
60448;;Neufchelles;NEUFCHELLES;60890;60;OISE;1
60449;;Neufvy-sur-Aronde;NEUFVY-SUR-ARONDE;60190;60;OISE;1
60450;;Neuilly-en-Thelle;NEUILLY-EN-THELLE;60530;60;OISE;1
60451;;Neuilly-sous-Clermont;NEUILLY-SOUS-CLERMONT;60290;60;OISE;1
60452;;Neuville-Bosc;NEUVILLE-BOSC;60119;60;OISE;1
60453;La;Neuville-d'Aumont;NEUVILLE-D'AUMONT;60790;60;OISE;1
60454;La;Neuville-en-Hez;NEUVILLE-EN-HEZ;60510;60;OISE;1
60455;La;Neuville-Garnier;NEUVILLE-GARNIER;60390;60;OISE;1
60456;La;Neuville-Roy;NEUVILLE-ROY;60190;60;OISE;1
60457;La;Neuville-Saint-Pierre;NEUVILLE-SAINT-PIERRE;60480;60;OISE;1
60458;La;Neuville-sur-Oudeuil;NEUVILLE-SUR-OUDEUIL;60690;60;OISE;1
60459;La;Neuville-sur-Ressons;NEUVILLE-SUR-RESSONS;60490;60;OISE;1
60460;La;Neuville-Vault;NEUVILLE-VAULT;60112;60;OISE;1
60461;;Nivillers;NIVILLERS;60510;60;OISE;1
60462;;Noailles;NOAILLES;60430;60;OISE;1
60463;;Nogent-sur-Oise;NOGENT-SUR-OISE;60180;60;OISE;1
60464;;Nointel;NOINTEL;60600;60;OISE;1
60465;;Noirémont;NOIREMONT;60480;60;OISE;1
60466;;Noroy;NOROY;60130;60;OISE;1
60468;;Nourard-le-Franc;NOURARD-LE-FRANC;60130;60;OISE;1
60469;;Novillers;NOVILLERS;60730;60;OISE;1
60470;;Noyers-Saint-Martin;NOYERS-SAINT-MARTIN;60480;60;OISE;1
60471;;Noyon;NOYON;60400;60;OISE;1
60472;;Offoy;OFFOY;60210;60;OISE;1
60473;;Ognes;OGNES;60440;60;OISE;1
60474;;Ognolles;OGNOLLES;60310;60;OISE;1
60475;;Ognon;OGNON;60810;60;OISE;1
60476;;Omécourt;OMECOURT;60220;60;OISE;1
60477;;Ons-en-Bray;ONS-EN-BRAY;60650;60;OISE;1
60478;;Ormoy-le-Davien;ORMOY-LE-DAVIEN;60620;60;OISE;1
60479;;Ormoy-Villers;ORMOY-VILLERS;60800;60;OISE;1
60480;;Oroër;OROER;60510;60;OISE;1
60481;;Orrouy;ORROUY;60129;60;OISE;1
60482;;Orry-la-Ville;ORRY-LA-VILLE;60560;60;OISE;1
60483;;Orvillers-Sorel;ORVILLERS-SOREL;60490;60;OISE;1
60484;;Oudeuil;OUDEUIL;60860;60;OISE;1
60485;;Oursel-Maison;OURSEL-MAISON;60480;60;OISE;1
60486;;Paillart;PAILLART;60120;60;OISE;1
60487;;Parnes;PARNES;60240;60;OISE;1
60488;;Passel;PASSEL;60400;60;OISE;1
60489;;Péroy-les-Gombries;PEROY-LES-GOMBRIES;60440;60;OISE;1
60490;;Pierrefitte-en-Beauvaisis;PIERREFITTE-EN-BEAUVAISIS;60112;60;OISE;1
60491;;Pierrefonds;PIERREFONDS;60350;60;OISE;1
60492;;Pimprez;PIMPREZ;60170;60;OISE;1
60493;;Pisseleu;PISSELEU;60860;60;OISE;1
60494;;Plailly;PLAILLY;60128;60;OISE;1
60495;;Plainval;PLAINVAL;60130;60;OISE;1
60496;;Plainville;PLAINVILLE;60120;60;OISE;1
60497;Le;Plessier-sur-Bulles;PLESSIER-SUR-BULLES;60130;60;OISE;1
60498;Le;Plessier-sur-Saint-Just;PLESSIER-SUR-SAINT-JUST;60130;60;OISE;1
60499;;Plessis-de-Roye;PLESSIS-DE-ROYE;60310;60;OISE;1
60500;Le;Plessis-Belleville;PLESSIS-BELLEVILLE;60330;60;OISE;1
60501;Le;Plessis-Brion;PLESSIS-BRION;60150;60;OISE;1
60502;Le;Plessis-Patte-d'Oie;PLESSIS-PATTE-D'OIE;60640;60;OISE;1
60503;Le;Ployron;PLOYRON;60420;60;OISE;1
60504;;Ponchon;PONCHON;60430;60;OISE;1
60505;;Pontarmé;PONTARME;60520;60;OISE;1
60506;;Pont-l'Évêque;PONT-L'EVEQUE;60400;60;OISE;1
60507;;Pontoise-lès-Noyon;PONTOISE-LES-NOYON;60400;60;OISE;1
60508;;Pontpoint;PONTPOINT;60700;60;OISE;1
60509;;Pont-Sainte-Maxence;PONT-SAINTE-MAXENCE;60700;60;OISE;1
60510;;Porcheux;PORCHEUX;60390;60;OISE;1
60511;;Porquéricourt;PORQUERICOURT;60400;60;OISE;1
60512;;Pouilly;POUILLY;60790;60;OISE;1
60513;;Précy-sur-Oise;PRECY-SUR-OISE;60460;60;OISE;1
60514;;Prévillers;PREVILLERS;60360;60;OISE;1
60515;;Pronleroy;PRONLEROY;60190;60;OISE;1
60516;;Puiseux-en-Bray;PUISEUX-EN-BRAY;60850;60;OISE;1
60517;;Puiseux-le-Hauberger;PUISEUX-LE-HAUBERGER;60540;60;OISE;1
60518;;Puits-la-Vallée;PUITS-LA-VALLEE;60480;60;OISE;1
60519;;Quesmy;QUESMY;60640;60;OISE;1
60520;Le;Quesnel-Aubry;QUESNEL-AUBRY;60480;60;OISE;1
60521;;Quincampoix-Fleuzy;QUINCAMPOIX-FLEUZY;60220;60;OISE;1
60522;;Quinquempoix;QUINQUEMPOIX;60130;60;OISE;1
60523;;Rainvillers;RAINVILLERS;60155;60;OISE;1
60524;;Rantigny;RANTIGNY;60290;60;OISE;1
60525;;Raray;RARAY;60810;60;OISE;1
60526;;Ravenel;RAVENEL;60130;60;OISE;1
60527;;Réez-Fosse-Martin;REEZ-FOSSE-MARTIN;60620;60;OISE;1
60528;;Reilly;REILLY;60240;60;OISE;1
60529;;Rémécourt;REMECOURT;60600;60;OISE;1
60530;;Rémérangles;REMERANGLES;60510;60;OISE;1
60531;;Remy;REMY;60190;60;OISE;1
60532;;Ressons-l'Abbaye;RESSONS-L'ABBAYE;60790;60;OISE;1
60533;;Ressons-sur-Matz;RESSONS-SUR-MATZ;60490;60;OISE;1
60534;;Rethondes;RETHONDES;60153;60;OISE;1
60535;;Reuil-sur-Brêche;REUIL-SUR-BRECHE;60480;60;OISE;1
60536;;Rhuis;RHUIS;60410;60;OISE;1
60537;;Ribécourt-Dreslincourt;RIBECOURT-DRESLINCOURT;60170;60;OISE;1
60538;;Ricquebourg;RICQUEBOURG;60490;60;OISE;1
60539;;Rieux;RIEUX;60870;60;OISE;1
60540;;Rivecourt;RIVECOURT;60126;60;OISE;1
60541;;Roberval;ROBERVAL;60410;60;OISE;1
60542;;Rochy-Condé;ROCHY-CONDE;60510;60;OISE;1
60543;;Rocquemont;ROCQUEMONT;60800;60;OISE;1
60544;;Rocquencourt;ROCQUENCOURT;60120;60;OISE;1
60545;;Romescamps;ROMESCAMPS;60220;60;OISE;1
60546;;Rosières;ROSIERES;60440;60;OISE;1
60547;;Rosoy;ROSOY;60140;60;OISE;1
60548;;Rosoy-en-Multien;ROSOY-EN-MULTIEN;60620;60;OISE;1
60549;;Rotangy;ROTANGY;60360;60;OISE;1
60550;;Rothois;ROTHOIS;60690;60;OISE;1
60551;;Rousseloy;ROUSSELOY;60660;60;OISE;1
60552;;Rouville;ROUVILLE;60800;60;OISE;1
60553;;Rouvillers;ROUVILLERS;60190;60;OISE;1
60554;;Rouvres-en-Multien;ROUVRES-EN-MULTIEN;60620;60;OISE;1
60555;;Rouvroy-les-Merles;ROUVROY-LES-MERLES;60120;60;OISE;1
60556;;Royaucourt;ROYAUCOURT;60420;60;OISE;1
60557;;Roy-Boissy;ROY-BOISSY;60690;60;OISE;1
60558;;Roye-sur-Matz;ROYE-SUR-MATZ;60310;60;OISE;1
60559;La;Rue-Saint-Pierre;RUE-SAINT-PIERRE;60510;60;OISE;1
60560;;Rully;RULLY;60810;60;OISE;1
60561;;Russy-Bémont;RUSSY-BEMONT;60117;60;OISE;1
60562;;Sacy-le-Grand;SACY-LE-GRAND;60700;60;OISE;1
60563;;Sacy-le-Petit;SACY-LE-PETIT;60190;60;OISE;1
60564;;Sains-Morainvillers;SAINS-MORAINVILLERS;60420;60;OISE;1
60565;;Saint-André-Farivillers;SAINT-ANDRE-FARIVILLERS;60480;60;OISE;1
60566;;Saint-Arnoult;SAINT-ARNOULT;60220;60;OISE;1
60567;;Saint-Aubin-en-Bray;SAINT-AUBIN-EN-BRAY;60650;60;OISE;1
60568;;Saint-Aubin-sous-Erquery;SAINT-AUBIN-SOUS-ERQUERY;60600;60;OISE;1
60569;;Saint-Crépin-aux-Bois;SAINT-CREPIN-AUX-BOIS;60170;60;OISE;1
60570;;Saint-Crépin-Ibouvillers;SAINT-CREPIN-IBOUVILLERS;60149;60;OISE;1
60571;;Saint-Deniscourt;SAINT-DENISCOURT;60380;60;OISE;1
60572;;Saint-Étienne-Roilaye;SAINT-ETIENNE-ROILAYE;60350;60;OISE;1
60573;;Sainte-Eusoye;SAINTE-EUSOYE;60480;60;OISE;1
60574;;Saint-Félix;SAINT-FELIX;60370;60;OISE;1
60575;;Sainte-Geneviève;SAINTE-GENEVIEVE;60730;60;OISE;1
60576;;Saint-Germain-la-Poterie;SAINT-GERMAIN-LA-POTERIE;60650;60;OISE;1
60577;;Saint-Germer-de-Fly;SAINT-GERMER-DE-FLY;60850;60;OISE;1
60578;;Saintines;SAINTINES;60410;60;OISE;1
60579;;Saint-Jean-aux-Bois;SAINT-JEAN-AUX-BOIS;60350;60;OISE;1
60581;;Saint-Just-en-Chaussée;SAINT-JUST-EN-CHAUSSEE;60130;60;OISE;1
60582;;Saint-Léger-aux-Bois;SAINT-LEGER-AUX-BOIS;60170;60;OISE;1
60583;;Saint-Léger-en-Bray;SAINT-LEGER-EN-BRAY;60155;60;OISE;1
60584;;Saint-Leu-d'Esserent;SAINT-LEU-D'ESSERENT;60340;60;OISE;1
60585;;Saint-Martin-aux-Bois;SAINT-MARTIN-AUX-BOIS;60420;60;OISE;1
60586;;Saint-Martin-le-Nœud;SAINT-MARTIN-LE-NOEUD;60000;60;OISE;1
60587;;Saint-Martin-Longueau;SAINT-MARTIN-LONGUEAU;60700;60;OISE;1
60588;;Saint-Maur;SAINT-MAUR;60210;60;OISE;1
60589;;Saint-Maximin;SAINT-MAXIMIN;60740;60;OISE;1
60590;;Saint-Omer-en-Chaussée;SAINT-OMER-EN-CHAUSSEE;60860;60;OISE;1
60591;;Saint-Paul;SAINT-PAUL;60650;60;OISE;1
60592;;Saint-Pierre-es-Champs;SAINT-PIERRE-ES-CHAMPS;60850;60;OISE;1
60593;;Saint-Pierre-lès-Bitry;SAINT-PIERRE-LES-BITRY;60350;60;OISE;1
60594;;Saint-Quentin-des-Prés;SAINT-QUENTIN-DES-PRES;60380;60;OISE;1
60595;;Saint-Remy-en-l'Eau;SAINT-REMY-EN-L'EAU;60130;60;OISE;1
60596;;Saint-Samson-la-Poterie;SAINT-SAMSON-LA-POTERIE;60220;60;OISE;1
60597;;Saint-Sauveur;SAINT-SAUVEUR;60320;60;OISE;1
60598;;Saint-Sulpice;SAINT-SULPICE;60430;60;OISE;1
60599;;Saint-Thibault;SAINT-THIBAULT;60210;60;OISE;1
60600;;Saint-Vaast-de-Longmont;SAINT-VAAST-DE-LONGMONT;60410;60;OISE;1
60601;;Saint-Vaast-lès-Mello;SAINT-VAAST-LES-MELLO;60660;60;OISE;1
60602;;Saint-Valery;SAINT-VALERY;60220;60;OISE;1
60603;;Salency;SALENCY;60400;60;OISE;1
60604;;Sarcus;SARCUS;60210;60;OISE;1
60605;;Sarnois;SARNOIS;60210;60;OISE;1
60608;Le;Saulchoy;SAULCHOY;60360;60;OISE;1
60609;;Savignies;SAVIGNIES;60650;60;OISE;1
60610;;Sempigny;SEMPIGNY;60400;60;OISE;1
60611;;Senantes;SENANTES;60650;60;OISE;1
60612;;Senlis;SENLIS;60300;60;OISE;1
60613;;Senots;SENOTS;60240;60;OISE;1
60614;;Serans;SERANS;60240;60;OISE;1
60615;;Sérévillers;SEREVILLERS;60120;60;OISE;1
60616;;Sérifontaine;SERIFONTAINE;60590;60;OISE;1
60617;;Sermaize;SERMAIZE;60400;60;OISE;1
60618;;Séry-Magneval;SERY-MAGNEVAL;60800;60;OISE;1
60619;;Silly-le-Long;SILLY-LE-LONG;60330;60;OISE;1
60620;;Silly-Tillard;SILLY-TILLARD;60430;60;OISE;1
60621;;Solente;SOLENTE;60310;60;OISE;1
60622;;Sommereux;SOMMEREUX;60210;60;OISE;1
60623;;Songeons;SONGEONS;60380;60;OISE;1
60624;;Sully;SULLY;60380;60;OISE;1
60625;;Suzoy;SUZOY;60400;60;OISE;1
60626;;Talmontiers;TALMONTIERS;60590;60;OISE;1
60627;;Tartigny;TARTIGNY;60120;60;OISE;1
60628;;Therdonne;THERDONNE;60510;60;OISE;1
60629;;Thérines;THERINES;60380;60;OISE;1
60630;;Thibivillers;THIBIVILLERS;60240;60;OISE;1
60631;;Thiers-sur-Thève;THIERS-SUR-THEVE;60520;60;OISE;1
60632;;Thiescourt;THIESCOURT;60310;60;OISE;1
60633;;Thieuloy-Saint-Antoine;THIEULOY-SAINT-ANTOINE;60210;60;OISE;1
60634;;Thieux;THIEUX;60480;60;OISE;1
60635;;Thiverny;THIVERNY;60160;60;OISE;1
60636;;Thourotte;THOUROTTE;60150;60;OISE;1
60637;;Thury-en-Valois;THURY-EN-VALOIS;60890;60;OISE;1
60638;;Thury-sous-Clermont;THURY-SOUS-CLERMONT;60250;60;OISE;1
60639;;Tillé;TILLE;60000;60;OISE;1
60640;;Tourly;TOURLY;60240;60;OISE;1
60641;;Tracy-le-Mont;TRACY-LE-MONT;60170;60;OISE;1
60642;;Tracy-le-Val;TRACY-LE-VAL;60170;60;OISE;1
60643;;Tricot;TRICOT;60420;60;OISE;1
60644;;Trie-Château;TRIE-CHATEAU;60590;60;OISE;1
60645;;Trie-la-Ville;TRIE-LA-VILLE;60590;60;OISE;1
60646;;Troissereux;TROISSEREUX;60112;60;OISE;1
60647;;Trosly-Breuil;TROSLY-BREUIL;60350;60;OISE;1
60648;;Troussencourt;TROUSSENCOURT;60120;60;OISE;1
60649;;Troussures;TROUSSURES;60390;60;OISE;1
60650;;Trumilly;TRUMILLY;60800;60;OISE;1
60651;;Ully-Saint-Georges;ULLY-SAINT-GEORGES;60730;60;OISE;1
60652;;Valdampierre;VALDAMPIERRE;60790;60;OISE;1
60653;;Valescourt;VALESCOURT;60130;60;OISE;1
60654;;Vandélicourt;VANDELICOURT;60490;60;OISE;1
60655;;Varesnes;VARESNES;60400;60;OISE;1
60656;;Varinfroy;VARINFROY;60890;60;OISE;1
60657;;Vauchelles;VAUCHELLES;60400;60;OISE;1
60658;;Vauciennes;VAUCIENNES;60117;60;OISE;1
60659;;Vaudancourt;VAUDANCOURT;60240;60;OISE;1
60660;Le;Vaumain;VAUMAIN;60590;60;OISE;1
60661;;Vaumoise;VAUMOISE;60117;60;OISE;1
60662;Le;Vauroux;VAUROUX;60390;60;OISE;1
60663;;Velennes;VELENNES;60510;60;OISE;1
60664;;Vendeuil-Caply;VENDEUIL-CAPLY;60120;60;OISE;1
60665;;Venette;VENETTE;60200;60;OISE;1
60666;;Ver-sur-Launette;VER-SUR-LAUNETTE;60950;60;OISE;1
60667;;Verberie;VERBERIE;60410;60;OISE;1
60668;;Verderel-lès-Sauqueuse;VERDEREL-LES-SAUQUEUSE;60112;60;OISE;1
60669;;Verderonne;VERDERONNE;60140;60;OISE;1
60670;;Verneuil-en-Halatte;VERNEUIL-EN-HALATTE;60550;60;OISE;1
60671;;Versigny;VERSIGNY;60440;60;OISE;1
60672;;Vez;VEZ;60117;60;OISE;1
60673;;Viefvillers;VIEFVILLERS;60360;60;OISE;1
60674;;Vieux-Moulin;VIEUX-MOULIN;60350;60;OISE;1
60675;;Vignemont;VIGNEMONT;60162;60;OISE;1
60676;;Ville;VILLE;60400;60;OISE;1
60677;;Villembray;VILLEMBRAY;60650;60;OISE;1
60678;;Villeneuve-les-Sablons;VILLENEUVE-LES-SABLONS;60175;60;OISE;1
60679;La;Villeneuve-sous-Thury;VILLENEUVE-SOUS-THURY;60890;60;OISE;1
60680;;Villeneuve-sur-Verberie;VILLENEUVE-SUR-VERBERIE;60410;60;OISE;1
60681;;Villers-Saint-Barthélemy;VILLERS-SAINT-BARTHELEMY;60650;60;OISE;1
60682;;Villers-Saint-Frambourg;VILLERS-SAINT-FRAMBOURG;60810;60;OISE;1
60683;;Villers-Saint-Genest;VILLERS-SAINT-GENEST;60620;60;OISE;1
60684;;Villers-Saint-Paul;VILLERS-SAINT-PAUL;60870;60;OISE;1
60685;;Villers-Saint-Sépulcre;VILLERS-SAINT-SEPULCRE;60134;60;OISE;1
60686;;Villers-sous-Saint-Leu;VILLERS-SOUS-SAINT-LEU;60340;60;OISE;1
60687;;Villers-sur-Auchy;VILLERS-SUR-AUCHY;60650;60;OISE;1
60688;;Villers-sur-Bonnières;VILLERS-SUR-BONNIERES;60860;60;OISE;1
60689;;Villers-sur-Coudun;VILLERS-SUR-COUDUN;60150;60;OISE;1
60690;;Villers-sur-Trie;VILLERS-SUR-TRIE;60590;60;OISE;1
60691;;Villers-Vermont;VILLERS-VERMONT;60380;60;OISE;1
60692;;Villers-Vicomte;VILLERS-VICOMTE;60120;60;OISE;1
60693;;Villeselve;VILLESELVE;60640;60;OISE;1
60694;;Villotran;VILLOTRAN;60390;60;OISE;1
60695;;Vineuil-Saint-Firmin;VINEUIL-SAINT-FIRMIN;60500;60;OISE;1
60697;;Vrocourt;VROCOURT;60112;60;OISE;1
60698;;Wacquemoulin;WACQUEMOULIN;60420;60;OISE;1
60699;;Wambez;WAMBEZ;60380;60;OISE;1
60700;;Warluis;WARLUIS;60430;60;OISE;1
60701;;Wavignies;WAVIGNIES;60130;60;OISE;1
60702;;Welles-Pérennes;WELLES-PERENNES;60420;60;OISE;1
60703;Aux;Marais;MARAIS;60000;60;OISE;1
61001;;Alençon;ALENCON;61000;61;ORNE;1
61002;;Almenêches;ALMENECHES;61570;61;ORNE;1
61003;;Anceins;ANCEINS;61550;61;ORNE;1
61004;;Antoigny;ANTOIGNY;61410;61;ORNE;1
61005;;Appenai-sous-Bellême;APPENAI-SOUS-BELLEME;61130;61;ORNE;1
61006;;Argentan;ARGENTAN;61200;61;ORNE;1
61007;;Athis-de-l'Orne;ATHIS-DE-L'ORNE;61430;61;ORNE;1
61008;;Aube;AUBE;61270;61;ORNE;1
61009;;Aubry-en-Exmes;AUBRY-EN-EXMES;61160;61;ORNE;1
61010;;Aubry-le-Panthou;AUBRY-LE-PANTHOU;61120;61;ORNE;1
61011;;Aubusson;AUBUSSON;61100;61;ORNE;1
61012;;Auguaise;AUGUAISE;61270;61;ORNE;1
61013;;Aunay-les-Bois;AUNAY-LES-BOIS;61500;61;ORNE;1
61014;;Aunou-le-Faucon;AUNOU-LE-FAUCON;61200;61;ORNE;1
61015;;Aunou-sur-Orne;AUNOU-SUR-ORNE;61500;61;ORNE;1
61016;;Autheuil;AUTHEUIL;61190;61;ORNE;1
61017;Les;Authieux-du-Puits;AUTHIEUX-DU-PUITS;61240;61;ORNE;1
61018;;Avernes-Saint-Gourgon;AVERNES-SAINT-GOURGON;61470;61;ORNE;1
61019;;Avernes-sous-Exmes;AVERNES-SOUS-EXMES;61310;61;ORNE;1
61020;;Avoine;AVOINE;61150;61;ORNE;1
61021;;Avrilly;AVRILLY;61700;61;ORNE;1
61023;;Bailleul;BAILLEUL;61160;61;ORNE;1
61024;;Banvou;BANVOU;61450;61;ORNE;1
61025;La;Baroche-sous-Lucé;BAROCHE-SOUS-LUCE;61330;61;ORNE;1
61026;;Barville;BARVILLE;61170;61;ORNE;1
61027;;Batilly;BATILLY;61150;61;ORNE;1
61028;;Bazoches-au-Houlme;BAZOCHES-AU-HOULME;61210;61;ORNE;1
61029;;Bazoches-sur-Hoëne;BAZOCHES-SUR-HOENE;61560;61;ORNE;1
61030;La;Bazoque;BAZOQUE;61100;61;ORNE;1
61031;;Beauchêne;BEAUCHENE;61800;61;ORNE;1
61032;;Beaufai;BEAUFAI;61270;61;ORNE;1
61033;;Beaulandais;BEAULANDAIS;61140;61;ORNE;1
61034;;Beaulieu;BEAULIEU;61190;61;ORNE;1
61035;;Beauvain;BEAUVAIN;61600;61;ORNE;1
61036;;Belfonds;BELFONDS;61500;61;ORNE;1
61037;;Bellavilliers;BELLAVILLIERS;61360;61;ORNE;1
61038;;Bellême;BELLEME;61130;61;ORNE;1
61039;La;Bellière;BELLIERE;61570;61;ORNE;1
61040;;Bellou-en-Houlme;BELLOU-EN-HOULME;61220;61;ORNE;1
61041;;Bellou-le-Trichard;BELLOU-LE-TRICHARD;61130;61;ORNE;1
61042;;Bellou-sur-Huisne;BELLOU-SUR-HUISNE;61110;61;ORNE;1
61043;;Berd'huis;BERD'HUIS;61340;61;ORNE;1
61044;;Berjou;BERJOU;61430;61;ORNE;1
61045;;Bivilliers;BIVILLIERS;61190;61;ORNE;1
61046;;Bizou;BIZOU;61290;61;ORNE;1
61047;;Bocquencé;BOCQUENCE;61550;61;ORNE;1
61048;;Boëcé;BOECE;61560;61;ORNE;1
61049;;Boissei-la-Lande;BOISSEI-LA-LANDE;61570;61;ORNE;1
61050;;Boissy-Maugis;BOISSY-MAUGIS;61110;61;ORNE;1
61051;;Boitron;BOITRON;61500;61;ORNE;1
61052;;Bonnefoi;BONNEFOI;61270;61;ORNE;1
61053;;Bonsmoulins;BONSMOULINS;61380;61;ORNE;1
61054;Le;Bosc-Renoult;BOSC-RENOULT;61470;61;ORNE;1
61055;;Boucé;BOUCE;61570;61;ORNE;1
61056;Le;Bouillon;BOUILLON;61500;61;ORNE;1
61057;Le;Bourg-Saint-Léonard;BOURG-SAINT-LEONARD;61310;61;ORNE;1
61058;;Bréel;BREEL;61100;61;ORNE;1
61059;;Bresolettes;BRESOLETTES;61190;61;ORNE;1
61060;;Brethel;BRETHEL;61270;61;ORNE;1
61061;;Bretoncelles;BRETONCELLES;61110;61;ORNE;1
61062;;Brieux;BRIEUX;61160;61;ORNE;1
61063;;Briouze;BRIOUZE;61220;61;ORNE;1
61064;;Brullemail;BRULLEMAIL;61390;61;ORNE;1
61065;;Bubertré;BUBERTRE;61190;61;ORNE;1
61066;;Buré;BURE;61170;61;ORNE;1
61067;;Bures;BURES;61170;61;ORNE;1
61068;;Bursard;BURSARD;61500;61;ORNE;1
61069;;Cahan;CAHAN;61430;61;ORNE;1
61070;;Caligny;CALIGNY;61100;61;ORNE;1
61071;;Camembert;CAMEMBERT;61120;61;ORNE;1
61072;;Canapville;CANAPVILLE;61120;61;ORNE;1
61073;La;Carneille;CARNEILLE;61100;61;ORNE;1
61074;;Carrouges;CARROUGES;61320;61;ORNE;1
61075;;Ceaucé;CEAUCE;61330;61;ORNE;1
61076;Le;Cercueil;CERCUEIL;61500;61;ORNE;1
61077;;Cerisé;CERISE;61000;61;ORNE;1
61078;;Cerisy-Belle-Étoile;CERISY-BELLE-ETOILE;61100;61;ORNE;1
61079;;Ceton;CETON;61260;61;ORNE;1
61080;;Chahains;CHAHAINS;61320;61;ORNE;1
61081;;Chailloué;CHAILLOUE;61500;61;ORNE;1
61082;Le;Chalange;CHALANGE;61390;61;ORNE;1
61083;;Chambois;CHAMBOIS;61160;61;ORNE;1
61084;;Champcerie;CHAMPCERIE;61210;61;ORNE;1
61085;Le;Champ-de-la-Pierre;CHAMP-DE-LA-PIERRE;61320;61;ORNE;1
61086;Les;Champeaux;CHAMPEAUX;61120;61;ORNE;1
61087;;Champeaux-sur-Sarthe;CHAMPEAUX-SUR-SARTHE;61560;61;ORNE;1
61088;;Champ-Haut;CHAMP-HAUT;61240;61;ORNE;1
61089;;Champosoult;CHAMPOSOULT;61120;61;ORNE;1
61090;;Champs;CHAMPS;61190;61;ORNE;1
61091;;Champsecret;CHAMPSECRET;61700;61;ORNE;1
61092;;Chandai;CHANDAI;61300;61;ORNE;1
61093;;Chanu;CHANU;61800;61;ORNE;1
61094;La;Chapelle-au-Moine;CHAPELLE-AU-MOINE;61100;61;ORNE;1
61095;La;Chapelle-Biche;CHAPELLE-BICHE;61100;61;ORNE;1
61096;La;Chapelle-d'Andaine;CHAPELLE-D'ANDAINE;61140;61;ORNE;1
61097;La;Chapelle-Montligeon;CHAPELLE-MONTLIGEON;61400;61;ORNE;1
61098;La;Chapelle-près-Sées;CHAPELLE-PRES-SEES;61500;61;ORNE;1
61099;La;Chapelle-Souëf;CHAPELLE-SOUEF;61130;61;ORNE;1
61100;La;Chapelle-Viel;CHAPELLE-VIEL;61270;61;ORNE;1
61101;Le;Château-d'Almenêches;CHATEAU-D'ALMENECHES;61570;61;ORNE;1
61102;Le;Châtellier;CHATELLIER;61450;61;ORNE;1
61103;;Chaumont;CHAUMONT;61230;61;ORNE;1
61104;La;Chaux;CHAUX;61600;61;ORNE;1
61105;;Chemilli;CHEMILLI;61360;61;ORNE;1
61106;;Chênedouit;CHENEDOUIT;61210;61;ORNE;1
61107;;Ciral;CIRAL;61320;61;ORNE;1
61108;;Cisai-Saint-Aubin;CISAI-SAINT-AUBIN;61230;61;ORNE;1
61109;;Clairefougère;CLAIREFOUGERE;61800;61;ORNE;1
61110;La;Cochère;COCHERE;61310;61;ORNE;1
61111;;Colombiers;COLOMBIERS;61250;61;ORNE;1
61112;;Colonard-Corubert;COLONARD-CORUBERT;61340;61;ORNE;1
61113;;Comblot;COMBLOT;61400;61;ORNE;1
61114;;Commeaux;COMMEAUX;61200;61;ORNE;1
61115;;Condeau;CONDEAU;61110;61;ORNE;1
61116;;Condé-sur-Huisne;CONDE-SUR-HUISNE;61110;61;ORNE;1
61117;;Condé-sur-Sarthe;CONDE-SUR-SARTHE;61250;61;ORNE;1
61118;;Corbon;CORBON;61400;61;ORNE;1
61120;;Coudehard;COUDEHARD;61160;61;ORNE;1
61121;;Coulimer;COULIMER;61360;61;ORNE;1
61122;;Coulmer;COULMER;61230;61;ORNE;1
61123;;Coulonces;COULONCES;61160;61;ORNE;1
61124;La;Coulonche;COULONCHE;61220;61;ORNE;1
61125;;Coulonges-les-Sablons;COULONGES-LES-SABLONS;61110;61;ORNE;1
61126;;Coulonges-sur-Sarthe;COULONGES-SUR-SARTHE;61170;61;ORNE;1
61127;La;Courbe;COURBE;61150;61;ORNE;1
61128;;Courcerault;COURCERAULT;61340;61;ORNE;1
61129;;Courgeon;COURGEON;61400;61;ORNE;1
61130;;Courgeoût;COURGEOUT;61560;61;ORNE;1
61131;;Courménil;COURMENIL;61310;61;ORNE;1
61133;;Courtomer;COURTOMER;61390;61;ORNE;1
61135;;Couterne;COUTERNE;61410;61;ORNE;1
61136;;Couvains;COUVAINS;61550;61;ORNE;1
61137;;Craménil;CRAMENIL;61220;61;ORNE;1
61138;;Croisilles;CROISILLES;61230;61;ORNE;1
61139;;Crouttes;CROUTTES;61120;61;ORNE;1
61140;;Crulai;CRULAI;61300;61;ORNE;1
61141;;Cuissai;CUISSAI;61250;61;ORNE;1
61142;;Dame-Marie;DAME-MARIE;61130;61;ORNE;1
61143;;Damigny;DAMIGNY;61250;61;ORNE;1
61144;;Dancé;DANCE;61340;61;ORNE;1
61145;;Domfront;DOMFRONT;61700;61;ORNE;1
61146;;Dompierre;DOMPIERRE;61700;61;ORNE;1
61147;;Dorceau;DORCEAU;61110;61;ORNE;1
61148;;Durcet;DURCET;61100;61;ORNE;1
61149;;Échalou;ECHALOU;61440;61;ORNE;1
61150;;Échauffour;ECHAUFFOUR;61370;61;ORNE;1
61151;;Écorcei;ECORCEI;61270;61;ORNE;1
61152;;Écorches;ECORCHES;61160;61;ORNE;1
61153;;Écouché;ECOUCHE;61150;61;ORNE;1
61154;;Eperrais;EPERRAIS;61400;61;ORNE;1
61155;L';Épinay-le-Comte;EPINAY-LE-COMTE;61350;61;ORNE;1
61156;;Essay;ESSAY;61500;61;ORNE;1
61157;;Exmes;EXMES;61310;61;ORNE;1
61158;;Faverolles;FAVEROLLES;61600;61;ORNE;1
61159;;Fay;FAY;61390;61;ORNE;1
61160;;Feings;FEINGS;61400;61;ORNE;1
61161;;Fel;FEL;61160;61;ORNE;1
61162;La;Ferrière-au-Doyen;FERRIERE-AU-DOYEN;61380;61;ORNE;1
61163;La;Ferrière-aux-Étangs;FERRIERE-AUX-ETANGS;61450;61;ORNE;1
61164;La;Ferrière-Béchet;FERRIERE-BECHET;61500;61;ORNE;1
61165;La;Ferrière-Bochard;FERRIERE-BOCHARD;61420;61;ORNE;1
61166;;Ferrières-la-Verrerie;FERRIERES-LA-VERRERIE;61390;61;ORNE;1
61167;La;Ferté-Frênel;FERTE-FRENEL;61550;61;ORNE;1
61168;La;Ferté-Macé;FERTE-MACE;61600;61;ORNE;1
61169;;Flers;FLERS;61100;61;ORNE;1
61170;;Fleuré;FLEURE;61200;61;ORNE;1
61171;;Fontaine-les-Bassets;FONTAINE-LES-BASSETS;61160;61;ORNE;1
61172;;Fontenai-les-Louvets;FONTENAI-LES-LOUVETS;61420;61;ORNE;1
61173;;Fontenai-sur-Orne;FONTENAI-SUR-ORNE;61200;61;ORNE;1
61174;La;Forêt-Auvray;FORET-AUVRAY;61210;61;ORNE;1
61175;;Forges;FORGES;61250;61;ORNE;1
61176;;Francheville;FRANCHEVILLE;61570;61;ORNE;1
61177;;Frênes;FRENES;61800;61;ORNE;1
61178;La;Fresnaie-Fayel;FRESNAIE-FAYEL;61230;61;ORNE;1
61179;La;Fresnaye-au-Sauvage;FRESNAYE-AU-SAUVAGE;61210;61;ORNE;1
61180;;Fresnay-le-Samson;FRESNAY-LE-SAMSON;61120;61;ORNE;1
61181;;Gacé;GACE;61230;61;ORNE;1
61182;;Gandelain;GANDELAIN;61420;61;ORNE;1
61183;;Gâprée;GAPREE;61390;61;ORNE;1
61184;;Gauville;GAUVILLE;61550;61;ORNE;1
61185;;Gémages;GEMAGES;61130;61;ORNE;1
61186;;Geneslay;GENESLAY;61140;61;ORNE;1
61187;Les;Genettes;GENETTES;61270;61;ORNE;1
61188;La;Genevraie;GENEVRAIE;61240;61;ORNE;1
61189;;Giel-Courteilles;GIEL-COURTEILLES;61210;61;ORNE;1
61190;;Ginai;GINAI;61310;61;ORNE;1
61191;;Glos-la-Ferrière;GLOS-LA-FERRIERE;61550;61;ORNE;1
61192;;Godisson;GODISSON;61240;61;ORNE;1
61193;La;Gonfrière;GONFRIERE;61550;61;ORNE;1
61194;;Goulet;GOULET;61150;61;ORNE;1
61195;Le;Grais;GRAIS;61600;61;ORNE;1
61196;Le;Gué-de-la-Chaîne;GUE-DE-LA-CHAINE;61130;61;ORNE;1
61197;;Guêprei;GUEPREI;61160;61;ORNE;1
61198;;Guerquesalles;GUERQUESALLES;61120;61;ORNE;1
61199;;Habloville;HABLOVILLE;61210;61;ORNE;1
61200;;Haleine;HALEINE;61410;61;ORNE;1
61201;La;Haute-Chapelle;HAUTE-CHAPELLE;61700;61;ORNE;1
61202;;Hauterive;HAUTERIVE;61250;61;ORNE;1
61203;;Héloup;HELOUP;61250;61;ORNE;1
61204;L';Hermitière;HERMITIERE;61260;61;ORNE;1
61205;;Heugon;HEUGON;61470;61;ORNE;1
61206;L';Hôme-Chamondot;HOME-CHAMONDOT;61290;61;ORNE;1
61207;;Igé;IGE;61130;61;ORNE;1
61208;;Irai;IRAI;61190;61;ORNE;1
61209;;Joué-du-Bois;JOUE-DU-BOIS;61320;61;ORNE;1
61210;;Joué-du-Plain;JOUE-DU-PLAIN;61150;61;ORNE;1
61211;;Juvigny-sous-Andaine;JUVIGNY-SOUS-ANDAINE;61140;61;ORNE;1
61212;;Juvigny-sur-Orne;JUVIGNY-SUR-ORNE;61200;61;ORNE;1
61213;;Lalacelle;LALACELLE;61320;61;ORNE;1
61214;L';Aigle;AIGLE;61300;61;ORNE;1
61215;;Laleu;LALEU;61170;61;ORNE;1
61216;La;Lande-de-Goult;LANDE-DE-GOULT;61320;61;ORNE;1
61217;La;Lande-de-Lougé;LANDE-DE-LOUGE;61210;61;ORNE;1
61218;La;Lande-Patry;LANDE-PATRY;61100;61;ORNE;1
61219;La;Lande-Saint-Siméon;LANDE-SAINT-SIMEON;61100;61;ORNE;1
61220;La;Lande-sur-Eure;LANDE-SUR-EURE;61290;61;ORNE;1
61221;;Landigou;LANDIGOU;61100;61;ORNE;1
61222;;Landisacq;LANDISACQ;61100;61;ORNE;1
61223;;Larchamp;LARCHAMP;61800;61;ORNE;1
61224;;Larré;LARRE;61250;61;ORNE;1
61225;;Lignères;LIGNERES;61240;61;ORNE;1
61226;;Lignerolles;LIGNEROLLES;61190;61;ORNE;1
61227;;Lignou;LIGNOU;61220;61;ORNE;1
61228;;Livaie;LIVAIE;61420;61;ORNE;1
61229;;Loisail;LOISAIL;61400;61;ORNE;1
61230;;Longny-au-Perche;LONGNY-AU-PERCHE;61290;61;ORNE;1
61231;;Longuenoë;LONGUENOE;61320;61;ORNE;1
61232;;Lonlay-l'Abbaye;LONLAY-L'ABBAYE;61700;61;ORNE;1
61233;;Lonlay-le-Tesson;LONLAY-LE-TESSON;61600;61;ORNE;1
61234;;Lonrai;LONRAI;61250;61;ORNE;1
61235;;Loré;LORE;61330;61;ORNE;1
61236;;Loucé;LOUCE;61150;61;ORNE;1
61237;;Lougé-sur-Maire;LOUGE-SUR-MAIRE;61150;61;ORNE;1
61238;;Louvières-en-Auge;LOUVIERES-EN-AUGE;61160;61;ORNE;1
61239;;Lucé;LUCE;61330;61;ORNE;1
61240;;Macé;MACE;61500;61;ORNE;1
61241;La;Madeleine-Bouvet;MADELEINE-BOUVET;61110;61;ORNE;1
61242;Le;Mage;MAGE;61290;61;ORNE;1
61243;;Magny-le-Désert;MAGNY-LE-DESERT;61600;61;ORNE;1
61244;;Mahéru;MAHERU;61380;61;ORNE;1
61245;;Maison-Maugis;MAISON-MAUGIS;61110;61;ORNE;1
61246;;Mâle;MALE;61260;61;ORNE;1
61247;;Malétable;MALETABLE;61290;61;ORNE;1
61248;;Mantilly;MANTILLY;61350;61;ORNE;1
61249;;Marcei;MARCEI;61570;61;ORNE;1
61250;;Marchainville;MARCHAINVILLE;61290;61;ORNE;1
61251;;Marchemaisons;MARCHEMAISONS;61170;61;ORNE;1
61252;;Mardilly;MARDILLY;61230;61;ORNE;1
61253;;Marmouillé;MARMOUILLE;61240;61;ORNE;1
61255;;Mauves-sur-Huisne;MAUVES-SUR-HUISNE;61400;61;ORNE;1
61256;;Médavy;MEDAVY;61570;61;ORNE;1
61257;;Méhoudin;MEHOUDIN;61410;61;ORNE;1
61258;Le;Mêle-sur-Sarthe;MELE-SUR-SARTHE;61170;61;ORNE;1
61259;Le;Ménil-Bérard;MENIL-BERARD;61270;61;ORNE;1
61260;Le;Ménil-de-Briouze;MENIL-DE-BRIOUZE;61220;61;ORNE;1
61261;Le;Ménil-Broût;MENIL-BROUT;61250;61;ORNE;1
61262;Le;Ménil-Ciboult;MENIL-CIBOULT;61800;61;ORNE;1
61263;;Ménil-Erreux;MENIL-ERREUX;61250;61;ORNE;1
61264;;Ménil-Froger;MENIL-FROGER;61240;61;ORNE;1
61265;;Ménil-Gondouin;MENIL-GONDOUIN;61210;61;ORNE;1
61266;Le;Ménil-Guyon;MENIL-GUYON;61170;61;ORNE;1
61267;;Ménil-Hermei;MENIL-HERMEI;61210;61;ORNE;1
61268;;Ménil-Hubert-en-Exmes;MENIL-HUBERT-EN-EXMES;61230;61;ORNE;1
61269;;Ménil-Hubert-sur-Orne;MENIL-HUBERT-SUR-ORNE;61430;61;ORNE;1
61270;;Ménil-Jean;MENIL-JEAN;61210;61;ORNE;1
61271;Le;Ménil-Scelleur;MENIL-SCELLEUR;61320;61;ORNE;1
61272;Le;Ménil-Vicomte;MENIL-VICOMTE;61240;61;ORNE;1
61273;;Ménil-Vin;MENIL-VIN;61210;61;ORNE;1
61274;Les;Menus;MENUS;61290;61;ORNE;1
61275;Le;Merlerault;MERLERAULT;61240;61;ORNE;1
61276;;Merri;MERRI;61160;61;ORNE;1
61277;La;Mesnière;MESNIERE;61560;61;ORNE;1
61278;;Messei;MESSEI;61440;61;ORNE;1
61279;;Mieuxcé;MIEUXCE;61250;61;ORNE;1
61280;;Monceaux-au-Perche;MONCEAUX-AU-PERCHE;61290;61;ORNE;1
61281;;Moncy;MONCY;61800;61;ORNE;1
61282;;Monnai;MONNAI;61470;61;ORNE;1
61283;;Montabard;MONTABARD;61160;61;ORNE;1
61284;;Montchevrel;MONTCHEVREL;61170;61;ORNE;1
61285;;Montgaroult;MONTGAROULT;61150;61;ORNE;1
61286;;Montgaudry;MONTGAUDRY;61360;61;ORNE;1
61287;;Montilly-sur-Noireau;MONTILLY-SUR-NOIREAU;61100;61;ORNE;1
61288;;Montmerrei;MONTMERREI;61570;61;ORNE;1
61289;;Mont-Ormel;MONT-ORMEL;61160;61;ORNE;1
61290;;Montreuil-au-Houlme;MONTREUIL-AU-HOULME;61210;61;ORNE;1
61291;;Montreuil-la-Cambe;MONTREUIL-LA-CAMBE;61160;61;ORNE;1
61292;;Montsecret;MONTSECRET;61800;61;ORNE;1
61293;;Mortagne-au-Perche;MORTAGNE-AU-PERCHE;61400;61;ORNE;1
61294;;Mortrée;MORTREE;61570;61;ORNE;1
61295;La;Motte-Fouquet;MOTTE-FOUQUET;61600;61;ORNE;1
61296;;Moulicent;MOULICENT;61290;61;ORNE;1
61297;;Moulins-la-Marche;MOULINS-LA-MARCHE;61380;61;ORNE;1
61298;;Moulins-sur-Orne;MOULINS-SUR-ORNE;61200;61;ORNE;1
61299;;Moussonvilliers;MOUSSONVILLIERS;61190;61;ORNE;1
61300;;Moutiers-au-Perche;MOUTIERS-AU-PERCHE;61110;61;ORNE;1
61301;;Neauphe-sous-Essai;NEAUPHE-SOUS-ESSAI;61500;61;ORNE;1
61302;;Neauphe-sur-Dive;NEAUPHE-SUR-DIVE;61160;61;ORNE;1
61303;;Nécy;NECY;61160;61;ORNE;1
61304;;Neuilly-le-Bisson;NEUILLY-LE-BISSON;61250;61;ORNE;1
61305;;Neuilly-sur-Eure;NEUILLY-SUR-EURE;61290;61;ORNE;1
61306;;Neuville-près-Sées;NEUVILLE-PRES-SEES;61500;61;ORNE;1
61307;;Neuville-sur-Touques;NEUVILLE-SUR-TOUQUES;61120;61;ORNE;1
61308;;Neuvy-au-Houlme;NEUVY-AU-HOULME;61210;61;ORNE;1
61309;;Nocé;NOCE;61340;61;ORNE;1
61310;;Nonant-le-Pin;NONANT-LE-PIN;61240;61;ORNE;1
61311;;Normandel;NORMANDEL;61190;61;ORNE;1
61313;;Notre-Dame-du-Rocher;NOTRE-DAME-DU-ROCHER;61100;61;ORNE;1
61314;;Occagnes;OCCAGNES;61200;61;ORNE;1
61315;;Omméel;OMMEEL;61160;61;ORNE;1
61316;;Ommoy;OMMOY;61160;61;ORNE;1
61317;;Orgères;ORGERES;61230;61;ORNE;1
61318;;Origny-le-Butin;ORIGNY-LE-BUTIN;61130;61;ORNE;1
61319;;Origny-le-Roux;ORIGNY-LE-ROUX;61130;61;ORNE;1
61320;;Orville;ORVILLE;61120;61;ORNE;1
61321;;Pacé;PACE;61250;61;ORNE;1
61322;;Parfondeval;PARFONDEVAL;61400;61;ORNE;1
61323;Le;Pas-Saint-l'Homer;PAS-SAINT-L'HOMER;61290;61;ORNE;1
61324;;Passais;PASSAIS;61350;61;ORNE;1
61325;La;Perrière;PERRIERE;61360;61;ORNE;1
61326;;Perrou;PERROU;61700;61;ORNE;1
61327;;Pervenchères;PERVENCHERES;61360;61;ORNE;1
61328;Le;Pin-au-Haras;PIN-AU-HARAS;61310;61;ORNE;1
61329;Le;Pin-la-Garenne;PIN-LA-GARENNE;61400;61;ORNE;1
61330;;Planches;PLANCHES;61370;61;ORNE;1
61331;Le;Plantis;PLANTIS;61170;61;ORNE;1
61332;;Pointel;POINTEL;61220;61;ORNE;1
61333;;Pontchardon;PONTCHARDON;61120;61;ORNE;1
61335;La;Poterie-au-Perche;POTERIE-AU-PERCHE;61190;61;ORNE;1
61336;;Pouvrai;POUVRAI;61130;61;ORNE;1
61337;;Préaux-du-Perche;PREAUX-DU-PERCHE;61340;61;ORNE;1
61338;;Prépotin;PREPOTIN;61190;61;ORNE;1
61339;;Putanges-Pont-Écrepin;PUTANGES-PONT-ECREPIN;61210;61;ORNE;1
61340;;Rabodanges;RABODANGES;61210;61;ORNE;1
61341;;Radon;RADON;61250;61;ORNE;1
61342;;Rai;RAI;61270;61;ORNE;1
61343;;Randonnai;RANDONNAI;61190;61;ORNE;1
61344;;Rânes;RANES;61150;61;ORNE;1
61345;;Rémalard;REMALARD;61110;61;ORNE;1
61346;Le;Renouard;RENOUARD;61120;61;ORNE;1
61347;;Résenlieu;RESENLIEU;61230;61;ORNE;1
61348;;Réveillon;REVEILLON;61400;61;ORNE;1
61349;;Ri;RI;61210;61;ORNE;1
61350;La;Roche-Mabile;ROCHE-MABILE;61420;61;ORNE;1
61351;;Roiville;ROIVILLE;61120;61;ORNE;1
61352;;Rônai;RONAI;61160;61;ORNE;1
61353;;Ronfeugerai;RONFEUGERAI;61100;61;ORNE;1
61354;Les;Rotours;ROTOURS;61210;61;ORNE;1
61355;;Rouellé;ROUELLE;61700;61;ORNE;1
61356;La;Rouge;ROUGE;61260;61;ORNE;1
61357;;Rouperroux;ROUPERROUX;61320;61;ORNE;1
61358;;Sai;SAI;61200;61;ORNE;1
61359;;Saint-Agnan-sur-Erre;SAINT-AGNAN-SUR-ERRE;61340;61;ORNE;1
61360;;Saint-Agnan-sur-Sarthe;SAINT-AGNAN-SUR-SARTHE;61170;61;ORNE;1
61361;;Saint-André-de-Briouze;SAINT-ANDRE-DE-BRIOUZE;61220;61;ORNE;1
61362;;Saint-André-de-Messei;SAINT-ANDRE-DE-MESSEI;61440;61;ORNE;1
61363;;Saint-Aquilin-de-Corbion;SAINT-AQUILIN-DE-CORBION;61380;61;ORNE;1
61364;;Saint-Aubert-sur-Orne;SAINT-AUBERT-SUR-ORNE;61210;61;ORNE;1
61365;;Saint-Aubin-d'Appenai;SAINT-AUBIN-D'APPENAI;61170;61;ORNE;1
61366;;Saint-Aubin-de-Bonneval;SAINT-AUBIN-DE-BONNEVAL;61470;61;ORNE;1
61367;;Saint-Aubin-de-Courteraie;SAINT-AUBIN-DE-COURTERAIE;61560;61;ORNE;1
61368;;Saint-Aubin-des-Grois;SAINT-AUBIN-DES-GROIS;61340;61;ORNE;1
61369;;Saint-Bômer-les-Forges;SAINT-BOMER-LES-FORGES;61700;61;ORNE;1
61370;;Saint-Brice;SAINT-BRICE;61700;61;ORNE;1
61371;;Saint-Brice-sous-Rânes;SAINT-BRICE-SOUS-RANES;61150;61;ORNE;1
61372;;Saint-Céneri-le-Gérei;SAINT-CENERI-LE-GEREI;61250;61;ORNE;1
61373;;Sainte-Céronne-lès-Mortagne;SAINTE-CERONNE-LES-MORTAGNE;61380;61;ORNE;1
61374;;Saint-Christophe-de-Chaulieu;SAINT-CHRISTOPHE-DE-CHAULIEU;61800;61;ORNE;1
61375;;Saint-Christophe-le-Jajolet;SAINT-CHRISTOPHE-LE-JAJOLET;61570;61;ORNE;1
61376;;Saint-Clair-de-Halouze;SAINT-CLAIR-DE-HALOUZE;61490;61;ORNE;1
61377;;Saint-Cornier-des-Landes;SAINT-CORNIER-DES-LANDES;61800;61;ORNE;1
61378;;Sainte-Croix-sur-Orne;SAINTE-CROIX-SUR-ORNE;61210;61;ORNE;1
61379;;Saint-Cyr-la-Rosière;SAINT-CYR-LA-ROSIERE;61130;61;ORNE;1
61380;;Saint-Denis-de-Villenette;SAINT-DENIS-DE-VILLENETTE;61330;61;ORNE;1
61381;;Saint-Denis-sur-Huisne;SAINT-DENIS-SUR-HUISNE;61400;61;ORNE;1
61382;;Saint-Denis-sur-Sarthon;SAINT-DENIS-SUR-SARTHON;61420;61;ORNE;1
61383;;Saint-Didier-sous-Écouves;SAINT-DIDIER-SOUS-ECOUVES;61320;61;ORNE;1
61384;;Saint-Ellier-les-Bois;SAINT-ELLIER-LES-BOIS;61320;61;ORNE;1
61385;;Saint-Evroult-de-Montfort;SAINT-EVROULT-DE-MONTFORT;61230;61;ORNE;1
61386;;Saint-Evroult-Notre-Dame-du-Bois;SAINT-EVROULT-NOTRE-DAME-DU-BOIS;61550;61;ORNE;1
61387;;Saint-Fraimbault;SAINT-FRAIMBAULT;61350;61;ORNE;1
61388;;Saint-Fulgent-des-Ormes;SAINT-FULGENT-DES-ORMES;61130;61;ORNE;1
61389;;Sainte-Gauburge-Sainte-Colombe;SAINTE-GAUBURGE-SAINTE-COLOMBE;61370;61;ORNE;1
61390;;Saint-Georges-d'Annebecq;SAINT-GEORGES-D'ANNEBECQ;61600;61;ORNE;1
61391;;Saint-Georges-des-Groseillers;SAINT-GEORGES-DES-GROSEILLERS;61100;61;ORNE;1
61392;;Saint-Germain-d'Aunay;SAINT-GERMAIN-D'AUNAY;61470;61;ORNE;1
61393;;Saint-Germain-de-Clairefeuille;SAINT-GERMAIN-DE-CLAIREFEUILLE;61240;61;ORNE;1
61394;;Saint-Germain-de-la-Coudre;SAINT-GERMAIN-DE-LA-COUDRE;61130;61;ORNE;1
61395;;Saint-Germain-des-Grois;SAINT-GERMAIN-DES-GROIS;61110;61;ORNE;1
61396;;Saint-Germain-de-Martigny;SAINT-GERMAIN-DE-MARTIGNY;61560;61;ORNE;1
61397;;Saint-Germain-du-Corbéis;SAINT-GERMAIN-DU-CORBEIS;61000;61;ORNE;1
61398;;Saint-Germain-le-Vieux;SAINT-GERMAIN-LE-VIEUX;61390;61;ORNE;1
61399;;Saint-Gervais-des-Sablons;SAINT-GERVAIS-DES-SABLONS;61160;61;ORNE;1
61400;;Saint-Gervais-du-Perron;SAINT-GERVAIS-DU-PERRON;61500;61;ORNE;1
61401;;Saint-Gilles-des-Marais;SAINT-GILLES-DES-MARAIS;61700;61;ORNE;1
61402;;Saint-Hilaire-de-Briouze;SAINT-HILAIRE-DE-BRIOUZE;61220;61;ORNE;1
61403;;Saint-Hilaire-la-Gérard;SAINT-HILAIRE-LA-GERARD;61500;61;ORNE;1
61404;;Saint-Hilaire-le-Châtel;SAINT-HILAIRE-LE-CHATEL;61400;61;ORNE;1
61405;;Saint-Hilaire-sur-Erre;SAINT-HILAIRE-SUR-ERRE;61340;61;ORNE;1
61406;;Saint-Hilaire-sur-Risle;SAINT-HILAIRE-SUR-RISLE;61270;61;ORNE;1
61407;;Sainte-Honorine-la-Chardonne;SAINTE-HONORINE-LA-CHARDONNE;61430;61;ORNE;1
61408;;Sainte-Honorine-la-Guillaume;SAINTE-HONORINE-LA-GUILLAUME;61210;61;ORNE;1
61409;;Saint-Jean-de-la-Forêt;SAINT-JEAN-DE-LA-FORET;61340;61;ORNE;1
61410;;Saint-Jean-des-Bois;SAINT-JEAN-DES-BOIS;61800;61;ORNE;1
61411;;Saint-Jouin-de-Blavou;SAINT-JOUIN-DE-BLAVOU;61360;61;ORNE;1
61412;;Saint-Julien-sur-Sarthe;SAINT-JULIEN-SUR-SARTHE;61170;61;ORNE;1
61413;;Saint-Lambert-sur-Dive;SAINT-LAMBERT-SUR-DIVE;61160;61;ORNE;1
61414;;Saint-Langis-lès-Mortagne;SAINT-LANGIS-LES-MORTAGNE;61400;61;ORNE;1
61415;;Saint-Léger-sur-Sarthe;SAINT-LEGER-SUR-SARTHE;61170;61;ORNE;1
61416;;Saint-Léonard-des-Parcs;SAINT-LEONARD-DES-PARCS;61390;61;ORNE;1
61417;;Saint-Loyer-des-Champs;SAINT-LOYER-DES-CHAMPS;61570;61;ORNE;1
61418;;Saint-Mard-de-Réno;SAINT-MARD-DE-RENO;61400;61;ORNE;1
61419;;Sainte-Marguerite-de-Carrouges;SAINTE-MARGUERITE-DE-CARROUGES;61320;61;ORNE;1
61420;;Sainte-Marie-la-Robert;SAINTE-MARIE-LA-ROBERT;61320;61;ORNE;1
61421;;Saint-Mars-d'Égrenne;SAINT-MARS-D'EGRENNE;61350;61;ORNE;1
61422;Les;Aspres;ASPRES;61270;61;ORNE;1
61423;;Saint-Martin-d'Écublei;SAINT-MARTIN-D'ECUBLEI;61300;61;ORNE;1
61424;;Saint-Martin-des-Landes;SAINT-MARTIN-DES-LANDES;61320;61;ORNE;1
61425;;Saint-Martin-des-Pézerits;SAINT-MARTIN-DES-PEZERITS;61380;61;ORNE;1
61426;;Saint-Martin-du-Vieux-Bellême;SAINT-MARTIN-DU-VIEUX-BELLEME;61130;61;ORNE;1
61427;;Saint-Martin-l'Aiguillon;SAINT-MARTIN-L'AIGUILLON;61320;61;ORNE;1
61428;;Saint-Maurice-du-Désert;SAINT-MAURICE-DU-DESERT;61600;61;ORNE;1
61429;;Saint-Maurice-lès-Charencey;SAINT-MAURICE-LES-CHARENCEY;61190;61;ORNE;1
61430;;Saint-Maurice-sur-Huisne;SAINT-MAURICE-SUR-HUISNE;61110;61;ORNE;1
61431;;Saint-Michel-des-Andaines;SAINT-MICHEL-DES-ANDAINES;61600;61;ORNE;1
61432;;Saint-Michel-Tubœuf;SAINT-MICHEL-TUBOEUF;61300;61;ORNE;1
61433;;Saint-Nicolas-des-Bois;SAINT-NICOLAS-DES-BOIS;61250;61;ORNE;1
61434;;Saint-Nicolas-des-Laitiers;SAINT-NICOLAS-DES-LAITIERS;61550;61;ORNE;1
61435;;Saint-Nicolas-de-Sommaire;SAINT-NICOLAS-DE-SOMMAIRE;61550;61;ORNE;1
61436;;Sainte-Opportune;SAINTE-OPPORTUNE;61100;61;ORNE;1
61437;;Saint-Ouen-de-la-Cour;SAINT-OUEN-DE-LA-COUR;61130;61;ORNE;1
61438;;Saint-Ouen-de-Sécherouvre;SAINT-OUEN-DE-SECHEROUVRE;61560;61;ORNE;1
61439;;Saint-Ouen-le-Brisoult;SAINT-OUEN-LE-BRISOULT;61410;61;ORNE;1
61440;;Saint-Ouen-sur-Iton;SAINT-OUEN-SUR-ITON;61300;61;ORNE;1
61441;;Saint-Ouen-sur-Maire;SAINT-OUEN-SUR-MAIRE;61150;61;ORNE;1
61442;;Saint-Patrice-du-Désert;SAINT-PATRICE-DU-DESERT;61600;61;ORNE;1
61443;;Saint-Paul;SAINT-PAUL;61100;61;ORNE;1
61444;;Saint-Philbert-sur-Orne;SAINT-PHILBERT-SUR-ORNE;61430;61;ORNE;1
61445;;Saint-Pierre-d'Entremont;SAINT-PIERRE-D'ENTREMONT;61800;61;ORNE;1
61446;;Saint-Pierre-des-Loges;SAINT-PIERRE-DES-LOGES;61370;61;ORNE;1
61447;;Saint-Pierre-du-Regard;SAINT-PIERRE-DU-REGARD;61790;61;ORNE;1
61448;;Saint-Pierre-la-Bruyère;SAINT-PIERRE-LA-BRUYERE;61340;61;ORNE;1
61449;;Saint-Pierre-la-Rivière;SAINT-PIERRE-LA-RIVIERE;61310;61;ORNE;1
61450;;Saint-Quentin-de-Blavou;SAINT-QUENTIN-DE-BLAVOU;61360;61;ORNE;1
61451;;Saint-Quentin-les-Chardonnets;SAINT-QUENTIN-LES-CHARDONNETS;61800;61;ORNE;1
61452;;Saint-Roch-sur-Égrenne;SAINT-ROCH-SUR-EGRENNE;61350;61;ORNE;1
61453;;Saint-Sauveur-de-Carrouges;SAINT-SAUVEUR-DE-CARROUGES;61320;61;ORNE;1
61454;;Sainte-Scolasse-sur-Sarthe;SAINTE-SCOLASSE-SUR-SARTHE;61170;61;ORNE;1
61455;;Saint-Siméon;SAINT-SIMEON;61350;61;ORNE;1
61456;;Saint-Sulpice-sur-Risle;SAINT-SULPICE-SUR-RISLE;61300;61;ORNE;1
61457;;Saint-Symphorien-des-Bruyères;SAINT-SYMPHORIEN-DES-BRUYERES;61300;61;ORNE;1
61458;;Saint-Victor-de-Réno;SAINT-VICTOR-DE-RENO;61290;61;ORNE;1
61459;;Saires-la-Verrerie;SAIRES-LA-VERRERIE;61220;61;ORNE;1
61460;Le;Sap;SAP;61470;61;ORNE;1
61461;Le;Sap-André;SAP-ANDRE;61230;61;ORNE;1
61462;;Sarceaux;SARCEAUX;61200;61;ORNE;1
61463;La;Sauvagère;SAUVAGERE;61600;61;ORNE;1
61464;;Sées;SEES;61500;61;ORNE;1
61465;;Ségrie-Fontaine;SEGRIE-FONTAINE;61100;61;ORNE;1
61466;La;Selle-la-Forge;SELLE-LA-FORGE;61100;61;ORNE;1
61467;;Semallé;SEMALLE;61250;61;ORNE;1
61468;;Sentilly;SENTILLY;61150;61;ORNE;1
61469;;Sept-Forges;SEPT-FORGES;61330;61;ORNE;1
61470;;Serans;SERANS;61150;61;ORNE;1
61471;;Sérigny;SERIGNY;61130;61;ORNE;1
61472;;Sévigny;SEVIGNY;61200;61;ORNE;1
61473;;Sevrai;SEVRAI;61150;61;ORNE;1
61474;;Silly-en-Gouffern;SILLY-EN-GOUFFERN;61310;61;ORNE;1
61475;;Soligny-la-Trappe;SOLIGNY-LA-TRAPPE;61380;61;ORNE;1
61476;;Suré;SURE;61360;61;ORNE;1
61477;;Survie;SURVIE;61310;61;ORNE;1
61478;;Taillebois;TAILLEBOIS;61100;61;ORNE;1
61479;;Tanques;TANQUES;61150;61;ORNE;1
61480;;Tanville;TANVILLE;61500;61;ORNE;1
61481;;Tellières-le-Plessis;TELLIERES-LE-PLESSIS;61390;61;ORNE;1
61482;;Tessé-Froulay;TESSE-FROULAY;61410;61;ORNE;1
61483;;Bagnoles-de-l'Orne;BAGNOLES-DE-L'ORNE;61140;61;ORNE;1
61484;Le;Theil;THEIL;61260;61;ORNE;1
61485;;Ticheville;TICHEVILLE;61120;61;ORNE;1
61486;;Tinchebray;TINCHEBRAY;61800;61;ORNE;1
61487;;Torchamp;TORCHAMP;61330;61;ORNE;1
61488;;Touquettes;TOUQUETTES;61550;61;ORNE;1
61489;Les;Tourailles;TOURAILLES;61100;61;ORNE;1
61490;;Tournai-sur-Dive;TOURNAI-SUR-DIVE;61160;61;ORNE;1
61491;;Tourouvre;TOUROUVRE;61190;61;ORNE;1
61492;;Trémont;TREMONT;61390;61;ORNE;1
61493;La;Trinité-des-Laitiers;TRINITE-DES-LAITIERS;61230;61;ORNE;1
61494;;Trun;TRUN;61160;61;ORNE;1
61496;;Urou-et-Crennes;UROU-ET-CRENNES;61200;61;ORNE;1
61497;;Valframbert;VALFRAMBERT;61250;61;ORNE;1
61498;;Vaunoise;VAUNOISE;61130;61;ORNE;1
61499;Les;Ventes-de-Bourse;VENTES-DE-BOURSE;61170;61;ORNE;1
61500;La;Ventrouze;VENTROUZE;61190;61;ORNE;1
61501;;Verrières;VERRIERES;61110;61;ORNE;1
61502;;Vidai;VIDAI;61360;61;ORNE;1
61503;;Vieux-Pont;VIEUX-PONT;61150;61;ORNE;1
61504;;Villebadin;VILLEBADIN;61310;61;ORNE;1
61505;;Villedieu-lès-Bailleul;VILLEDIEU-LES-BAILLEUL;61160;61;ORNE;1
61506;;Villers-en-Ouche;VILLERS-EN-OUCHE;61550;61;ORNE;1
61507;;Villiers-sous-Mortagne;VILLIERS-SOUS-MORTAGNE;61400;61;ORNE;1
61508;;Vimoutiers;VIMOUTIERS;61120;61;ORNE;1
61509;;Vingt-Hanaps;VINGT-HANAPS;61250;61;ORNE;1
61510;;Vitrai-sous-Laigle;VITRAI-SOUS-LAIGLE;61300;61;ORNE;1
61511;;Vrigny;VRIGNY;61570;61;ORNE;1
61512;Les;Yveteaux;YVETEAUX;61210;61;ORNE;1
61513;;Yvrandes;YVRANDES;61800;61;ORNE;1
62001;;Ablain-Saint-Nazaire;ABLAIN-SAINT-NAZAIRE;62153;62;PAS DE CALAIS;1
62002;;Ablainzevelle;ABLAINZEVELLE;62116;62;PAS DE CALAIS;1
62003;;Acheville;ACHEVILLE;62320;62;PAS DE CALAIS;1
62004;;Achicourt;ACHICOURT;62217;62;PAS DE CALAIS;1
62005;;Achiet-le-Grand;ACHIET-LE-GRAND;62121;62;PAS DE CALAIS;1
62006;;Achiet-le-Petit;ACHIET-LE-PETIT;62121;62;PAS DE CALAIS;1
62007;;Acq;ACQ;62144;62;PAS DE CALAIS;1
62008;;Acquin-Westbécourt;ACQUIN-WESTBECOURT;62380;62;PAS DE CALAIS;1
62009;;Adinfer;ADINFER;62116;62;PAS DE CALAIS;1
62010;;Affringues;AFFRINGUES;62380;62;PAS DE CALAIS;1
62011;;Agnez-lès-Duisans;AGNEZ-LES-DUISANS;62161;62;PAS DE CALAIS;1
62012;;Agnières;AGNIERES;62690;62;PAS DE CALAIS;1
62013;;Agny;AGNY;62217;62;PAS DE CALAIS;1
62014;;Aire-sur-la-Lys;AIRE-SUR-LA-LYS;62120;62;PAS DE CALAIS;1
62015;;Airon-Notre-Dame;AIRON-NOTRE-DAME;62180;62;PAS DE CALAIS;1
62016;;Airon-Saint-Vaast;AIRON-SAINT-VAAST;62180;62;PAS DE CALAIS;1
62017;;Aix-en-Ergny;AIX-EN-ERGNY;62650;62;PAS DE CALAIS;1
62018;;Aix-en-Issart;AIX-EN-ISSART;62170;62;PAS DE CALAIS;1
62019;;Aix-Noulette;AIX-NOULETTE;62160;62;PAS DE CALAIS;1
62020;;Alembon;ALEMBON;62850;62;PAS DE CALAIS;1
62021;;Alette;ALETTE;62650;62;PAS DE CALAIS;1
62022;;Alincthun;ALINCTHUN;62142;62;PAS DE CALAIS;1
62023;;Allouagne;ALLOUAGNE;62157;62;PAS DE CALAIS;1
62024;;Alquines;ALQUINES;62850;62;PAS DE CALAIS;1
62025;;Ambleteuse;AMBLETEUSE;62164;62;PAS DE CALAIS;1
62026;;Ambricourt;AMBRICOURT;62310;62;PAS DE CALAIS;1
62027;;Ambrines;AMBRINES;62127;62;PAS DE CALAIS;1
62028;;Ames;AMES;62190;62;PAS DE CALAIS;1
62029;;Amettes;AMETTES;62260;62;PAS DE CALAIS;1
62030;;Amplier;AMPLIER;62760;62;PAS DE CALAIS;1
62031;;Andres;ANDRES;62340;62;PAS DE CALAIS;1
62032;;Angres;ANGRES;62143;62;PAS DE CALAIS;1
62033;;Annay;ANNAY;62880;62;PAS DE CALAIS;1
62034;;Annequin;ANNEQUIN;62149;62;PAS DE CALAIS;1
62035;;Annezin;ANNEZIN;62232;62;PAS DE CALAIS;1
62036;;Anvin;ANVIN;62134;62;PAS DE CALAIS;1
62037;;Anzin-Saint-Aubin;ANZIN-SAINT-AUBIN;62223;62;PAS DE CALAIS;1
62038;;Ardres;ARDRES;62610;62;PAS DE CALAIS;1
62039;;Arleux-en-Gohelle;ARLEUX-EN-GOHELLE;62580;62;PAS DE CALAIS;1
62040;;Arques;ARQUES;62510;62;PAS DE CALAIS;1
62041;;Arras;ARRAS;62000;62;PAS DE CALAIS;1
62042;;Athies;ATHIES;62223;62;PAS DE CALAIS;1
62043;Les;Attaques;ATTAQUES;62730;62;PAS DE CALAIS;1
62044;;Attin;ATTIN;62170;62;PAS DE CALAIS;1
62045;;Aubigny-en-Artois;AUBIGNY-EN-ARTOIS;62690;62;PAS DE CALAIS;1
62046;;Aubin-Saint-Vaast;AUBIN-SAINT-VAAST;62140;62;PAS DE CALAIS;1
62047;;Aubrometz;AUBROMETZ;62390;62;PAS DE CALAIS;1
62048;;Auchel;AUCHEL;62260;62;PAS DE CALAIS;1
62049;;Auchy-au-Bois;AUCHY-AU-BOIS;62190;62;PAS DE CALAIS;1
62050;;Auchy-lès-Hesdin;AUCHY-LES-HESDIN;62770;62;PAS DE CALAIS;1
62051;;Auchy-les-Mines;AUCHY-LES-MINES;62138;62;PAS DE CALAIS;1
62052;;Audembert;AUDEMBERT;62250;62;PAS DE CALAIS;1
62053;;Audincthun;AUDINCTHUN;62560;62;PAS DE CALAIS;1
62054;;Audinghen;AUDINGHEN;62179;62;PAS DE CALAIS;1
62055;;Audrehem;AUDREHEM;62890;62;PAS DE CALAIS;1
62056;;Audresselles;AUDRESSELLES;62164;62;PAS DE CALAIS;1
62057;;Audruicq;AUDRUICQ;62370;62;PAS DE CALAIS;1
62058;;Aumerval;AUMERVAL;62550;62;PAS DE CALAIS;1
62059;;Autingues;AUTINGUES;62610;62;PAS DE CALAIS;1
62060;;Auxi-le-Château;AUXI-LE-CHATEAU;62390;62;PAS DE CALAIS;1
62061;;Averdoingt;AVERDOINGT;62127;62;PAS DE CALAIS;1
62062;;Avesnes;AVESNES;62650;62;PAS DE CALAIS;1
62063;;Avesnes-le-Comte;AVESNES-LE-COMTE;62810;62;PAS DE CALAIS;1
62064;;Avesnes-lès-Bapaume;AVESNES-LES-BAPAUME;62450;62;PAS DE CALAIS;1
62065;;Avion;AVION;62210;62;PAS DE CALAIS;1
62066;;Avondance;AVONDANCE;62310;62;PAS DE CALAIS;1
62067;;Avroult;AVROULT;62560;62;PAS DE CALAIS;1
62068;;Ayette;AYETTE;62116;62;PAS DE CALAIS;1
62069;;Azincourt;AZINCOURT;62310;62;PAS DE CALAIS;1
62070;;Bailleul-aux-Cornailles;BAILLEUL-AUX-CORNAILLES;62127;62;PAS DE CALAIS;1
62071;;Bailleul-lès-Pernes;BAILLEUL-LES-PERNES;62550;62;PAS DE CALAIS;1
62072;;Bailleulmont;BAILLEULMONT;62123;62;PAS DE CALAIS;1
62073;;Bailleul-Sir-Berthoult;BAILLEUL-SIR-BERTHOULT;62580;62;PAS DE CALAIS;1
62074;;Bailleulval;BAILLEULVAL;62123;62;PAS DE CALAIS;1
62075;;Baincthun;BAINCTHUN;62360;62;PAS DE CALAIS;1
62076;;Bainghen;BAINGHEN;62850;62;PAS DE CALAIS;1
62077;;Bajus;BAJUS;62150;62;PAS DE CALAIS;1
62078;;Balinghem;BALINGHEM;62610;62;PAS DE CALAIS;1
62079;;Bancourt;BANCOURT;62450;62;PAS DE CALAIS;1
62080;;Bapaume;BAPAUME;62450;62;PAS DE CALAIS;1
62081;;Baralle;BARALLE;62860;62;PAS DE CALAIS;1
62082;;Barastre;BARASTRE;62124;62;PAS DE CALAIS;1
62083;;Barlin;BARLIN;62620;62;PAS DE CALAIS;1
62084;;Barly;BARLY;62810;62;PAS DE CALAIS;1
62085;;Basseux;BASSEUX;62123;62;PAS DE CALAIS;1
62086;;Bavincourt;BAVINCOURT;62158;62;PAS DE CALAIS;1
62087;;Bayenghem-lès-Éperlecques;BAYENGHEM-LES-EPERLECQUES;62910;62;PAS DE CALAIS;1
62088;;Bayenghem-lès-Seninghem;BAYENGHEM-LES-SENINGHEM;62380;62;PAS DE CALAIS;1
62089;;Bazinghen;BAZINGHEN;62250;62;PAS DE CALAIS;1
62090;;Béalencourt;BEALENCOURT;62770;62;PAS DE CALAIS;1
62091;;Beaudricourt;BEAUDRICOURT;62810;62;PAS DE CALAIS;1
62092;;Beaufort-Blavincourt;BEAUFORT-BLAVINCOURT;62810;62;PAS DE CALAIS;1
62093;;Beaulencourt;BEAULENCOURT;62450;62;PAS DE CALAIS;1
62094;;Beaumerie-Saint-Martin;BEAUMERIE-SAINT-MARTIN;62170;62;PAS DE CALAIS;1
62095;;Beaumetz-lès-Aire;BEAUMETZ-LES-AIRE;62960;62;PAS DE CALAIS;1
62096;;Beaumetz-lès-Cambrai;BEAUMETZ-LES-CAMBRAI;62124;62;PAS DE CALAIS;1
62097;;Beaumetz-lès-Loges;BEAUMETZ-LES-LOGES;62123;62;PAS DE CALAIS;1
62099;;Beaurains;BEAURAINS;62217;62;PAS DE CALAIS;1
62100;;Beaurainville;BEAURAINVILLE;62990;62;PAS DE CALAIS;1
62101;;Beauvois;BEAUVOIS;62130;62;PAS DE CALAIS;1
62102;;Bécourt;BECOURT;62240;62;PAS DE CALAIS;1
62103;;Béhagnies;BEHAGNIES;62121;62;PAS DE CALAIS;1
62104;;Bellebrune;BELLEBRUNE;62142;62;PAS DE CALAIS;1
62105;;Belle-et-Houllefort;BELLE-ET-HOULLEFORT;62142;62;PAS DE CALAIS;1
62106;;Bellonne;BELLONNE;62490;62;PAS DE CALAIS;1
62107;;Bénifontaine;BENIFONTAINE;62410;62;PAS DE CALAIS;1
62108;;Berck;BERCK;62600;62;PAS DE CALAIS;1
62109;;Bergueneuse;BERGUENEUSE;62134;62;PAS DE CALAIS;1
62111;;Berlencourt-le-Cauroy;BERLENCOURT-LE-CAUROY;62810;62;PAS DE CALAIS;1
62112;;Berles-au-Bois;BERLES-AU-BOIS;62123;62;PAS DE CALAIS;1
62113;;Berles-Monchel;BERLES-MONCHEL;62690;62;PAS DE CALAIS;1
62114;;Bermicourt;BERMICOURT;62130;62;PAS DE CALAIS;1
62115;;Berneville;BERNEVILLE;62123;62;PAS DE CALAIS;1
62116;;Bernieulles;BERNIEULLES;62170;62;PAS DE CALAIS;1
62117;;Bertincourt;BERTINCOURT;62124;62;PAS DE CALAIS;1
62118;;Béthonsart;BETHONSART;62690;62;PAS DE CALAIS;1
62119;;Béthune;BETHUNE;62400;62;PAS DE CALAIS;1
62120;;Beugin;BEUGIN;62150;62;PAS DE CALAIS;1
62121;;Beugnâtre;BEUGNATRE;62450;62;PAS DE CALAIS;1
62122;;Beugny;BEUGNY;62124;62;PAS DE CALAIS;1
62123;;Beussent;BEUSSENT;62170;62;PAS DE CALAIS;1
62124;;Beutin;BEUTIN;62170;62;PAS DE CALAIS;1
62125;;Beuvrequen;BEUVREQUEN;62250;62;PAS DE CALAIS;1
62126;;Beuvry;BEUVRY;62660;62;PAS DE CALAIS;1
62127;;Bezinghem;BEZINGHEM;62650;62;PAS DE CALAIS;1
62128;;Biache-Saint-Vaast;BIACHE-SAINT-VAAST;62118;62;PAS DE CALAIS;1
62129;;Biefvillers-lès-Bapaume;BIEFVILLERS-LES-BAPAUME;62450;62;PAS DE CALAIS;1
62130;;Bienvillers-au-Bois;BIENVILLERS-AU-BOIS;62111;62;PAS DE CALAIS;1
62131;;Bihucourt;BIHUCOURT;62121;62;PAS DE CALAIS;1
62132;;Billy-Berclau;BILLY-BERCLAU;62138;62;PAS DE CALAIS;1
62133;;Billy-Montigny;BILLY-MONTIGNY;62420;62;PAS DE CALAIS;1
62134;;Bimont;BIMONT;62650;62;PAS DE CALAIS;1
62135;;Blairville;BLAIRVILLE;62173;62;PAS DE CALAIS;1
62137;;Blangerval-Blangermont;BLANGERVAL-BLANGERMONT;62270;62;PAS DE CALAIS;1
62138;;Blangy-sur-Ternoise;BLANGY-SUR-TERNOISE;62770;62;PAS DE CALAIS;1
62139;;Blendecques;BLENDECQUES;62575;62;PAS DE CALAIS;1
62140;;Bléquin;BLEQUIN;62380;62;PAS DE CALAIS;1
62141;;Blessy;BLESSY;62120;62;PAS DE CALAIS;1
62142;;Blingel;BLINGEL;62770;62;PAS DE CALAIS;1
62143;;Boffles;BOFFLES;62390;62;PAS DE CALAIS;1
62144;;Boiry-Becquerelle;BOIRY-BECQUERELLE;62128;62;PAS DE CALAIS;1
62145;;Boiry-Notre-Dame;BOIRY-NOTRE-DAME;62156;62;PAS DE CALAIS;1
62146;;Boiry-Saint-Martin;BOIRY-SAINT-MARTIN;62175;62;PAS DE CALAIS;1
62147;;Boiry-Sainte-Rictrude;BOIRY-SAINTE-RICTRUDE;62175;62;PAS DE CALAIS;1
62148;;Bois-Bernard;BOIS-BERNARD;62320;62;PAS DE CALAIS;1
62149;;Boisdinghem;BOISDINGHEM;62500;62;PAS DE CALAIS;1
62150;;Boisjean;BOISJEAN;62170;62;PAS DE CALAIS;1
62151;;Boisleux-au-Mont;BOISLEUX-AU-MONT;62175;62;PAS DE CALAIS;1
62152;;Boisleux-Saint-Marc;BOISLEUX-SAINT-MARC;62175;62;PAS DE CALAIS;1
62153;;Bomy;BOMY;62960;62;PAS DE CALAIS;1
62154;;Bonnières;BONNIERES;62270;62;PAS DE CALAIS;1
62155;;Bonningues-lès-Ardres;BONNINGUES-LES-ARDRES;62890;62;PAS DE CALAIS;1
62156;;Bonningues-lès-Calais;BONNINGUES-LES-CALAIS;62340;62;PAS DE CALAIS;1
62157;;Boubers-lès-Hesmond;BOUBERS-LES-HESMOND;62990;62;PAS DE CALAIS;1
62158;;Boubers-sur-Canche;BOUBERS-SUR-CANCHE;62270;62;PAS DE CALAIS;1
62160;;Boulogne-sur-Mer;BOULOGNE-SUR-MER;62200;62;PAS DE CALAIS;1
62161;;Bouquehault;BOUQUEHAULT;62340;62;PAS DE CALAIS;1
62162;;Bourecq;BOURECQ;62190;62;PAS DE CALAIS;1
62163;;Bouret-sur-Canche;BOURET-SUR-CANCHE;62270;62;PAS DE CALAIS;1
62164;;Bourlon;BOURLON;62860;62;PAS DE CALAIS;1
62165;;Bournonville;BOURNONVILLE;62240;62;PAS DE CALAIS;1
62166;;Bours;BOURS;62550;62;PAS DE CALAIS;1
62167;;Boursin;BOURSIN;62132;62;PAS DE CALAIS;1
62168;;Bourthes;BOURTHES;62650;62;PAS DE CALAIS;1
62169;;Bouvelinghem;BOUVELINGHEM;62380;62;PAS DE CALAIS;1
62170;;Bouvigny-Boyeffles;BOUVIGNY-BOYEFFLES;62172;62;PAS DE CALAIS;1
62171;;Boyaval;BOYAVAL;62134;62;PAS DE CALAIS;1
62172;;Boyelles;BOYELLES;62128;62;PAS DE CALAIS;1
62173;;Brebières;BREBIERES;62117;62;PAS DE CALAIS;1
62174;;Brêmes;BREMES;62610;62;PAS DE CALAIS;1
62175;;Brévillers;BREVILLERS;62140;62;PAS DE CALAIS;1
62176;;Bréxent-Énocq;BREXENT-ENOCQ;62170;62;PAS DE CALAIS;1
62177;;Brimeux;BRIMEUX;62170;62;PAS DE CALAIS;1
62178;;Bruay-la-Buissière;BRUAY-LA-BUISSIERE;62700;62;PAS DE CALAIS;1
62179;;Brunembert;BRUNEMBERT;62240;62;PAS DE CALAIS;1
62180;;Brias;BRIAS;62130;62;PAS DE CALAIS;1
62181;;Bucquoy;BUCQUOY;62116;62;PAS DE CALAIS;1
62182;;Buire-au-Bois;BUIRE-AU-BOIS;62390;62;PAS DE CALAIS;1
62183;;Buire-le-Sec;BUIRE-LE-SEC;62870;62;PAS DE CALAIS;1
62184;;Buissy;BUISSY;62860;62;PAS DE CALAIS;1
62185;;Bullecourt;BULLECOURT;62128;62;PAS DE CALAIS;1
62186;;Bully-les-Mines;BULLY-LES-MINES;62160;62;PAS DE CALAIS;1
62187;;Buneville;BUNEVILLE;62130;62;PAS DE CALAIS;1
62188;;Burbure;BURBURE;62151;62;PAS DE CALAIS;1
62189;;Bus;BUS;62124;62;PAS DE CALAIS;1
62190;;Busnes;BUSNES;62350;62;PAS DE CALAIS;1
62191;;Caffiers;CAFFIERS;62132;62;PAS DE CALAIS;1
62192;;Cagnicourt;CAGNICOURT;62182;62;PAS DE CALAIS;1
62193;;Calais;CALAIS;62100;62;PAS DE CALAIS;1
62194;;Calonne-Ricouart;CALONNE-RICOUART;62470;62;PAS DE CALAIS;1
62195;;Calonne-sur-la-Lys;CALONNE-SUR-LA-LYS;62350;62;PAS DE CALAIS;1
62196;La;Calotterie;CALOTTERIE;62170;62;PAS DE CALAIS;1
62197;;Camblain-Châtelain;CAMBLAIN-CHATELAIN;62470;62;PAS DE CALAIS;1
62198;;Cambligneul;CAMBLIGNEUL;62690;62;PAS DE CALAIS;1
62199;;Camblain-l'Abbé;CAMBLAIN-L'ABBE;62690;62;PAS DE CALAIS;1
62200;;Cambrin;CAMBRIN;62149;62;PAS DE CALAIS;1
62201;;Camiers;CAMIERS;62176;62;PAS DE CALAIS;1
62202;;Campagne-lès-Boulonnais;CAMPAGNE-LES-BOULONNAIS;62650;62;PAS DE CALAIS;1
62203;;Campagne-lès-Guines;CAMPAGNE-LES-GUINES;62340;62;PAS DE CALAIS;1
62204;;Campagne-lès-Hesdin;CAMPAGNE-LES-HESDIN;62870;62;PAS DE CALAIS;1
62205;;Campagne-lès-Wardrecques;CAMPAGNE-LES-WARDRECQUES;62120;62;PAS DE CALAIS;1
62206;;Campigneulles-les-Grandes;CAMPIGNEULLES-LES-GRANDES;62170;62;PAS DE CALAIS;1
62207;;Campigneulles-les-Petites;CAMPIGNEULLES-LES-PETITES;62170;62;PAS DE CALAIS;1
62208;;Canettemont;CANETTEMONT;62270;62;PAS DE CALAIS;1
62209;;Canlers;CANLERS;62310;62;PAS DE CALAIS;1
62210;;Canteleux;CANTELEUX;62270;62;PAS DE CALAIS;1
62211;;Capelle-Fermont;CAPELLE-FERMONT;62690;62;PAS DE CALAIS;1
62212;;Capelle-lès-Hesdin;CAPELLE-LES-HESDIN;62140;62;PAS DE CALAIS;1
62213;;Carency;CARENCY;62144;62;PAS DE CALAIS;1
62214;;Carly;CARLY;62830;62;PAS DE CALAIS;1
62215;;Carvin;CARVIN;62220;62;PAS DE CALAIS;1
62216;La;Cauchie;CAUCHIE;62158;62;PAS DE CALAIS;1
62217;;Cauchy-à-la-Tour;CAUCHY-A-LA-TOUR;62260;62;PAS DE CALAIS;1
62218;;Caucourt;CAUCOURT;62150;62;PAS DE CALAIS;1
62219;;Caumont;CAUMONT;62140;62;PAS DE CALAIS;1
62220;;Cavron-Saint-Martin;CAVRON-SAINT-MARTIN;62140;62;PAS DE CALAIS;1
62221;;Chelers;CHELERS;62127;62;PAS DE CALAIS;1
62222;;Chériennes;CHERIENNES;62140;62;PAS DE CALAIS;1
62223;;Chérisy;CHERISY;62128;62;PAS DE CALAIS;1
62224;;Chocques;CHOCQUES;62920;62;PAS DE CALAIS;1
62225;;Clairmarais;CLAIRMARAIS;62500;62;PAS DE CALAIS;1
62226;;Clarques;CLARQUES;62129;62;PAS DE CALAIS;1
62227;;Clenleu;CLENLEU;62650;62;PAS DE CALAIS;1
62228;;Clerques;CLERQUES;62890;62;PAS DE CALAIS;1
62229;;Cléty;CLETY;62380;62;PAS DE CALAIS;1
62230;;Colembert;COLEMBERT;62142;62;PAS DE CALAIS;1
62231;;Colline-Beaumont;COLLINE-BEAUMONT;62180;62;PAS DE CALAIS;1
62232;La;Comté;COMTE;62150;62;PAS DE CALAIS;1
62233;;Conchil-le-Temple;CONCHIL-LE-TEMPLE;62180;62;PAS DE CALAIS;1
62234;;Conchy-sur-Canche;CONCHY-SUR-CANCHE;62270;62;PAS DE CALAIS;1
62235;;Condette;CONDETTE;62360;62;PAS DE CALAIS;1
62236;;Contes;CONTES;62990;62;PAS DE CALAIS;1
62237;;Conteville-lès-Boulogne;CONTEVILLE-LES-BOULOGNE;62126;62;PAS DE CALAIS;1
62238;;Conteville-en-Ternois;CONTEVILLE-EN-TERNOIS;62130;62;PAS DE CALAIS;1
62239;;Coquelles;COQUELLES;62231;62;PAS DE CALAIS;1
62240;;Corbehem;CORBEHEM;62112;62;PAS DE CALAIS;1
62241;;Cormont;CORMONT;62630;62;PAS DE CALAIS;1
62242;;Couin;COUIN;62760;62;PAS DE CALAIS;1
62243;;Coullemont;COULLEMONT;62158;62;PAS DE CALAIS;1
62244;;Coulogne;COULOGNE;62137;62;PAS DE CALAIS;1
62245;;Coulomby;COULOMBY;62380;62;PAS DE CALAIS;1
62246;;Coupelle-Neuve;COUPELLE-NEUVE;62310;62;PAS DE CALAIS;1
62247;;Coupelle-Vieille;COUPELLE-VIEILLE;62310;62;PAS DE CALAIS;1
62248;;Courcelles-le-Comte;COURCELLES-LE-COMTE;62121;62;PAS DE CALAIS;1
62249;;Courcelles-lès-Lens;COURCELLES-LES-LENS;62970;62;PAS DE CALAIS;1
62250;;Courrières;COURRIERES;62710;62;PAS DE CALAIS;1
62251;;Courset;COURSET;62240;62;PAS DE CALAIS;1
62252;La;Couture;COUTURE;62136;62;PAS DE CALAIS;1
62253;;Couturelle;COUTURELLE;62158;62;PAS DE CALAIS;1
62254;;Coyecques;COYECQUES;62560;62;PAS DE CALAIS;1
62255;;Crémarest;CREMAREST;62240;62;PAS DE CALAIS;1
62256;;Crépy;CREPY;62310;62;PAS DE CALAIS;1
62257;;Créquy;CREQUY;62310;62;PAS DE CALAIS;1
62258;;Croisette;CROISETTE;62130;62;PAS DE CALAIS;1
62259;;Croisilles;CROISILLES;62128;62;PAS DE CALAIS;1
62260;;Croix-en-Ternois;CROIX-EN-TERNOIS;62130;62;PAS DE CALAIS;1
62261;;Cucq;CUCQ;62780;62;PAS DE CALAIS;1
62262;;Cuinchy;CUINCHY;62149;62;PAS DE CALAIS;1
62263;;Dainville;DAINVILLE;62000;62;PAS DE CALAIS;1
62264;;Dannes;DANNES;62187;62;PAS DE CALAIS;1
62265;;Delettes;DELETTES;62129;62;PAS DE CALAIS;1
62266;;Denier;DENIER;62810;62;PAS DE CALAIS;1
62267;;Dennebrœucq;DENNEBROEUCQ;62560;62;PAS DE CALAIS;1
62268;;Desvres;DESVRES;62240;62;PAS DE CALAIS;1
62269;;Diéval;DIEVAL;62460;62;PAS DE CALAIS;1
62270;;Divion;DIVION;62460;62;PAS DE CALAIS;1
62271;;Dohem;DOHEM;62380;62;PAS DE CALAIS;1
62272;;Douchy-lès-Ayette;DOUCHY-LES-AYETTE;62116;62;PAS DE CALAIS;1
62273;;Doudeauville;DOUDEAUVILLE;62830;62;PAS DE CALAIS;1
62274;;Dourges;DOURGES;62119;62;PAS DE CALAIS;1
62275;;Douriez;DOURIEZ;62870;62;PAS DE CALAIS;1
62276;;Douvrin;DOUVRIN;62138;62;PAS DE CALAIS;1
62277;;Drocourt;DROCOURT;62320;62;PAS DE CALAIS;1
62278;;Drouvin-le-Marais;DROUVIN-LE-MARAIS;62131;62;PAS DE CALAIS;1
62279;;Duisans;DUISANS;62161;62;PAS DE CALAIS;1
62280;;Dury;DURY;62156;62;PAS DE CALAIS;1
62281;;Echinghen;ECHINGHEN;62360;62;PAS DE CALAIS;1
62282;;Éclimeux;ECLIMEUX;62770;62;PAS DE CALAIS;1
62283;;Écoivres;ECOIVRES;62270;62;PAS DE CALAIS;1
62284;;Écourt-Saint-Quentin;ECOURT-SAINT-QUENTIN;62860;62;PAS DE CALAIS;1
62285;;Écoust-Saint-Mein;ECOUST-SAINT-MEIN;62128;62;PAS DE CALAIS;1
62286;;Ecquedecques;ECQUEDECQUES;62190;62;PAS DE CALAIS;1
62288;;Ecques;ECQUES;62129;62;PAS DE CALAIS;1
62289;;Écuires;ECUIRES;62170;62;PAS DE CALAIS;1
62290;;Écurie;ECURIE;62223;62;PAS DE CALAIS;1
62291;;Éleu-dit-Leauwette;ELEU-DIT-LEAUWETTE;62300;62;PAS DE CALAIS;1
62292;;Elnes;ELNES;62380;62;PAS DE CALAIS;1
62293;;Embry;EMBRY;62990;62;PAS DE CALAIS;1
62294;;Enguinegatte;ENGUINEGATTE;62145;62;PAS DE CALAIS;1
62295;;Enquin-les-Mines;ENQUIN-LES-MINES;62145;62;PAS DE CALAIS;1
62296;;Enquin-sur-Baillons;ENQUIN-SUR-BAILLONS;62650;62;PAS DE CALAIS;1
62297;;Éperlecques;EPERLECQUES;62910;62;PAS DE CALAIS;1
62298;;Épinoy;EPINOY;62860;62;PAS DE CALAIS;1
62299;;Eps;EPS;62134;62;PAS DE CALAIS;1
62300;;Équihen-Plage;EQUIHEN-PLAGE;62224;62;PAS DE CALAIS;1
62301;;Équirre;EQUIRRE;62134;62;PAS DE CALAIS;1
62302;;Ergny;ERGNY;62650;62;PAS DE CALAIS;1
62303;;Érin;ERIN;62134;62;PAS DE CALAIS;1
62304;;Erny-Saint-Julien;ERNY-SAINT-JULIEN;62960;62;PAS DE CALAIS;1
62306;;Ervillers;ERVILLERS;62121;62;PAS DE CALAIS;1
62307;;Escalles;ESCALLES;62179;62;PAS DE CALAIS;1
62308;;Escœuilles;ESCOEUILLES;62850;62;PAS DE CALAIS;1
62309;;Esquerdes;ESQUERDES;62380;62;PAS DE CALAIS;1
62310;;Essars;ESSARS;62400;62;PAS DE CALAIS;1
62311;;Estevelles;ESTEVELLES;62880;62;PAS DE CALAIS;1
62312;;Estrée;ESTREE;62170;62;PAS DE CALAIS;1
62313;;Estrée-Blanche;ESTREE-BLANCHE;62145;62;PAS DE CALAIS;1
62314;;Estrée-Cauchy;ESTREE-CAUCHY;62690;62;PAS DE CALAIS;1
62315;;Estréelles;ESTREELLES;62170;62;PAS DE CALAIS;1
62316;;Estrée-Wamin;ESTREE-WAMIN;62810;62;PAS DE CALAIS;1
62317;;Étaing;ETAING;62156;62;PAS DE CALAIS;1
62318;;Étaples;ETAPLES;62630;62;PAS DE CALAIS;1
62319;;Éterpigny;ETERPIGNY;62156;62;PAS DE CALAIS;1
62320;;Étrun;ETRUN;62161;62;PAS DE CALAIS;1
62321;;Évin-Malmaison;EVIN-MALMAISON;62141;62;PAS DE CALAIS;1
62322;;Famechon;FAMECHON;62760;62;PAS DE CALAIS;1
62323;;Fampoux;FAMPOUX;62118;62;PAS DE CALAIS;1
62324;;Farbus;FARBUS;62580;62;PAS DE CALAIS;1
62325;;Fauquembergues;FAUQUEMBERGUES;62560;62;PAS DE CALAIS;1
62326;;Favreuil;FAVREUIL;62450;62;PAS DE CALAIS;1
62327;;Febvin-Palfart;FEBVIN-PALFART;62960;62;PAS DE CALAIS;1
62328;;Ferfay;FERFAY;62260;62;PAS DE CALAIS;1
62329;;Ferques;FERQUES;62250;62;PAS DE CALAIS;1
62330;;Festubert;FESTUBERT;62149;62;PAS DE CALAIS;1
62331;;Feuchy;FEUCHY;62223;62;PAS DE CALAIS;1
62332;;Ficheux;FICHEUX;62173;62;PAS DE CALAIS;1
62333;;Fiefs;FIEFS;62134;62;PAS DE CALAIS;1
62334;;Fiennes;FIENNES;62132;62;PAS DE CALAIS;1
62335;;Fillièvres;FILLIEVRES;62770;62;PAS DE CALAIS;1
62336;;Fléchin;FLECHIN;62960;62;PAS DE CALAIS;1
62337;;Flers;FLERS;62270;62;PAS DE CALAIS;1
62338;;Fleurbaix;FLEURBAIX;62840;62;PAS DE CALAIS;1
62339;;Fleury;FLEURY;62134;62;PAS DE CALAIS;1
62340;;Floringhem;FLORINGHEM;62550;62;PAS DE CALAIS;1
62341;;Foncquevillers;FONCQUEVILLERS;62111;62;PAS DE CALAIS;1
62342;;Fontaine-lès-Boulans;FONTAINE-LES-BOULANS;62134;62;PAS DE CALAIS;1
62343;;Fontaine-lès-Croisilles;FONTAINE-LES-CROISILLES;62128;62;PAS DE CALAIS;1
62344;;Fontaine-lès-Hermans;FONTAINE-LES-HERMANS;62550;62;PAS DE CALAIS;1
62345;;Fontaine-l'Étalon;FONTAINE-L'ETALON;62390;62;PAS DE CALAIS;1
62346;;Fortel-en-Artois;FORTEL-EN-ARTOIS;62270;62;PAS DE CALAIS;1
62347;;Fosseux;FOSSEUX;62810;62;PAS DE CALAIS;1
62348;;Foufflin-Ricametz;FOUFFLIN-RICAMETZ;62130;62;PAS DE CALAIS;1
62349;;Fouquereuil;FOUQUEREUIL;62232;62;PAS DE CALAIS;1
62350;;Fouquières-lès-Béthune;FOUQUIERES-LES-BETHUNE;62232;62;PAS DE CALAIS;1
62351;;Fouquières-lès-Lens;FOUQUIERES-LES-LENS;62740;62;PAS DE CALAIS;1
62352;;Framecourt;FRAMECOURT;62130;62;PAS DE CALAIS;1
62353;;Frémicourt;FREMICOURT;62450;62;PAS DE CALAIS;1
62354;;Frencq;FRENCQ;62630;62;PAS DE CALAIS;1
62355;;Fresnes-lès-Montauban;FRESNES-LES-MONTAUBAN;62490;62;PAS DE CALAIS;1
62356;;Fresnicourt-le-Dolmen;FRESNICOURT-LE-DOLMEN;62150;62;PAS DE CALAIS;1
62357;;Fresnoy;FRESNOY;62770;62;PAS DE CALAIS;1
62358;;Fresnoy-en-Gohelle;FRESNOY-EN-GOHELLE;62580;62;PAS DE CALAIS;1
62359;;Fressin;FRESSIN;62140;62;PAS DE CALAIS;1
62360;;Fréthun;FRETHUN;62185;62;PAS DE CALAIS;1
62361;;Frévent;FREVENT;62270;62;PAS DE CALAIS;1
62362;;Frévillers;FREVILLERS;62127;62;PAS DE CALAIS;1
62363;;Frévin-Capelle;FREVIN-CAPELLE;62690;62;PAS DE CALAIS;1
62364;;Fruges;FRUGES;62310;62;PAS DE CALAIS;1
62365;;Galametz;GALAMETZ;62770;62;PAS DE CALAIS;1
62366;;Gauchin-Légal;GAUCHIN-LEGAL;62150;62;PAS DE CALAIS;1
62367;;Gauchin-Verloingt;GAUCHIN-VERLOINGT;62130;62;PAS DE CALAIS;1
62368;;Gaudiempré;GAUDIEMPRE;62760;62;PAS DE CALAIS;1
62369;;Gavrelle;GAVRELLE;62580;62;PAS DE CALAIS;1
62370;;Gennes-Ivergny;GENNES-IVERGNY;62390;62;PAS DE CALAIS;1
62371;;Givenchy-en-Gohelle;GIVENCHY-EN-GOHELLE;62580;62;PAS DE CALAIS;1
62372;;Givenchy-le-Noble;GIVENCHY-LE-NOBLE;62810;62;PAS DE CALAIS;1
62373;;Givenchy-lès-la-Bassée;GIVENCHY-LES-LA-BASSEE;62149;62;PAS DE CALAIS;1
62374;;Gomiécourt;GOMIECOURT;62121;62;PAS DE CALAIS;1
62375;;Gommecourt;GOMMECOURT;62111;62;PAS DE CALAIS;1
62376;;Gonnehem;GONNEHEM;62920;62;PAS DE CALAIS;1
62377;;Gosnay;GOSNAY;62199;62;PAS DE CALAIS;1
62378;;Gouves;GOUVES;62123;62;PAS DE CALAIS;1
62379;;Gouy-en-Artois;GOUY-EN-ARTOIS;62123;62;PAS DE CALAIS;1
62380;;Gouy-Servins;GOUY-SERVINS;62530;62;PAS DE CALAIS;1
62381;;Gouy-en-Ternois;GOUY-EN-TERNOIS;62127;62;PAS DE CALAIS;1
62382;;Gouy-Saint-André;GOUY-SAINT-ANDRE;62870;62;PAS DE CALAIS;1
62383;;Gouy-sous-Bellonne;GOUY-SOUS-BELLONNE;62112;62;PAS DE CALAIS;1
62384;;Graincourt-lès-Havrincourt;GRAINCOURT-LES-HAVRINCOURT;62147;62;PAS DE CALAIS;1
62385;;Grand-Rullecourt;GRAND-RULLECOURT;62810;62;PAS DE CALAIS;1
62386;;Grenay;GRENAY;62160;62;PAS DE CALAIS;1
62387;;Grévillers;GREVILLERS;62450;62;PAS DE CALAIS;1
62388;;Grigny;GRIGNY;62140;62;PAS DE CALAIS;1
62389;;Grincourt-lès-Pas;GRINCOURT-LES-PAS;62760;62;PAS DE CALAIS;1
62390;;Groffliers;GROFFLIERS;62600;62;PAS DE CALAIS;1
62391;;Guarbecque;GUARBECQUE;62330;62;PAS DE CALAIS;1
62392;;Guémappe;GUEMAPPE;62128;62;PAS DE CALAIS;1
62393;;Guemps;GUEMPS;62370;62;PAS DE CALAIS;1
62395;;Guigny;GUIGNY;62140;62;PAS DE CALAIS;1
62396;;Guinecourt;GUINECOURT;62130;62;PAS DE CALAIS;1
62397;;Guînes;GUINES;62340;62;PAS DE CALAIS;1
62398;;Guisy;GUISY;62140;62;PAS DE CALAIS;1
62399;;Habarcq;HABARCQ;62123;62;PAS DE CALAIS;1
62400;;Haillicourt;HAILLICOURT;62940;62;PAS DE CALAIS;1
62401;;Haisnes;HAISNES;62138;62;PAS DE CALAIS;1
62402;;Halinghen;HALINGHEN;62830;62;PAS DE CALAIS;1
62403;;Hallines;HALLINES;62570;62;PAS DE CALAIS;1
62404;;Halloy;HALLOY;62760;62;PAS DE CALAIS;1
62405;;Hamblain-les-Prés;HAMBLAIN-LES-PRES;62118;62;PAS DE CALAIS;1
62406;;Hamelincourt;HAMELINCOURT;62121;62;PAS DE CALAIS;1
62407;;Ham-en-Artois;HAM-EN-ARTOIS;62190;62;PAS DE CALAIS;1
62408;;Hames-Boucres;HAMES-BOUCRES;62340;62;PAS DE CALAIS;1
62409;;Hannescamps;HANNESCAMPS;62111;62;PAS DE CALAIS;1
62410;;Haplincourt;HAPLINCOURT;62124;62;PAS DE CALAIS;1
62411;;Haravesnes;HARAVESNES;62390;62;PAS DE CALAIS;1
62412;;Hardinghen;HARDINGHEN;62132;62;PAS DE CALAIS;1
62413;;Harnes;HARNES;62440;62;PAS DE CALAIS;1
62414;;Haucourt;HAUCOURT;62156;62;PAS DE CALAIS;1
62415;;Haute-Avesnes;HAUTE-AVESNES;62144;62;PAS DE CALAIS;1
62416;;Hautecloque;HAUTECLOQUE;62130;62;PAS DE CALAIS;1
62418;;Hauteville;HAUTEVILLE;62810;62;PAS DE CALAIS;1
62419;;Haut-Loquin;HAUT-LOQUIN;62850;62;PAS DE CALAIS;1
62421;;Havrincourt;HAVRINCOURT;62147;62;PAS DE CALAIS;1
62422;;Hébuterne;HEBUTERNE;62111;62;PAS DE CALAIS;1
62423;;Helfaut;HELFAUT;62570;62;PAS DE CALAIS;1
62424;;Hendecourt-lès-Cagnicourt;HENDECOURT-LES-CAGNICOURT;62182;62;PAS DE CALAIS;1
62425;;Hendecourt-lès-Ransart;HENDECOURT-LES-RANSART;62175;62;PAS DE CALAIS;1
62426;;Héninel;HENINEL;62128;62;PAS DE CALAIS;1
62427;;Hénin-Beaumont;HENIN-BEAUMONT;62110;62;PAS DE CALAIS;1
62428;;Hénin-sur-Cojeul;HENIN-SUR-COJEUL;62128;62;PAS DE CALAIS;1
62429;;Henneveux;HENNEVEUX;62142;62;PAS DE CALAIS;1
62430;;Hénu;HENU;62760;62;PAS DE CALAIS;1
62431;;Herbelles;HERBELLES;62129;62;PAS DE CALAIS;1
62432;;Herbinghen;HERBINGHEN;62850;62;PAS DE CALAIS;1
62433;;Héricourt;HERICOURT;62130;62;PAS DE CALAIS;1
62434;La;Herlière;HERLIERE;62158;62;PAS DE CALAIS;1
62435;;Herlincourt;HERLINCOURT;62130;62;PAS DE CALAIS;1
62436;;Herlin-le-Sec;HERLIN-LE-SEC;62130;62;PAS DE CALAIS;1
62437;;Herly;HERLY;62650;62;PAS DE CALAIS;1
62438;;Hermaville;HERMAVILLE;62690;62;PAS DE CALAIS;1
62439;;Hermelinghen;HERMELINGHEN;62132;62;PAS DE CALAIS;1
62440;;Hermies;HERMIES;62147;62;PAS DE CALAIS;1
62441;;Hermin;HERMIN;62150;62;PAS DE CALAIS;1
62442;;Hernicourt;HERNICOURT;62130;62;PAS DE CALAIS;1
62443;;Hersin-Coupigny;HERSIN-COUPIGNY;62530;62;PAS DE CALAIS;1
62444;;Hervelinghen;HERVELINGHEN;62179;62;PAS DE CALAIS;1
62445;;Hesdigneul-lès-Béthune;HESDIGNEUL-LES-BETHUNE;62196;62;PAS DE CALAIS;1
62446;;Hesdigneul-lès-Boulogne;HESDIGNEUL-LES-BOULOGNE;62360;62;PAS DE CALAIS;1
62447;;Hesdin;HESDIN;62140;62;PAS DE CALAIS;1
62448;;Hesdin-l'Abbé;HESDIN-L'ABBE;62360;62;PAS DE CALAIS;1
62449;;Hesmond;HESMOND;62990;62;PAS DE CALAIS;1
62450;;Hestrus;HESTRUS;62550;62;PAS DE CALAIS;1
62451;;Heuchin;HEUCHIN;62134;62;PAS DE CALAIS;1
62452;;Heuringhem;HEURINGHEM;62575;62;PAS DE CALAIS;1
62453;;Hézecques;HEZECQUES;62310;62;PAS DE CALAIS;1
62454;;Hinges;HINGES;62232;62;PAS DE CALAIS;1
62455;;Hocquinghen;HOCQUINGHEN;62850;62;PAS DE CALAIS;1
62456;;Houchin;HOUCHIN;62620;62;PAS DE CALAIS;1
62457;;Houdain;HOUDAIN;62150;62;PAS DE CALAIS;1
62458;;Houlle;HOULLE;62910;62;PAS DE CALAIS;1
62459;;Houvin-Houvigneul;HOUVIN-HOUVIGNEUL;62270;62;PAS DE CALAIS;1
62460;;Hubersent;HUBERSENT;62630;62;PAS DE CALAIS;1
62461;;Huby-Saint-Leu;HUBY-SAINT-LEU;62140;62;PAS DE CALAIS;1
62462;;Huclier;HUCLIER;62130;62;PAS DE CALAIS;1
62463;;Hucqueliers;HUCQUELIERS;62650;62;PAS DE CALAIS;1
62464;;Hulluch;HULLUCH;62410;62;PAS DE CALAIS;1
62465;;Humbercamps;HUMBERCAMPS;62158;62;PAS DE CALAIS;1
62466;;Humbert;HUMBERT;62650;62;PAS DE CALAIS;1
62467;;Humerœuille;HUMEROEUILLE;62130;62;PAS DE CALAIS;1
62468;;Humières;HUMIERES;62130;62;PAS DE CALAIS;1
62469;;Inchy-en-Artois;INCHY-EN-ARTOIS;62860;62;PAS DE CALAIS;1
62470;;Incourt;INCOURT;62770;62;PAS DE CALAIS;1
62471;;Inghem;INGHEM;62129;62;PAS DE CALAIS;1
62472;;Inxent;INXENT;62170;62;PAS DE CALAIS;1
62473;;Isbergues;ISBERGUES;62330;62;PAS DE CALAIS;1
62474;;Isques;ISQUES;62360;62;PAS DE CALAIS;1
62475;;Ivergny;IVERGNY;62810;62;PAS DE CALAIS;1
62476;;Izel-lès-Équerchin;IZEL-LES-EQUERCHIN;62490;62;PAS DE CALAIS;1
62477;;Izel-lès-Hameau;IZEL-LES-HAMEAU;62690;62;PAS DE CALAIS;1
62478;;Journy;JOURNY;62850;62;PAS DE CALAIS;1
62479;;Labeuvrière;LABEUVRIERE;62122;62;PAS DE CALAIS;1
62480;;Labourse;LABOURSE;62113;62;PAS DE CALAIS;1
62481;;Labroye;LABROYE;62140;62;PAS DE CALAIS;1
62483;;Lacres;LACRES;62830;62;PAS DE CALAIS;1
62484;;Lagnicourt-Marcel;LAGNICOURT-MARCEL;62159;62;PAS DE CALAIS;1
62485;;Laires;LAIRES;62960;62;PAS DE CALAIS;1
62486;;Lambres;LAMBRES;62120;62;PAS DE CALAIS;1
62487;;Landrethun-le-Nord;LANDRETHUN-LE-NORD;62250;62;PAS DE CALAIS;1
62488;;Landrethun-lès-Ardres;LANDRETHUN-LES-ARDRES;62610;62;PAS DE CALAIS;1
62489;;Lapugnoy;LAPUGNOY;62122;62;PAS DE CALAIS;1
62490;;Lattre-Saint-Quentin;LATTRE-SAINT-QUENTIN;62810;62;PAS DE CALAIS;1
62491;;Laventie;LAVENTIE;62840;62;PAS DE CALAIS;1
62492;;Lebiez;LEBIEZ;62990;62;PAS DE CALAIS;1
62493;;Lebucquière;LEBUCQUIERE;62124;62;PAS DE CALAIS;1
62494;;Léchelle;LECHELLE;62124;62;PAS DE CALAIS;1
62495;;Ledinghem;LEDINGHEM;62380;62;PAS DE CALAIS;1
62496;;Lefaux;LEFAUX;62630;62;PAS DE CALAIS;1
62497;;Leforest;LEFOREST;62790;62;PAS DE CALAIS;1
62498;;Lens;LENS;62300;62;PAS DE CALAIS;1
62499;;Lépine;LEPINE;62170;62;PAS DE CALAIS;1
62500;;Lespesses;LESPESSES;62190;62;PAS DE CALAIS;1
62501;;Lespinoy;LESPINOY;62990;62;PAS DE CALAIS;1
62502;;Lestrem;LESTREM;62136;62;PAS DE CALAIS;1
62503;;Leubringhen;LEUBRINGHEN;62250;62;PAS DE CALAIS;1
62504;;Leulinghem;LEULINGHEM;62500;62;PAS DE CALAIS;1
62505;;Leulinghen-Bernes;LEULINGHEN-BERNES;62250;62;PAS DE CALAIS;1
62506;;Licques;LICQUES;62850;62;PAS DE CALAIS;1
62507;;Liencourt;LIENCOURT;62810;62;PAS DE CALAIS;1
62508;;Lières;LIERES;62190;62;PAS DE CALAIS;1
62509;;Liettres;LIETTRES;62145;62;PAS DE CALAIS;1
62510;;Liévin;LIEVIN;62800;62;PAS DE CALAIS;1
62511;;Lignereuil;LIGNEREUIL;62810;62;PAS DE CALAIS;1
62512;;Ligny-lès-Aire;LIGNY-LES-AIRE;62960;62;PAS DE CALAIS;1
62513;;Ligny-sur-Canche;LIGNY-SUR-CANCHE;62270;62;PAS DE CALAIS;1
62514;;Ligny-Saint-Flochel;LIGNY-SAINT-FLOCHEL;62127;62;PAS DE CALAIS;1
62515;;Ligny-Thilloy;LIGNY-THILLOY;62450;62;PAS DE CALAIS;1
62516;;Lillers;LILLERS;62190;62;PAS DE CALAIS;1
62517;;Linghem;LINGHEM;62120;62;PAS DE CALAIS;1
62518;;Linzeux;LINZEUX;62270;62;PAS DE CALAIS;1
62519;;Lisbourg;LISBOURG;62134;62;PAS DE CALAIS;1
62520;;Locon;LOCON;62400;62;PAS DE CALAIS;1
62521;La;Loge;LOGE;62140;62;PAS DE CALAIS;1
62522;;Loison-sur-Créquoise;LOISON-SUR-CREQUOISE;62990;62;PAS DE CALAIS;1
62523;;Loison-sous-Lens;LOISON-SOUS-LENS;62218;62;PAS DE CALAIS;1
62524;;Longfossé;LONGFOSSE;62240;62;PAS DE CALAIS;1
62525;;Longuenesse;LONGUENESSE;62219;62;PAS DE CALAIS;1
62526;;Longueville;LONGUEVILLE;62142;62;PAS DE CALAIS;1
62527;;Longvilliers;LONGVILLIERS;62630;62;PAS DE CALAIS;1
62528;;Loos-en-Gohelle;LOOS-EN-GOHELLE;62750;62;PAS DE CALAIS;1
62529;;Lorgies;LORGIES;62840;62;PAS DE CALAIS;1
62530;;Lottinghen;LOTTINGHEN;62240;62;PAS DE CALAIS;1
62531;;Louches;LOUCHES;62610;62;PAS DE CALAIS;1
62532;;Lozinghem;LOZINGHEM;62540;62;PAS DE CALAIS;1
62533;;Lugy;LUGY;62310;62;PAS DE CALAIS;1
62534;;Lumbres;LUMBRES;62380;62;PAS DE CALAIS;1
62535;La;Madelaine-sous-Montreuil;MADELAINE-SOUS-MONTREUIL;62170;62;PAS DE CALAIS;1
62536;;Magnicourt-en-Comte;MAGNICOURT-EN-COMTE;62127;62;PAS DE CALAIS;1
62537;;Magnicourt-sur-Canche;MAGNICOURT-SUR-CANCHE;62270;62;PAS DE CALAIS;1
62538;;Maintenay;MAINTENAY;62870;62;PAS DE CALAIS;1
62539;;Maisnil;MAISNIL;62130;62;PAS DE CALAIS;1
62540;;Maisnil-lès-Ruitz;MAISNIL-LES-RUITZ;62620;62;PAS DE CALAIS;1
62541;;Maisoncelle;MAISONCELLE;62310;62;PAS DE CALAIS;1
62542;;Maizières;MAIZIERES;62127;62;PAS DE CALAIS;1
62543;;Mametz;MAMETZ;62120;62;PAS DE CALAIS;1
62544;;Manin;MANIN;62810;62;PAS DE CALAIS;1
62545;;Maninghem;MANINGHEM;62650;62;PAS DE CALAIS;1
62546;;Maninghen-Henne;MANINGHEN-HENNE;62250;62;PAS DE CALAIS;1
62547;;Marant;MARANT;62170;62;PAS DE CALAIS;1
62548;;Marck;MARCK;62730;62;PAS DE CALAIS;1
62549;;Marconne;MARCONNE;62140;62;PAS DE CALAIS;1
62550;;Marconnelle;MARCONNELLE;62140;62;PAS DE CALAIS;1
62551;;Marenla;MARENLA;62990;62;PAS DE CALAIS;1
62552;;Maresquel-Ecquemicourt;MARESQUEL-ECQUEMICOURT;62990;62;PAS DE CALAIS;1
62553;;Marest;MAREST;62550;62;PAS DE CALAIS;1
62554;;Maresville;MARESVILLE;62630;62;PAS DE CALAIS;1
62555;;Marles-les-Mines;MARLES-LES-MINES;62540;62;PAS DE CALAIS;1
62556;;Marles-sur-Canche;MARLES-SUR-CANCHE;62170;62;PAS DE CALAIS;1
62557;;Marœuil;MAROEUIL;62161;62;PAS DE CALAIS;1
62558;;Marquay;MARQUAY;62127;62;PAS DE CALAIS;1
62559;;Marquion;MARQUION;62860;62;PAS DE CALAIS;1
62560;;Marquise;MARQUISE;62250;62;PAS DE CALAIS;1
62561;;Martinpuich;MARTINPUICH;62450;62;PAS DE CALAIS;1
62562;;Matringhem;MATRINGHEM;62310;62;PAS DE CALAIS;1
62563;;Mazingarbe;MAZINGARBE;62670;62;PAS DE CALAIS;1
62564;;Mazinghem;MAZINGHEM;62120;62;PAS DE CALAIS;1
62565;;Mencas;MENCAS;62310;62;PAS DE CALAIS;1
62566;;Menneville;MENNEVILLE;62240;62;PAS DE CALAIS;1
62567;;Mentque-Nortbécourt;MENTQUE-NORTBECOURT;62890;62;PAS DE CALAIS;1
62568;;Mercatel;MERCATEL;62217;62;PAS DE CALAIS;1
62569;;Merck-Saint-Liévin;MERCK-SAINT-LIEVIN;62560;62;PAS DE CALAIS;1
62570;;Méricourt;MERICOURT;62680;62;PAS DE CALAIS;1
62571;;Merlimont;MERLIMONT;62155;62;PAS DE CALAIS;1
62572;;Metz-en-Couture;METZ-EN-COUTURE;62124;62;PAS DE CALAIS;1
62573;;Meurchin;MEURCHIN;62410;62;PAS DE CALAIS;1
62574;;Mingoval;MINGOVAL;62690;62;PAS DE CALAIS;1
62576;;Moncheaux-lès-Frévent;MONCHEAUX-LES-FREVENT;62270;62;PAS DE CALAIS;1
62577;;Monchel-sur-Canche;MONCHEL-SUR-CANCHE;62270;62;PAS DE CALAIS;1
62578;;Monchiet;MONCHIET;62123;62;PAS DE CALAIS;1
62579;;Monchy-au-Bois;MONCHY-AU-BOIS;62111;62;PAS DE CALAIS;1
62580;;Monchy-Breton;MONCHY-BRETON;62127;62;PAS DE CALAIS;1
62581;;Monchy-Cayeux;MONCHY-CAYEUX;62134;62;PAS DE CALAIS;1
62582;;Monchy-le-Preux;MONCHY-LE-PREUX;62118;62;PAS DE CALAIS;1
62583;;Mondicourt;MONDICOURT;62760;62;PAS DE CALAIS;1
62584;;Mont-Bernanchon;MONT-BERNANCHON;62350;62;PAS DE CALAIS;1
62585;;Montcavrel;MONTCAVREL;62170;62;PAS DE CALAIS;1
62586;;Montenescourt;MONTENESCOURT;62123;62;PAS DE CALAIS;1
62587;;Montigny-en-Gohelle;MONTIGNY-EN-GOHELLE;62640;62;PAS DE CALAIS;1
62588;;Montreuil;MONTREUIL;62170;62;PAS DE CALAIS;1
62589;;Mont-Saint-Éloi;MONT-SAINT-ELOI;62144;62;PAS DE CALAIS;1
62590;;Monts-en-Ternois;MONTS-EN-TERNOIS;62130;62;PAS DE CALAIS;1
62591;;Morchies;MORCHIES;62124;62;PAS DE CALAIS;1
62592;;Moringhem;MORINGHEM;62910;62;PAS DE CALAIS;1
62593;;Morval;MORVAL;62450;62;PAS DE CALAIS;1
62594;;Mory;MORY;62159;62;PAS DE CALAIS;1
62595;;Moulle;MOULLE;62910;62;PAS DE CALAIS;1
62596;;Mouriez;MOURIEZ;62140;62;PAS DE CALAIS;1
62597;;Moyenneville;MOYENNEVILLE;62121;62;PAS DE CALAIS;1
62598;;Muncq-Nieurlet;MUNCQ-NIEURLET;62890;62;PAS DE CALAIS;1
62599;;Nabringhen;NABRINGHEN;62142;62;PAS DE CALAIS;1
62600;;Nédon;NEDON;62550;62;PAS DE CALAIS;1
62601;;Nédonchel;NEDONCHEL;62550;62;PAS DE CALAIS;1
62602;;Nempont-Saint-Firmin;NEMPONT-SAINT-FIRMIN;62180;62;PAS DE CALAIS;1
62603;;Nesles;NESLES;62152;62;PAS DE CALAIS;1
62604;;Neufchâtel-Hardelot;NEUFCHATEL-HARDELOT;62152;62;PAS DE CALAIS;1
62605;;Neulette;NEULETTE;62770;62;PAS DE CALAIS;1
62606;;Neuve-Chapelle;NEUVE-CHAPELLE;62840;62;PAS DE CALAIS;1
62607;;Neuville-au-Cornet;NEUVILLE-AU-CORNET;62130;62;PAS DE CALAIS;1
62608;;Neuville-Bourjonval;NEUVILLE-BOURJONVAL;62124;62;PAS DE CALAIS;1
62609;;Neuville-Saint-Vaast;NEUVILLE-SAINT-VAAST;62580;62;PAS DE CALAIS;1
62610;;Neuville-sous-Montreuil;NEUVILLE-SOUS-MONTREUIL;62170;62;PAS DE CALAIS;1
62611;;Neuville-Vitasse;NEUVILLE-VITASSE;62217;62;PAS DE CALAIS;1
62612;;Neuvireuil;NEUVIREUIL;62580;62;PAS DE CALAIS;1
62613;;Nielles-lès-Bléquin;NIELLES-LES-BLEQUIN;62380;62;PAS DE CALAIS;1
62614;;Nielles-lès-Ardres;NIELLES-LES-ARDRES;62610;62;PAS DE CALAIS;1
62615;;Nielles-lès-Calais;NIELLES-LES-CALAIS;62185;62;PAS DE CALAIS;1
62616;;Nœux-lès-Auxi;NOEUX-LES-AUXI;62390;62;PAS DE CALAIS;1
62617;;Nœux-les-Mines;NOEUX-LES-MINES;62290;62;PAS DE CALAIS;1
62618;;Nordausques;NORDAUSQUES;62890;62;PAS DE CALAIS;1
62619;;Noreuil;NOREUIL;62128;62;PAS DE CALAIS;1
62620;;Norrent-Fontes;NORRENT-FONTES;62120;62;PAS DE CALAIS;1
62621;;Nortkerque;NORTKERQUE;62370;62;PAS DE CALAIS;1
62622;;Nort-Leulinghem;NORT-LEULINGHEM;62890;62;PAS DE CALAIS;1
62623;;Nouvelle-Église;NOUVELLE-EGLISE;62370;62;PAS DE CALAIS;1
62624;;Noyelles-Godault;NOYELLES-GODAULT;62950;62;PAS DE CALAIS;1
62625;;Noyelles-lès-Humières;NOYELLES-LES-HUMIERES;62770;62;PAS DE CALAIS;1
62626;;Noyelles-lès-Vermelles;NOYELLES-LES-VERMELLES;62980;62;PAS DE CALAIS;1
62627;;Noyelles-sous-Bellonne;NOYELLES-SOUS-BELLONNE;62490;62;PAS DE CALAIS;1
62628;;Noyelles-sous-Lens;NOYELLES-SOUS-LENS;62221;62;PAS DE CALAIS;1
62629;;Noyellette;NOYELLETTE;62123;62;PAS DE CALAIS;1
62630;;Noyelle-Vion;NOYELLE-VION;62810;62;PAS DE CALAIS;1
62631;;Nuncq-Hautecôte;NUNCQ-HAUTECOTE;62270;62;PAS DE CALAIS;1
62632;;Oblinghem;OBLINGHEM;62920;62;PAS DE CALAIS;1
62633;;Œuf-en-Ternois;OEUF-EN-TERNOIS;62130;62;PAS DE CALAIS;1
62634;;Offekerque;OFFEKERQUE;62370;62;PAS DE CALAIS;1
62635;;Offin;OFFIN;62990;62;PAS DE CALAIS;1
62636;;Offrethun;OFFRETHUN;62250;62;PAS DE CALAIS;1
62637;;Oignies;OIGNIES;62590;62;PAS DE CALAIS;1
62638;;Oisy-le-Verger;OISY-LE-VERGER;62860;62;PAS DE CALAIS;1
62639;;Oppy;OPPY;62580;62;PAS DE CALAIS;1
62640;;Orville;ORVILLE;62760;62;PAS DE CALAIS;1
62641;;Ostreville;OSTREVILLE;62130;62;PAS DE CALAIS;1
62642;;Ourton;OURTON;62460;62;PAS DE CALAIS;1
62643;;Outreau;OUTREAU;62230;62;PAS DE CALAIS;1
62644;;Ouve-Wirquin;OUVE-WIRQUIN;62380;62;PAS DE CALAIS;1
62645;;Oye-Plage;OYE-PLAGE;62215;62;PAS DE CALAIS;1
62646;;Palluel;PALLUEL;62860;62;PAS DE CALAIS;1
62647;Le;Parcq;PARCQ;62770;62;PAS DE CALAIS;1
62648;;Parenty;PARENTY;62650;62;PAS DE CALAIS;1
62649;;Pas-en-Artois;PAS-EN-ARTOIS;62760;62;PAS DE CALAIS;1
62650;;Pelves;PELVES;62118;62;PAS DE CALAIS;1
62651;;Penin;PENIN;62127;62;PAS DE CALAIS;1
62652;;Pernes;PERNES;62550;62;PAS DE CALAIS;1
62653;;Pernes-lès-Boulogne;PERNES-LES-BOULOGNE;62126;62;PAS DE CALAIS;1
62654;;Peuplingues;PEUPLINGUES;62231;62;PAS DE CALAIS;1
62655;;Pierremont;PIERREMONT;62130;62;PAS DE CALAIS;1
62656;;Pihem;PIHEM;62570;62;PAS DE CALAIS;1
62657;;Pihen-lès-Guînes;PIHEN-LES-GUINES;62340;62;PAS DE CALAIS;1
62658;;Pittefaux;PITTEFAUX;62126;62;PAS DE CALAIS;1
62659;;Planques;PLANQUES;62310;62;PAS DE CALAIS;1
62660;;Plouvain;PLOUVAIN;62118;62;PAS DE CALAIS;1
62661;;Bouin-Plumoison;BOUIN-PLUMOISON;62140;62;PAS DE CALAIS;1
62662;;Polincove;POLINCOVE;62370;62;PAS DE CALAIS;1
62663;;Pommera;POMMERA;62760;62;PAS DE CALAIS;1
62664;;Pommier;POMMIER;62111;62;PAS DE CALAIS;1
62665;Le;Ponchel;PONCHEL;62390;62;PAS DE CALAIS;1
62666;;Pont-à-Vendin;PONT-A-VENDIN;62880;62;PAS DE CALAIS;1
62667;Le;Portel;PORTEL;62480;62;PAS DE CALAIS;1
62668;;Prédefin;PREDEFIN;62134;62;PAS DE CALAIS;1
62669;;Pressy;PRESSY;62550;62;PAS DE CALAIS;1
62670;;Preures;PREURES;62650;62;PAS DE CALAIS;1
62671;;Pronville;PRONVILLE;62860;62;PAS DE CALAIS;1
62672;;Puisieux;PUISIEUX;62116;62;PAS DE CALAIS;1
62673;;Quéant;QUEANT;62860;62;PAS DE CALAIS;1
62674;;Quelmes;QUELMES;62500;62;PAS DE CALAIS;1
62675;;Quercamps;QUERCAMPS;62380;62;PAS DE CALAIS;1
62676;;Quernes;QUERNES;62120;62;PAS DE CALAIS;1
62677;Le;Quesnoy-en-Artois;QUESNOY-EN-ARTOIS;62140;62;PAS DE CALAIS;1
62678;;Quesques;QUESQUES;62240;62;PAS DE CALAIS;1
62679;;Questrecques;QUESTRECQUES;62830;62;PAS DE CALAIS;1
62680;;Quiéry-la-Motte;QUIERY-LA-MOTTE;62490;62;PAS DE CALAIS;1
62681;;Quiestède;QUIESTEDE;62120;62;PAS DE CALAIS;1
62682;;Quilen;QUILEN;62650;62;PAS DE CALAIS;1
62683;;Quœux-Haut-Maînil;QUOEUX-HAUT-MAINIL;62390;62;PAS DE CALAIS;1
62684;;Racquinghem;RACQUINGHEM;62120;62;PAS DE CALAIS;1
62685;;Radinghem;RADINGHEM;62310;62;PAS DE CALAIS;1
62686;;Ramecourt;RAMECOURT;62130;62;PAS DE CALAIS;1
62688;;Rang-du-Fliers;RANG-DU-FLIERS;62180;62;PAS DE CALAIS;1
62689;;Ransart;RANSART;62173;62;PAS DE CALAIS;1
62690;;Raye-sur-Authie;RAYE-SUR-AUTHIE;62140;62;PAS DE CALAIS;1
62691;;Rebecques;REBECQUES;62120;62;PAS DE CALAIS;1
62692;;Rebergues;REBERGUES;62850;62;PAS DE CALAIS;1
62693;;Rebreuve-Ranchicourt;REBREUVE-RANCHICOURT;62150;62;PAS DE CALAIS;1
62694;;Rebreuve-sur-Canche;REBREUVE-SUR-CANCHE;62270;62;PAS DE CALAIS;1
62695;;Rebreuviette;REBREUVIETTE;62270;62;PAS DE CALAIS;1
62696;;Reclinghem;RECLINGHEM;62560;62;PAS DE CALAIS;1
62697;;Récourt;RECOURT;62860;62;PAS DE CALAIS;1
62698;;Recques-sur-Course;RECQUES-SUR-COURSE;62170;62;PAS DE CALAIS;1
62699;;Recques-sur-Hem;RECQUES-SUR-HEM;62890;62;PAS DE CALAIS;1
62700;;Regnauville;REGNAUVILLE;62140;62;PAS DE CALAIS;1
62701;;Rely;RELY;62120;62;PAS DE CALAIS;1
62702;;Remilly-Wirquin;REMILLY-WIRQUIN;62380;62;PAS DE CALAIS;1
62703;;Rémy;REMY;62156;62;PAS DE CALAIS;1
62704;;Renty;RENTY;62560;62;PAS DE CALAIS;1
62705;;Rety;RETY;62720;62;PAS DE CALAIS;1
62706;;Richebourg;RICHEBOURG;62136;62;PAS DE CALAIS;1
62708;;Riencourt-lès-Bapaume;RIENCOURT-LES-BAPAUME;62450;62;PAS DE CALAIS;1
62709;;Riencourt-lès-Cagnicourt;RIENCOURT-LES-CAGNICOURT;62182;62;PAS DE CALAIS;1
62710;;Rimboval;RIMBOVAL;62990;62;PAS DE CALAIS;1
62711;;Rinxent;RINXENT;62720;62;PAS DE CALAIS;1
62712;;Rivière;RIVIERE;62173;62;PAS DE CALAIS;1
62713;;Robecq;ROBECQ;62350;62;PAS DE CALAIS;1
62714;;Roclincourt;ROCLINCOURT;62223;62;PAS DE CALAIS;1
62715;;Rocquigny;ROCQUIGNY;62450;62;PAS DE CALAIS;1
62716;;Rodelinghem;RODELINGHEM;62610;62;PAS DE CALAIS;1
62717;;Roëllecourt;ROELLECOURT;62130;62;PAS DE CALAIS;1
62718;;Rœux;ROEUX;62118;62;PAS DE CALAIS;1
62719;;Rollancourt;ROLLANCOURT;62770;62;PAS DE CALAIS;1
62720;;Rombly;ROMBLY;62120;62;PAS DE CALAIS;1
62721;;Roquetoire;ROQUETOIRE;62120;62;PAS DE CALAIS;1
62722;;Rougefay;ROUGEFAY;62390;62;PAS DE CALAIS;1
62723;;Roussent;ROUSSENT;62870;62;PAS DE CALAIS;1
62724;;Rouvroy;ROUVROY;62320;62;PAS DE CALAIS;1
62725;;Royon;ROYON;62990;62;PAS DE CALAIS;1
62726;;Ruisseauville;RUISSEAUVILLE;62310;62;PAS DE CALAIS;1
62727;;Ruitz;RUITZ;62620;62;PAS DE CALAIS;1
62728;;Rumaucourt;RUMAUCOURT;62860;62;PAS DE CALAIS;1
62729;;Rumilly;RUMILLY;62650;62;PAS DE CALAIS;1
62730;;Ruminghem;RUMINGHEM;62370;62;PAS DE CALAIS;1
62731;;Ruyaulcourt;RUYAULCOURT;62124;62;PAS DE CALAIS;1
62732;;Sachin;SACHIN;62550;62;PAS DE CALAIS;1
62733;;Sailly-au-Bois;SAILLY-AU-BOIS;62111;62;PAS DE CALAIS;1
62734;;Sailly-en-Ostrevent;SAILLY-EN-OSTREVENT;62490;62;PAS DE CALAIS;1
62735;;Sailly-Labourse;SAILLY-LABOURSE;62113;62;PAS DE CALAIS;1
62736;;Sailly-sur-la-Lys;SAILLY-SUR-LA-LYS;62840;62;PAS DE CALAIS;1
62737;;Sains-en-Gohelle;SAINS-EN-GOHELLE;62114;62;PAS DE CALAIS;1
62738;;Sains-lès-Fressin;SAINS-LES-FRESSIN;62310;62;PAS DE CALAIS;1
62739;;Sains-lès-Marquion;SAINS-LES-MARQUION;62860;62;PAS DE CALAIS;1
62740;;Sains-lès-Pernes;SAINS-LES-PERNES;62550;62;PAS DE CALAIS;1
62741;;Saint-Amand;SAINT-AMAND;62760;62;PAS DE CALAIS;1
62742;;Saint-Aubin;SAINT-AUBIN;62170;62;PAS DE CALAIS;1
62743;;Sainte-Austreberthe;SAINTE-AUSTREBERTHE;62140;62;PAS DE CALAIS;1
62744;;Sainte-Catherine;SAINTE-CATHERINE;62223;62;PAS DE CALAIS;1
62745;;Saint-Denœux;SAINT-DENOEUX;62990;62;PAS DE CALAIS;1
62746;;Saint-Étienne-au-Mont;SAINT-ETIENNE-AU-MONT;62360;62;PAS DE CALAIS;1
62747;;Saint-Floris;SAINT-FLORIS;62350;62;PAS DE CALAIS;1
62748;;Saint-Folquin;SAINT-FOLQUIN;62370;62;PAS DE CALAIS;1
62749;;Saint-Georges;SAINT-GEORGES;62770;62;PAS DE CALAIS;1
62750;;Saint-Hilaire-Cottes;SAINT-HILAIRE-COTTES;62120;62;PAS DE CALAIS;1
62751;;Saint-Inglevert;SAINT-INGLEVERT;62250;62;PAS DE CALAIS;1
62752;;Saint-Josse;SAINT-JOSSE;62170;62;PAS DE CALAIS;1
62753;;Saint-Laurent-Blangy;SAINT-LAURENT-BLANGY;62223;62;PAS DE CALAIS;1
62754;;Saint-Léger;SAINT-LEGER;62128;62;PAS DE CALAIS;1
62755;;Saint-Léonard;SAINT-LEONARD;62360;62;PAS DE CALAIS;1
62756;;Sainte-Marie-Kerque;SAINTE-MARIE-KERQUE;62370;62;PAS DE CALAIS;1
62757;;Saint-Martin-au-Laërt;SAINT-MARTIN-AU-LAERT;62500;62;PAS DE CALAIS;1
62758;;Saint-Martin-Boulogne;SAINT-MARTIN-BOULOGNE;62280;62;PAS DE CALAIS;1
62759;;Saint-Martin-Choquel;SAINT-MARTIN-CHOQUEL;62240;62;PAS DE CALAIS;1
62760;;Saint-Martin-d'Hardinghem;SAINT-MARTIN-D'HARDINGHEM;62560;62;PAS DE CALAIS;1
62761;;Saint-Martin-sur-Cojeul;SAINT-MARTIN-SUR-COJEUL;62128;62;PAS DE CALAIS;1
62762;;Saint-Michel-sous-Bois;SAINT-MICHEL-SOUS-BOIS;62650;62;PAS DE CALAIS;1
62763;;Saint-Michel-sur-Ternoise;SAINT-MICHEL-SUR-TERNOISE;62130;62;PAS DE CALAIS;1
62764;;Saint-Nicolas;SAINT-NICOLAS;62223;62;PAS DE CALAIS;1
62765;;Saint-Omer;SAINT-OMER;62500;62;PAS DE CALAIS;1
62766;;Saint-Omer-Capelle;SAINT-OMER-CAPELLE;62162;62;PAS DE CALAIS;1
62767;;Saint-Pol-sur-Ternoise;SAINT-POL-SUR-TERNOISE;62130;62;PAS DE CALAIS;1
62768;;Saint-Rémy-au-Bois;SAINT-REMY-AU-BOIS;62870;62;PAS DE CALAIS;1
62769;;Saint-Tricat;SAINT-TRICAT;62185;62;PAS DE CALAIS;1
62770;;Saint-Venant;SAINT-VENANT;62350;62;PAS DE CALAIS;1
62771;;Sallaumines;SALLAUMINES;62430;62;PAS DE CALAIS;1
62772;;Salperwick;SALPERWICK;62500;62;PAS DE CALAIS;1
62773;;Samer;SAMER;62830;62;PAS DE CALAIS;1
62774;;Sangatte;SANGATTE;62231;62;PAS DE CALAIS;1
62775;;Sanghen;SANGHEN;62850;62;PAS DE CALAIS;1
62776;;Sapignies;SAPIGNIES;62121;62;PAS DE CALAIS;1
62777;Le;Sars;SARS;62450;62;PAS DE CALAIS;1
62778;;Sars-le-Bois;SARS-LE-BOIS;62810;62;PAS DE CALAIS;1
62779;;Sarton;SARTON;62760;62;PAS DE CALAIS;1
62780;;Sauchy-Cauchy;SAUCHY-CAUCHY;62860;62;PAS DE CALAIS;1
62781;;Sauchy-Lestrée;SAUCHY-LESTREE;62860;62;PAS DE CALAIS;1
62782;;Saudemont;SAUDEMONT;62860;62;PAS DE CALAIS;1
62783;;Saulchoy;SAULCHOY;62870;62;PAS DE CALAIS;1
62784;;Saulty;SAULTY;62158;62;PAS DE CALAIS;1
62785;;Savy-Berlette;SAVY-BERLETTE;62690;62;PAS DE CALAIS;1
62786;;Selles;SELLES;62240;62;PAS DE CALAIS;1
62787;;Sempy;SEMPY;62170;62;PAS DE CALAIS;1
62788;;Seninghem;SENINGHEM;62380;62;PAS DE CALAIS;1
62789;;Senlecques;SENLECQUES;62240;62;PAS DE CALAIS;1
62790;;Senlis;SENLIS;62310;62;PAS DE CALAIS;1
62791;;Séricourt;SERICOURT;62270;62;PAS DE CALAIS;1
62792;;Serques;SERQUES;62910;62;PAS DE CALAIS;1
62793;;Servins;SERVINS;62530;62;PAS DE CALAIS;1
62794;;Setques;SETQUES;62380;62;PAS DE CALAIS;1
62795;;Sibiville;SIBIVILLE;62270;62;PAS DE CALAIS;1
62796;;Simencourt;SIMENCOURT;62123;62;PAS DE CALAIS;1
62797;;Siracourt;SIRACOURT;62130;62;PAS DE CALAIS;1
62798;;Sombrin;SOMBRIN;62810;62;PAS DE CALAIS;1
62799;;Sorrus;SORRUS;62170;62;PAS DE CALAIS;1
62800;;Souastre;SOUASTRE;62111;62;PAS DE CALAIS;1
62801;;Souchez;SOUCHEZ;62153;62;PAS DE CALAIS;1
62802;Le;Souich;SOUICH;62810;62;PAS DE CALAIS;1
62803;;Surques;SURQUES;62850;62;PAS DE CALAIS;1
62804;;Sus-Saint-Léger;SUS-SAINT-LEGER;62810;62;PAS DE CALAIS;1
62805;;Tangry;TANGRY;62550;62;PAS DE CALAIS;1
62806;;Tardinghen;TARDINGHEN;62179;62;PAS DE CALAIS;1
62807;;Tatinghem;TATINGHEM;62500;62;PAS DE CALAIS;1
62808;;Teneur;TENEUR;62134;62;PAS DE CALAIS;1
62809;;Ternas;TERNAS;62127;62;PAS DE CALAIS;1
62810;;Thélus;THELUS;62580;62;PAS DE CALAIS;1
62811;;Thérouanne;THEROUANNE;62129;62;PAS DE CALAIS;1
62812;;Thiembronne;THIEMBRONNE;62560;62;PAS DE CALAIS;1
62813;La;Thieuloye;THIEULOYE;62130;62;PAS DE CALAIS;1
62814;;Thièvres;THIEVRES;62760;62;PAS DE CALAIS;1
62815;;Tigny-Noyelle;TIGNY-NOYELLE;62180;62;PAS DE CALAIS;1
62816;;Tilloy-lès-Hermaville;TILLOY-LES-HERMAVILLE;62690;62;PAS DE CALAIS;1
62817;;Tilloy-lès-Mofflaines;TILLOY-LES-MOFFLAINES;62217;62;PAS DE CALAIS;1
62818;;Tilly-Capelle;TILLY-CAPELLE;62134;62;PAS DE CALAIS;1
62819;;Tilques;TILQUES;62500;62;PAS DE CALAIS;1
62820;;Tincques;TINCQUES;62127;62;PAS DE CALAIS;1
62821;;Tingry;TINGRY;62830;62;PAS DE CALAIS;1
62822;;Tollent;TOLLENT;62390;62;PAS DE CALAIS;1
62823;;Torcy;TORCY;62310;62;PAS DE CALAIS;1
62824;;Tortefontaine;TORTEFONTAINE;62140;62;PAS DE CALAIS;1
62825;;Tortequesne;TORTEQUESNE;62490;62;PAS DE CALAIS;1
62826;Le;Touquet-Paris-Plage;TOUQUET-PARIS-PLAGE;62520;62;PAS DE CALAIS;1
62827;;Tournehem-sur-la-Hem;TOURNEHEM-SUR-LA-HEM;62890;62;PAS DE CALAIS;1
62828;;Tramecourt;TRAMECOURT;62310;62;PAS DE CALAIS;1
62829;Le;Transloy;TRANSLOY;62450;62;PAS DE CALAIS;1
62830;;Trescault;TRESCAULT;62147;62;PAS DE CALAIS;1
62831;;Troisvaux;TROISVAUX;62130;62;PAS DE CALAIS;1
62832;;Tubersent;TUBERSENT;62630;62;PAS DE CALAIS;1
62833;;Vacquerie-le-Boucq;VACQUERIE-LE-BOUCQ;62270;62;PAS DE CALAIS;1
62834;;Vacqueriette-Erquières;VACQUERIETTE-ERQUIERES;62140;62;PAS DE CALAIS;1
62835;;Valhuon;VALHUON;62550;62;PAS DE CALAIS;1
62836;;Vaudricourt;VAUDRICOURT;62131;62;PAS DE CALAIS;1
62837;;Vaudringhem;VAUDRINGHEM;62380;62;PAS DE CALAIS;1
62838;;Vaulx;VAULX;62390;62;PAS DE CALAIS;1
62839;;Vaulx-Vraucourt;VAULX-VRAUCOURT;62159;62;PAS DE CALAIS;1
62840;;Vélu;VELU;62124;62;PAS DE CALAIS;1
62841;;Vendin-lès-Béthune;VENDIN-LES-BETHUNE;62232;62;PAS DE CALAIS;1
62842;;Vendin-le-Vieil;VENDIN-LE-VIEIL;62880;62;PAS DE CALAIS;1
62843;;Verchin;VERCHIN;62310;62;PAS DE CALAIS;1
62844;;Verchocq;VERCHOCQ;62560;62;PAS DE CALAIS;1
62845;;Verlincthun;VERLINCTHUN;62830;62;PAS DE CALAIS;1
62846;;Vermelles;VERMELLES;62980;62;PAS DE CALAIS;1
62847;;Verquigneul;VERQUIGNEUL;62113;62;PAS DE CALAIS;1
62848;;Verquin;VERQUIN;62131;62;PAS DE CALAIS;1
62849;;Verton;VERTON;62180;62;PAS DE CALAIS;1
62850;;Vieil-Hesdin;VIEIL-HESDIN;62770;62;PAS DE CALAIS;1
62851;;Vieille-Chapelle;VIEILLE-CHAPELLE;62136;62;PAS DE CALAIS;1
62852;;Vieille-Église;VIEILLE-EGLISE;62162;62;PAS DE CALAIS;1
62853;;Vieil-Moutier;VIEIL-MOUTIER;62240;62;PAS DE CALAIS;1
62854;;Villers-au-Bois;VILLERS-AU-BOIS;62144;62;PAS DE CALAIS;1
62855;;Villers-au-Flos;VILLERS-AU-FLOS;62450;62;PAS DE CALAIS;1
62856;;Villers-Brûlin;VILLERS-BRULIN;62690;62;PAS DE CALAIS;1
62857;;Villers-Châtel;VILLERS-CHATEL;62690;62;PAS DE CALAIS;1
62858;;Villers-lès-Cagnicourt;VILLERS-LES-CAGNICOURT;62182;62;PAS DE CALAIS;1
62859;;Villers-l'Hôpital;VILLERS-L'HOPITAL;62390;62;PAS DE CALAIS;1
62860;;Villers-Sir-Simon;VILLERS-SIR-SIMON;62127;62;PAS DE CALAIS;1
62861;;Vimy;VIMY;62580;62;PAS DE CALAIS;1
62862;;Vincly;VINCLY;62310;62;PAS DE CALAIS;1
62863;;Violaines;VIOLAINES;62138;62;PAS DE CALAIS;1
62864;;Vis-en-Artois;VIS-EN-ARTOIS;62156;62;PAS DE CALAIS;1
62865;;Vitry-en-Artois;VITRY-EN-ARTOIS;62490;62;PAS DE CALAIS;1
62866;;Waben;WABEN;62180;62;PAS DE CALAIS;1
62867;;Wacquinghen;WACQUINGHEN;62250;62;PAS DE CALAIS;1
62868;;Wail;WAIL;62770;62;PAS DE CALAIS;1
62869;;Wailly;WAILLY;62217;62;PAS DE CALAIS;1
62870;;Wailly-Beaucamp;WAILLY-BEAUCAMP;62170;62;PAS DE CALAIS;1
62871;;Wambercourt;WAMBERCOURT;62140;62;PAS DE CALAIS;1
62872;;Wamin;WAMIN;62770;62;PAS DE CALAIS;1
62873;;Wancourt;WANCOURT;62128;62;PAS DE CALAIS;1
62874;;Wanquetin;WANQUETIN;62123;62;PAS DE CALAIS;1
62875;;Wardrecques;WARDRECQUES;62120;62;PAS DE CALAIS;1
62876;;Warlencourt-Eaucourt;WARLENCOURT-EAUCOURT;62450;62;PAS DE CALAIS;1
62877;;Warlincourt-lès-Pas;WARLINCOURT-LES-PAS;62760;62;PAS DE CALAIS;1
62878;;Warlus;WARLUS;62123;62;PAS DE CALAIS;1
62879;;Warluzel;WARLUZEL;62810;62;PAS DE CALAIS;1
62880;Le;Wast;WAST;62142;62;PAS DE CALAIS;1
62881;;Beauvoir-Wavans;BEAUVOIR-WAVANS;62390;62;PAS DE CALAIS;1
62882;;Wavrans-sur-l'Aa;WAVRANS-SUR-L'AA;62380;62;PAS DE CALAIS;1
62883;;Wavrans-sur-Ternoise;WAVRANS-SUR-TERNOISE;62130;62;PAS DE CALAIS;1
62885;;Westrehem;WESTREHEM;62960;62;PAS DE CALAIS;1
62886;;Wicquinghem;WICQUINGHEM;62650;62;PAS DE CALAIS;1
62887;;Widehem;WIDEHEM;62630;62;PAS DE CALAIS;1
62888;;Wierre-au-Bois;WIERRE-AU-BOIS;62830;62;PAS DE CALAIS;1
62889;;Wierre-Effroy;WIERRE-EFFROY;62720;62;PAS DE CALAIS;1
62890;;Willeman;WILLEMAN;62770;62;PAS DE CALAIS;1
62891;;Willencourt;WILLENCOURT;62390;62;PAS DE CALAIS;1
62892;;Willerval;WILLERVAL;62580;62;PAS DE CALAIS;1
62893;;Wimereux;WIMEREUX;62930;62;PAS DE CALAIS;1
62894;;Wimille;WIMILLE;62126;62;PAS DE CALAIS;1
62895;;Wingles;WINGLES;62410;62;PAS DE CALAIS;1
62896;;Wirwignes;WIRWIGNES;62240;62;PAS DE CALAIS;1
62897;;Wismes;WISMES;62380;62;PAS DE CALAIS;1
62898;;Wisques;WISQUES;62219;62;PAS DE CALAIS;1
62899;;Wissant;WISSANT;62179;62;PAS DE CALAIS;1
62900;;Witternesse;WITTERNESSE;62120;62;PAS DE CALAIS;1
62901;;Wittes;WITTES;62120;62;PAS DE CALAIS;1
62902;;Wizernes;WIZERNES;62570;62;PAS DE CALAIS;1
62903;;Zoteux;ZOTEUX;62650;62;PAS DE CALAIS;1
62904;;Zouafques;ZOUAFQUES;62890;62;PAS DE CALAIS;1
62905;;Zudausques;ZUDAUSQUES;62500;62;PAS DE CALAIS;1
62906;;Zutkerque;ZUTKERQUE;62370;62;PAS DE CALAIS;1
62907;;Libercourt;LIBERCOURT;62820;62;PAS DE CALAIS;1
62908;La;Capelle-lès-Boulogne;CAPELLE-LES-BOULOGNE;62360;62;PAS DE CALAIS;1
62909;;Ytres;YTRES;62124;62;PAS DE CALAIS;1
63001;;Aigueperse;AIGUEPERSE;63260;63;PUY DE DOME;1
63002;;Aix-la-Fayette;AIX-LA-FAYETTE;63980;63;PUY DE DOME;1
63003;;Ambert;AMBERT;63600;63;PUY DE DOME;1
63004;Les;Ancizes-Comps;ANCIZES-COMPS;63770;63;PUY DE DOME;1
63005;;Antoingt;ANTOINGT;63340;63;PUY DE DOME;1
63006;;Anzat-le-Luguet;ANZAT-LE-LUGUET;63420;63;PUY DE DOME;1
63007;;Apchat;APCHAT;63420;63;PUY DE DOME;1
63008;;Arconsat;ARCONSAT;63250;63;PUY DE DOME;1
63009;;Ardes;ARDES;63420;63;PUY DE DOME;1
63010;;Arlanc;ARLANC;63220;63;PUY DE DOME;1
63011;;Ars-les-Favets;ARS-LES-FAVETS;63700;63;PUY DE DOME;1
63012;;Artonne;ARTONNE;63460;63;PUY DE DOME;1
63013;;Aubiat;AUBIAT;63260;63;PUY DE DOME;1
63014;;Aubière;AUBIERE;63170;63;PUY DE DOME;1
63015;;Aubusson-d'Auvergne;AUBUSSON-D'AUVERGNE;63120;63;PUY DE DOME;1
63016;;Augerolles;AUGEROLLES;63930;63;PUY DE DOME;1
63017;;Augnat;AUGNAT;63340;63;PUY DE DOME;1
63018;;Aulhat-Saint-Privat;AULHAT-SAINT-PRIVAT;63500;63;PUY DE DOME;1
63019;;Aulnat;AULNAT;63510;63;PUY DE DOME;1
63020;;Aurières;AURIERES;63210;63;PUY DE DOME;1
63021;;Authezat;AUTHEZAT;63730;63;PUY DE DOME;1
63022;;Auzat-la-Combelle;AUZAT-LA-COMBELLE;63570;63;PUY DE DOME;1
63023;;Auzelles;AUZELLES;63590;63;PUY DE DOME;1
63024;;Avèze;AVEZE;63690;63;PUY DE DOME;1
63025;;Ayat-sur-Sioule;AYAT-SUR-SIOULE;63390;63;PUY DE DOME;1
63026;;Aydat;AYDAT;63970;63;PUY DE DOME;1
63027;;Baffie;BAFFIE;63600;63;PUY DE DOME;1
63028;;Bagnols;BAGNOLS;63810;63;PUY DE DOME;1
63029;;Bansat;BANSAT;63570;63;PUY DE DOME;1
63030;;Bas-et-Lezat;BAS-ET-LEZAT;63310;63;PUY DE DOME;1
63031;;Beaulieu;BEAULIEU;63570;63;PUY DE DOME;1
63032;;Beaumont;BEAUMONT;63110;63;PUY DE DOME;1
63033;;Beaumont-lès-Randan;BEAUMONT-LES-RANDAN;63310;63;PUY DE DOME;1
63034;;Beauregard-l'Évêque;BEAUREGARD-L'EVEQUE;63116;63;PUY DE DOME;1
63035;;Beauregard-Vendon;BEAUREGARD-VENDON;63460;63;PUY DE DOME;1
63036;;Bergonne;BERGONNE;63500;63;PUY DE DOME;1
63037;;Bertignat;BERTIGNAT;63480;63;PUY DE DOME;1
63038;;Besse-et-Saint-Anastaise;BESSE-ET-SAINT-ANASTAISE;63610;63;PUY DE DOME;1
63039;;Beurières;BEURIERES;63220;63;PUY DE DOME;1
63040;;Billom;BILLOM;63160;63;PUY DE DOME;1
63041;;Biollet;BIOLLET;63640;63;PUY DE DOME;1
63042;;Blanzat;BLANZAT;63112;63;PUY DE DOME;1
63043;;Blot-l'Église;BLOT-L'EGLISE;63440;63;PUY DE DOME;1
63044;;Bongheat;BONGHEAT;63160;63;PUY DE DOME;1
63045;;Bort-l'Étang;BORT-L'ETANG;63190;63;PUY DE DOME;1
63046;;Boudes;BOUDES;63340;63;PUY DE DOME;1
63047;La;Bourboule;BOURBOULE;63150;63;PUY DE DOME;1
63048;;Bourg-Lastic;BOURG-LASTIC;63760;63;PUY DE DOME;1
63049;;Bouzel;BOUZEL;63910;63;PUY DE DOME;1
63050;;Brassac-les-Mines;BRASSAC-LES-MINES;63570;63;PUY DE DOME;1
63051;;Brenat;BRENAT;63500;63;PUY DE DOME;1
63052;Le;Breuil-sur-Couze;BREUIL-SUR-COUZE;63340;63;PUY DE DOME;1
63053;;Briffons;BRIFFONS;63820;63;PUY DE DOME;1
63054;Le;Broc;BROC;63500;63;PUY DE DOME;1
63055;;Bromont-Lamothe;BROMONT-LAMOTHE;63230;63;PUY DE DOME;1
63056;;Brousse;BROUSSE;63490;63;PUY DE DOME;1
63057;Le;Brugeron;BRUGERON;63880;63;PUY DE DOME;1
63058;;Bulhon;BULHON;63350;63;PUY DE DOME;1
63059;;Busséol;BUSSEOL;63270;63;PUY DE DOME;1
63060;;Bussières;BUSSIERES;63330;63;PUY DE DOME;1
63061;;Bussières-et-Pruns;BUSSIERES-ET-PRUNS;63260;63;PUY DE DOME;1
63062;;Buxières-sous-Montaigut;BUXIERES-SOUS-MONTAIGUT;63700;63;PUY DE DOME;1
63063;;Cébazat;CEBAZAT;63118;63;PUY DE DOME;1
63064;La;Celle;CELLE;63620;63;PUY DE DOME;1
63065;;Ceilloux;CEILLOUX;63520;63;PUY DE DOME;1
63066;;Celles-sur-Durolle;CELLES-SUR-DUROLLE;63250;63;PUY DE DOME;1
63067;La;Cellette;CELLETTE;63330;63;PUY DE DOME;1
63068;;Cellule;CELLULE;63200;63;PUY DE DOME;1
63069;Le;Cendre;CENDRE;63670;63;PUY DE DOME;1
63070;;Ceyrat;CEYRAT;63122;63;PUY DE DOME;1
63071;;Ceyssat;CEYSSAT;63210;63;PUY DE DOME;1
63072;;Chabreloche;CHABRELOCHE;63250;63;PUY DE DOME;1
63073;;Chadeleuf;CHADELEUF;63320;63;PUY DE DOME;1
63074;;Chalus;CHALUS;63340;63;PUY DE DOME;1
63075;;Chamalières;CHAMALIERES;63400;63;PUY DE DOME;1
63076;;Chambon-sur-Dolore;CHAMBON-SUR-DOLORE;63980;63;PUY DE DOME;1
63077;;Chambon-sur-Lac;CHAMBON-SUR-LAC;63790;63;PUY DE DOME;1
63078;;Chaméane;CHAMEANE;63580;63;PUY DE DOME;1
63079;;Champagnat-le-Jeune;CHAMPAGNAT-LE-JEUNE;63580;63;PUY DE DOME;1
63080;;Champeix;CHAMPEIX;63320;63;PUY DE DOME;1
63081;;Champétières;CHAMPETIERES;63600;63;PUY DE DOME;1
63082;;Champs;CHAMPS;63440;63;PUY DE DOME;1
63083;;Chanat-la-Mouteyre;CHANAT-LA-MOUTEYRE;63530;63;PUY DE DOME;1
63084;;Chanonat;CHANONAT;63450;63;PUY DE DOME;1
63085;;Chapdes-Beaufort;CHAPDES-BEAUFORT;63230;63;PUY DE DOME;1
63086;La;Chapelle-Agnon;CHAPELLE-AGNON;63590;63;PUY DE DOME;1
63087;La;Chapelle-Marcousse;CHAPELLE-MARCOUSSE;63420;63;PUY DE DOME;1
63088;La;Chapelle-sur-Usson;CHAPELLE-SUR-USSON;63580;63;PUY DE DOME;1
63089;;Chappes;CHAPPES;63720;63;PUY DE DOME;1
63090;;Chaptuzat;CHAPTUZAT;63260;63;PUY DE DOME;1
63091;;Charbonnier-les-Mines;CHARBONNIER-LES-MINES;63340;63;PUY DE DOME;1
63092;;Charbonnières-les-Varennes;CHARBONNIERES-LES-VARENNES;63410;63;PUY DE DOME;1
63093;;Charbonnières-les-Vieilles;CHARBONNIERES-LES-VIEILLES;63410;63;PUY DE DOME;1
63094;;Charensat;CHARENSAT;63640;63;PUY DE DOME;1
63095;;Charnat;CHARNAT;63290;63;PUY DE DOME;1
63096;;Chas;CHAS;63160;63;PUY DE DOME;1
63097;;Chassagne;CHASSAGNE;63320;63;PUY DE DOME;1
63098;;Chastreix;CHASTREIX;63680;63;PUY DE DOME;1
63099;;Châteaugay;CHATEAUGAY;63119;63;PUY DE DOME;1
63100;;Châteauneuf-les-Bains;CHATEAUNEUF-LES-BAINS;63390;63;PUY DE DOME;1
63101;;Château-sur-Cher;CHATEAU-SUR-CHER;63330;63;PUY DE DOME;1
63102;;Châteldon;CHATELDON;63290;63;PUY DE DOME;1
63103;;Châtel-Guyon;CHATEL-GUYON;63140;63;PUY DE DOME;1
63104;La;Chaulme;CHAULME;63660;63;PUY DE DOME;1
63105;;Chaumont-le-Bourg;CHAUMONT-LE-BOURG;63220;63;PUY DE DOME;1
63106;;Chauriat;CHAURIAT;63117;63;PUY DE DOME;1
63107;;Chavaroux;CHAVAROUX;63720;63;PUY DE DOME;1
63108;Le;Cheix;CHEIX;63200;63;PUY DE DOME;1
63109;;Chidrac;CHIDRAC;63320;63;PUY DE DOME;1
63110;;Cisternes-la-Forêt;CISTERNES-LA-FORET;63740;63;PUY DE DOME;1
63111;;Clémensat;CLEMENSAT;63320;63;PUY DE DOME;1
63112;;Clerlande;CLERLANDE;63720;63;PUY DE DOME;1
63113;;Clermont-Ferrand;CLERMONT-FERRAND;63000;63;PUY DE DOME;1
63114;;Collanges;COLLANGES;63340;63;PUY DE DOME;1
63115;;Combrailles;COMBRAILLES;63380;63;PUY DE DOME;1
63116;;Combronde;COMBRONDE;63460;63;PUY DE DOME;1
63117;;Compains;COMPAINS;63610;63;PUY DE DOME;1
63118;;Condat-en-Combraille;CONDAT-EN-COMBRAILLE;63380;63;PUY DE DOME;1
63119;;Condat-lès-Montboissier;CONDAT-LES-MONTBOISSIER;63490;63;PUY DE DOME;1
63120;;Corent;CORENT;63730;63;PUY DE DOME;1
63121;;Coudes;COUDES;63114;63;PUY DE DOME;1
63122;;Courgoul;COURGOUL;63320;63;PUY DE DOME;1
63123;;Cournols;COURNOLS;63450;63;PUY DE DOME;1
63124;;Cournon-d'Auvergne;COURNON-D'AUVERGNE;63800;63;PUY DE DOME;1
63125;;Courpière;COURPIERE;63120;63;PUY DE DOME;1
63126;Le;Crest;CREST;63450;63;PUY DE DOME;1
63127;;Creste;CRESTE;63320;63;PUY DE DOME;1
63128;;Crevant-Laveine;CREVANT-LAVEINE;63350;63;PUY DE DOME;1
63129;;Cros;CROS;63810;63;PUY DE DOME;1
63130;La;Crouzille;CROUZILLE;63700;63;PUY DE DOME;1
63131;;Culhat;CULHAT;63350;63;PUY DE DOME;1
63132;;Cunlhat;CUNLHAT;63590;63;PUY DE DOME;1
63133;;Dallet;DALLET;63111;63;PUY DE DOME;1
63134;;Dauzat-sur-Vodable;DAUZAT-SUR-VODABLE;63340;63;PUY DE DOME;1
63135;;Davayat;DAVAYAT;63200;63;PUY DE DOME;1
63136;;Domaize;DOMAIZE;63520;63;PUY DE DOME;1
63137;;Doranges;DORANGES;63220;63;PUY DE DOME;1
63138;;Dorat;DORAT;63300;63;PUY DE DOME;1
63139;;Dore-l'Église;DORE-L'EGLISE;63220;63;PUY DE DOME;1
63140;;Durmignat;DURMIGNAT;63700;63;PUY DE DOME;1
63141;;Durtol;DURTOL;63830;63;PUY DE DOME;1
63142;;Échandelys;ECHANDELYS;63980;63;PUY DE DOME;1
63143;;Effiat;EFFIAT;63260;63;PUY DE DOME;1
63144;;Égliseneuve-d'Entraigues;EGLISENEUVE-D'ENTRAIGUES;63850;63;PUY DE DOME;1
63145;;Égliseneuve-des-Liards;EGLISENEUVE-DES-LIARDS;63490;63;PUY DE DOME;1
63146;;Égliseneuve-près-Billom;EGLISENEUVE-PRES-BILLOM;63160;63;PUY DE DOME;1
63147;;Églisolles;EGLISOLLES;63840;63;PUY DE DOME;1
63148;;Ennezat;ENNEZAT;63720;63;PUY DE DOME;1
63149;;Entraigues;ENTRAIGUES;63720;63;PUY DE DOME;1
63150;;Enval;ENVAL;63530;63;PUY DE DOME;1
63151;;Escoutoux;ESCOUTOUX;63300;63;PUY DE DOME;1
63152;;Espinasse;ESPINASSE;63390;63;PUY DE DOME;1
63153;;Espinchal;ESPINCHAL;63850;63;PUY DE DOME;1
63154;;Espirat;ESPIRAT;63160;63;PUY DE DOME;1
63155;;Estandeuil;ESTANDEUIL;63520;63;PUY DE DOME;1
63156;;Esteil;ESTEIL;63570;63;PUY DE DOME;1
63157;;Fayet-le-Château;FAYET-LE-CHATEAU;63160;63;PUY DE DOME;1
63158;;Fayet-Ronaye;FAYET-RONAYE;63630;63;PUY DE DOME;1
63159;;Fernoël;FERNOEL;63620;63;PUY DE DOME;1
63160;;Flat;FLAT;63500;63;PUY DE DOME;1
63161;La;Forie;FORIE;63600;63;PUY DE DOME;1
63162;;Fournols;FOURNOLS;63980;63;PUY DE DOME;1
63163;;Gelles;GELLES;63740;63;PUY DE DOME;1
63164;;Gerzat;GERZAT;63360;63;PUY DE DOME;1
63165;;Giat;GIAT;63620;63;PUY DE DOME;1
63166;;Gignat;GIGNAT;63340;63;PUY DE DOME;1
63167;;Gimeaux;GIMEAUX;63200;63;PUY DE DOME;1
63168;;Glaine-Montaigut;GLAINE-MONTAIGUT;63160;63;PUY DE DOME;1
63169;La;Godivelle;GODIVELLE;63850;63;PUY DE DOME;1
63170;La;Goutelle;GOUTELLE;63230;63;PUY DE DOME;1
63171;;Gouttières;GOUTTIERES;63390;63;PUY DE DOME;1
63172;;Grandeyrolles;GRANDEYROLLES;63320;63;PUY DE DOME;1
63173;;Grandrif;GRANDRIF;63600;63;PUY DE DOME;1
63174;;Grandval;GRANDVAL;63890;63;PUY DE DOME;1
63175;;Herment;HERMENT;63470;63;PUY DE DOME;1
63176;;Heume-l'Église;HEUME-L'EGLISE;63210;63;PUY DE DOME;1
63177;;Isserteaux;ISSERTEAUX;63270;63;PUY DE DOME;1
63178;;Issoire;ISSOIRE;63500;63;PUY DE DOME;1
63179;;Job;JOB;63990;63;PUY DE DOME;1
63180;;Joze;JOZE;63350;63;PUY DE DOME;1
63181;;Jozerand;JOZERAND;63460;63;PUY DE DOME;1
63182;;Jumeaux;JUMEAUX;63570;63;PUY DE DOME;1
63183;;Labessette;LABESSETTE;63690;63;PUY DE DOME;1
63184;;Lachaux;LACHAUX;63290;63;PUY DE DOME;1
63185;;Lamontgie;LAMONTGIE;63570;63;PUY DE DOME;1
63186;;Landogne;LANDOGNE;63380;63;PUY DE DOME;1
63187;;Lapeyrouse;LAPEYROUSE;63700;63;PUY DE DOME;1
63188;;Laps;LAPS;63270;63;PUY DE DOME;1
63189;;Laqueuille;LAQUEUILLE;63820;63;PUY DE DOME;1
63190;;Larodde;LARODDE;63690;63;PUY DE DOME;1
63191;;Lastic;LASTIC;63760;63;PUY DE DOME;1
63192;La;Tour-d'Auvergne;TOUR-D'AUVERGNE;63680;63;PUY DE DOME;1
63193;;Lempdes;LEMPDES;63370;63;PUY DE DOME;1
63194;;Lempty;LEMPTY;63190;63;PUY DE DOME;1
63195;;Lezoux;LEZOUX;63190;63;PUY DE DOME;1
63196;;Limons;LIMONS;63290;63;PUY DE DOME;1
63197;;Lisseuil;LISSEUIL;63440;63;PUY DE DOME;1
63198;;Loubeyrat;LOUBEYRAT;63410;63;PUY DE DOME;1
63199;;Ludesse;LUDESSE;63320;63;PUY DE DOME;1
63200;;Lussat;LUSSAT;63360;63;PUY DE DOME;1
63201;;Luzillat;LUZILLAT;63350;63;PUY DE DOME;1
63202;;Madriat;MADRIAT;63340;63;PUY DE DOME;1
63203;;Malauzat;MALAUZAT;63200;63;PUY DE DOME;1
63204;;Malintrat;MALINTRAT;63510;63;PUY DE DOME;1
63205;;Manglieu;MANGLIEU;63270;63;PUY DE DOME;1
63206;;Manzat;MANZAT;63410;63;PUY DE DOME;1
63207;;Marat;MARAT;63480;63;PUY DE DOME;1
63208;;Marcillat;MARCILLAT;63440;63;PUY DE DOME;1
63209;;Mareugheol;MAREUGHEOL;63340;63;PUY DE DOME;1
63210;;Maringues;MARINGUES;63350;63;PUY DE DOME;1
63211;;Marsac-en-Livradois;MARSAC-EN-LIVRADOIS;63940;63;PUY DE DOME;1
63212;;Marsat;MARSAT;63200;63;PUY DE DOME;1
63213;Les;Martres-d'Artière;MARTRES-D'ARTIERE;63430;63;PUY DE DOME;1
63214;Les;Martres-de-Veyre;MARTRES-DE-VEYRE;63730;63;PUY DE DOME;1
63215;;Martres-sur-Morge;MARTRES-SUR-MORGE;63720;63;PUY DE DOME;1
63216;;Mauzun;MAUZUN;63160;63;PUY DE DOME;1
63218;;Mayres;MAYRES;63220;63;PUY DE DOME;1
63219;;Mazaye;MAZAYE;63230;63;PUY DE DOME;1
63220;;Mazoires;MAZOIRES;63420;63;PUY DE DOME;1
63221;;Medeyrolles;MEDEYROLLES;63220;63;PUY DE DOME;1
63222;;Meilhaud;MEILHAUD;63320;63;PUY DE DOME;1
63223;;Menat;MENAT;63560;63;PUY DE DOME;1
63224;;Ménétrol;MENETROL;63200;63;PUY DE DOME;1
63225;;Messeix;MESSEIX;63750;63;PUY DE DOME;1
63226;;Mezel;MEZEL;63115;63;PUY DE DOME;1
63227;;Mirefleurs;MIREFLEURS;63730;63;PUY DE DOME;1
63228;;Miremont;MIREMONT;63380;63;PUY DE DOME;1
63229;;Moissat;MOISSAT;63190;63;PUY DE DOME;1
63230;Le;Monestier;MONESTIER;63890;63;PUY DE DOME;1
63231;La;Monnerie-le-Montel;MONNERIE-LE-MONTEL;63650;63;PUY DE DOME;1
63232;;Mons;MONS;63310;63;PUY DE DOME;1
63233;;Montaigut;MONTAIGUT;63700;63;PUY DE DOME;1
63234;;Montaigut-le-Blanc;MONTAIGUT-LE-BLANC;63320;63;PUY DE DOME;1
63235;;Montcel;MONTCEL;63460;63;PUY DE DOME;1
63236;;Mont-Dore;MONT-DORE;63240;63;PUY DE DOME;1
63237;;Montel-de-Gelat;MONTEL-DE-GELAT;63380;63;PUY DE DOME;1
63238;;Montfermy;MONTFERMY;63230;63;PUY DE DOME;1
63239;;Montmorin;MONTMORIN;63160;63;PUY DE DOME;1
63240;;Montpensier;MONTPENSIER;63260;63;PUY DE DOME;1
63241;;Montpeyroux;MONTPEYROUX;63114;63;PUY DE DOME;1
63242;;Moriat;MORIAT;63340;63;PUY DE DOME;1
63243;;Moureuille;MOUREUILLE;63700;63;PUY DE DOME;1
63244;La;Moutade;MOUTADE;63200;63;PUY DE DOME;1
63245;;Mozac;MOZAC;63200;63;PUY DE DOME;1
63246;;Murat-le-Quaire;MURAT-LE-QUAIRE;63150;63;PUY DE DOME;1
63247;;Murol;MUROL;63790;63;PUY DE DOME;1
63248;;Nébouzat;NEBOUZAT;63210;63;PUY DE DOME;1
63249;;Néronde-sur-Dore;NERONDE-SUR-DORE;63120;63;PUY DE DOME;1
63250;;Neschers;NESCHERS;63320;63;PUY DE DOME;1
63251;;Neuf-Église;NEUF-EGLISE;63560;63;PUY DE DOME;1
63252;;Neuville;NEUVILLE;63160;63;PUY DE DOME;1
63253;;Noalhat;NOALHAT;63290;63;PUY DE DOME;1
63254;;Nohanent;NOHANENT;63830;63;PUY DE DOME;1
63255;;Nonette;NONETTE;63340;63;PUY DE DOME;1
63256;;Novacelles;NOVACELLES;63220;63;PUY DE DOME;1
63257;;Olby;OLBY;63210;63;PUY DE DOME;1
63258;;Olliergues;OLLIERGUES;63880;63;PUY DE DOME;1
63259;;Olloix;OLLOIX;63450;63;PUY DE DOME;1
63260;;Olmet;OLMET;63880;63;PUY DE DOME;1
63261;;Orbeil;ORBEIL;63500;63;PUY DE DOME;1
63262;;Orcet;ORCET;63670;63;PUY DE DOME;1
63263;;Orcines;ORCINES;63870;63;PUY DE DOME;1
63264;;Orcival;ORCIVAL;63210;63;PUY DE DOME;1
63265;;Orléat;ORLEAT;63190;63;PUY DE DOME;1
63266;;Orsonnette;ORSONNETTE;63340;63;PUY DE DOME;1
63267;;Palladuc;PALLADUC;63550;63;PUY DE DOME;1
63268;;Pardines;PARDINES;63500;63;PUY DE DOME;1
63269;;Parent;PARENT;63270;63;PUY DE DOME;1
63270;;Parentignat;PARENTIGNAT;63500;63;PUY DE DOME;1
63271;;Paslières;PASLIERES;63290;63;PUY DE DOME;1
63272;;Pérignat-lès-Sarliève;PERIGNAT-LES-SARLIEVE;63170;63;PUY DE DOME;1
63273;;Pérignat-sur-Allier;PERIGNAT-SUR-ALLIER;63800;63;PUY DE DOME;1
63274;;Perpezat;PERPEZAT;63210;63;PUY DE DOME;1
63275;;Perrier;PERRIER;63500;63;PUY DE DOME;1
63276;;Peschadoires;PESCHADOIRES;63920;63;PUY DE DOME;1
63277;;Peslières;PESLIERES;63580;63;PUY DE DOME;1
63278;;Pessat-Villeneuve;PESSAT-VILLENEUVE;63200;63;PUY DE DOME;1
63279;;Picherande;PICHERANDE;63113;63;PUY DE DOME;1
63280;;Pignols;PIGNOLS;63270;63;PUY DE DOME;1
63281;;Pionsat;PIONSAT;63330;63;PUY DE DOME;1
63282;;Plauzat;PLAUZAT;63730;63;PUY DE DOME;1
63283;;Pontaumur;PONTAUMUR;63380;63;PUY DE DOME;1
63284;;Pont-du-Château;PONT-DU-CHATEAU;63430;63;PUY DE DOME;1
63285;;Pontgibaud;PONTGIBAUD;63230;63;PUY DE DOME;1
63286;;Pouzol;POUZOL;63440;63;PUY DE DOME;1
63287;Les;Pradeaux;PRADEAUX;63500;63;PUY DE DOME;1
63288;;Prompsat;PROMPSAT;63200;63;PUY DE DOME;1
63289;;Prondines;PRONDINES;63470;63;PUY DE DOME;1
63290;;Pulvérières;PULVERIERES;63230;63;PUY DE DOME;1
63291;;Puy-Guillaume;PUY-GUILLAUME;63290;63;PUY DE DOME;1
63292;;Puy-Saint-Gulmier;PUY-SAINT-GULMIER;63470;63;PUY DE DOME;1
63293;Le;Quartier;QUARTIER;63330;63;PUY DE DOME;1
63294;;Queuille;QUEUILLE;63780;63;PUY DE DOME;1
63295;;Randan;RANDAN;63310;63;PUY DE DOME;1
63296;;Ravel;RAVEL;63190;63;PUY DE DOME;1
63297;;Reignat;REIGNAT;63160;63;PUY DE DOME;1
63298;La;Renaudie;RENAUDIE;63930;63;PUY DE DOME;1
63299;;Rentières;RENTIERES;63420;63;PUY DE DOME;1
63300;;Riom;RIOM;63200;63;PUY DE DOME;1
63301;;Ris;RIS;63290;63;PUY DE DOME;1
63302;La;Roche-Blanche;ROCHE-BLANCHE;63670;63;PUY DE DOME;1
63303;;Roche-Charles-la-Mayrand;ROCHE-CHARLES-LA-MAYRAND;63420;63;PUY DE DOME;1
63304;;Roche-d'Agoux;ROCHE-D'AGOUX;63330;63;PUY DE DOME;1
63305;;Rochefort-Montagne;ROCHEFORT-MONTAGNE;63210;63;PUY DE DOME;1
63306;La;Roche-Noire;ROCHE-NOIRE;63800;63;PUY DE DOME;1
63307;;Romagnat;ROMAGNAT;63540;63;PUY DE DOME;1
63308;;Royat;ROYAT;63130;63;PUY DE DOME;1
63309;;Saillant;SAILLANT;63840;63;PUY DE DOME;1
63310;;Sainte-Agathe;SAINTE-AGATHE;63120;63;PUY DE DOME;1
63311;;Saint-Agoulin;SAINT-AGOULIN;63260;63;PUY DE DOME;1
63312;;Saint-Alyre-d'Arlanc;SAINT-ALYRE-D'ARLANC;63220;63;PUY DE DOME;1
63313;;Saint-Alyre-ès-Montagne;SAINT-ALYRE-ES-MONTAGNE;63420;63;PUY DE DOME;1
63314;;Saint-Amant-Roche-Savine;SAINT-AMANT-ROCHE-SAVINE;63890;63;PUY DE DOME;1
63315;;Saint-Amant-Tallende;SAINT-AMANT-TALLENDE;63450;63;PUY DE DOME;1
63317;;Saint-André-le-Coq;SAINT-ANDRE-LE-COQ;63310;63;PUY DE DOME;1
63318;;Saint-Angel;SAINT-ANGEL;63410;63;PUY DE DOME;1
63319;;Saint-Anthème;SAINT-ANTHEME;63660;63;PUY DE DOME;1
63320;;Saint-Avit;SAINT-AVIT;63380;63;PUY DE DOME;1
63321;;Saint-Babel;SAINT-BABEL;63500;63;PUY DE DOME;1
63322;;Saint-Beauzire;SAINT-BEAUZIRE;63360;63;PUY DE DOME;1
63323;;Saint-Bonnet-le-Bourg;SAINT-BONNET-LE-BOURG;63630;63;PUY DE DOME;1
63324;;Saint-Bonnet-le-Chastel;SAINT-BONNET-LE-CHASTEL;63630;63;PUY DE DOME;1
63325;;Saint-Bonnet-lès-Allier;SAINT-BONNET-LES-ALLIER;63800;63;PUY DE DOME;1
63326;;Saint-Bonnet-près-Orcival;SAINT-BONNET-PRES-ORCIVAL;63210;63;PUY DE DOME;1
63327;;Saint-Bonnet-près-Riom;SAINT-BONNET-PRES-RIOM;63200;63;PUY DE DOME;1
63328;;Sainte-Catherine;SAINTE-CATHERINE;63580;63;PUY DE DOME;1
63329;;Sainte-Christine;SAINTE-CHRISTINE;63390;63;PUY DE DOME;1
63330;;Saint-Cirgues-sur-Couze;SAINT-CIRGUES-SUR-COUZE;63320;63;PUY DE DOME;1
63331;;Saint-Clément-de-Valorgue;SAINT-CLEMENT-DE-VALORGUE;63660;63;PUY DE DOME;1
63332;;Saint-Clément-de-Régnat;SAINT-CLEMENT-DE-REGNAT;63310;63;PUY DE DOME;1
63333;;Saint-Denis-Combarnazat;SAINT-DENIS-COMBARNAZAT;63310;63;PUY DE DOME;1
63334;;Saint-Dier-d'Auvergne;SAINT-DIER-D'AUVERGNE;63520;63;PUY DE DOME;1
63335;;Saint-Diéry;SAINT-DIERY;63320;63;PUY DE DOME;1
63336;;Saint-Donat;SAINT-DONAT;63680;63;PUY DE DOME;1
63337;;Saint-Éloy-la-Glacière;SAINT-ELOY-LA-GLACIERE;63890;63;PUY DE DOME;1
63338;;Saint-Éloy-les-Mines;SAINT-ELOY-LES-MINES;63700;63;PUY DE DOME;1
63339;;Saint-Étienne-des-Champs;SAINT-ETIENNE-DES-CHAMPS;63380;63;PUY DE DOME;1
63340;;Saint-Étienne-sur-Usson;SAINT-ETIENNE-SUR-USSON;63580;63;PUY DE DOME;1
63341;;Saint-Ferréol-des-Côtes;SAINT-FERREOL-DES-COTES;63600;63;PUY DE DOME;1
63342;;Saint-Floret;SAINT-FLORET;63320;63;PUY DE DOME;1
63343;;Saint-Flour;SAINT-FLOUR;63520;63;PUY DE DOME;1
63344;;Saint-Gal-sur-Sioule;SAINT-GAL-SUR-SIOULE;63440;63;PUY DE DOME;1
63345;;Saint-Genès-Champanelle;SAINT-GENES-CHAMPANELLE;63122;63;PUY DE DOME;1
63346;;Saint-Genès-Champespe;SAINT-GENES-CHAMPESPE;63850;63;PUY DE DOME;1
63347;;Saint-Genès-du-Retz;SAINT-GENES-DU-RETZ;63260;63;PUY DE DOME;1
63348;;Saint-Genès-la-Tourette;SAINT-GENES-LA-TOURETTE;63580;63;PUY DE DOME;1
63349;;Saint-Georges-de-Mons;SAINT-GEORGES-DE-MONS;63780;63;PUY DE DOME;1
63350;;Saint-Georges-sur-Allier;SAINT-GEORGES-SUR-ALLIER;63800;63;PUY DE DOME;1
63351;;Saint-Germain-près-Herment;SAINT-GERMAIN-PRES-HERMENT;63470;63;PUY DE DOME;1
63352;;Saint-Germain-Lembron;SAINT-GERMAIN-LEMBRON;63340;63;PUY DE DOME;1
63353;;Saint-Germain-l'Herm;SAINT-GERMAIN-L'HERM;63630;63;PUY DE DOME;1
63354;;Saint-Gervais-d'Auvergne;SAINT-GERVAIS-D'AUVERGNE;63390;63;PUY DE DOME;1
63355;;Saint-Gervais-sous-Meymont;SAINT-GERVAIS-SOUS-MEYMONT;63880;63;PUY DE DOME;1
63356;;Saint-Gervazy;SAINT-GERVAZY;63340;63;PUY DE DOME;1
63357;;Saint-Hérent;SAINT-HERENT;63340;63;PUY DE DOME;1
63358;;Saint-Hilaire-la-Croix;SAINT-HILAIRE-LA-CROIX;63440;63;PUY DE DOME;1
63359;;Saint-Hilaire-les-Monges;SAINT-HILAIRE-LES-MONGES;63380;63;PUY DE DOME;1
63360;;Saint-Hilaire;SAINT-HILAIRE;63330;63;PUY DE DOME;1
63362;;Saint-Ignat;SAINT-IGNAT;63720;63;PUY DE DOME;1
63363;;Saint-Jacques-d'Ambur;SAINT-JACQUES-D'AMBUR;63230;63;PUY DE DOME;1
63364;;Saint-Jean-d'Heurs;SAINT-JEAN-D'HEURS;63190;63;PUY DE DOME;1
63365;;Saint-Jean-des-Ollières;SAINT-JEAN-DES-OLLIERES;63520;63;PUY DE DOME;1
63366;;Saint-Jean-en-Val;SAINT-JEAN-EN-VAL;63490;63;PUY DE DOME;1
63367;;Saint-Jean-Saint-Gervais;SAINT-JEAN-SAINT-GERVAIS;63570;63;PUY DE DOME;1
63368;;Saint-Julien-de-Coppel;SAINT-JULIEN-DE-COPPEL;63160;63;PUY DE DOME;1
63369;;Saint-Julien-la-Geneste;SAINT-JULIEN-LA-GENESTE;63390;63;PUY DE DOME;1
63370;;Saint-Julien-Puy-Lavèze;SAINT-JULIEN-PUY-LAVEZE;63820;63;PUY DE DOME;1
63371;;Saint-Just;SAINT-JUST;63600;63;PUY DE DOME;1
63372;;Saint-Laure;SAINT-LAURE;63350;63;PUY DE DOME;1
63373;;Saint-Maigner;SAINT-MAIGNER;63330;63;PUY DE DOME;1
63374;;Saint-Martin-des-Olmes;SAINT-MARTIN-DES-OLMES;63600;63;PUY DE DOME;1
63375;;Saint-Martin-des-Plains;SAINT-MARTIN-DES-PLAINS;63570;63;PUY DE DOME;1
63376;;Saint-Martin-d'Ollières;SAINT-MARTIN-D'OLLIERES;63580;63;PUY DE DOME;1
63377;;Saint-Maurice-près-Pionsat;SAINT-MAURICE-PRES-PIONSAT;63330;63;PUY DE DOME;1
63378;;Saint-Maurice;SAINT-MAURICE;63270;63;PUY DE DOME;1
63379;;Saint-Myon;SAINT-MYON;63460;63;PUY DE DOME;1
63380;;Saint-Nectaire;SAINT-NECTAIRE;63710;63;PUY DE DOME;1
63381;;Saint-Ours;SAINT-OURS;63230;63;PUY DE DOME;1
63382;;Saint-Pardoux;SAINT-PARDOUX;63440;63;PUY DE DOME;1
63383;;Saint-Pierre-Colamine;SAINT-PIERRE-COLAMINE;63610;63;PUY DE DOME;1
63384;;Saint-Pierre-la-Bourlhonne;SAINT-PIERRE-LA-BOURLHONNE;63480;63;PUY DE DOME;1
63385;;Saint-Pierre-le-Chastel;SAINT-PIERRE-LE-CHASTEL;63230;63;PUY DE DOME;1
63386;;Saint-Pierre-Roche;SAINT-PIERRE-ROCHE;63210;63;PUY DE DOME;1
63387;;Saint-Priest-Bramefant;SAINT-PRIEST-BRAMEFANT;63310;63;PUY DE DOME;1
63388;;Saint-Priest-des-Champs;SAINT-PRIEST-DES-CHAMPS;63640;63;PUY DE DOME;1
63389;;Saint-Quentin-sur-Sauxillanges;SAINT-QUENTIN-SUR-SAUXILLANGES;63490;63;PUY DE DOME;1
63390;;Saint-Quintin-sur-Sioule;SAINT-QUINTIN-SUR-SIOULE;63440;63;PUY DE DOME;1
63391;;Saint-Rémy-de-Blot;SAINT-REMY-DE-BLOT;63440;63;PUY DE DOME;1
63392;;Saint-Rémy-de-Chargnat;SAINT-REMY-DE-CHARGNAT;63500;63;PUY DE DOME;1
63393;;Saint-Rémy-sur-Durolle;SAINT-REMY-SUR-DUROLLE;63550;63;PUY DE DOME;1
63394;;Saint-Romain;SAINT-ROMAIN;63660;63;PUY DE DOME;1
63395;;Saint-Sandoux;SAINT-SANDOUX;63450;63;PUY DE DOME;1
63396;;Saint-Saturnin;SAINT-SATURNIN;63450;63;PUY DE DOME;1
63397;;Saint-Sauves-d'Auvergne;SAINT-SAUVES-D'AUVERGNE;63950;63;PUY DE DOME;1
63398;;Saint-Sauveur-la-Sagne;SAINT-SAUVEUR-LA-SAGNE;63220;63;PUY DE DOME;1
63399;;Saint-Sulpice;SAINT-SULPICE;63760;63;PUY DE DOME;1
63400;;Saint-Sylvestre-Pragoulin;SAINT-SYLVESTRE-PRAGOULIN;63310;63;PUY DE DOME;1
63401;;Saint-Victor-la-Rivière;SAINT-VICTOR-LA-RIVIERE;63790;63;PUY DE DOME;1
63402;;Saint-Victor-Montvianeix;SAINT-VICTOR-MONTVIANEIX;63550;63;PUY DE DOME;1
63403;;Saint-Vincent;SAINT-VINCENT;63320;63;PUY DE DOME;1
63404;;Saint-Yvoine;SAINT-YVOINE;63500;63;PUY DE DOME;1
63405;;Sallèdes;SALLEDES;63270;63;PUY DE DOME;1
63406;;Sardon;SARDON;63260;63;PUY DE DOME;1
63407;;Saulzet-le-Froid;SAULZET-LE-FROID;63970;63;PUY DE DOME;1
63408;;Sauret-Besserve;SAURET-BESSERVE;63390;63;PUY DE DOME;1
63409;;Saurier;SAURIER;63320;63;PUY DE DOME;1
63410;;Sauvagnat;SAUVAGNAT;63470;63;PUY DE DOME;1
63411;;Sauvagnat-Sainte-Marthe;SAUVAGNAT-SAINTE-MARTHE;63500;63;PUY DE DOME;1
63412;;Sauvessanges;SAUVESSANGES;63840;63;PUY DE DOME;1
63413;La;Sauvetat;SAUVETAT;63730;63;PUY DE DOME;1
63414;;Sauviat;SAUVIAT;63120;63;PUY DE DOME;1
63415;;Sauxillanges;SAUXILLANGES;63490;63;PUY DE DOME;1
63416;;Savennes;SAVENNES;63750;63;PUY DE DOME;1
63417;;Sayat;SAYAT;63530;63;PUY DE DOME;1
63418;;Sermentizon;SERMENTIZON;63120;63;PUY DE DOME;1
63419;;Servant;SERVANT;63560;63;PUY DE DOME;1
63420;;Seychalles;SEYCHALLES;63190;63;PUY DE DOME;1
63421;;Singles;SINGLES;63690;63;PUY DE DOME;1
63422;;Solignat;SOLIGNAT;63500;63;PUY DE DOME;1
63423;;Sugères;SUGERES;63490;63;PUY DE DOME;1
63424;;Surat;SURAT;63720;63;PUY DE DOME;1
63425;;Tallende;TALLENDE;63450;63;PUY DE DOME;1
63426;;Tauves;TAUVES;63690;63;PUY DE DOME;1
63427;;Teilhède;TEILHEDE;63460;63;PUY DE DOME;1
63428;;Teilhet;TEILHET;63560;63;PUY DE DOME;1
63429;;Ternant-les-Eaux;TERNANT-LES-EAUX;63340;63;PUY DE DOME;1
63430;;Thiers;THIERS;63300;63;PUY DE DOME;1
63431;;Thiolières;THIOLIERES;63600;63;PUY DE DOME;1
63432;;Thuret;THURET;63260;63;PUY DE DOME;1
63433;;Tortebesse;TORTEBESSE;63470;63;PUY DE DOME;1
63434;;Tours-sur-Meymont;TOURS-SUR-MEYMONT;63590;63;PUY DE DOME;1
63435;;Tourzel-Ronzières;TOURZEL-RONZIERES;63320;63;PUY DE DOME;1
63436;;Tralaigues;TRALAIGUES;63380;63;PUY DE DOME;1
63437;;Trémouille-Saint-Loup;TREMOUILLE-SAINT-LOUP;63810;63;PUY DE DOME;1
63438;;Trézioux;TREZIOUX;63520;63;PUY DE DOME;1
63439;;Usson;USSON;63490;63;PUY DE DOME;1
63440;;Valbeleix;VALBELEIX;63610;63;PUY DE DOME;1
63441;;Valcivières;VALCIVIERES;63600;63;PUY DE DOME;1
63442;;Valz-sous-Châteauneuf;VALZ-SOUS-CHATEAUNEUF;63580;63;PUY DE DOME;1
63443;;Varennes-sur-Morge;VARENNES-SUR-MORGE;63720;63;PUY DE DOME;1
63444;;Varennes-sur-Usson;VARENNES-SUR-USSON;63500;63;PUY DE DOME;1
63445;;Vassel;VASSEL;63910;63;PUY DE DOME;1
63446;;Vensat;VENSAT;63260;63;PUY DE DOME;1
63447;;Vergheas;VERGHEAS;63330;63;PUY DE DOME;1
63448;;Vernet-la-Varenne;VERNET-LA-VARENNE;63580;63;PUY DE DOME;1
63449;Le;Vernet-Sainte-Marguerite;VERNET-SAINTE-MARGUERITE;63710;63;PUY DE DOME;1
63450;;Verneugheol;VERNEUGHEOL;63470;63;PUY DE DOME;1
63451;;Vernines;VERNINES;63210;63;PUY DE DOME;1
63452;;Verrières;VERRIERES;63320;63;PUY DE DOME;1
63453;;Vertaizon;VERTAIZON;63910;63;PUY DE DOME;1
63454;;Vertolaye;VERTOLAYE;63480;63;PUY DE DOME;1
63455;;Veyre-Monton;VEYRE-MONTON;63960;63;PUY DE DOME;1
63456;;Vichel;VICHEL;63340;63;PUY DE DOME;1
63457;;Vic-le-Comte;VIC-LE-COMTE;63270;63;PUY DE DOME;1
63458;;Villeneuve;VILLENEUVE;63340;63;PUY DE DOME;1
63459;;Villeneuve-les-Cerfs;VILLENEUVE-LES-CERFS;63310;63;PUY DE DOME;1
63460;;Villosanges;VILLOSANGES;63380;63;PUY DE DOME;1
63461;;Vinzelles;VINZELLES;63350;63;PUY DE DOME;1
63462;;Virlet;VIRLET;63330;63;PUY DE DOME;1
63463;;Viscomtat;VISCOMTAT;63250;63;PUY DE DOME;1
63464;;Vitrac;VITRAC;63410;63;PUY DE DOME;1
63465;;Viverols;VIVEROLS;63840;63;PUY DE DOME;1
63466;;Vodable;VODABLE;63500;63;PUY DE DOME;1
63467;;Voingt;VOINGT;63620;63;PUY DE DOME;1
63468;;Vollore-Montagne;VOLLORE-MONTAGNE;63120;63;PUY DE DOME;1
63469;;Vollore-Ville;VOLLORE-VILLE;63120;63;PUY DE DOME;1
63470;;Volvic;VOLVIC;63530;63;PUY DE DOME;1
63471;;Youx;YOUX;63700;63;PUY DE DOME;1
63472;;Yronde-et-Buron;YRONDE-ET-BURON;63270;63;PUY DE DOME;1
63473;;Yssac-la-Tourette;YSSAC-LA-TOURETTE;63200;63;PUY DE DOME;1
64001;;Aast;AAST;64460;64;PYRENEES ATLANTIQUES;1
64002;;Abère;ABERE;64160;64;PYRENEES ATLANTIQUES;1
64003;;Abidos;ABIDOS;64150;64;PYRENEES ATLANTIQUES;1
64004;;Abitain;ABITAIN;64390;64;PYRENEES ATLANTIQUES;1
64005;;Abos;ABOS;64360;64;PYRENEES ATLANTIQUES;1
64006;;Accous;ACCOUS;64490;64;PYRENEES ATLANTIQUES;1
64007;;Agnos;AGNOS;64400;64;PYRENEES ATLANTIQUES;1
64008;;Ahaxe-Alciette-Bascassan;AHAXE-ALCIETTE-BASCASSAN;64220;64;PYRENEES ATLANTIQUES;1
64009;;Ahetze;AHETZE;64210;64;PYRENEES ATLANTIQUES;1
64010;;Aïcirits-Camou-Suhast;AICIRITS-CAMOU-SUHAST;64120;64;PYRENEES ATLANTIQUES;1
64011;;Aincille;AINCILLE;64220;64;PYRENEES ATLANTIQUES;1
64012;;Ainharp;AINHARP;64130;64;PYRENEES ATLANTIQUES;1
64013;;Ainhice-Mongelos;AINHICE-MONGELOS;64220;64;PYRENEES ATLANTIQUES;1
64014;;Ainhoa;AINHOA;64250;64;PYRENEES ATLANTIQUES;1
64015;;Alçay-Alçabéhéty-Sunharette;ALCAY-ALCABEHETY-SUNHARETTE;64470;64;PYRENEES ATLANTIQUES;1
64016;;Aldudes;ALDUDES;64430;64;PYRENEES ATLANTIQUES;1
64017;;Alos-Sibas-Abense;ALOS-SIBAS-ABENSE;64470;64;PYRENEES ATLANTIQUES;1
64018;;Amendeuix-Oneix;AMENDEUIX-ONEIX;64120;64;PYRENEES ATLANTIQUES;1
64019;;Amorots-Succos;AMOROTS-SUCCOS;64120;64;PYRENEES ATLANTIQUES;1
64020;;Ance;ANCE;64570;64;PYRENEES ATLANTIQUES;1
64021;;Andoins;ANDOINS;64420;64;PYRENEES ATLANTIQUES;1
64022;;Andrein;ANDREIN;64390;64;PYRENEES ATLANTIQUES;1
64023;;Angaïs;ANGAIS;64510;64;PYRENEES ATLANTIQUES;1
64024;;Anglet;ANGLET;64600;64;PYRENEES ATLANTIQUES;1
64025;;Angous;ANGOUS;64190;64;PYRENEES ATLANTIQUES;1
64026;;Anhaux;ANHAUX;64220;64;PYRENEES ATLANTIQUES;1
64027;;Anos;ANOS;64160;64;PYRENEES ATLANTIQUES;1
64028;;Anoye;ANOYE;64350;64;PYRENEES ATLANTIQUES;1
64029;;Aramits;ARAMITS;64570;64;PYRENEES ATLANTIQUES;1
64031;;Arancou;ARANCOU;64270;64;PYRENEES ATLANTIQUES;1
64032;;Araujuzon;ARAUJUZON;64190;64;PYRENEES ATLANTIQUES;1
64033;;Araux;ARAUX;64190;64;PYRENEES ATLANTIQUES;1
64034;;Arbérats-Sillègue;ARBERATS-SILLEGUE;64120;64;PYRENEES ATLANTIQUES;1
64035;;Arbonne;ARBONNE;64210;64;PYRENEES ATLANTIQUES;1
64036;;Arbouet-Sussaute;ARBOUET-SUSSAUTE;64120;64;PYRENEES ATLANTIQUES;1
64037;;Arbus;ARBUS;64230;64;PYRENEES ATLANTIQUES;1
64038;;Arcangues;ARCANGUES;64200;64;PYRENEES ATLANTIQUES;1
64039;;Aren;AREN;64400;64;PYRENEES ATLANTIQUES;1
64040;;Arette;ARETTE;64570;64;PYRENEES ATLANTIQUES;1
64041;;Aressy;ARESSY;64320;64;PYRENEES ATLANTIQUES;1
64042;;Argagnon;ARGAGNON;64300;64;PYRENEES ATLANTIQUES;1
64043;;Argelos;ARGELOS;64450;64;PYRENEES ATLANTIQUES;1
64044;;Arget;ARGET;64410;64;PYRENEES ATLANTIQUES;1
64045;;Arhansus;ARHANSUS;64120;64;PYRENEES ATLANTIQUES;1
64046;;Armendarits;ARMENDARITS;64640;64;PYRENEES ATLANTIQUES;1
64047;;Arnéguy;ARNEGUY;64220;64;PYRENEES ATLANTIQUES;1
64048;;Arnos;ARNOS;64370;64;PYRENEES ATLANTIQUES;1
64049;;Aroue-Ithorots-Olhaïby;AROUE-ITHOROTS-OLHAIBY;64120;64;PYRENEES ATLANTIQUES;1
64050;;Arrast-Larrebieu;ARRAST-LARREBIEU;64130;64;PYRENEES ATLANTIQUES;1
64051;;Arraute-Charritte;ARRAUTE-CHARRITTE;64120;64;PYRENEES ATLANTIQUES;1
64052;;Arricau-Bordes;ARRICAU-BORDES;64350;64;PYRENEES ATLANTIQUES;1
64053;;Arrien;ARRIEN;64420;64;PYRENEES ATLANTIQUES;1
64054;;Arros-de-Nay;ARROS-DE-NAY;64800;64;PYRENEES ATLANTIQUES;1
64056;;Arrosès;ARROSES;64350;64;PYRENEES ATLANTIQUES;1
64057;;Arthez-de-Béarn;ARTHEZ-DE-BEARN;64370;64;PYRENEES ATLANTIQUES;1
64058;;Arthez-d'Asson;ARTHEZ-D'ASSON;64800;64;PYRENEES ATLANTIQUES;1
64059;;Artigueloutan;ARTIGUELOUTAN;64420;64;PYRENEES ATLANTIQUES;1
64060;;Artiguelouve;ARTIGUELOUVE;64230;64;PYRENEES ATLANTIQUES;1
64061;;Artix;ARTIX;64170;64;PYRENEES ATLANTIQUES;1
64062;;Arudy;ARUDY;64260;64;PYRENEES ATLANTIQUES;1
64063;;Arzacq-Arraziguet;ARZACQ-ARRAZIGUET;64410;64;PYRENEES ATLANTIQUES;1
64064;;Asasp-Arros;ASASP-ARROS;64660;64;PYRENEES ATLANTIQUES;1
64065;;Ascain;ASCAIN;64310;64;PYRENEES ATLANTIQUES;1
64066;;Ascarat;ASCARAT;64220;64;PYRENEES ATLANTIQUES;1
64067;;Assat;ASSAT;64510;64;PYRENEES ATLANTIQUES;1
64068;;Asson;ASSON;64800;64;PYRENEES ATLANTIQUES;1
64069;;Aste-Béon;ASTE-BEON;64260;64;PYRENEES ATLANTIQUES;1
64070;;Astis;ASTIS;64450;64;PYRENEES ATLANTIQUES;1
64071;;Athos-Aspis;ATHOS-ASPIS;64390;64;PYRENEES ATLANTIQUES;1
64072;;Aubertin;AUBERTIN;64290;64;PYRENEES ATLANTIQUES;1
64073;;Aubin;AUBIN;64230;64;PYRENEES ATLANTIQUES;1
64074;;Aubous;AUBOUS;64330;64;PYRENEES ATLANTIQUES;1
64075;;Audaux;AUDAUX;64190;64;PYRENEES ATLANTIQUES;1
64077;;Auga;AUGA;64450;64;PYRENEES ATLANTIQUES;1
64078;;Auriac;AURIAC;64450;64;PYRENEES ATLANTIQUES;1
64079;;Aurions-Idernes;AURIONS-IDERNES;64350;64;PYRENEES ATLANTIQUES;1
64080;;Aussevielle;AUSSEVIELLE;64230;64;PYRENEES ATLANTIQUES;1
64081;;Aussurucq;AUSSURUCQ;64130;64;PYRENEES ATLANTIQUES;1
64082;;Auterrive;AUTERRIVE;64270;64;PYRENEES ATLANTIQUES;1
64083;;Autevielle-Saint-Martin-Bideren;AUTEVIELLE-SAINT-MARTIN-BIDEREN;64390;64;PYRENEES ATLANTIQUES;1
64084;;Aydie;AYDIE;64330;64;PYRENEES ATLANTIQUES;1
64085;;Aydius;AYDIUS;64490;64;PYRENEES ATLANTIQUES;1
64086;;Ayherre;AYHERRE;64240;64;PYRENEES ATLANTIQUES;1
64087;;Baigts-de-Béarn;BAIGTS-DE-BEARN;64300;64;PYRENEES ATLANTIQUES;1
64088;;Balansun;BALANSUN;64300;64;PYRENEES ATLANTIQUES;1
64089;;Baleix;BALEIX;64460;64;PYRENEES ATLANTIQUES;1
64090;;Baliracq-Maumusson;BALIRACQ-MAUMUSSON;64330;64;PYRENEES ATLANTIQUES;1
64091;;Baliros;BALIROS;64510;64;PYRENEES ATLANTIQUES;1
64092;;Banca;BANCA;64430;64;PYRENEES ATLANTIQUES;1
64093;;Barcus;BARCUS;64130;64;PYRENEES ATLANTIQUES;1
64094;;Bardos;BARDOS;64520;64;PYRENEES ATLANTIQUES;1
64095;;Barinque;BARINQUE;64160;64;PYRENEES ATLANTIQUES;1
64096;;Barraute-Camu;BARRAUTE-CAMU;64390;64;PYRENEES ATLANTIQUES;1
64097;;Barzun;BARZUN;64530;64;PYRENEES ATLANTIQUES;1
64098;;Bassillon-Vauzé;BASSILLON-VAUZE;64350;64;PYRENEES ATLANTIQUES;1
64099;;Bastanès;BASTANES;64190;64;PYRENEES ATLANTIQUES;1
64100;;Bassussarry;BASSUSSARRY;64200;64;PYRENEES ATLANTIQUES;1
64101;;Baudreix;BAUDREIX;64800;64;PYRENEES ATLANTIQUES;1
64102;;Bayonne;BAYONNE;64100;64;PYRENEES ATLANTIQUES;1
64103;;Bédeille;BEDEILLE;64460;64;PYRENEES ATLANTIQUES;1
64104;;Bedous;BEDOUS;64490;64;PYRENEES ATLANTIQUES;1
64105;;Béguios;BEGUIOS;64120;64;PYRENEES ATLANTIQUES;1
64106;;Béhasque-Lapiste;BEHASQUE-LAPISTE;64120;64;PYRENEES ATLANTIQUES;1
64107;;Béhorléguy;BEHORLEGUY;64220;64;PYRENEES ATLANTIQUES;1
64108;;Bellocq;BELLOCQ;64270;64;PYRENEES ATLANTIQUES;1
64109;;Bénéjacq;BENEJACQ;64800;64;PYRENEES ATLANTIQUES;1
64110;;Béost;BEOST;64440;64;PYRENEES ATLANTIQUES;1
64111;;Bentayou-Sérée;BENTAYOU-SEREE;64460;64;PYRENEES ATLANTIQUES;1
64112;;Bérenx;BERENX;64300;64;PYRENEES ATLANTIQUES;1
64113;;Bergouey-Viellenave;BERGOUEY-VIELLENAVE;64270;64;PYRENEES ATLANTIQUES;1
64114;;Bernadets;BERNADETS;64160;64;PYRENEES ATLANTIQUES;1
64115;;Berrogain-Laruns;BERROGAIN-LARUNS;64130;64;PYRENEES ATLANTIQUES;1
64116;;Bescat;BESCAT;64260;64;PYRENEES ATLANTIQUES;1
64117;;Bésingrand;BESINGRAND;64150;64;PYRENEES ATLANTIQUES;1
64118;;Bétracq;BETRACQ;64350;64;PYRENEES ATLANTIQUES;1
64119;;Beuste;BEUSTE;64800;64;PYRENEES ATLANTIQUES;1
64120;;Beyrie-sur-Joyeuse;BEYRIE-SUR-JOYEUSE;64120;64;PYRENEES ATLANTIQUES;1
64121;;Beyrie-en-Béarn;BEYRIE-EN-BEARN;64230;64;PYRENEES ATLANTIQUES;1
64122;;Biarritz;BIARRITZ;64200;64;PYRENEES ATLANTIQUES;1
64123;;Bidache;BIDACHE;64520;64;PYRENEES ATLANTIQUES;1
64124;;Bidarray;BIDARRAY;64780;64;PYRENEES ATLANTIQUES;1
64125;;Bidart;BIDART;64210;64;PYRENEES ATLANTIQUES;1
64126;;Bidos;BIDOS;64400;64;PYRENEES ATLANTIQUES;1
64127;;Bielle;BIELLE;64260;64;PYRENEES ATLANTIQUES;1
64128;;Bilhères;BILHERES;64260;64;PYRENEES ATLANTIQUES;1
64129;;Billère;BILLERE;64140;64;PYRENEES ATLANTIQUES;1
64130;;Biriatou;BIRIATOU;64700;64;PYRENEES ATLANTIQUES;1
64131;;Biron;BIRON;64300;64;PYRENEES ATLANTIQUES;1
64132;;Bizanos;BIZANOS;64320;64;PYRENEES ATLANTIQUES;1
64133;;Boeil-Bezing;BOEIL-BEZING;64510;64;PYRENEES ATLANTIQUES;1
64134;;Bonloc;BONLOC;64240;64;PYRENEES ATLANTIQUES;1
64135;;Bonnut;BONNUT;64300;64;PYRENEES ATLANTIQUES;1
64136;;Borce;BORCE;64490;64;PYRENEES ATLANTIQUES;1
64137;;Bordères;BORDERES;64800;64;PYRENEES ATLANTIQUES;1
64138;;Bordes;BORDES;64510;64;PYRENEES ATLANTIQUES;1
64139;;Bosdarros;BOSDARROS;64290;64;PYRENEES ATLANTIQUES;1
64140;;Boucau;BOUCAU;64340;64;PYRENEES ATLANTIQUES;1
64141;;Boueilh-Boueilho-Lasque;BOUEILH-BOUEILHO-LASQUE;64330;64;PYRENEES ATLANTIQUES;1
64142;;Bougarber;BOUGARBER;64230;64;PYRENEES ATLANTIQUES;1
64143;;Bouillon;BOUILLON;64410;64;PYRENEES ATLANTIQUES;1
64144;;Boumourt;BOUMOURT;64370;64;PYRENEES ATLANTIQUES;1
64145;;Bourdettes;BOURDETTES;64800;64;PYRENEES ATLANTIQUES;1
64146;;Bournos;BOURNOS;64450;64;PYRENEES ATLANTIQUES;1
64147;;Briscous;BRISCOUS;64240;64;PYRENEES ATLANTIQUES;1
64148;;Bruges-Capbis-Mifaget;BRUGES-CAPBIS-MIFAGET;64800;64;PYRENEES ATLANTIQUES;1
64149;;Bugnein;BUGNEIN;64190;64;PYRENEES ATLANTIQUES;1
64150;;Bunus;BUNUS;64120;64;PYRENEES ATLANTIQUES;1
64151;;Burgaronne;BURGARONNE;64390;64;PYRENEES ATLANTIQUES;1
64152;;Buros;BUROS;64160;64;PYRENEES ATLANTIQUES;1
64153;;Burosse-Mendousse;BUROSSE-MENDOUSSE;64330;64;PYRENEES ATLANTIQUES;1
64154;;Bussunarits-Sarrasquette;BUSSUNARITS-SARRASQUETTE;64220;64;PYRENEES ATLANTIQUES;1
64155;;Bustince-Iriberry;BUSTINCE-IRIBERRY;64220;64;PYRENEES ATLANTIQUES;1
64156;;Buziet;BUZIET;64680;64;PYRENEES ATLANTIQUES;1
64157;;Buzy;BUZY;64260;64;PYRENEES ATLANTIQUES;1
64158;;Cabidos;CABIDOS;64410;64;PYRENEES ATLANTIQUES;1
64159;;Cadillon;CADILLON;64330;64;PYRENEES ATLANTIQUES;1
64160;;Cambo-les-Bains;CAMBO-LES-BAINS;64250;64;PYRENEES ATLANTIQUES;1
64161;;Came;CAME;64520;64;PYRENEES ATLANTIQUES;1
64162;;Camou-Cihigue;CAMOU-CIHIGUE;64470;64;PYRENEES ATLANTIQUES;1
64165;;Cardesse;CARDESSE;64360;64;PYRENEES ATLANTIQUES;1
64166;;Caro;CARO;64220;64;PYRENEES ATLANTIQUES;1
64167;;Carrère;CARRERE;64160;64;PYRENEES ATLANTIQUES;1
64168;;Carresse-Cassaber;CARRESSE-CASSABER;64270;64;PYRENEES ATLANTIQUES;1
64170;;Castagnède;CASTAGNEDE;64270;64;PYRENEES ATLANTIQUES;1
64171;;Casteide-Cami;CASTEIDE-CAMI;64170;64;PYRENEES ATLANTIQUES;1
64172;;Casteide-Candau;CASTEIDE-CANDAU;64370;64;PYRENEES ATLANTIQUES;1
64173;;Casteide-Doat;CASTEIDE-DOAT;64460;64;PYRENEES ATLANTIQUES;1
64174;;Castéra-Loubix;CASTERA-LOUBIX;64460;64;PYRENEES ATLANTIQUES;1
64175;;Castet;CASTET;64260;64;PYRENEES ATLANTIQUES;1
64176;;Castetbon;CASTETBON;64190;64;PYRENEES ATLANTIQUES;1
64177;;Castétis;CASTETIS;64300;64;PYRENEES ATLANTIQUES;1
64178;;Castetnau-Camblong;CASTETNAU-CAMBLONG;64190;64;PYRENEES ATLANTIQUES;1
64179;;Castetner;CASTETNER;64300;64;PYRENEES ATLANTIQUES;1
64180;;Castetpugon;CASTETPUGON;64330;64;PYRENEES ATLANTIQUES;1
64181;;(CANTON;CASTILLON;64370;64;PYRENEES ATLANTIQUES;1
64182;;(CANTON;CASTILLON;64350;64;PYRENEES ATLANTIQUES;1
64183;;Caubios-Loos;CAUBIOS-LOOS;64230;64;PYRENEES ATLANTIQUES;1
64184;;Cescau;CESCAU;64170;64;PYRENEES ATLANTIQUES;1
64185;;Cette-Eygun;CETTE-EYGUN;64490;64;PYRENEES ATLANTIQUES;1
64186;;Charre;CHARRE;64190;64;PYRENEES ATLANTIQUES;1
64187;;Charritte-de-Bas;CHARRITTE-DE-BAS;64130;64;PYRENEES ATLANTIQUES;1
64188;;Chéraute;CHERAUTE;64130;64;PYRENEES ATLANTIQUES;1
64189;;Ciboure;CIBOURE;64500;64;PYRENEES ATLANTIQUES;1
64190;;Claracq;CLARACQ;64330;64;PYRENEES ATLANTIQUES;1
64191;;Coarraze;COARRAZE;64800;64;PYRENEES ATLANTIQUES;1
64192;;Conchez-de-Béarn;CONCHEZ-DE-BEARN;64330;64;PYRENEES ATLANTIQUES;1
64193;;Corbère-Abères;CORBERE-ABERES;64350;64;PYRENEES ATLANTIQUES;1
64194;;Coslédaà-Lube-Boast;COSLEDAA-LUBE-BOAST;64160;64;PYRENEES ATLANTIQUES;1
64195;;Coublucq;COUBLUCQ;64410;64;PYRENEES ATLANTIQUES;1
64196;;Crouseilles;CROUSEILLES;64350;64;PYRENEES ATLANTIQUES;1
64197;;Cuqueron;CUQUERON;64360;64;PYRENEES ATLANTIQUES;1
64198;;Denguin;DENGUIN;64230;64;PYRENEES ATLANTIQUES;1
64199;;Diusse;DIUSSE;64330;64;PYRENEES ATLANTIQUES;1
64200;;Doazon;DOAZON;64370;64;PYRENEES ATLANTIQUES;1
64201;;Dognen;DOGNEN;64190;64;PYRENEES ATLANTIQUES;1
64202;;Domezain-Berraute;DOMEZAIN-BERRAUTE;64120;64;PYRENEES ATLANTIQUES;1
64203;;Doumy;DOUMY;64450;64;PYRENEES ATLANTIQUES;1
64204;;Eaux-Bonnes;EAUX-BONNES;64440;64;PYRENEES ATLANTIQUES;1
64205;;Escos;ESCOS;64270;64;PYRENEES ATLANTIQUES;1
64206;;Escot;ESCOT;64490;64;PYRENEES ATLANTIQUES;1
64207;;Escou;ESCOU;64870;64;PYRENEES ATLANTIQUES;1
64208;;Escoubès;ESCOUBES;64160;64;PYRENEES ATLANTIQUES;1
64209;;Escout;ESCOUT;64870;64;PYRENEES ATLANTIQUES;1
64210;;Escurès;ESCURES;64350;64;PYRENEES ATLANTIQUES;1
64211;;Eslourenties-Daban;ESLOURENTIES-DABAN;64420;64;PYRENEES ATLANTIQUES;1
64212;;Espéchède;ESPECHEDE;64160;64;PYRENEES ATLANTIQUES;1
64213;;Espelette;ESPELETTE;64250;64;PYRENEES ATLANTIQUES;1
64214;;Espès-Undurein;ESPES-UNDUREIN;64130;64;PYRENEES ATLANTIQUES;1
64215;;Espiute;ESPIUTE;64390;64;PYRENEES ATLANTIQUES;1
64216;;Espoey;ESPOEY;64420;64;PYRENEES ATLANTIQUES;1
64217;;Esquiule;ESQUIULE;64400;64;PYRENEES ATLANTIQUES;1
64218;;Estérençuby;ESTERENCUBY;64220;64;PYRENEES ATLANTIQUES;1
64219;;Estialescq;ESTIALESCQ;64290;64;PYRENEES ATLANTIQUES;1
64220;;Estos;ESTOS;64400;64;PYRENEES ATLANTIQUES;1
64221;;Etcharry;ETCHARRY;64120;64;PYRENEES ATLANTIQUES;1
64222;;Etchebar;ETCHEBAR;64470;64;PYRENEES ATLANTIQUES;1
64223;;Etsaut;ETSAUT;64490;64;PYRENEES ATLANTIQUES;1
64224;;Eysus;EYSUS;64400;64;PYRENEES ATLANTIQUES;1
64225;;Féas;FEAS;64570;64;PYRENEES ATLANTIQUES;1
64226;;Fichous-Riumayou;FICHOUS-RIUMAYOU;64410;64;PYRENEES ATLANTIQUES;1
64227;;Gabaston;GABASTON;64160;64;PYRENEES ATLANTIQUES;1
64228;;Gabat;GABAT;64120;64;PYRENEES ATLANTIQUES;1
64229;;Gamarthe;GAMARTHE;64220;64;PYRENEES ATLANTIQUES;1
64230;;Gan;GAN;64290;64;PYRENEES ATLANTIQUES;1
64231;;Garindein;GARINDEIN;64130;64;PYRENEES ATLANTIQUES;1
64232;;Garlède-Mondebat;GARLEDE-MONDEBAT;64450;64;PYRENEES ATLANTIQUES;1
64233;;Garlin;GARLIN;64330;64;PYRENEES ATLANTIQUES;1
64234;;Garos;GAROS;64410;64;PYRENEES ATLANTIQUES;1
64235;;Garris;GARRIS;64120;64;PYRENEES ATLANTIQUES;1
64236;;Gayon;GAYON;64350;64;PYRENEES ATLANTIQUES;1
64237;;Gelos;GELOS;64110;64;PYRENEES ATLANTIQUES;1
64238;;Ger;GER;64530;64;PYRENEES ATLANTIQUES;1
64239;;Gerderest;GERDEREST;64160;64;PYRENEES ATLANTIQUES;1
64240;;Gère-Bélesten;GERE-BELESTEN;64260;64;PYRENEES ATLANTIQUES;1
64241;;Géronce;GERONCE;64400;64;PYRENEES ATLANTIQUES;1
64242;;Gestas;GESTAS;64190;64;PYRENEES ATLANTIQUES;1
64243;;Géus-d'Arzacq;GEUS-D'ARZACQ;64370;64;PYRENEES ATLANTIQUES;1
64244;;Geüs-d'Oloron;GEUS-D'OLORON;64400;64;PYRENEES ATLANTIQUES;1
64245;;Goès;GOES;64400;64;PYRENEES ATLANTIQUES;1
64246;;Gomer;GOMER;64420;64;PYRENEES ATLANTIQUES;1
64247;;Gotein-Libarrenx;GOTEIN-LIBARRENX;64130;64;PYRENEES ATLANTIQUES;1
64249;;Guéthary;GUETHARY;64210;64;PYRENEES ATLANTIQUES;1
64250;;Guiche;GUICHE;64520;64;PYRENEES ATLANTIQUES;1
64251;;Guinarthe-Parenties;GUINARTHE-PARENTIES;64390;64;PYRENEES ATLANTIQUES;1
64252;;Gurmençon;GURMENCON;64400;64;PYRENEES ATLANTIQUES;1
64253;;Gurs;GURS;64190;64;PYRENEES ATLANTIQUES;1
64254;;Hagetaubin;HAGETAUBIN;64370;64;PYRENEES ATLANTIQUES;1
64255;;Halsou;HALSOU;64480;64;PYRENEES ATLANTIQUES;1
64256;;Hasparren;HASPARREN;64240;64;PYRENEES ATLANTIQUES;1
64257;;Haut-de-Bosdarros;HAUT-DE-BOSDARROS;64800;64;PYRENEES ATLANTIQUES;1
64258;;Haux;HAUX;64470;64;PYRENEES ATLANTIQUES;1
64259;;Hélette;HELETTE;64640;64;PYRENEES ATLANTIQUES;1
64260;;Hendaye;HENDAYE;64700;64;PYRENEES ATLANTIQUES;1
64261;;Herrère;HERRERE;64680;64;PYRENEES ATLANTIQUES;1
64262;;Higuères-Souye;HIGUERES-SOUYE;64160;64;PYRENEES ATLANTIQUES;1
64263;L';Hôpital-d'Orion;HOPITAL-D'ORION;64270;64;PYRENEES ATLANTIQUES;1
64264;L';Hôpital-Saint-Blaise;HOPITAL-SAINT-BLAISE;64130;64;PYRENEES ATLANTIQUES;1
64265;;Hosta;HOSTA;64120;64;PYRENEES ATLANTIQUES;1
64266;;Hours;HOURS;64420;64;PYRENEES ATLANTIQUES;1
64267;;Ibarrolle;IBARROLLE;64120;64;PYRENEES ATLANTIQUES;1
64268;;Idaux-Mendy;IDAUX-MENDY;64130;64;PYRENEES ATLANTIQUES;1
64269;;Idron;IDRON;64320;64;PYRENEES ATLANTIQUES;1
64270;;Igon;IGON;64800;64;PYRENEES ATLANTIQUES;1
64271;;Iholdy;IHOLDY;64640;64;PYRENEES ATLANTIQUES;1
64272;;Ilharre;ILHARRE;64120;64;PYRENEES ATLANTIQUES;1
64273;;Irissarry;IRISSARRY;64780;64;PYRENEES ATLANTIQUES;1
64274;;Irouléguy;IROULEGUY;64220;64;PYRENEES ATLANTIQUES;1
64275;;Ispoure;ISPOURE;64220;64;PYRENEES ATLANTIQUES;1
64276;;Issor;ISSOR;64570;64;PYRENEES ATLANTIQUES;1
64277;;Isturits;ISTURITS;64240;64;PYRENEES ATLANTIQUES;1
64279;;Itxassou;ITXASSOU;64250;64;PYRENEES ATLANTIQUES;1
64280;;Izeste;IZESTE;64260;64;PYRENEES ATLANTIQUES;1
64281;;Jasses;JASSES;64190;64;PYRENEES ATLANTIQUES;1
64282;;Jatxou;JATXOU;64480;64;PYRENEES ATLANTIQUES;1
64283;;Jaxu;JAXU;64220;64;PYRENEES ATLANTIQUES;1
64284;;Jurançon;JURANCON;64110;64;PYRENEES ATLANTIQUES;1
64285;;Juxue;JUXUE;64120;64;PYRENEES ATLANTIQUES;1
64286;;Laà-Mondrans;LAA-MONDRANS;64300;64;PYRENEES ATLANTIQUES;1
64287;;Laàs;LAAS;64390;64;PYRENEES ATLANTIQUES;1
64288;;Labastide-Cézéracq;LABASTIDE-CEZERACQ;64170;64;PYRENEES ATLANTIQUES;1
64289;La;Bastide-Clairence;BASTIDE-CLAIRENCE;64240;64;PYRENEES ATLANTIQUES;1
64290;;Labastide-Monréjeau;LABASTIDE-MONREJEAU;64170;64;PYRENEES ATLANTIQUES;1
64291;;Labastide-Villefranche;LABASTIDE-VILLEFRANCHE;64270;64;PYRENEES ATLANTIQUES;1
64292;;Labatmale;LABATMALE;64530;64;PYRENEES ATLANTIQUES;1
64293;;Labatut;LABATUT;64460;64;PYRENEES ATLANTIQUES;1
64294;;Labets-Biscay;LABETS-BISCAY;64120;64;PYRENEES ATLANTIQUES;1
64295;;Labeyrie;LABEYRIE;64300;64;PYRENEES ATLANTIQUES;1
64296;;Lacadée;LACADEE;64300;64;PYRENEES ATLANTIQUES;1
64297;;Lacarre;LACARRE;64220;64;PYRENEES ATLANTIQUES;1
64298;;Lacarry-Arhan-Charritte-de-Haut;LACARRY-ARHAN-CHARRITTE-DE-HAUT;64470;64;PYRENEES ATLANTIQUES;1
64299;;Lacommande;LACOMMANDE;64360;64;PYRENEES ATLANTIQUES;1
64300;;Lacq;LACQ;64170;64;PYRENEES ATLANTIQUES;1
64301;;Lagor;LAGOR;64150;64;PYRENEES ATLANTIQUES;1
64302;;Lagos;LAGOS;64800;64;PYRENEES ATLANTIQUES;1
64303;;Laguinge-Restoue;LAGUINGE-RESTOUE;64470;64;PYRENEES ATLANTIQUES;1
64304;;Lahonce;LAHONCE;64990;64;PYRENEES ATLANTIQUES;1
64305;;Lahontan;LAHONTAN;64270;64;PYRENEES ATLANTIQUES;1
64306;;Lahourcade;LAHOURCADE;64150;64;PYRENEES ATLANTIQUES;1
64307;;Lalongue;LALONGUE;64350;64;PYRENEES ATLANTIQUES;1
64308;;Lalonquette;LALONQUETTE;64450;64;PYRENEES ATLANTIQUES;1
64309;;Lamayou;LAMAYOU;64460;64;PYRENEES ATLANTIQUES;1
64310;;Lanne-en-Barétous;LANNE-EN-BARETOUS;64570;64;PYRENEES ATLANTIQUES;1
64311;;Lannecaube;LANNECAUBE;64350;64;PYRENEES ATLANTIQUES;1
64312;;Lanneplaà;LANNEPLAA;64300;64;PYRENEES ATLANTIQUES;1
64313;;Lantabat;LANTABAT;64640;64;PYRENEES ATLANTIQUES;1
64314;;Larceveau-Arros-Cibits;LARCEVEAU-ARROS-CIBITS;64120;64;PYRENEES ATLANTIQUES;1
64315;;Laroin;LAROIN;64110;64;PYRENEES ATLANTIQUES;1
64316;;Larrau;LARRAU;64560;64;PYRENEES ATLANTIQUES;1
64317;;Larressore;LARRESSORE;64480;64;PYRENEES ATLANTIQUES;1
64318;;Larreule;LARREULE;64410;64;PYRENEES ATLANTIQUES;1
64319;;Larribar-Sorhapuru;LARRIBAR-SORHAPURU;64120;64;PYRENEES ATLANTIQUES;1
64320;;Laruns;LARUNS;64440;64;PYRENEES ATLANTIQUES;1
64321;;Lasclaveries;LASCLAVERIES;64450;64;PYRENEES ATLANTIQUES;1
64322;;Lasse;LASSE;64220;64;PYRENEES ATLANTIQUES;1
64323;;Lasserre;LASSERRE;64350;64;PYRENEES ATLANTIQUES;1
64324;;Lasseube;LASSEUBE;64290;64;PYRENEES ATLANTIQUES;1
64325;;Lasseubetat;LASSEUBETAT;64290;64;PYRENEES ATLANTIQUES;1
64326;;Lay-Lamidou;LAY-LAMIDOU;64190;64;PYRENEES ATLANTIQUES;1
64327;;Lecumberry;LECUMBERRY;64220;64;PYRENEES ATLANTIQUES;1
64328;;Ledeuix;LEDEUIX;64400;64;PYRENEES ATLANTIQUES;1
64329;;Lée;LEE;64320;64;PYRENEES ATLANTIQUES;1
64330;;Lées-Athas;LEES-ATHAS;64490;64;PYRENEES ATLANTIQUES;1
64331;;Lembeye;LEMBEYE;64350;64;PYRENEES ATLANTIQUES;1
64332;;Lème;LEME;64450;64;PYRENEES ATLANTIQUES;1
64334;;Léren;LEREN;64270;64;PYRENEES ATLANTIQUES;1
64335;;Lescar;LESCAR;64230;64;PYRENEES ATLANTIQUES;1
64336;;Lescun;LESCUN;64490;64;PYRENEES ATLANTIQUES;1
64337;;Lespielle;LESPIELLE;64350;64;PYRENEES ATLANTIQUES;1
64338;;Lespourcy;LESPOURCY;64160;64;PYRENEES ATLANTIQUES;1
64339;;Lestelle-Bétharram;LESTELLE-BETHARRAM;64800;64;PYRENEES ATLANTIQUES;1
64340;;Lichans-Sunhar;LICHANS-SUNHAR;64470;64;PYRENEES ATLANTIQUES;1
64341;;Lichos;LICHOS;64130;64;PYRENEES ATLANTIQUES;1
64342;;Licq-Athérey;LICQ-ATHEREY;64560;64;PYRENEES ATLANTIQUES;1
64343;;Limendous;LIMENDOUS;64420;64;PYRENEES ATLANTIQUES;1
64344;;Livron;LIVRON;64530;64;PYRENEES ATLANTIQUES;1
64345;;Lohitzun-Oyhercq;LOHITZUN-OYHERCQ;64120;64;PYRENEES ATLANTIQUES;1
64346;;Lombia;LOMBIA;64160;64;PYRENEES ATLANTIQUES;1
64347;;Lonçon;LONCON;64410;64;PYRENEES ATLANTIQUES;1
64348;;Lons;LONS;64140;64;PYRENEES ATLANTIQUES;1
64349;;Loubieng;LOUBIENG;64300;64;PYRENEES ATLANTIQUES;1
64350;;Louhossoa;LOUHOSSOA;64250;64;PYRENEES ATLANTIQUES;1
64351;;Lourdios-Ichère;LOURDIOS-ICHERE;64570;64;PYRENEES ATLANTIQUES;1
64352;;Lourenties;LOURENTIES;64420;64;PYRENEES ATLANTIQUES;1
64353;;Louvie-Juzon;LOUVIE-JUZON;64260;64;PYRENEES ATLANTIQUES;1
64354;;Louvie-Soubiron;LOUVIE-SOUBIRON;64440;64;PYRENEES ATLANTIQUES;1
64355;;Louvigny;LOUVIGNY;64410;64;PYRENEES ATLANTIQUES;1
64356;;Luc-Armau;LUC-ARMAU;64350;64;PYRENEES ATLANTIQUES;1
64357;;Lucarré;LUCARRE;64350;64;PYRENEES ATLANTIQUES;1
64358;;Lucgarier;LUCGARIER;64420;64;PYRENEES ATLANTIQUES;1
64359;;Lucq-de-Béarn;LUCQ-DE-BEARN;64360;64;PYRENEES ATLANTIQUES;1
64360;;Lurbe-Saint-Christau;LURBE-SAINT-CHRISTAU;64660;64;PYRENEES ATLANTIQUES;1
64361;;Lussagnet-Lusson;LUSSAGNET-LUSSON;64160;64;PYRENEES ATLANTIQUES;1
64362;;Luxe-Sumberraute;LUXE-SUMBERRAUTE;64120;64;PYRENEES ATLANTIQUES;1
64363;;Lys;LYS;64260;64;PYRENEES ATLANTIQUES;1
64364;;Macaye;MACAYE;64240;64;PYRENEES ATLANTIQUES;1
64365;;Malaussanne;MALAUSSANNE;64410;64;PYRENEES ATLANTIQUES;1
64366;;Mascaraàs-Haron;MASCARAAS-HARON;64330;64;PYRENEES ATLANTIQUES;1
64367;;Maslacq;MASLACQ;64300;64;PYRENEES ATLANTIQUES;1
64368;;Masparraute;MASPARRAUTE;64120;64;PYRENEES ATLANTIQUES;1
64369;;Maspie-Lalonquère-Juillacq;MASPIE-LALONQUERE-JUILLACQ;64350;64;PYRENEES ATLANTIQUES;1
64370;;Maucor;MAUCOR;64160;64;PYRENEES ATLANTIQUES;1
64371;;Mauléon-Licharre;MAULEON-LICHARRE;64130;64;PYRENEES ATLANTIQUES;1
64372;;Maure;MAURE;64460;64;PYRENEES ATLANTIQUES;1
64373;;Mazères-Lezons;MAZERES-LEZONS;64110;64;PYRENEES ATLANTIQUES;1
64374;;Mazerolles;MAZEROLLES;64230;64;PYRENEES ATLANTIQUES;1
64375;;Méharin;MEHARIN;64120;64;PYRENEES ATLANTIQUES;1
64376;;Meillon;MEILLON;64510;64;PYRENEES ATLANTIQUES;1
64377;;Mendionde;MENDIONDE;64240;64;PYRENEES ATLANTIQUES;1
64378;;Menditte;MENDITTE;64130;64;PYRENEES ATLANTIQUES;1
64379;;Mendive;MENDIVE;64220;64;PYRENEES ATLANTIQUES;1
64380;;Méracq;MERACQ;64410;64;PYRENEES ATLANTIQUES;1
64381;;Méritein;MERITEIN;64190;64;PYRENEES ATLANTIQUES;1
64382;;Mesplède;MESPLEDE;64370;64;PYRENEES ATLANTIQUES;1
64383;;Mialos;MIALOS;64410;64;PYRENEES ATLANTIQUES;1
64385;;Miossens-Lanusse;MIOSSENS-LANUSSE;64450;64;PYRENEES ATLANTIQUES;1
64386;;Mirepeix;MIREPEIX;64800;64;PYRENEES ATLANTIQUES;1
64387;;Momas;MOMAS;64230;64;PYRENEES ATLANTIQUES;1
64388;;Momy;MOMY;64350;64;PYRENEES ATLANTIQUES;1
64389;;Monassut-Audiracq;MONASSUT-AUDIRACQ;64160;64;PYRENEES ATLANTIQUES;1
64390;;Moncaup;MONCAUP;64350;64;PYRENEES ATLANTIQUES;1
64391;;Moncayolle-Larrory-Mendibieu;MONCAYOLLE-LARRORY-MENDIBIEU;64130;64;PYRENEES ATLANTIQUES;1
64392;;Moncla;MONCLA;64330;64;PYRENEES ATLANTIQUES;1
64393;;Monein;MONEIN;64360;64;PYRENEES ATLANTIQUES;1
64394;;Monpezat;MONPEZAT;64350;64;PYRENEES ATLANTIQUES;1
64395;;Monségur;MONSEGUR;64460;64;PYRENEES ATLANTIQUES;1
64396;;Mont;MONT;64300;64;PYRENEES ATLANTIQUES;1
64397;;Montagut;MONTAGUT;64410;64;PYRENEES ATLANTIQUES;1
64398;;Montaner;MONTANER;64460;64;PYRENEES ATLANTIQUES;1
64399;;Montardon;MONTARDON;64121;64;PYRENEES ATLANTIQUES;1
64400;;Montaut;MONTAUT;64800;64;PYRENEES ATLANTIQUES;1
64401;;Mont-Disse;MONT-DISSE;64330;64;PYRENEES ATLANTIQUES;1
64403;;Montfort;MONTFORT;64190;64;PYRENEES ATLANTIQUES;1
64404;;Montory;MONTORY;64470;64;PYRENEES ATLANTIQUES;1
64405;;Morlaàs;MORLAAS;64160;64;PYRENEES ATLANTIQUES;1
64406;;Morlanne;MORLANNE;64370;64;PYRENEES ATLANTIQUES;1
64407;;Mouguerre;MOUGUERRE;64990;64;PYRENEES ATLANTIQUES;1
64408;;Mouhous;MOUHOUS;64330;64;PYRENEES ATLANTIQUES;1
64409;;Moumour;MOUMOUR;64400;64;PYRENEES ATLANTIQUES;1
64410;;Mourenx;MOURENX;64150;64;PYRENEES ATLANTIQUES;1
64411;;Musculdy;MUSCULDY;64130;64;PYRENEES ATLANTIQUES;1
64412;;Nabas;NABAS;64190;64;PYRENEES ATLANTIQUES;1
64413;;Narcastet;NARCASTET;64510;64;PYRENEES ATLANTIQUES;1
64414;;Narp;NARP;64190;64;PYRENEES ATLANTIQUES;1
64415;;Navailles-Angos;NAVAILLES-ANGOS;64450;64;PYRENEES ATLANTIQUES;1
64416;;Navarrenx;NAVARRENX;64190;64;PYRENEES ATLANTIQUES;1
64417;;Nay;NAY;64800;64;PYRENEES ATLANTIQUES;1
64418;;Noguères;NOGUERES;64150;64;PYRENEES ATLANTIQUES;1
64419;;Nousty;NOUSTY;64420;64;PYRENEES ATLANTIQUES;1
64420;;Ogenne-Camptort;OGENNE-CAMPTORT;64190;64;PYRENEES ATLANTIQUES;1
64421;;Ogeu-les-Bains;OGEU-LES-BAINS;64680;64;PYRENEES ATLANTIQUES;1
64422;;Oloron-Sainte-Marie;OLORON-SAINTE-MARIE;64400;64;PYRENEES ATLANTIQUES;1
64423;;Oraàs;ORAAS;64390;64;PYRENEES ATLANTIQUES;1
64424;;Ordiarp;ORDIARP;64130;64;PYRENEES ATLANTIQUES;1
64425;;Orègue;OREGUE;64120;64;PYRENEES ATLANTIQUES;1
64426;;Orin;ORIN;64400;64;PYRENEES ATLANTIQUES;1
64427;;Orion;ORION;64390;64;PYRENEES ATLANTIQUES;1
64428;;Orriule;ORRIULE;64390;64;PYRENEES ATLANTIQUES;1
64429;;Orsanco;ORSANCO;64120;64;PYRENEES ATLANTIQUES;1
64430;;Orthez;ORTHEZ;64300;64;PYRENEES ATLANTIQUES;1
64431;;Os-Marsillon;OS-MARSILLON;64150;64;PYRENEES ATLANTIQUES;1
64432;;Ossas-Suhare;OSSAS-SUHARE;64470;64;PYRENEES ATLANTIQUES;1
64433;;Osse-en-Aspe;OSSE-EN-ASPE;64490;64;PYRENEES ATLANTIQUES;1
64434;;Ossenx;OSSENX;64190;64;PYRENEES ATLANTIQUES;1
64435;;Osserain-Rivareyte;OSSERAIN-RIVAREYTE;64390;64;PYRENEES ATLANTIQUES;1
64436;;Ossès;OSSES;64780;64;PYRENEES ATLANTIQUES;1
64437;;Ostabat-Asme;OSTABAT-ASME;64120;64;PYRENEES ATLANTIQUES;1
64438;;Ouillon;OUILLON;64160;64;PYRENEES ATLANTIQUES;1
64439;;Ousse;OUSSE;64320;64;PYRENEES ATLANTIQUES;1
64440;;Ozenx-Montestrucq;OZENX-MONTESTRUCQ;64300;64;PYRENEES ATLANTIQUES;1
64441;;Pagolle;PAGOLLE;64120;64;PYRENEES ATLANTIQUES;1
64442;;Parbayse;PARBAYSE;64360;64;PYRENEES ATLANTIQUES;1
64443;;Pardies;PARDIES;64150;64;PYRENEES ATLANTIQUES;1
64444;;Pardies-Piétat;PARDIES-PIETAT;64800;64;PYRENEES ATLANTIQUES;1
64445;;Pau;PAU;64000;64;PYRENEES ATLANTIQUES;1
64446;;Peyrelongue-Abos;PEYRELONGUE-ABOS;64350;64;PYRENEES ATLANTIQUES;1
64447;;Piets-Plasence-Moustrou;PIETS-PLASENCE-MOUSTROU;64410;64;PYRENEES ATLANTIQUES;1
64448;;Poey-de-Lescar;POEY-DE-LESCAR;64230;64;PYRENEES ATLANTIQUES;1
64449;;Poey-d'Oloron;POEY-D'OLORON;64400;64;PYRENEES ATLANTIQUES;1
64450;;Pomps;POMPS;64370;64;PYRENEES ATLANTIQUES;1
64451;;Ponson-Debat-Pouts;PONSON-DEBAT-POUTS;64460;64;PYRENEES ATLANTIQUES;1
64452;;Ponson-Dessus;PONSON-DESSUS;64460;64;PYRENEES ATLANTIQUES;1
64453;;Pontacq;PONTACQ;64530;64;PYRENEES ATLANTIQUES;1
64454;;Pontiacq-Viellepinte;PONTIACQ-VIELLEPINTE;64460;64;PYRENEES ATLANTIQUES;1
64455;;Portet;PORTET;64330;64;PYRENEES ATLANTIQUES;1
64456;;Pouliacq;POULIACQ;64410;64;PYRENEES ATLANTIQUES;1
64457;;Poursiugues-Boucoue;POURSIUGUES-BOUCOUE;64410;64;PYRENEES ATLANTIQUES;1
64458;;Préchacq-Josbaig;PRECHACQ-JOSBAIG;64190;64;PYRENEES ATLANTIQUES;1
64459;;Préchacq-Navarrenx;PRECHACQ-NAVARRENX;64190;64;PYRENEES ATLANTIQUES;1
64460;;Précilhon;PRECILHON;64400;64;PYRENEES ATLANTIQUES;1
64461;;Puyoô;PUYOO;64270;64;PYRENEES ATLANTIQUES;1
64462;;Ramous;RAMOUS;64270;64;PYRENEES ATLANTIQUES;1
64463;;Rébénacq;REBENACQ;64260;64;PYRENEES ATLANTIQUES;1
64464;;Ribarrouy;RIBARROUY;64330;64;PYRENEES ATLANTIQUES;1
64465;;Riupeyrous;RIUPEYROUS;64160;64;PYRENEES ATLANTIQUES;1
64466;;Rivehaute;RIVEHAUTE;64190;64;PYRENEES ATLANTIQUES;1
64467;;Rontignon;RONTIGNON;64110;64;PYRENEES ATLANTIQUES;1
64468;;Roquiague;ROQUIAGUE;64130;64;PYRENEES ATLANTIQUES;1
64469;;Saint-Abit;SAINT-ABIT;64800;64;PYRENEES ATLANTIQUES;1
64470;;Saint-Armou;SAINT-ARMOU;64160;64;PYRENEES ATLANTIQUES;1
64471;;Saint-Boès;SAINT-BOES;64300;64;PYRENEES ATLANTIQUES;1
64472;;Saint-Castin;SAINT-CASTIN;64160;64;PYRENEES ATLANTIQUES;1
64473;;Sainte-Colome;SAINTE-COLOME;64260;64;PYRENEES ATLANTIQUES;1
64474;;Saint-Dos;SAINT-DOS;64270;64;PYRENEES ATLANTIQUES;1
64475;;Sainte-Engrâce;SAINTE-ENGRACE;64560;64;PYRENEES ATLANTIQUES;1
64476;;Saint-Esteben;SAINT-ESTEBEN;64640;64;PYRENEES ATLANTIQUES;1
64477;;Saint-Étienne-de-Baïgorry;SAINT-ETIENNE-DE-BAIGORRY;64430;64;PYRENEES ATLANTIQUES;1
64478;;Saint-Faust;SAINT-FAUST;64110;64;PYRENEES ATLANTIQUES;1
64479;;Saint-Girons-en-Béarn;SAINT-GIRONS-EN-BEARN;64300;64;PYRENEES ATLANTIQUES;1
64480;;Saint-Gladie-Arrive-Munein;SAINT-GLADIE-ARRIVE-MUNEIN;64390;64;PYRENEES ATLANTIQUES;1
64481;;Saint-Goin;SAINT-GOIN;64400;64;PYRENEES ATLANTIQUES;1
64482;;Saint-Jammes;SAINT-JAMMES;64160;64;PYRENEES ATLANTIQUES;1
64483;;Saint-Jean-de-Luz;SAINT-JEAN-DE-LUZ;64500;64;PYRENEES ATLANTIQUES;1
64484;;Saint-Jean-le-Vieux;SAINT-JEAN-LE-VIEUX;64220;64;PYRENEES ATLANTIQUES;1
64485;;Saint-Jean-Pied-de-Port;SAINT-JEAN-PIED-DE-PORT;64220;64;PYRENEES ATLANTIQUES;1
64486;;Saint-Jean-Poudge;SAINT-JEAN-POUDGE;64330;64;PYRENEES ATLANTIQUES;1
64487;;Saint-Just-Ibarre;SAINT-JUST-IBARRE;64120;64;PYRENEES ATLANTIQUES;1
64488;;Saint-Laurent-Bretagne;SAINT-LAURENT-BRETAGNE;64160;64;PYRENEES ATLANTIQUES;1
64489;;Saint-Martin-d'Arberoue;SAINT-MARTIN-D'ARBEROUE;64640;64;PYRENEES ATLANTIQUES;1
64490;;Saint-Martin-d'Arrossa;SAINT-MARTIN-D'ARROSSA;64780;64;PYRENEES ATLANTIQUES;1
64491;;Saint-Médard;SAINT-MEDARD;64370;64;PYRENEES ATLANTIQUES;1
64492;;Saint-Michel;SAINT-MICHEL;64220;64;PYRENEES ATLANTIQUES;1
64493;;Saint-Palais;SAINT-PALAIS;64120;64;PYRENEES ATLANTIQUES;1
64494;;Saint-Pé-de-Léren;SAINT-PE-DE-LEREN;64270;64;PYRENEES ATLANTIQUES;1
64495;;Saint-Pée-sur-Nivelle;SAINT-PEE-SUR-NIVELLE;64310;64;PYRENEES ATLANTIQUES;1
64496;;Saint-Pierre-d'Irube;SAINT-PIERRE-D'IRUBE;64990;64;PYRENEES ATLANTIQUES;1
64498;;Saint-Vincent;SAINT-VINCENT;64800;64;PYRENEES ATLANTIQUES;1
64499;;Salies-de-Béarn;SALIES-DE-BEARN;64270;64;PYRENEES ATLANTIQUES;1
64500;;Salles-Mongiscard;SALLES-MONGISCARD;64300;64;PYRENEES ATLANTIQUES;1
64501;;Sallespisse;SALLESPISSE;64300;64;PYRENEES ATLANTIQUES;1
64502;;Sames;SAMES;64520;64;PYRENEES ATLANTIQUES;1
64503;;Samsons-Lion;SAMSONS-LION;64350;64;PYRENEES ATLANTIQUES;1
64504;;Sare;SARE;64310;64;PYRENEES ATLANTIQUES;1
64505;;Sarpourenx;SARPOURENX;64300;64;PYRENEES ATLANTIQUES;1
64506;;Sarrance;SARRANCE;64490;64;PYRENEES ATLANTIQUES;1
64507;;Saubole;SAUBOLE;64420;64;PYRENEES ATLANTIQUES;1
64508;;Saucède;SAUCEDE;64400;64;PYRENEES ATLANTIQUES;1
64509;;Sauguis-Saint-Étienne;SAUGUIS-SAINT-ETIENNE;64470;64;PYRENEES ATLANTIQUES;1
64510;;Sault-de-Navailles;SAULT-DE-NAVAILLES;64300;64;PYRENEES ATLANTIQUES;1
64511;;Sauvagnon;SAUVAGNON;64230;64;PYRENEES ATLANTIQUES;1
64512;;Sauvelade;SAUVELADE;64150;64;PYRENEES ATLANTIQUES;1
64513;;Sauveterre-de-Béarn;SAUVETERRE-DE-BEARN;64390;64;PYRENEES ATLANTIQUES;1
64514;;Séby;SEBY;64410;64;PYRENEES ATLANTIQUES;1
64515;;Sedze-Maubecq;SEDZE-MAUBECQ;64160;64;PYRENEES ATLANTIQUES;1
64516;;Sedzère;SEDZERE;64160;64;PYRENEES ATLANTIQUES;1
64517;;Séméacq-Blachon;SEMEACQ-BLACHON;64350;64;PYRENEES ATLANTIQUES;1
64518;;Sendets;SENDETS;64320;64;PYRENEES ATLANTIQUES;1
64519;;Serres-Castet;SERRES-CASTET;64121;64;PYRENEES ATLANTIQUES;1
64520;;Serres-Morlaàs;SERRES-MORLAAS;64160;64;PYRENEES ATLANTIQUES;1
64521;;Serres-Sainte-Marie;SERRES-SAINTE-MARIE;64170;64;PYRENEES ATLANTIQUES;1
64522;;Sévignacq-Meyracq;SEVIGNACQ-MEYRACQ;64260;64;PYRENEES ATLANTIQUES;1
64523;;Sévignacq;SEVIGNACQ;64160;64;PYRENEES ATLANTIQUES;1
64524;;Simacourbe;SIMACOURBE;64350;64;PYRENEES ATLANTIQUES;1
64525;;Siros;SIROS;64230;64;PYRENEES ATLANTIQUES;1
64526;;Soumoulou;SOUMOULOU;64420;64;PYRENEES ATLANTIQUES;1
64527;;Souraïde;SOURAIDE;64250;64;PYRENEES ATLANTIQUES;1
64528;;Suhescun;SUHESCUN;64780;64;PYRENEES ATLANTIQUES;1
64529;;Sus;SUS;64190;64;PYRENEES ATLANTIQUES;1
64530;;Susmiou;SUSMIOU;64190;64;PYRENEES ATLANTIQUES;1
64531;;Tabaille-Usquain;TABAILLE-USQUAIN;64190;64;PYRENEES ATLANTIQUES;1
64532;;Tadousse-Ussau;TADOUSSE-USSAU;64330;64;PYRENEES ATLANTIQUES;1
64533;;Tardets-Sorholus;TARDETS-SORHOLUS;64470;64;PYRENEES ATLANTIQUES;1
64534;;Taron-Sadirac-Viellenave;TARON-SADIRAC-VIELLENAVE;64330;64;PYRENEES ATLANTIQUES;1
64535;;Tarsacq;TARSACQ;64360;64;PYRENEES ATLANTIQUES;1
64536;;Thèze;THEZE;64450;64;PYRENEES ATLANTIQUES;1
64537;;Trois-Villes;TROIS-VILLES;64470;64;PYRENEES ATLANTIQUES;1
64538;;Uhart-Cize;UHART-CIZE;64220;64;PYRENEES ATLANTIQUES;1
64539;;Uhart-Mixe;UHART-MIXE;64120;64;PYRENEES ATLANTIQUES;1
64540;;Urcuit;URCUIT;64990;64;PYRENEES ATLANTIQUES;1
64541;;Urdès;URDES;64370;64;PYRENEES ATLANTIQUES;1
64542;;Urdos;URDOS;64490;64;PYRENEES ATLANTIQUES;1
64543;;Urepel;UREPEL;64430;64;PYRENEES ATLANTIQUES;1
64544;;Urost;UROST;64160;64;PYRENEES ATLANTIQUES;1
64545;;Urrugne;URRUGNE;64122;64;PYRENEES ATLANTIQUES;1
64546;;Urt;URT;64240;64;PYRENEES ATLANTIQUES;1
64547;;Ustaritz;USTARITZ;64480;64;PYRENEES ATLANTIQUES;1
64548;;Uzan;UZAN;64370;64;PYRENEES ATLANTIQUES;1
64549;;Uzein;UZEIN;64230;64;PYRENEES ATLANTIQUES;1
64550;;Uzos;UZOS;64110;64;PYRENEES ATLANTIQUES;1
64551;;Verdets;VERDETS;64400;64;PYRENEES ATLANTIQUES;1
64552;;Vialer;VIALER;64330;64;PYRENEES ATLANTIQUES;1
64554;;Viellenave-d'Arthez;VIELLENAVE-D'ARTHEZ;64170;64;PYRENEES ATLANTIQUES;1
64555;;Viellenave-de-Navarrenx;VIELLENAVE-DE-NAVARRENX;64190;64;PYRENEES ATLANTIQUES;1
64556;;Vielleségure;VIELLESEGURE;64150;64;PYRENEES ATLANTIQUES;1
64557;;Vignes;VIGNES;64410;64;PYRENEES ATLANTIQUES;1
64558;;Villefranque;VILLEFRANQUE;64990;64;PYRENEES ATLANTIQUES;1
64559;;Viodos-Abense-de-Bas;VIODOS-ABENSE-DE-BAS;64130;64;PYRENEES ATLANTIQUES;1
64560;;Viven;VIVEN;64450;64;PYRENEES ATLANTIQUES;1
65001;;Adast;ADAST;65260;65;HAUTES PYRENEES;1
65002;;Adé;ADE;65100;65;HAUTES PYRENEES;1
65003;;Adervielle-Pouchergues;ADERVIELLE-POUCHERGUES;65240;65;HAUTES PYRENEES;1
65004;;Agos-Vidalos;AGOS-VIDALOS;65400;65;HAUTES PYRENEES;1
65005;;Allier;ALLIER;65360;65;HAUTES PYRENEES;1
65006;;Ancizan;ANCIZAN;65440;65;HAUTES PYRENEES;1
65007;;Andrest;ANDREST;65390;65;HAUTES PYRENEES;1
65009;;Anères;ANERES;65150;65;HAUTES PYRENEES;1
65010;;Angos;ANGOS;65690;65;HAUTES PYRENEES;1
65011;Les;Angles;ANGLES;65100;65;HAUTES PYRENEES;1
65012;;Anla;ANLA;65370;65;HAUTES PYRENEES;1
65013;;Ansost;ANSOST;65140;65;HAUTES PYRENEES;1
65014;;Antichan;ANTICHAN;65370;65;HAUTES PYRENEES;1
65015;;Antin;ANTIN;65220;65;HAUTES PYRENEES;1
65016;;Antist;ANTIST;65200;65;HAUTES PYRENEES;1
65017;;Aragnouet;ARAGNOUET;65170;65;HAUTES PYRENEES;1
65018;;Arbéost;ARBEOST;65560;65;HAUTES PYRENEES;1
65019;;Arcizac-Adour;ARCIZAC-ADOUR;65360;65;HAUTES PYRENEES;1
65020;;Arcizac-ez-Angles;ARCIZAC-EZ-ANGLES;65100;65;HAUTES PYRENEES;1
65021;;Arcizans-Avant;ARCIZANS-AVANT;65400;65;HAUTES PYRENEES;1
65022;;Arcizans-Dessus;ARCIZANS-DESSUS;65400;65;HAUTES PYRENEES;1
65023;;Ardengost;ARDENGOST;65240;65;HAUTES PYRENEES;1
65024;;Argelès-Bagnères;ARGELES-BAGNERES;65200;65;HAUTES PYRENEES;1
65025;;Argelès-Gazost;ARGELES-GAZOST;65400;65;HAUTES PYRENEES;1
65026;;Aries-Espénan;ARIES-ESPENAN;65230;65;HAUTES PYRENEES;1
65027;;Armenteule;ARMENTEULE;65510;65;HAUTES PYRENEES;1
65028;;Arné;ARNE;65670;65;HAUTES PYRENEES;1
65029;;Arras-en-Lavedan;ARRAS-EN-LAVEDAN;65400;65;HAUTES PYRENEES;1
65031;;Arreau;ARREAU;65240;65;HAUTES PYRENEES;1
65032;;Arrens-Marsous;ARRENS-MARSOUS;65400;65;HAUTES PYRENEES;1
65033;;Arrodets-ez-Angles;ARRODETS-EZ-ANGLES;65100;65;HAUTES PYRENEES;1
65034;;Arrodets;ARRODETS;65130;65;HAUTES PYRENEES;1
65035;;Artagnan;ARTAGNAN;65500;65;HAUTES PYRENEES;1
65036;;Artalens-Souin;ARTALENS-SOUIN;65400;65;HAUTES PYRENEES;1
65037;;Artiguemy;ARTIGUEMY;65130;65;HAUTES PYRENEES;1
65038;;Artigues;ARTIGUES;65100;65;HAUTES PYRENEES;1
65039;;Aspin-Aure;ASPIN-AURE;65240;65;HAUTES PYRENEES;1
65040;;Aspin-en-Lavedan;ASPIN-EN-LAVEDAN;65100;65;HAUTES PYRENEES;1
65041;;Asque;ASQUE;65130;65;HAUTES PYRENEES;1
65042;;Asté;ASTE;65200;65;HAUTES PYRENEES;1
65043;;Astugue;ASTUGUE;65200;65;HAUTES PYRENEES;1
65044;;Aubarède;AUBAREDE;65350;65;HAUTES PYRENEES;1
65045;;Aucun;AUCUN;65400;65;HAUTES PYRENEES;1
65046;;Aulon;AULON;65440;65;HAUTES PYRENEES;1
65047;;Aureilhan;AUREILHAN;65800;65;HAUTES PYRENEES;1
65048;;Aurensan;AURENSAN;65390;65;HAUTES PYRENEES;1
65049;;Auriébat;AURIEBAT;65700;65;HAUTES PYRENEES;1
65050;;Avajan;AVAJAN;65240;65;HAUTES PYRENEES;1
65051;;Aventignan;AVENTIGNAN;65660;65;HAUTES PYRENEES;1
65052;;Averan;AVERAN;65380;65;HAUTES PYRENEES;1
65053;;Aveux;AVEUX;65370;65;HAUTES PYRENEES;1
65054;;Avezac-Prat-Lahitte;AVEZAC-PRAT-LAHITTE;65130;65;HAUTES PYRENEES;1
65055;;Ayros-Arbouix;AYROS-ARBOUIX;65400;65;HAUTES PYRENEES;1
65056;;Ayzac-Ost;AYZAC-OST;65400;65;HAUTES PYRENEES;1
65057;;Azereix;AZEREIX;65380;65;HAUTES PYRENEES;1
65058;;Azet;AZET;65170;65;HAUTES PYRENEES;1
65059;;Bagnères-de-Bigorre;BAGNERES-DE-BIGORRE;65200;65;HAUTES PYRENEES;1
65060;;Banios;BANIOS;65200;65;HAUTES PYRENEES;1
65061;;Barbachen;BARBACHEN;65140;65;HAUTES PYRENEES;1
65062;;Barbazan-Debat;BARBAZAN-DEBAT;65690;65;HAUTES PYRENEES;1
65063;;Barbazan-Dessus;BARBAZAN-DESSUS;65360;65;HAUTES PYRENEES;1
65064;;Bareilles;BAREILLES;65240;65;HAUTES PYRENEES;1
65065;;Barlest;BARLEST;65100;65;HAUTES PYRENEES;1
65066;;Barrancoueu;BARRANCOUEU;65240;65;HAUTES PYRENEES;1
65067;;Barry;BARRY;65380;65;HAUTES PYRENEES;1
65068;;Barthe;BARTHE;65230;65;HAUTES PYRENEES;1
65069;La;Barthe-de-Neste;BARTHE-DE-NESTE;65250;65;HAUTES PYRENEES;1
65070;;Bartrès;BARTRES;65100;65;HAUTES PYRENEES;1
65071;;Batsère;BATSERE;65130;65;HAUTES PYRENEES;1
65072;;Bazet;BAZET;65460;65;HAUTES PYRENEES;1
65073;;Bazillac;BAZILLAC;65140;65;HAUTES PYRENEES;1
65074;;Bazordan;BAZORDAN;65670;65;HAUTES PYRENEES;1
65075;;Bazus-Aure;BAZUS-AURE;65170;65;HAUTES PYRENEES;1
65076;;Bazus-Neste;BAZUS-NESTE;65250;65;HAUTES PYRENEES;1
65077;;Beaucens;BEAUCENS;65400;65;HAUTES PYRENEES;1
65078;;Beaudéan;BEAUDEAN;65710;65;HAUTES PYRENEES;1
65079;;Bégole;BEGOLE;65190;65;HAUTES PYRENEES;1
65080;;Bénac;BENAC;65380;65;HAUTES PYRENEES;1
65081;;Benqué;BENQUE;65130;65;HAUTES PYRENEES;1
65082;;Berbérust-Lias;BERBERUST-LIAS;65100;65;HAUTES PYRENEES;1
65083;;Bernac-Debat;BERNAC-DEBAT;65360;65;HAUTES PYRENEES;1
65084;;Bernac-Dessus;BERNAC-DESSUS;65360;65;HAUTES PYRENEES;1
65085;;Bernadets-Debat;BERNADETS-DEBAT;65220;65;HAUTES PYRENEES;1
65086;;Bernadets-Dessus;BERNADETS-DESSUS;65190;65;HAUTES PYRENEES;1
65087;;Bertren;BERTREN;65370;65;HAUTES PYRENEES;1
65088;;Betbèze;BETBEZE;65230;65;HAUTES PYRENEES;1
65089;;Betpouey;BETPOUEY;65120;65;HAUTES PYRENEES;1
65090;;Betpouy;BETPOUY;65230;65;HAUTES PYRENEES;1
65091;;Bettes;BETTES;65130;65;HAUTES PYRENEES;1
65092;;Beyrède-Jumet;BEYREDE-JUMET;65410;65;HAUTES PYRENEES;1
65093;;Bize;BIZE;65150;65;HAUTES PYRENEES;1
65094;;Bizous;BIZOUS;65150;65;HAUTES PYRENEES;1
65095;;Bonnefont;BONNEFONT;65220;65;HAUTES PYRENEES;1
65096;;Bonnemazon;BONNEMAZON;65130;65;HAUTES PYRENEES;1
65097;;Bonrepos;BONREPOS;65330;65;HAUTES PYRENEES;1
65098;;Boô-Silhen;BOO-SILHEN;65400;65;HAUTES PYRENEES;1
65099;;Bordères-Louron;BORDERES-LOURON;65590;65;HAUTES PYRENEES;1
65100;;Bordères-sur-l'Échez;BORDERES-SUR-L'ECHEZ;65320;65;HAUTES PYRENEES;1
65101;;Bordes;BORDES;65190;65;HAUTES PYRENEES;1
65102;;Bouilh-Devant;BOUILH-DEVANT;65140;65;HAUTES PYRENEES;1
65103;;Bouilh-Péreuilh;BOUILH-PEREUILH;65350;65;HAUTES PYRENEES;1
65104;;Boulin;BOULIN;65350;65;HAUTES PYRENEES;1
65105;;Bourg-de-Bigorre;BOURG-DE-BIGORRE;65130;65;HAUTES PYRENEES;1
65106;;Bourisp;BOURISP;65170;65;HAUTES PYRENEES;1
65107;;Bourréac;BOURREAC;65100;65;HAUTES PYRENEES;1
65108;;Bours;BOURS;65460;65;HAUTES PYRENEES;1
65109;;Bramevaque;BRAMEVAQUE;65370;65;HAUTES PYRENEES;1
65110;;Bugard;BUGARD;65220;65;HAUTES PYRENEES;1
65111;;Bulan;BULAN;65130;65;HAUTES PYRENEES;1
65112;;Bun;BUN;65400;65;HAUTES PYRENEES;1
65113;;Burg;BURG;65190;65;HAUTES PYRENEES;1
65114;;Buzon;BUZON;65140;65;HAUTES PYRENEES;1
65115;;Cabanac;CABANAC;65350;65;HAUTES PYRENEES;1
65116;;Cadéac;CADEAC;65240;65;HAUTES PYRENEES;1
65117;;Cadeilhan-Trachère;CADEILHAN-TRACHERE;65170;65;HAUTES PYRENEES;1
65118;;Caharet;CAHARET;65190;65;HAUTES PYRENEES;1
65119;;Caixon;CAIXON;65500;65;HAUTES PYRENEES;1
65120;;Calavanté;CALAVANTE;65190;65;HAUTES PYRENEES;1
65121;;Camalès;CAMALES;65500;65;HAUTES PYRENEES;1
65122;;Camous;CAMOUS;65410;65;HAUTES PYRENEES;1
65123;;Campan;CAMPAN;65710;65;HAUTES PYRENEES;1
65124;;Camparan;CAMPARAN;65170;65;HAUTES PYRENEES;1
65125;;Campistrous;CAMPISTROUS;65300;65;HAUTES PYRENEES;1
65126;;Campuzan;CAMPUZAN;65230;65;HAUTES PYRENEES;1
65127;;Capvern;CAPVERN;65130;65;HAUTES PYRENEES;1
65128;;Castelbajac;CASTELBAJAC;65330;65;HAUTES PYRENEES;1
65129;;Castelnau-Magnoac;CASTELNAU-MAGNOAC;65230;65;HAUTES PYRENEES;1
65130;;Castelnau-Rivière-Basse;CASTELNAU-RIVIERE-BASSE;65700;65;HAUTES PYRENEES;1
65131;;Castelvieilh;CASTELVIEILH;65350;65;HAUTES PYRENEES;1
65132;;Castéra-Lanusse;CASTERA-LANUSSE;65190;65;HAUTES PYRENEES;1
65133;;Castéra-Lou;CASTERA-LOU;65350;65;HAUTES PYRENEES;1
65134;;Casterets;CASTERETS;65230;65;HAUTES PYRENEES;1
65135;;Castillon;CASTILLON;65130;65;HAUTES PYRENEES;1
65136;;Caubous;CAUBOUS;65230;65;HAUTES PYRENEES;1
65137;;Caussade-Rivière;CAUSSADE-RIVIERE;65700;65;HAUTES PYRENEES;1
65138;;Cauterets;CAUTERETS;65110;65;HAUTES PYRENEES;1
65139;;Cazarilh;CAZARILH;65370;65;HAUTES PYRENEES;1
65140;;Cazaux-Debat;CAZAUX-DEBAT;65590;65;HAUTES PYRENEES;1
65141;;Cazaux-Fréchet-Anéran-Camors;CAZAUX-FRECHET-ANERAN-CAMORS;65510;65;HAUTES PYRENEES;1
65142;;Chelle-Debat;CHELLE-DEBAT;65350;65;HAUTES PYRENEES;1
65143;;Chelle-Spou;CHELLE-SPOU;65130;65;HAUTES PYRENEES;1
65144;;Cheust;CHEUST;65100;65;HAUTES PYRENEES;1
65145;;Chèze;CHEZE;65120;65;HAUTES PYRENEES;1
65146;;Chis;CHIS;65800;65;HAUTES PYRENEES;1
65147;;Cieutat;CIEUTAT;65200;65;HAUTES PYRENEES;1
65148;;Cizos;CIZOS;65230;65;HAUTES PYRENEES;1
65149;;Clarac;CLARAC;65190;65;HAUTES PYRENEES;1
65150;;Clarens;CLARENS;65300;65;HAUTES PYRENEES;1
65151;;Collongues;COLLONGUES;65350;65;HAUTES PYRENEES;1
65153;;Coussan;COUSSAN;65350;65;HAUTES PYRENEES;1
65154;;Créchets;CRECHETS;65370;65;HAUTES PYRENEES;1
65155;;Devèze;DEVEZE;65230;65;HAUTES PYRENEES;1
65156;;Dours;DOURS;65350;65;HAUTES PYRENEES;1
65157;;Ens;ENS;65170;65;HAUTES PYRENEES;1
65158;;Esbareich;ESBAREICH;65370;65;HAUTES PYRENEES;1
65159;;Escala;ESCALA;65250;65;HAUTES PYRENEES;1
65160;;Escaunets;ESCAUNETS;65500;65;HAUTES PYRENEES;1
65161;;Escondeaux;ESCONDEAUX;65140;65;HAUTES PYRENEES;1
65162;;Esconnets;ESCONNETS;65130;65;HAUTES PYRENEES;1
65163;;Escots;ESCOTS;65130;65;HAUTES PYRENEES;1
65164;;Escoubès-Pouts;ESCOUBES-POUTS;65100;65;HAUTES PYRENEES;1
65165;;Esparros;ESPARROS;65130;65;HAUTES PYRENEES;1
65166;;Espèche;ESPECHE;65130;65;HAUTES PYRENEES;1
65167;;Espieilh;ESPIEILH;65130;65;HAUTES PYRENEES;1
65168;;Esquièze-Sère;ESQUIEZE-SERE;65120;65;HAUTES PYRENEES;1
65169;;Estaing;ESTAING;65400;65;HAUTES PYRENEES;1
65170;;Estampures;ESTAMPURES;65220;65;HAUTES PYRENEES;1
65171;;Estarvielle;ESTARVIELLE;65510;65;HAUTES PYRENEES;1
65172;;Estensan;ESTENSAN;65170;65;HAUTES PYRENEES;1
65173;;Esterre;ESTERRE;65120;65;HAUTES PYRENEES;1
65174;;Estirac;ESTIRAC;65700;65;HAUTES PYRENEES;1
65175;;Ferrère;FERRERE;65370;65;HAUTES PYRENEES;1
65176;;Ferrières;FERRIERES;65560;65;HAUTES PYRENEES;1
65177;;Fontrailles;FONTRAILLES;65220;65;HAUTES PYRENEES;1
65178;;Fréchède;FRECHEDE;65220;65;HAUTES PYRENEES;1
65179;;Fréchendets;FRECHENDETS;65130;65;HAUTES PYRENEES;1
65180;;Fréchet-Aure;FRECHET-AURE;65240;65;HAUTES PYRENEES;1
65181;;Fréchou-Fréchet;FRECHOU-FRECHET;65190;65;HAUTES PYRENEES;1
65182;;Gaillagos;GAILLAGOS;65400;65;HAUTES PYRENEES;1
65183;;Galan;GALAN;65330;65;HAUTES PYRENEES;1
65184;;Galez;GALEZ;65330;65;HAUTES PYRENEES;1
65185;;Gardères;GARDERES;65320;65;HAUTES PYRENEES;1
65186;;Gaudent;GAUDENT;65370;65;HAUTES PYRENEES;1
65187;;Gaussan;GAUSSAN;65670;65;HAUTES PYRENEES;1
65188;;Gavarnie;GAVARNIE;65120;65;HAUTES PYRENEES;1
65189;;Gayan;GAYAN;65320;65;HAUTES PYRENEES;1
65190;;Gazave;GAZAVE;65250;65;HAUTES PYRENEES;1
65191;;Gazost;GAZOST;65100;65;HAUTES PYRENEES;1
65192;;Gèdre;GEDRE;65120;65;HAUTES PYRENEES;1
65193;;Gembrie;GEMBRIE;65370;65;HAUTES PYRENEES;1
65194;;Générest;GENEREST;65150;65;HAUTES PYRENEES;1
65195;;Génos;GENOS;65510;65;HAUTES PYRENEES;1
65196;;Gensac;GENSAC;65140;65;HAUTES PYRENEES;1
65197;;Ger;GER;65100;65;HAUTES PYRENEES;1
65198;;Gerde;GERDE;65200;65;HAUTES PYRENEES;1
65199;;Germ;GERM;65510;65;HAUTES PYRENEES;1
65200;;Germs-sur-l'Oussouet;GERMS-SUR-L'OUSSOUET;65200;65;HAUTES PYRENEES;1
65201;;Geu;GEU;65100;65;HAUTES PYRENEES;1
65202;;Gez;GEZ;65400;65;HAUTES PYRENEES;1
65203;;Gez-ez-Angles;GEZ-EZ-ANGLES;65100;65;HAUTES PYRENEES;1
65204;;Gonez;GONEZ;65350;65;HAUTES PYRENEES;1
65205;;Gouaux;GOUAUX;65440;65;HAUTES PYRENEES;1
65206;;Goudon;GOUDON;65190;65;HAUTES PYRENEES;1
65207;;Gourgue;GOURGUE;65130;65;HAUTES PYRENEES;1
65208;;Grailhen;GRAILHEN;65170;65;HAUTES PYRENEES;1
65209;;Grézian;GREZIAN;65440;65;HAUTES PYRENEES;1
65210;;Grust;GRUST;65120;65;HAUTES PYRENEES;1
65211;;Guchan;GUCHAN;65170;65;HAUTES PYRENEES;1
65212;;Guchen;GUCHEN;65440;65;HAUTES PYRENEES;1
65213;;Guizerix;GUIZERIX;65230;65;HAUTES PYRENEES;1
65214;;Hachan;HACHAN;65230;65;HAUTES PYRENEES;1
65215;;Hagedet;HAGEDET;65700;65;HAUTES PYRENEES;1
65216;;Hauban;HAUBAN;65200;65;HAUTES PYRENEES;1
65217;;Hautaget;HAUTAGET;65150;65;HAUTES PYRENEES;1
65218;;Hèches;HECHES;65250;65;HAUTES PYRENEES;1
65219;;Hères;HERES;65700;65;HAUTES PYRENEES;1
65220;;Hibarette;HIBARETTE;65380;65;HAUTES PYRENEES;1
65221;;Hiis;HIIS;65200;65;HAUTES PYRENEES;1
65222;;Hitte;HITTE;65190;65;HAUTES PYRENEES;1
65223;;Horgues;HORGUES;65310;65;HAUTES PYRENEES;1
65224;;Houeydets;HOUEYDETS;65330;65;HAUTES PYRENEES;1
65225;;Hourc;HOURC;65350;65;HAUTES PYRENEES;1
65226;;Ibos;IBOS;65420;65;HAUTES PYRENEES;1
65228;;Ilhet;ILHET;65410;65;HAUTES PYRENEES;1
65229;;Ilheu;ILHEU;65370;65;HAUTES PYRENEES;1
65230;;Izaourt;IZAOURT;65370;65;HAUTES PYRENEES;1
65231;;Izaux;IZAUX;65250;65;HAUTES PYRENEES;1
65232;;Jacque;JACQUE;65350;65;HAUTES PYRENEES;1
65233;;Jarret;JARRET;65100;65;HAUTES PYRENEES;1
65234;;Jézeau;JEZEAU;65240;65;HAUTES PYRENEES;1
65235;;Juillan;JUILLAN;65290;65;HAUTES PYRENEES;1
65236;;Julos;JULOS;65100;65;HAUTES PYRENEES;1
65237;;Juncalas;JUNCALAS;65100;65;HAUTES PYRENEES;1
65238;;Labassère;LABASSERE;65200;65;HAUTES PYRENEES;1
65239;;Labastide;LABASTIDE;65130;65;HAUTES PYRENEES;1
65240;;Labatut-Rivière;LABATUT-RIVIERE;65700;65;HAUTES PYRENEES;1
65241;;Laborde;LABORDE;65130;65;HAUTES PYRENEES;1
65242;;Lacassagne;LACASSAGNE;65140;65;HAUTES PYRENEES;1
65243;;Lafitole;LAFITOLE;65700;65;HAUTES PYRENEES;1
65244;;Lagarde;LAGARDE;65320;65;HAUTES PYRENEES;1
65245;;Lagrange;LAGRANGE;65300;65;HAUTES PYRENEES;1
65247;;Arrayou-Lahitte;ARRAYOU-LAHITTE;65100;65;HAUTES PYRENEES;1
65248;;Lahitte-Toupière;LAHITTE-TOUPIERE;65700;65;HAUTES PYRENEES;1
65249;;Lalanne;LALANNE;65230;65;HAUTES PYRENEES;1
65250;;Lalanne-Trie;LALANNE-TRIE;65220;65;HAUTES PYRENEES;1
65251;;Laloubère;LALOUBERE;65310;65;HAUTES PYRENEES;1
65252;;Lamarque-Pontacq;LAMARQUE-PONTACQ;65380;65;HAUTES PYRENEES;1
65253;;Lamarque-Rustaing;LAMARQUE-RUSTAING;65220;65;HAUTES PYRENEES;1
65254;;Laméac;LAMEAC;65140;65;HAUTES PYRENEES;1
65255;;Lançon;LANCON;65240;65;HAUTES PYRENEES;1
65256;;Lanespède;LANESPEDE;65190;65;HAUTES PYRENEES;1
65257;;Lanne;LANNE;65380;65;HAUTES PYRENEES;1
65258;;Lannemezan;LANNEMEZAN;65300;65;HAUTES PYRENEES;1
65259;;Lansac;LANSAC;65350;65;HAUTES PYRENEES;1
65260;;Lapeyre;LAPEYRE;65220;65;HAUTES PYRENEES;1
65261;;Laran;LARAN;65670;65;HAUTES PYRENEES;1
65262;;Larreule;LARREULE;65700;65;HAUTES PYRENEES;1
65263;;Larroque;LARROQUE;65230;65;HAUTES PYRENEES;1
65264;;Lascazères;LASCAZERES;65700;65;HAUTES PYRENEES;1
65265;;Laslades;LASLADES;65350;65;HAUTES PYRENEES;1
65266;;Lassales;LASSALES;65670;65;HAUTES PYRENEES;1
65267;;Lau-Balagnas;LAU-BALAGNAS;65400;65;HAUTES PYRENEES;1
65268;;Layrisse;LAYRISSE;65380;65;HAUTES PYRENEES;1
65269;;Lescurry;LESCURRY;65140;65;HAUTES PYRENEES;1
65270;;Lespouey;LESPOUEY;65190;65;HAUTES PYRENEES;1
65271;;Lézignan;LEZIGNAN;65100;65;HAUTES PYRENEES;1
65272;;Lhez;LHEZ;65190;65;HAUTES PYRENEES;1
65273;;Liac;LIAC;65140;65;HAUTES PYRENEES;1
65274;;Libaros;LIBAROS;65330;65;HAUTES PYRENEES;1
65275;;Lies;LIES;65200;65;HAUTES PYRENEES;1
65276;;Lizos;LIZOS;65350;65;HAUTES PYRENEES;1
65277;;Lombrès;LOMBRES;65150;65;HAUTES PYRENEES;1
65278;;Lomné;LOMNE;65130;65;HAUTES PYRENEES;1
65279;;Lortet;LORTET;65250;65;HAUTES PYRENEES;1
65280;;Loubajac;LOUBAJAC;65100;65;HAUTES PYRENEES;1
65281;;Loucrup;LOUCRUP;65200;65;HAUTES PYRENEES;1
65282;;Loudenvielle;LOUDENVIELLE;65510;65;HAUTES PYRENEES;1
65283;;Loudervielle;LOUDERVIELLE;65510;65;HAUTES PYRENEES;1
65284;;Louey;LOUEY;65290;65;HAUTES PYRENEES;1
65285;;Louit;LOUIT;65350;65;HAUTES PYRENEES;1
65286;;Lourdes;LOURDES;65100;65;HAUTES PYRENEES;1
65287;;Loures-Barousse;LOURES-BAROUSSE;65370;65;HAUTES PYRENEES;1
65288;;Lubret-Saint-Luc;LUBRET-SAINT-LUC;65220;65;HAUTES PYRENEES;1
65289;;Luby-Betmont;LUBY-BETMONT;65220;65;HAUTES PYRENEES;1
65290;;Luc;LUC;65190;65;HAUTES PYRENEES;1
65291;;Lugagnan;LUGAGNAN;65100;65;HAUTES PYRENEES;1
65292;;Luquet;LUQUET;65320;65;HAUTES PYRENEES;1
65293;;Lustar;LUSTAR;65220;65;HAUTES PYRENEES;1
65294;;Lutilhous;LUTILHOUS;65300;65;HAUTES PYRENEES;1
65295;;Luz-Saint-Sauveur;LUZ-SAINT-SAUVEUR;65120;65;HAUTES PYRENEES;1
65296;;Madiran;MADIRAN;65700;65;HAUTES PYRENEES;1
65297;;Mansan;MANSAN;65140;65;HAUTES PYRENEES;1
65298;;Marquerie;MARQUERIE;65350;65;HAUTES PYRENEES;1
65299;;Marsac;MARSAC;65500;65;HAUTES PYRENEES;1
65300;;Marsas;MARSAS;65200;65;HAUTES PYRENEES;1
65301;;Marseillan;MARSEILLAN;65350;65;HAUTES PYRENEES;1
65303;;Mascaras;MASCARAS;65190;65;HAUTES PYRENEES;1
65304;;Maubourguet;MAUBOURGUET;65700;65;HAUTES PYRENEES;1
65305;;Mauléon-Barousse;MAULEON-BAROUSSE;65370;65;HAUTES PYRENEES;1
65306;;Mauvezin;MAUVEZIN;65130;65;HAUTES PYRENEES;1
65307;;Mazères-de-Neste;MAZERES-DE-NESTE;65660;65;HAUTES PYRENEES;1
65308;;Mazerolles;MAZEROLLES;65220;65;HAUTES PYRENEES;1
65309;;Mazouau;MAZOUAU;65250;65;HAUTES PYRENEES;1
65310;;Mérilheu;MERILHEU;65200;65;HAUTES PYRENEES;1
65311;;Mingot;MINGOT;65140;65;HAUTES PYRENEES;1
65312;;Molère;MOLERE;65130;65;HAUTES PYRENEES;1
65313;;Momères;MOMERES;65360;65;HAUTES PYRENEES;1
65314;;Monfaucon;MONFAUCON;65140;65;HAUTES PYRENEES;1
65315;;Monléon-Magnoac;MONLEON-MAGNOAC;65670;65;HAUTES PYRENEES;1
65316;;Monlong;MONLONG;65670;65;HAUTES PYRENEES;1
65317;;Mont;MONT;65510;65;HAUTES PYRENEES;1
65318;;Montastruc;MONTASTRUC;65330;65;HAUTES PYRENEES;1
65319;;Montégut;MONTEGUT;65150;65;HAUTES PYRENEES;1
65320;;Montgaillard;MONTGAILLARD;65200;65;HAUTES PYRENEES;1
65321;;Montignac;MONTIGNAC;65690;65;HAUTES PYRENEES;1
65322;;Montoussé;MONTOUSSE;65250;65;HAUTES PYRENEES;1
65323;;Montsérié;MONTSERIE;65150;65;HAUTES PYRENEES;1
65324;;Moulédous;MOULEDOUS;65190;65;HAUTES PYRENEES;1
65325;;Moumoulous;MOUMOULOUS;65140;65;HAUTES PYRENEES;1
65326;;Mun;MUN;65350;65;HAUTES PYRENEES;1
65327;;Nestier;NESTIER;65150;65;HAUTES PYRENEES;1
65328;;Neuilh;NEUILH;65200;65;HAUTES PYRENEES;1
65329;;Nistos;NISTOS;65150;65;HAUTES PYRENEES;1
65330;;Nouilhan;NOUILHAN;65500;65;HAUTES PYRENEES;1
65331;;Odos;ODOS;65310;65;HAUTES PYRENEES;1
65332;;Oléac-Debat;OLEAC-DEBAT;65350;65;HAUTES PYRENEES;1
65333;;Oléac-Dessus;OLEAC-DESSUS;65190;65;HAUTES PYRENEES;1
65334;;Omex;OMEX;65100;65;HAUTES PYRENEES;1
65335;;Ordizan;ORDIZAN;65200;65;HAUTES PYRENEES;1
65336;;Organ;ORGAN;65230;65;HAUTES PYRENEES;1
65337;;Orieux;ORIEUX;65190;65;HAUTES PYRENEES;1
65338;;Orignac;ORIGNAC;65200;65;HAUTES PYRENEES;1
65339;;Orincles;ORINCLES;65380;65;HAUTES PYRENEES;1
65340;;Orleix;ORLEIX;65800;65;HAUTES PYRENEES;1
65341;;Oroix;OROIX;65320;65;HAUTES PYRENEES;1
65342;;Osmets;OSMETS;65350;65;HAUTES PYRENEES;1
65343;;Ossen;OSSEN;65100;65;HAUTES PYRENEES;1
65344;;Ossun;OSSUN;65380;65;HAUTES PYRENEES;1
65345;;Ossun-ez-Angles;OSSUN-EZ-ANGLES;65100;65;HAUTES PYRENEES;1
65346;;Oueilloux;OUEILLOUX;65190;65;HAUTES PYRENEES;1
65347;;Ourde;OURDE;65370;65;HAUTES PYRENEES;1
65348;;Ourdis-Cotdoussan;OURDIS-COTDOUSSAN;65100;65;HAUTES PYRENEES;1
65349;;Ourdon;OURDON;65100;65;HAUTES PYRENEES;1
65350;;Oursbelille;OURSBELILLE;65490;65;HAUTES PYRENEES;1
65351;;Ousté;OUSTE;65100;65;HAUTES PYRENEES;1
65352;;Ouzous;OUZOUS;65400;65;HAUTES PYRENEES;1
65353;;Ozon;OZON;65190;65;HAUTES PYRENEES;1
65354;;Pailhac;PAILHAC;65240;65;HAUTES PYRENEES;1
65355;;Paréac;PAREAC;65100;65;HAUTES PYRENEES;1
65356;;Péré;PERE;65130;65;HAUTES PYRENEES;1
65357;;Peyraube;PEYRAUBE;65190;65;HAUTES PYRENEES;1
65358;;Peyret-Saint-André;PEYRET-SAINT-ANDRE;65230;65;HAUTES PYRENEES;1
65359;;Peyriguère;PEYRIGUERE;65350;65;HAUTES PYRENEES;1
65360;;Peyrouse;PEYROUSE;65270;65;HAUTES PYRENEES;1
65361;;Peyrun;PEYRUN;65140;65;HAUTES PYRENEES;1
65362;;Pierrefitte-Nestalas;PIERREFITTE-NESTALAS;65260;65;HAUTES PYRENEES;1
65363;;Pinas;PINAS;65300;65;HAUTES PYRENEES;1
65364;;Pintac;PINTAC;65320;65;HAUTES PYRENEES;1
65366;;Poueyferré;POUEYFERRE;65100;65;HAUTES PYRENEES;1
65367;;Poumarous;POUMAROUS;65190;65;HAUTES PYRENEES;1
65368;;Pouy;POUY;65230;65;HAUTES PYRENEES;1
65369;;Pouyastruc;POUYASTRUC;65350;65;HAUTES PYRENEES;1
65370;;Pouzac;POUZAC;65200;65;HAUTES PYRENEES;1
65371;;Préchac;PRECHAC;65400;65;HAUTES PYRENEES;1
65372;;Pujo;PUJO;65500;65;HAUTES PYRENEES;1
65373;;Puntous;PUNTOUS;65230;65;HAUTES PYRENEES;1
65374;;Puydarrieux;PUYDARRIEUX;65220;65;HAUTES PYRENEES;1
65375;;Rabastens-de-Bigorre;RABASTENS-DE-BIGORRE;65140;65;HAUTES PYRENEES;1
65376;;Recurt;RECURT;65330;65;HAUTES PYRENEES;1
65377;;Réjaumont;REJAUMONT;65300;65;HAUTES PYRENEES;1
65378;;Ricaud;RICAUD;65190;65;HAUTES PYRENEES;1
65379;;Ris;RIS;65590;65;HAUTES PYRENEES;1
65380;;Sabalos;SABALOS;65350;65;HAUTES PYRENEES;1
65381;;Sabarros;SABARROS;65330;65;HAUTES PYRENEES;1
65382;;Sacoué;SACOUE;65370;65;HAUTES PYRENEES;1
65383;;Sadournin;SADOURNIN;65220;65;HAUTES PYRENEES;1
65384;;Sailhan;SAILHAN;65170;65;HAUTES PYRENEES;1
65385;;Saint-Arroman;SAINT-ARROMAN;65250;65;HAUTES PYRENEES;1
65386;;Saint-Créac;SAINT-CREAC;65100;65;HAUTES PYRENEES;1
65387;;Saint-Lanne;SAINT-LANNE;65700;65;HAUTES PYRENEES;1
65388;;Saint-Lary-Soulan;SAINT-LARY-SOULAN;65170;65;HAUTES PYRENEES;1
65389;;Saint-Laurent-de-Neste;SAINT-LAURENT-DE-NESTE;65150;65;HAUTES PYRENEES;1
65390;;Saint-Lézer;SAINT-LEZER;65500;65;HAUTES PYRENEES;1
65391;;Sainte-Marie;SAINTE-MARIE;65370;65;HAUTES PYRENEES;1
65392;;Saint-Martin;SAINT-MARTIN;65360;65;HAUTES PYRENEES;1
65393;;Saint-Pastous;SAINT-PASTOUS;65400;65;HAUTES PYRENEES;1
65394;;Saint-Paul;SAINT-PAUL;65150;65;HAUTES PYRENEES;1
65395;;Saint-Pé-de-Bigorre;SAINT-PE-DE-BIGORRE;65270;65;HAUTES PYRENEES;1
65396;;Saint-Savin;SAINT-SAVIN;65400;65;HAUTES PYRENEES;1
65397;;Saint-Sever-de-Rustan;SAINT-SEVER-DE-RUSTAN;65140;65;HAUTES PYRENEES;1
65398;;Saléchan;SALECHAN;65370;65;HAUTES PYRENEES;1
65399;;Saligos;SALIGOS;65120;65;HAUTES PYRENEES;1
65400;;Salles;SALLES;65400;65;HAUTES PYRENEES;1
65401;;Salles-Adour;SALLES-ADOUR;65360;65;HAUTES PYRENEES;1
65402;;Samuran;SAMURAN;65370;65;HAUTES PYRENEES;1
65403;;Sanous;SANOUS;65500;65;HAUTES PYRENEES;1
65404;;Sariac-Magnoac;SARIAC-MAGNOAC;65230;65;HAUTES PYRENEES;1
65405;;Sarlabous;SARLABOUS;65130;65;HAUTES PYRENEES;1
65406;;Sarniguet;SARNIGUET;65390;65;HAUTES PYRENEES;1
65407;;Sarp;SARP;65370;65;HAUTES PYRENEES;1
65408;;Sarrancolin;SARRANCOLIN;65410;65;HAUTES PYRENEES;1
65409;;Sarriac-Bigorre;SARRIAC-BIGORRE;65140;65;HAUTES PYRENEES;1
65410;;Sarrouilles;SARROUILLES;65600;65;HAUTES PYRENEES;1
65411;;Sassis;SASSIS;65120;65;HAUTES PYRENEES;1
65412;;Sauveterre;SAUVETERRE;65700;65;HAUTES PYRENEES;1
65413;;Sazos;SAZOS;65120;65;HAUTES PYRENEES;1
65414;;Ségalas;SEGALAS;65140;65;HAUTES PYRENEES;1
65415;;Ségus;SEGUS;65100;65;HAUTES PYRENEES;1
65416;;Seich;SEICH;65150;65;HAUTES PYRENEES;1
65417;;Séméac;SEMEAC;65600;65;HAUTES PYRENEES;1
65418;;Sénac;SENAC;65140;65;HAUTES PYRENEES;1
65419;;Sentous;SENTOUS;65330;65;HAUTES PYRENEES;1
65420;;Sère-en-Lavedan;SERE-EN-LAVEDAN;65400;65;HAUTES PYRENEES;1
65421;;Sère-Lanso;SERE-LANSO;65100;65;HAUTES PYRENEES;1
65422;;Séron;SERON;65320;65;HAUTES PYRENEES;1
65423;;Sère-Rustaing;SERE-RUSTAING;65220;65;HAUTES PYRENEES;1
65424;;Sers;SERS;65120;65;HAUTES PYRENEES;1
65425;;Siarrouy;SIARROUY;65500;65;HAUTES PYRENEES;1
65426;;Sinzos;SINZOS;65190;65;HAUTES PYRENEES;1
65427;;Siradan;SIRADAN;65370;65;HAUTES PYRENEES;1
65428;;Sireix;SIREIX;65400;65;HAUTES PYRENEES;1
65429;;Sombrun;SOMBRUN;65700;65;HAUTES PYRENEES;1
65430;;Soréac;SOREAC;65350;65;HAUTES PYRENEES;1
65431;;Sost;SOST;65370;65;HAUTES PYRENEES;1
65432;;Soublecause;SOUBLECAUSE;65700;65;HAUTES PYRENEES;1
65433;;Soues;SOUES;65430;65;HAUTES PYRENEES;1
65435;;Soulom;SOULOM;65260;65;HAUTES PYRENEES;1
65436;;Souyeaux;SOUYEAUX;65350;65;HAUTES PYRENEES;1
65437;;Tajan;TAJAN;65300;65;HAUTES PYRENEES;1
65438;;Talazac;TALAZAC;65500;65;HAUTES PYRENEES;1
65439;;Tarasteix;TARASTEIX;65320;65;HAUTES PYRENEES;1
65440;;Tarbes;TARBES;65000;65;HAUTES PYRENEES;1
65441;;Thèbe;THEBE;65370;65;HAUTES PYRENEES;1
65442;;Thermes-Magnoac;THERMES-MAGNOAC;65230;65;HAUTES PYRENEES;1
65443;;Thuy;THUY;65350;65;HAUTES PYRENEES;1
65444;;Tibiran-Jaunac;TIBIRAN-JAUNAC;65660;65;HAUTES PYRENEES;1
65445;;Tilhouse;TILHOUSE;65130;65;HAUTES PYRENEES;1
65446;;Tostat;TOSTAT;65140;65;HAUTES PYRENEES;1
65447;;Tournay;TOURNAY;65190;65;HAUTES PYRENEES;1
65448;;Tournous-Darré;TOURNOUS-DARRE;65220;65;HAUTES PYRENEES;1
65449;;Tournous-Devant;TOURNOUS-DEVANT;65330;65;HAUTES PYRENEES;1
65450;;Tramezaïgues;TRAMEZAIGUES;65170;65;HAUTES PYRENEES;1
65451;;Trébons;TREBONS;65200;65;HAUTES PYRENEES;1
65452;;Trie-sur-Baïse;TRIE-SUR-BAISE;65220;65;HAUTES PYRENEES;1
65453;;Troubat;TROUBAT;65370;65;HAUTES PYRENEES;1
65454;;Trouley-Labarthe;TROULEY-LABARTHE;65140;65;HAUTES PYRENEES;1
65455;;Tuzaguet;TUZAGUET;65150;65;HAUTES PYRENEES;1
65456;;Uglas;UGLAS;65300;65;HAUTES PYRENEES;1
65457;;Ugnouas;UGNOUAS;65140;65;HAUTES PYRENEES;1
65458;;Uz;UZ;65400;65;HAUTES PYRENEES;1
65459;;Uzer;UZER;65200;65;HAUTES PYRENEES;1
65460;;Vic-en-Bigorre;VIC-EN-BIGORRE;65500;65;HAUTES PYRENEES;1
65461;;Vidou;VIDOU;65220;65;HAUTES PYRENEES;1
65462;;Vidouze;VIDOUZE;65700;65;HAUTES PYRENEES;1
65463;;Viella;VIELLA;65120;65;HAUTES PYRENEES;1
65464;;Vielle-Adour;VIELLE-ADOUR;65360;65;HAUTES PYRENEES;1
65465;;Vielle-Aure;VIELLE-AURE;65170;65;HAUTES PYRENEES;1
65466;;Vielle-Louron;VIELLE-LOURON;65240;65;HAUTES PYRENEES;1
65467;;Vier-Bordes;VIER-BORDES;65400;65;HAUTES PYRENEES;1
65468;;Vieuzos;VIEUZOS;65230;65;HAUTES PYRENEES;1
65469;;Viey;VIEY;65120;65;HAUTES PYRENEES;1
65470;;Viger;VIGER;65100;65;HAUTES PYRENEES;1
65471;;Vignec;VIGNEC;65170;65;HAUTES PYRENEES;1
65472;;Villefranque;VILLEFRANQUE;65700;65;HAUTES PYRENEES;1
65473;;Villelongue;VILLELONGUE;65260;65;HAUTES PYRENEES;1
65474;;Villembits;VILLEMBITS;65220;65;HAUTES PYRENEES;1
65475;;Villemur;VILLEMUR;65230;65;HAUTES PYRENEES;1
65476;;Villenave-près-Béarn;VILLENAVE-PRES-BEARN;65500;65;HAUTES PYRENEES;1
65477;;Villenave-près-Marsac;VILLENAVE-PRES-MARSAC;65500;65;HAUTES PYRENEES;1
65478;;Viscos;VISCOS;65120;65;HAUTES PYRENEES;1
65479;;Visker;VISKER;65200;65;HAUTES PYRENEES;1
65480;;Vizos;VIZOS;65120;65;HAUTES PYRENEES;1
65481;;Barèges;BAREGES;65120;65;HAUTES PYRENEES;1
65482;;Cantaous;CANTAOUS;65150;65;HAUTES PYRENEES;1
66001;L';Albère;ALBERE;66480;66;PYRENEES ORIENTALES;1
66002;;Alénya;ALENYA;66200;66;PYRENEES ORIENTALES;1
66003;;Amélie-les-Bains-Palalda;AMELIE-LES-BAINS-PALALDA;66110;66;PYRENEES ORIENTALES;1
66004;Les;Angles;ANGLES;66210;66;PYRENEES ORIENTALES;1
66005;;Angoustrine-Villeneuve-des-Escaldes;ANGOUSTRINE-VILLENEUVE-DES-ESCALDES;66760;66;PYRENEES ORIENTALES;1
66006;;Ansignan;ANSIGNAN;66220;66;PYRENEES ORIENTALES;1
66007;;Arboussols;ARBOUSSOLS;66320;66;PYRENEES ORIENTALES;1
66008;;Argelès-sur-Mer;ARGELES-SUR-MER;66700;66;PYRENEES ORIENTALES;1
66009;;Arles-sur-Tech;ARLES-SUR-TECH;66150;66;PYRENEES ORIENTALES;1
66010;;Ayguatébia-Talau;AYGUATEBIA-TALAU;66360;66;PYRENEES ORIENTALES;1
66011;;Bages;BAGES;66670;66;PYRENEES ORIENTALES;1
66012;;Baho;BAHO;66540;66;PYRENEES ORIENTALES;1
66013;;Baillestavy;BAILLESTAVY;66320;66;PYRENEES ORIENTALES;1
66014;;Baixas;BAIXAS;66390;66;PYRENEES ORIENTALES;1
66015;;Banyuls-dels-Aspres;BANYULS-DELS-ASPRES;66300;66;PYRENEES ORIENTALES;1
66016;;Banyuls-sur-Mer;BANYULS-SUR-MER;66650;66;PYRENEES ORIENTALES;1
66017;Le;Barcarès;BARCARES;66420;66;PYRENEES ORIENTALES;1
66018;La;Bastide;BASTIDE;66110;66;PYRENEES ORIENTALES;1
66019;;Bélesta;BELESTA;66720;66;PYRENEES ORIENTALES;1
66020;;Bolquère;BOLQUERE;66210;66;PYRENEES ORIENTALES;1
66021;;Bompas;BOMPAS;66430;66;PYRENEES ORIENTALES;1
66022;;Boule-d'Amont;BOULE-D'AMONT;66130;66;PYRENEES ORIENTALES;1
66023;;Bouleternère;BOULETERNERE;66130;66;PYRENEES ORIENTALES;1
66024;Le;Boulou;BOULOU;66160;66;PYRENEES ORIENTALES;1
66025;;Bourg-Madame;BOURG-MADAME;66760;66;PYRENEES ORIENTALES;1
66026;;Brouilla;BROUILLA;66620;66;PYRENEES ORIENTALES;1
66027;La;Cabanasse;CABANASSE;66210;66;PYRENEES ORIENTALES;1
66028;;Cabestany;CABESTANY;66330;66;PYRENEES ORIENTALES;1
66029;;Caixas;CAIXAS;66300;66;PYRENEES ORIENTALES;1
66030;;Calce;CALCE;66600;66;PYRENEES ORIENTALES;1
66032;;Calmeilles;CALMEILLES;66400;66;PYRENEES ORIENTALES;1
66033;;Camélas;CAMELAS;66300;66;PYRENEES ORIENTALES;1
66034;;Campôme;CAMPOME;66500;66;PYRENEES ORIENTALES;1
66035;;Campoussy;CAMPOUSSY;66730;66;PYRENEES ORIENTALES;1
66036;;Canaveilles;CANAVEILLES;66360;66;PYRENEES ORIENTALES;1
66037;;Canet-en-Roussillon;CANET-EN-ROUSSILLON;66140;66;PYRENEES ORIENTALES;1
66038;;Canohès;CANOHES;66680;66;PYRENEES ORIENTALES;1
66039;;Caramany;CARAMANY;66720;66;PYRENEES ORIENTALES;1
66040;;Casefabre;CASEFABRE;66130;66;PYRENEES ORIENTALES;1
66041;;Cases-de-Pène;CASES-DE-PENE;66600;66;PYRENEES ORIENTALES;1
66042;;Cassagnes;CASSAGNES;66720;66;PYRENEES ORIENTALES;1
66043;;Casteil;CASTEIL;66820;66;PYRENEES ORIENTALES;1
66044;;Castelnou;CASTELNOU;66300;66;PYRENEES ORIENTALES;1
66045;;Catllar;CATLLAR;66500;66;PYRENEES ORIENTALES;1
66046;;Caudiès-de-Fenouillèdes;CAUDIES-DE-FENOUILLEDES;66220;66;PYRENEES ORIENTALES;1
66047;;Caudiès-de-Conflent;CAUDIES-DE-CONFLENT;66360;66;PYRENEES ORIENTALES;1
66048;;Cerbère;CERBERE;66290;66;PYRENEES ORIENTALES;1
66049;;Céret;CERET;66400;66;PYRENEES ORIENTALES;1
66050;;Claira;CLAIRA;66530;66;PYRENEES ORIENTALES;1
66051;;Clara;CLARA;66500;66;PYRENEES ORIENTALES;1
66052;;Codalet;CODALET;66500;66;PYRENEES ORIENTALES;1
66053;;Collioure;COLLIOURE;66190;66;PYRENEES ORIENTALES;1
66054;;Conat;CONAT;66500;66;PYRENEES ORIENTALES;1
66055;;Corbère;CORBERE;66130;66;PYRENEES ORIENTALES;1
66056;;Corbère-les-Cabanes;CORBERE-LES-CABANES;66130;66;PYRENEES ORIENTALES;1
66057;;Corneilla-de-Conflent;CORNEILLA-DE-CONFLENT;66820;66;PYRENEES ORIENTALES;1
66058;;Corneilla-la-Rivière;CORNEILLA-LA-RIVIERE;66550;66;PYRENEES ORIENTALES;1
66059;;Corneilla-del-Vercol;CORNEILLA-DEL-VERCOL;66200;66;PYRENEES ORIENTALES;1
66060;;Corsavy;CORSAVY;66150;66;PYRENEES ORIENTALES;1
66061;;Coustouges;COUSTOUGES;66260;66;PYRENEES ORIENTALES;1
66062;;Dorres;DORRES;66760;66;PYRENEES ORIENTALES;1
66063;Les;Cluses;CLUSES;66480;66;PYRENEES ORIENTALES;1
66064;;Égat;EGAT;66120;66;PYRENEES ORIENTALES;1
66065;;Elne;ELNE;66200;66;PYRENEES ORIENTALES;1
66066;;Enveitg;ENVEITG;66760;66;PYRENEES ORIENTALES;1
66067;;Err;ERR;66800;66;PYRENEES ORIENTALES;1
66068;;Escaro;ESCARO;66360;66;PYRENEES ORIENTALES;1
66069;;Espira-de-l'Agly;ESPIRA-DE-L'AGLY;66600;66;PYRENEES ORIENTALES;1
66070;;Espira-de-Conflent;ESPIRA-DE-CONFLENT;66320;66;PYRENEES ORIENTALES;1
66071;;Estagel;ESTAGEL;66310;66;PYRENEES ORIENTALES;1
66072;;Estavar;ESTAVAR;66800;66;PYRENEES ORIENTALES;1
66073;;Estoher;ESTOHER;66320;66;PYRENEES ORIENTALES;1
66074;;Eus;EUS;66500;66;PYRENEES ORIENTALES;1
66075;;Eyne;EYNE;66800;66;PYRENEES ORIENTALES;1
66076;;Felluns;FELLUNS;66730;66;PYRENEES ORIENTALES;1
66077;;Fenouillet;FENOUILLET;66220;66;PYRENEES ORIENTALES;1
66078;;Fillols;FILLOLS;66820;66;PYRENEES ORIENTALES;1
66079;;Finestret;FINESTRET;66320;66;PYRENEES ORIENTALES;1
66080;;Fontpédrouse;FONTPEDROUSE;66360;66;PYRENEES ORIENTALES;1
66081;;Fontrabiouse;FONTRABIOUSE;66210;66;PYRENEES ORIENTALES;1
66082;;Formiguères;FORMIGUERES;66210;66;PYRENEES ORIENTALES;1
66083;;Fosse;FOSSE;66220;66;PYRENEES ORIENTALES;1
66084;;Fourques;FOURQUES;66300;66;PYRENEES ORIENTALES;1
66085;;Fuilla;FUILLA;66820;66;PYRENEES ORIENTALES;1
66086;;Glorianes;GLORIANES;66320;66;PYRENEES ORIENTALES;1
66088;;Ille-sur-Têt;ILLE-SUR-TET;66130;66;PYRENEES ORIENTALES;1
66089;;Joch;JOCH;66320;66;PYRENEES ORIENTALES;1
66090;;Jujols;JUJOLS;66360;66;PYRENEES ORIENTALES;1
66091;;Lamanère;LAMANERE;66230;66;PYRENEES ORIENTALES;1
66092;;Lansac;LANSAC;66720;66;PYRENEES ORIENTALES;1
66093;;Laroque-des-Albères;LAROQUE-DES-ALBERES;66740;66;PYRENEES ORIENTALES;1
66094;;Latour-Bas-Elne;LATOUR-BAS-ELNE;66200;66;PYRENEES ORIENTALES;1
66095;;Latour-de-Carol;LATOUR-DE-CAROL;66760;66;PYRENEES ORIENTALES;1
66096;;Latour-de-France;LATOUR-DE-FRANCE;66720;66;PYRENEES ORIENTALES;1
66097;;Lesquerde;LESQUERDE;66220;66;PYRENEES ORIENTALES;1
66098;La;Llagonne;LLAGONNE;66210;66;PYRENEES ORIENTALES;1
66099;;Llauro;LLAURO;66300;66;PYRENEES ORIENTALES;1
66100;;Llo;LLO;66800;66;PYRENEES ORIENTALES;1
66101;;Llupia;LLUPIA;66300;66;PYRENEES ORIENTALES;1
66102;;Mantet;MANTET;66360;66;PYRENEES ORIENTALES;1
66103;;Marquixanes;MARQUIXANES;66320;66;PYRENEES ORIENTALES;1
66104;Los;Masos;MASOS;66500;66;PYRENEES ORIENTALES;1
66105;;Matemale;MATEMALE;66210;66;PYRENEES ORIENTALES;1
66106;;Maureillas-las-Illas;MAUREILLAS-LAS-ILLAS;66480;66;PYRENEES ORIENTALES;1
66107;;Maury;MAURY;66460;66;PYRENEES ORIENTALES;1
66108;;Millas;MILLAS;66170;66;PYRENEES ORIENTALES;1
66109;;Molitg-les-Bains;MOLITG-LES-BAINS;66500;66;PYRENEES ORIENTALES;1
66111;;Montalba-le-Château;MONTALBA-LE-CHATEAU;66130;66;PYRENEES ORIENTALES;1
66112;;Montauriol;MONTAURIOL;66300;66;PYRENEES ORIENTALES;1
66113;;Montbolo;MONTBOLO;66110;66;PYRENEES ORIENTALES;1
66114;;Montescot;MONTESCOT;66200;66;PYRENEES ORIENTALES;1
66115;;Montesquieu-des-Albères;MONTESQUIEU-DES-ALBERES;66740;66;PYRENEES ORIENTALES;1
66116;;Montferrer;MONTFERRER;66150;66;PYRENEES ORIENTALES;1
66117;;Mont-Louis;MONT-LOUIS;66210;66;PYRENEES ORIENTALES;1
66118;;Montner;MONTNER;66720;66;PYRENEES ORIENTALES;1
66119;;Mosset;MOSSET;66500;66;PYRENEES ORIENTALES;1
66120;;Nahuja;NAHUJA;66340;66;PYRENEES ORIENTALES;1
66121;;Néfiach;NEFIACH;66170;66;PYRENEES ORIENTALES;1
66122;;Nohèdes;NOHEDES;66500;66;PYRENEES ORIENTALES;1
66123;;Nyer;NYER;66360;66;PYRENEES ORIENTALES;1
66124;;Font-Romeu-Odeillo-Via;FONT-ROMEU-ODEILLO-VIA;66120;66;PYRENEES ORIENTALES;1
66125;;Olette;OLETTE;66360;66;PYRENEES ORIENTALES;1
66126;;Oms;OMS;66400;66;PYRENEES ORIENTALES;1
66127;;Opoul-Périllos;OPOUL-PERILLOS;66600;66;PYRENEES ORIENTALES;1
66128;;Oreilla;OREILLA;66360;66;PYRENEES ORIENTALES;1
66129;;Ortaffa;ORTAFFA;66560;66;PYRENEES ORIENTALES;1
66130;;Osséja;OSSEJA;66340;66;PYRENEES ORIENTALES;1
66132;;Palau-de-Cerdagne;PALAU-DE-CERDAGNE;66340;66;PYRENEES ORIENTALES;1
66133;;Palau-del-Vidre;PALAU-DEL-VIDRE;66690;66;PYRENEES ORIENTALES;1
66134;;Passa;PASSA;66300;66;PYRENEES ORIENTALES;1
66136;;Perpignan;PERPIGNAN;66000;66;PYRENEES ORIENTALES;1
66137;Le;Perthus;PERTHUS;66480;66;PYRENEES ORIENTALES;1
66138;;Peyrestortes;PEYRESTORTES;66600;66;PYRENEES ORIENTALES;1
66139;;Pézilla-de-Conflent;PEZILLA-DE-CONFLENT;66730;66;PYRENEES ORIENTALES;1
66140;;Pézilla-la-Rivière;PEZILLA-LA-RIVIERE;66370;66;PYRENEES ORIENTALES;1
66141;;Pia;PIA;66380;66;PYRENEES ORIENTALES;1
66142;;Planès;PLANES;66210;66;PYRENEES ORIENTALES;1
66143;;Planèzes;PLANEZES;66720;66;PYRENEES ORIENTALES;1
66144;;Pollestres;POLLESTRES;66450;66;PYRENEES ORIENTALES;1
66145;;Ponteilla;PONTEILLA;66300;66;PYRENEES ORIENTALES;1
66146;;Porta;PORTA;66760;66;PYRENEES ORIENTALES;1
66147;;Porté-Puymorens;PORTE-PUYMORENS;66760;66;PYRENEES ORIENTALES;1
66148;;Port-Vendres;PORT-VENDRES;66660;66;PYRENEES ORIENTALES;1
66149;;Prades;PRADES;66500;66;PYRENEES ORIENTALES;1
66150;;Prats-de-Mollo-la-Preste;PRATS-DE-MOLLO-LA-PRESTE;66230;66;PYRENEES ORIENTALES;1
66151;;Prats-de-Sournia;PRATS-DE-SOURNIA;66730;66;PYRENEES ORIENTALES;1
66152;;Prugnanes;PRUGNANES;66220;66;PYRENEES ORIENTALES;1
66153;;Prunet-et-Belpuig;PRUNET-ET-BELPUIG;66130;66;PYRENEES ORIENTALES;1
66154;;Puyvalador;PUYVALADOR;66210;66;PYRENEES ORIENTALES;1
66155;;Py;PY;66360;66;PYRENEES ORIENTALES;1
66156;;Rabouillet;RABOUILLET;66730;66;PYRENEES ORIENTALES;1
66157;;Railleu;RAILLEU;66360;66;PYRENEES ORIENTALES;1
66158;;Rasiguères;RASIGUERES;66720;66;PYRENEES ORIENTALES;1
66159;;Réal;REAL;66210;66;PYRENEES ORIENTALES;1
66160;;Reynès;REYNES;66400;66;PYRENEES ORIENTALES;1
66161;;Ria-Sirach;RIA-SIRACH;66500;66;PYRENEES ORIENTALES;1
66162;;Rigarda;RIGARDA;66320;66;PYRENEES ORIENTALES;1
66164;;Rivesaltes;RIVESALTES;66600;66;PYRENEES ORIENTALES;1
66165;;Rodès;RODES;66320;66;PYRENEES ORIENTALES;1
66166;;Sahorre;SAHORRE;66360;66;PYRENEES ORIENTALES;1
66167;;Saillagouse;SAILLAGOUSE;66800;66;PYRENEES ORIENTALES;1
66168;;Saint-André;SAINT-ANDRE;66690;66;PYRENEES ORIENTALES;1
66169;;Saint-Arnac;SAINT-ARNAC;66220;66;PYRENEES ORIENTALES;1
66170;;Sainte-Colombe-de-la-Commanderie;SAINTE-COLOMBE-DE-LA-COMMANDERIE;66300;66;PYRENEES ORIENTALES;1
66171;;Saint-Cyprien;SAINT-CYPRIEN;66750;66;PYRENEES ORIENTALES;1
66172;;Saint-Estève;SAINT-ESTEVE;66240;66;PYRENEES ORIENTALES;1
66173;;Saint-Féliu-d'Amont;SAINT-FELIU-D'AMONT;66170;66;PYRENEES ORIENTALES;1
66174;;Saint-Féliu-d'Avall;SAINT-FELIU-D'AVALL;66170;66;PYRENEES ORIENTALES;1
66175;;Saint-Génis-des-Fontaines;SAINT-GENIS-DES-FONTAINES;66740;66;PYRENEES ORIENTALES;1
66176;;Saint-Hippolyte;SAINT-HIPPOLYTE;66510;66;PYRENEES ORIENTALES;1
66177;;Saint-Jean-Lasseille;SAINT-JEAN-LASSEILLE;66300;66;PYRENEES ORIENTALES;1
66178;;Saint-Jean-Pla-de-Corts;SAINT-JEAN-PLA-DE-CORTS;66400;66;PYRENEES ORIENTALES;1
66179;;Saint-Laurent-de-Cerdans;SAINT-LAURENT-DE-CERDANS;66260;66;PYRENEES ORIENTALES;1
66180;;Saint-Laurent-de-la-Salanque;SAINT-LAURENT-DE-LA-SALANQUE;66250;66;PYRENEES ORIENTALES;1
66181;;Sainte-Léocadie;SAINTE-LEOCADIE;66800;66;PYRENEES ORIENTALES;1
66182;;Sainte-Marie;SAINTE-MARIE;66470;66;PYRENEES ORIENTALES;1
66183;;Saint-Marsal;SAINT-MARSAL;66110;66;PYRENEES ORIENTALES;1
66184;;Saint-Martin;SAINT-MARTIN;66220;66;PYRENEES ORIENTALES;1
66185;;Saint-Michel-de-Llotes;SAINT-MICHEL-DE-LLOTES;66130;66;PYRENEES ORIENTALES;1
66186;;Saint-Nazaire;SAINT-NAZAIRE;66140;66;PYRENEES ORIENTALES;1
66187;;Saint-Paul-de-Fenouillet;SAINT-PAUL-DE-FENOUILLET;66220;66;PYRENEES ORIENTALES;1
66188;;Saint-Pierre-dels-Forcats;SAINT-PIERRE-DELS-FORCATS;66210;66;PYRENEES ORIENTALES;1
66189;;Saleilles;SALEILLES;66280;66;PYRENEES ORIENTALES;1
66190;;Salses-le-Château;SALSES-LE-CHATEAU;66600;66;PYRENEES ORIENTALES;1
66191;;Sansa;SANSA;66360;66;PYRENEES ORIENTALES;1
66192;;Sauto;SAUTO;66210;66;PYRENEES ORIENTALES;1
66193;;Serdinya;SERDINYA;66360;66;PYRENEES ORIENTALES;1
66194;;Serralongue;SERRALONGUE;66230;66;PYRENEES ORIENTALES;1
66195;Le;Soler;SOLER;66270;66;PYRENEES ORIENTALES;1
66196;;Sorède;SOREDE;66690;66;PYRENEES ORIENTALES;1
66197;;Souanyas;SOUANYAS;66360;66;PYRENEES ORIENTALES;1
66198;;Sournia;SOURNIA;66730;66;PYRENEES ORIENTALES;1
66199;;Taillet;TAILLET;66400;66;PYRENEES ORIENTALES;1
66201;;Tarerach;TARERACH;66320;66;PYRENEES ORIENTALES;1
66202;;Targassonne;TARGASSONNE;66120;66;PYRENEES ORIENTALES;1
66203;;Taulis;TAULIS;66110;66;PYRENEES ORIENTALES;1
66204;;Taurinya;TAURINYA;66500;66;PYRENEES ORIENTALES;1
66205;;Tautavel;TAUTAVEL;66720;66;PYRENEES ORIENTALES;1
66206;Le;Tech;TECH;66230;66;PYRENEES ORIENTALES;1
66207;;Terrats;TERRATS;66300;66;PYRENEES ORIENTALES;1
66208;;Théza;THEZA;66200;66;PYRENEES ORIENTALES;1
66209;;Thuès-Entre-Valls;THUES-ENTRE-VALLS;66360;66;PYRENEES ORIENTALES;1
66210;;Thuir;THUIR;66300;66;PYRENEES ORIENTALES;1
66211;;Tordères;TORDERES;66300;66;PYRENEES ORIENTALES;1
66212;;Torreilles;TORREILLES;66440;66;PYRENEES ORIENTALES;1
66213;;Toulouges;TOULOUGES;66350;66;PYRENEES ORIENTALES;1
66214;;Tresserre;TRESSERRE;66300;66;PYRENEES ORIENTALES;1
66215;;Trévillach;TREVILLACH;66130;66;PYRENEES ORIENTALES;1
66216;;Trilla;TRILLA;66220;66;PYRENEES ORIENTALES;1
66217;;Trouillas;TROUILLAS;66300;66;PYRENEES ORIENTALES;1
66218;;Ur;UR;66760;66;PYRENEES ORIENTALES;1
66219;;Urbanya;URBANYA;66500;66;PYRENEES ORIENTALES;1
66220;;Valcebollère;VALCEBOLLERE;66340;66;PYRENEES ORIENTALES;1
66221;;Valmanya;VALMANYA;66320;66;PYRENEES ORIENTALES;1
66222;;Vernet-les-Bains;VERNET-LES-BAINS;66820;66;PYRENEES ORIENTALES;1
66223;;Villefranche-de-Conflent;VILLEFRANCHE-DE-CONFLENT;66500;66;PYRENEES ORIENTALES;1
66224;;Villelongue-de-la-Salanque;VILLELONGUE-DE-LA-SALANQUE;66410;66;PYRENEES ORIENTALES;1
66225;;Villelongue-dels-Monts;VILLELONGUE-DELS-MONTS;66740;66;PYRENEES ORIENTALES;1
66226;;Villemolaque;VILLEMOLAQUE;66300;66;PYRENEES ORIENTALES;1
66227;;Villeneuve-de-la-Raho;VILLENEUVE-DE-LA-RAHO;66180;66;PYRENEES ORIENTALES;1
66228;;Villeneuve-la-Rivière;VILLENEUVE-LA-RIVIERE;66610;66;PYRENEES ORIENTALES;1
66230;;Vinça;VINCA;66320;66;PYRENEES ORIENTALES;1
66231;;Vingrau;VINGRAU;66600;66;PYRENEES ORIENTALES;1
66232;;Vira;VIRA;66220;66;PYRENEES ORIENTALES;1
66233;;Vivès;VIVES;66400;66;PYRENEES ORIENTALES;1
66234;Le;Vivier;VIVIER;66730;66;PYRENEES ORIENTALES;1
67001;;Achenheim;ACHENHEIM;67204;67;BAS RHIN;1
67002;;Adamswiller;ADAMSWILLER;67320;67;BAS RHIN;1
67003;;Albé;ALBE;67220;67;BAS RHIN;1
67004;;Allenwiller;ALLENWILLER;67310;67;BAS RHIN;1
67005;;Alteckendorf;ALTECKENDORF;67270;67;BAS RHIN;1
67006;;Altenheim;ALTENHEIM;67490;67;BAS RHIN;1
67008;;Altorf;ALTORF;67120;67;BAS RHIN;1
67009;;Altwiller;ALTWILLER;67260;67;BAS RHIN;1
67010;;Andlau;ANDLAU;67140;67;BAS RHIN;1
67011;;Artolsheim;ARTOLSHEIM;67390;67;BAS RHIN;1
67012;;Aschbach;ASCHBACH;67250;67;BAS RHIN;1
67013;;Asswiller;ASSWILLER;67320;67;BAS RHIN;1
67014;;Auenheim;AUENHEIM;67480;67;BAS RHIN;1
67016;;Avolsheim;AVOLSHEIM;67120;67;BAS RHIN;1
67017;;Baerendorf;BAERENDORF;67320;67;BAS RHIN;1
67018;;Balbronn;BALBRONN;67310;67;BAS RHIN;1
67019;;Baldenheim;BALDENHEIM;67600;67;BAS RHIN;1
67020;;Barembach;BAREMBACH;67130;67;BAS RHIN;1
67021;;Barr;BARR;67140;67;BAS RHIN;1
67022;;Bassemberg;BASSEMBERG;67220;67;BAS RHIN;1
67023;;Batzendorf;BATZENDORF;67500;67;BAS RHIN;1
67025;;Beinheim;BEINHEIM;67930;67;BAS RHIN;1
67026;;Bellefosse;BELLEFOSSE;67130;67;BAS RHIN;1
67027;;Belmont;BELMONT;67130;67;BAS RHIN;1
67028;;Benfeld;BENFELD;67230;67;BAS RHIN;1
67029;;Berg;BERG;67320;67;BAS RHIN;1
67030;;Bergbieten;BERGBIETEN;67310;67;BAS RHIN;1
67031;;Bernardswiller;BERNARDSWILLER;67210;67;BAS RHIN;1
67032;;Bernardvillé;BERNARDVILLE;67140;67;BAS RHIN;1
67033;;Bernolsheim;BERNOLSHEIM;67170;67;BAS RHIN;1
67034;;Berstett;BERSTETT;67370;67;BAS RHIN;1
67035;;Berstheim;BERSTHEIM;67170;67;BAS RHIN;1
67036;;Bettwiller;BETTWILLER;67320;67;BAS RHIN;1
67037;;Biblisheim;BIBLISHEIM;67360;67;BAS RHIN;1
67038;;Bietlenheim;BIETLENHEIM;67720;67;BAS RHIN;1
67039;;Bilwisheim;BILWISHEIM;67170;67;BAS RHIN;1
67040;;Bindernheim;BINDERNHEIM;67600;67;BAS RHIN;1
67041;;Birkenwald;BIRKENWALD;67440;67;BAS RHIN;1
67043;;Bischheim;BISCHHEIM;67800;67;BAS RHIN;1
67044;;Bischholtz;BISCHHOLTZ;67340;67;BAS RHIN;1
67045;;Bischoffsheim;BISCHOFFSHEIM;67870;67;BAS RHIN;1
67046;;Bischwiller;BISCHWILLER;67240;67;BAS RHIN;1
67047;;Bissert;BISSERT;67260;67;BAS RHIN;1
67048;;Bitschhoffen;BITSCHHOFFEN;67350;67;BAS RHIN;1
67049;;Blaesheim;BLAESHEIM;67113;67;BAS RHIN;1
67050;;Blancherupt;BLANCHERUPT;67130;67;BAS RHIN;1
67051;;Blienschwiller;BLIENSCHWILLER;67650;67;BAS RHIN;1
67052;;Bœrsch;BOERSCH;67530;67;BAS RHIN;1
67053;;Bœsenbiesen;BOESENBIESEN;67390;67;BAS RHIN;1
67054;;Bolsenheim;BOLSENHEIM;67150;67;BAS RHIN;1
67055;;Boofzheim;BOOFZHEIM;67860;67;BAS RHIN;1
67056;;Bootzheim;BOOTZHEIM;67390;67;BAS RHIN;1
67057;;Bosselshausen;BOSSELSHAUSEN;67330;67;BAS RHIN;1
67058;;Bossendorf;BOSSENDORF;67270;67;BAS RHIN;1
67059;;Bourg-Bruche;BOURG-BRUCHE;67420;67;BAS RHIN;1
67060;;Bourgheim;BOURGHEIM;67140;67;BAS RHIN;1
67061;;Bouxwiller;BOUXWILLER;67330;67;BAS RHIN;1
67062;;Breitenau;BREITENAU;67220;67;BAS RHIN;1
67063;;Breitenbach;BREITENBACH;67220;67;BAS RHIN;1
67065;;Breuschwickersheim;BREUSCHWICKERSHEIM;67112;67;BAS RHIN;1
67066;La;Broque;BROQUE;67130;67;BAS RHIN;1
67067;;Brumath;BRUMATH;67170;67;BAS RHIN;1
67068;;Buswiller;BUSWILLER;67350;67;BAS RHIN;1
67069;;Buhl;BUHL;67470;67;BAS RHIN;1
67070;;Burbach;BURBACH;67260;67;BAS RHIN;1
67071;;Bust;BUST;67320;67;BAS RHIN;1
67072;;Butten;BUTTEN;67430;67;BAS RHIN;1
67073;;Châtenois;CHATENOIS;67730;67;BAS RHIN;1
67074;;Cleebourg;CLEEBOURG;67160;67;BAS RHIN;1
67075;;Climbach;CLIMBACH;67510;67;BAS RHIN;1
67076;;Colroy-la-Roche;COLROY-LA-ROCHE;67420;67;BAS RHIN;1
67077;;Cosswiller;COSSWILLER;67310;67;BAS RHIN;1
67078;;Crastatt;CRASTATT;67310;67;BAS RHIN;1
67079;;Crœttwiller;CROETTWILLER;67470;67;BAS RHIN;1
67080;;Dachstein;DACHSTEIN;67120;67;BAS RHIN;1
67081;;Dahlenheim;DAHLENHEIM;67310;67;BAS RHIN;1
67082;;Dalhunden;DALHUNDEN;67770;67;BAS RHIN;1
67083;;Dambach;DAMBACH;67110;67;BAS RHIN;1
67084;;Dambach-la-Ville;DAMBACH-LA-VILLE;67650;67;BAS RHIN;1
67085;;Dangolsheim;DANGOLSHEIM;67310;67;BAS RHIN;1
67086;;Daubensand;DAUBENSAND;67150;67;BAS RHIN;1
67087;;Dauendorf;DAUENDORF;67350;67;BAS RHIN;1
67088;;Dehlingen;DEHLINGEN;67430;67;BAS RHIN;1
67089;;Dettwiller;DETTWILLER;67490;67;BAS RHIN;1
67090;;Diebolsheim;DIEBOLSHEIM;67230;67;BAS RHIN;1
67091;;Diedendorf;DIEDENDORF;67260;67;BAS RHIN;1
67092;;Dieffenbach-au-Val;DIEFFENBACH-AU-VAL;67220;67;BAS RHIN;1
67093;;Dieffenbach-lès-Wœrth;DIEFFENBACH-LES-WOERTH;67360;67;BAS RHIN;1
67094;;Dieffenthal;DIEFFENTHAL;67650;67;BAS RHIN;1
67095;;Diemeringen;DIEMERINGEN;67430;67;BAS RHIN;1
67096;;Dimbsthal;DIMBSTHAL;67440;67;BAS RHIN;1
67097;;Dingsheim;DINGSHEIM;67370;67;BAS RHIN;1
67098;;Dinsheim-sur-Bruche;DINSHEIM-SUR-BRUCHE;67190;67;BAS RHIN;1
67099;;Domfessel;DOMFESSEL;67430;67;BAS RHIN;1
67100;;Donnenheim;DONNENHEIM;67170;67;BAS RHIN;1
67101;;Dorlisheim;DORLISHEIM;67120;67;BAS RHIN;1
67102;;Dossenheim-Kochersberg;DOSSENHEIM-KOCHERSBERG;67117;67;BAS RHIN;1
67103;;Dossenheim-sur-Zinsel;DOSSENHEIM-SUR-ZINSEL;67330;67;BAS RHIN;1
67104;;Drachenbronn-Birlenbach;DRACHENBRONN-BIRLENBACH;67160;67;BAS RHIN;1
67105;;Drulingen;DRULINGEN;67320;67;BAS RHIN;1
67106;;Drusenheim;DRUSENHEIM;67410;67;BAS RHIN;1
67107;;Duntzenheim;DUNTZENHEIM;67270;67;BAS RHIN;1
67108;;Duppigheim;DUPPIGHEIM;67120;67;BAS RHIN;1
67109;;Durningen;DURNINGEN;67270;67;BAS RHIN;1
67110;;Durrenbach;DURRENBACH;67360;67;BAS RHIN;1
67111;;Durstel;DURSTEL;67320;67;BAS RHIN;1
67112;;Duttlenheim;DUTTLENHEIM;67120;67;BAS RHIN;1
67113;;Eberbach-Seltz;EBERBACH-SELTZ;67470;67;BAS RHIN;1
67115;;Ebersheim;EBERSHEIM;67600;67;BAS RHIN;1
67116;;Ebersmunster;EBERSMUNSTER;67600;67;BAS RHIN;1
67117;;Eckartswiller;ECKARTSWILLER;67700;67;BAS RHIN;1
67118;;Eckbolsheim;ECKBOLSHEIM;67201;67;BAS RHIN;1
67119;;Eckwersheim;ECKWERSHEIM;67550;67;BAS RHIN;1
67120;;Eichhoffen;EICHHOFFEN;67140;67;BAS RHIN;1
67121;;Elsenheim;ELSENHEIM;67390;67;BAS RHIN;1
67122;;Wangenbourg-Engenthal;WANGENBOURG-ENGENTHAL;67710;67;BAS RHIN;1
67123;;Engwiller;ENGWILLER;67350;67;BAS RHIN;1
67124;;Entzheim;ENTZHEIM;67960;67;BAS RHIN;1
67125;;Epfig;EPFIG;67680;67;BAS RHIN;1
67126;;Erckartswiller;ERCKARTSWILLER;67290;67;BAS RHIN;1
67127;;Ergersheim;ERGERSHEIM;67120;67;BAS RHIN;1
67128;;Ernolsheim-Bruche;ERNOLSHEIM-BRUCHE;67120;67;BAS RHIN;1
67129;;Ernolsheim-lès-Saverne;ERNOLSHEIM-LES-SAVERNE;67330;67;BAS RHIN;1
67130;;Erstein;ERSTEIN;67150;67;BAS RHIN;1
67131;;Eschau;ESCHAU;67114;67;BAS RHIN;1
67132;;Eschbach;ESCHBACH;67360;67;BAS RHIN;1
67133;;Eschbourg;ESCHBOURG;67320;67;BAS RHIN;1
67134;;Eschwiller;ESCHWILLER;67320;67;BAS RHIN;1
67135;;Ettendorf;ETTENDORF;67350;67;BAS RHIN;1
67136;;Eywiller;EYWILLER;67320;67;BAS RHIN;1
67137;;Fegersheim;FEGERSHEIM;67640;67;BAS RHIN;1
67138;;Fessenheim-le-Bas;FESSENHEIM-LE-BAS;67117;67;BAS RHIN;1
67139;;Flexbourg;FLEXBOURG;67310;67;BAS RHIN;1
67140;;Forstfeld;FORSTFELD;67480;67;BAS RHIN;1
67141;;Forstheim;FORSTHEIM;67580;67;BAS RHIN;1
67142;;Fort-Louis;FORT-LOUIS;67480;67;BAS RHIN;1
67143;;Fouchy;FOUCHY;67220;67;BAS RHIN;1
67144;;Fouday;FOUDAY;67130;67;BAS RHIN;1
67145;;Friedolsheim;FRIEDOLSHEIM;67490;67;BAS RHIN;1
67146;;Friesenheim;FRIESENHEIM;67860;67;BAS RHIN;1
67147;;Frœschwiller;FROESCHWILLER;67360;67;BAS RHIN;1
67148;;Frohmuhl;FROHMUHL;67290;67;BAS RHIN;1
67149;;Furchhausen;FURCHHAUSEN;67700;67;BAS RHIN;1
67150;;Furdenheim;FURDENHEIM;67117;67;BAS RHIN;1
67151;;Gambsheim;GAMBSHEIM;67760;67;BAS RHIN;1
67152;;Geispolsheim;GEISPOLSHEIM;67400;67;BAS RHIN;1
67153;;Geiswiller;GEISWILLER;67270;67;BAS RHIN;1
67154;;Gerstheim;GERSTHEIM;67150;67;BAS RHIN;1
67155;;Gertwiller;GERTWILLER;67140;67;BAS RHIN;1
67156;;Geudertheim;GEUDERTHEIM;67170;67;BAS RHIN;1
67158;;Gingsheim;GINGSHEIM;67270;67;BAS RHIN;1
67159;;Gœrlingen;GOERLINGEN;67320;67;BAS RHIN;1
67160;;Gœrsdorf;GOERSDORF;67360;67;BAS RHIN;1
67161;;Gottenhouse;GOTTENHOUSE;67700;67;BAS RHIN;1
67162;;Gottesheim;GOTTESHEIM;67490;67;BAS RHIN;1
67163;;Gougenheim;GOUGENHEIM;67270;67;BAS RHIN;1
67164;;Goxwiller;GOXWILLER;67210;67;BAS RHIN;1
67165;;Grandfontaine;GRANDFONTAINE;67130;67;BAS RHIN;1
67166;;Grassendorf;GRASSENDORF;67350;67;BAS RHIN;1
67167;;Grendelbruch;GRENDELBRUCH;67190;67;BAS RHIN;1
67168;;Gresswiller;GRESSWILLER;67190;67;BAS RHIN;1
67169;;Gries;GRIES;67240;67;BAS RHIN;1
67172;;Griesheim-près-Molsheim;GRIESHEIM-PRES-MOLSHEIM;67210;67;BAS RHIN;1
67173;;Griesheim-sur-Souffel;GRIESHEIM-SUR-SOUFFEL;67370;67;BAS RHIN;1
67174;;Gumbrechtshoffen;GUMBRECHTSHOFFEN;67110;67;BAS RHIN;1
67176;;Gundershoffen;GUNDERSHOFFEN;67110;67;BAS RHIN;1
67177;;Gunstett;GUNSTETT;67360;67;BAS RHIN;1
67178;;Gungwiller;GUNGWILLER;67320;67;BAS RHIN;1
67179;;Haegen;HAEGEN;67700;67;BAS RHIN;1
67180;;Haguenau;HAGUENAU;67500;67;BAS RHIN;1
67181;;Handschuheim;HANDSCHUHEIM;67117;67;BAS RHIN;1
67182;;Hangenbieten;HANGENBIETEN;67980;67;BAS RHIN;1
67183;;Harskirchen;HARSKIRCHEN;67260;67;BAS RHIN;1
67184;;Hatten;HATTEN;67690;67;BAS RHIN;1
67185;;Hattmatt;HATTMATT;67330;67;BAS RHIN;1
67186;;Hegeney;HEGENEY;67360;67;BAS RHIN;1
67187;;Heidolsheim;HEIDOLSHEIM;67390;67;BAS RHIN;1
67188;;Heiligenberg;HEILIGENBERG;67190;67;BAS RHIN;1
67189;;Heiligenstein;HEILIGENSTEIN;67140;67;BAS RHIN;1
67190;;Hengwiller;HENGWILLER;67440;67;BAS RHIN;1
67191;;Herbitzheim;HERBITZHEIM;67260;67;BAS RHIN;1
67192;;Herbsheim;HERBSHEIM;67230;67;BAS RHIN;1
67194;;Herrlisheim;HERRLISHEIM;67850;67;BAS RHIN;1
67195;;Hessenheim;HESSENHEIM;67390;67;BAS RHIN;1
67196;;Hilsenheim;HILSENHEIM;67600;67;BAS RHIN;1
67197;;Hindisheim;HINDISHEIM;67150;67;BAS RHIN;1
67198;;Hinsbourg;HINSBOURG;67290;67;BAS RHIN;1
67199;;Hinsingen;HINSINGEN;67260;67;BAS RHIN;1
67200;;Hipsheim;HIPSHEIM;67150;67;BAS RHIN;1
67201;;Hirschland;HIRSCHLAND;67320;67;BAS RHIN;1
67202;;Hochfelden;HOCHFELDEN;67270;67;BAS RHIN;1
67203;;Hochstett;HOCHSTETT;67170;67;BAS RHIN;1
67204;;Hœnheim;HOENHEIM;67800;67;BAS RHIN;1
67205;;Hœrdt;HOERDT;67720;67;BAS RHIN;1
67206;;Hoffen;HOFFEN;67250;67;BAS RHIN;1
67207;;Hohatzenheim;HOHATZENHEIM;67170;67;BAS RHIN;1
67208;;Hohengœft;HOHENGOEFT;67310;67;BAS RHIN;1
67209;;Hohfrankenheim;HOHFRANKENHEIM;67270;67;BAS RHIN;1
67210;Le;Hohwald;HOHWALD;67140;67;BAS RHIN;1
67212;;Holtzheim;HOLTZHEIM;67810;67;BAS RHIN;1
67213;;Hunspach;HUNSPACH;67250;67;BAS RHIN;1
67214;;Hurtigheim;HURTIGHEIM;67117;67;BAS RHIN;1
67215;;Huttendorf;HUTTENDORF;67270;67;BAS RHIN;1
67216;;Huttenheim;HUTTENHEIM;67230;67;BAS RHIN;1
67217;;Ichtratzheim;ICHTRATZHEIM;67640;67;BAS RHIN;1
67218;;Illkirch-Graffenstaden;ILLKIRCH-GRAFFENSTADEN;67400;67;BAS RHIN;1
67220;;Ingenheim;INGENHEIM;67270;67;BAS RHIN;1
67221;;Ingolsheim;INGOLSHEIM;67250;67;BAS RHIN;1
67222;;Ingwiller;INGWILLER;67340;67;BAS RHIN;1
67223;;Innenheim;INNENHEIM;67880;67;BAS RHIN;1
67225;;Issenhausen;ISSENHAUSEN;67330;67;BAS RHIN;1
67226;;Ittenheim;ITTENHEIM;67117;67;BAS RHIN;1
67227;;Itterswiller;ITTERSWILLER;67140;67;BAS RHIN;1
67228;;Neugartheim-Ittlenheim;NEUGARTHEIM-ITTLENHEIM;67370;67;BAS RHIN;1
67229;;Jetterswiller;JETTERSWILLER;67440;67;BAS RHIN;1
67230;;Kaltenhouse;KALTENHOUSE;67240;67;BAS RHIN;1
67231;;Kauffenheim;KAUFFENHEIM;67480;67;BAS RHIN;1
67232;;Keffenach;KEFFENACH;67250;67;BAS RHIN;1
67233;;Kertzfeld;KERTZFELD;67230;67;BAS RHIN;1
67234;;Keskastel;KESKASTEL;67260;67;BAS RHIN;1
67235;;Kesseldorf;KESSELDORF;67930;67;BAS RHIN;1
67236;;Kienheim;KIENHEIM;67270;67;BAS RHIN;1
67237;;Kilstett;KILSTETT;67840;67;BAS RHIN;1
67238;;Kindwiller;KINDWILLER;67350;67;BAS RHIN;1
67239;;Kintzheim;KINTZHEIM;67600;67;BAS RHIN;1
67240;;Kirchheim;KIRCHHEIM;67520;67;BAS RHIN;1
67241;;Kirrberg;KIRRBERG;67320;67;BAS RHIN;1
67242;;Kirrwiller;KIRRWILLER;67330;67;BAS RHIN;1
67244;;Kleingœft;KLEINGOEFT;67440;67;BAS RHIN;1
67245;;Knœrsheim;KNOERSHEIM;67310;67;BAS RHIN;1
67246;;Kogenheim;KOGENHEIM;67230;67;BAS RHIN;1
67247;;Kolbsheim;KOLBSHEIM;67120;67;BAS RHIN;1
67248;;Krautergersheim;KRAUTERGERSHEIM;67880;67;BAS RHIN;1
67249;;Krautwiller;KRAUTWILLER;67170;67;BAS RHIN;1
67250;;Kriegsheim;KRIEGSHEIM;67170;67;BAS RHIN;1
67252;;Kurtzenhouse;KURTZENHOUSE;67240;67;BAS RHIN;1
67253;;Kuttolsheim;KUTTOLSHEIM;67520;67;BAS RHIN;1
67254;;Kutzenhausen;KUTZENHAUSEN;67250;67;BAS RHIN;1
67255;;Lalaye;LALAYE;67220;67;BAS RHIN;1
67256;;Lampertheim;LAMPERTHEIM;67450;67;BAS RHIN;1
67257;;Lampertsloch;LAMPERTSLOCH;67250;67;BAS RHIN;1
67258;;Landersheim;LANDERSHEIM;67700;67;BAS RHIN;1
67259;;Langensoultzbach;LANGENSOULTZBACH;67360;67;BAS RHIN;1
67260;;Laubach;LAUBACH;67580;67;BAS RHIN;1
67261;;Lauterbourg;LAUTERBOURG;67630;67;BAS RHIN;1
67263;;Lembach;LEMBACH;67510;67;BAS RHIN;1
67264;;Leutenheim;LEUTENHEIM;67480;67;BAS RHIN;1
67265;;Lichtenberg;LICHTENBERG;67340;67;BAS RHIN;1
67266;;Limersheim;LIMERSHEIM;67150;67;BAS RHIN;1
67267;;Lingolsheim;LINGOLSHEIM;67380;67;BAS RHIN;1
67268;;Lipsheim;LIPSHEIM;67640;67;BAS RHIN;1
67269;;Littenheim;LITTENHEIM;67490;67;BAS RHIN;1
67270;;Lixhausen;LIXHAUSEN;67270;67;BAS RHIN;1
67271;;Lobsann;LOBSANN;67250;67;BAS RHIN;1
67272;;Lochwiller;LOCHWILLER;67440;67;BAS RHIN;1
67273;;Lohr;LOHR;67290;67;BAS RHIN;1
67274;;Lorentzen;LORENTZEN;67430;67;BAS RHIN;1
67275;;Lupstein;LUPSTEIN;67490;67;BAS RHIN;1
67276;;Lutzelhouse;LUTZELHOUSE;67130;67;BAS RHIN;1
67277;;Mackenheim;MACKENHEIM;67390;67;BAS RHIN;1
67278;;Mackwiller;MACKWILLER;67430;67;BAS RHIN;1
67279;;Maennolsheim;MAENNOLSHEIM;67700;67;BAS RHIN;1
67280;;Maisonsgoutte;MAISONSGOUTTE;67220;67;BAS RHIN;1
67281;;Marckolsheim;MARCKOLSHEIM;67390;67;BAS RHIN;1
67282;;Marlenheim;MARLENHEIM;67520;67;BAS RHIN;1
67283;;Marmoutier;MARMOUTIER;67440;67;BAS RHIN;1
67285;;Matzenheim;MATZENHEIM;67150;67;BAS RHIN;1
67286;;Meistratzheim;MEISTRATZHEIM;67210;67;BAS RHIN;1
67287;;Melsheim;MELSHEIM;67270;67;BAS RHIN;1
67288;;Memmelshoffen;MEMMELSHOFFEN;67250;67;BAS RHIN;1
67289;;Menchhoffen;MENCHHOFFEN;67340;67;BAS RHIN;1
67290;;Merkwiller-Pechelbronn;MERKWILLER-PECHELBRONN;67250;67;BAS RHIN;1
67291;;Mertzwiller;MERTZWILLER;67580;67;BAS RHIN;1
67292;;Mietesheim;MIETESHEIM;67580;67;BAS RHIN;1
67293;;Minversheim;MINVERSHEIM;67270;67;BAS RHIN;1
67295;;Mittelbergheim;MITTELBERGHEIM;67140;67;BAS RHIN;1
67296;;Mittelhausbergen;MITTELHAUSBERGEN;67206;67;BAS RHIN;1
67297;;Mittelhausen;MITTELHAUSEN;67170;67;BAS RHIN;1
67298;;Mittelschaeffolsheim;MITTELSCHAEFFOLSHEIM;67170;67;BAS RHIN;1
67299;;Mollkirch;MOLLKIRCH;67190;67;BAS RHIN;1
67300;;Molsheim;MOLSHEIM;67120;67;BAS RHIN;1
67301;;Mommenheim;MOMMENHEIM;67670;67;BAS RHIN;1
67302;;Monswiller;MONSWILLER;67700;67;BAS RHIN;1
67303;;Morsbronn-les-Bains;MORSBRONN-LES-BAINS;67360;67;BAS RHIN;1
67304;;Morschwiller;MORSCHWILLER;67350;67;BAS RHIN;1
67305;;Mothern;MOTHERN;67470;67;BAS RHIN;1
67306;;Muhlbach-sur-Bruche;MUHLBACH-SUR-BRUCHE;67130;67;BAS RHIN;1
67307;;Mulhausen;MULHAUSEN;67350;67;BAS RHIN;1
67308;;Munchhausen;MUNCHHAUSEN;67470;67;BAS RHIN;1
67309;;Mundolsheim;MUNDOLSHEIM;67450;67;BAS RHIN;1
67310;;Mussig;MUSSIG;67600;67;BAS RHIN;1
67311;;Muttersholtz;MUTTERSHOLTZ;67600;67;BAS RHIN;1
67312;;Mutzenhouse;MUTZENHOUSE;67270;67;BAS RHIN;1
67313;;Mutzig;MUTZIG;67190;67;BAS RHIN;1
67314;;Natzwiller;NATZWILLER;67130;67;BAS RHIN;1
67315;;Neewiller-près-Lauterbourg;NEEWILLER-PRES-LAUTERBOURG;67630;67;BAS RHIN;1
67317;;Neubois;NEUBOIS;67220;67;BAS RHIN;1
67319;;Neuhaeusel;NEUHAEUSEL;67480;67;BAS RHIN;1
67320;;Neuve-Église;NEUVE-EGLISE;67220;67;BAS RHIN;1
67321;;Neuviller-la-Roche;NEUVILLER-LA-ROCHE;67130;67;BAS RHIN;1
67322;;Neuwiller-lès-Saverne;NEUWILLER-LES-SAVERNE;67330;67;BAS RHIN;1
67324;;Niederbronn-les-Bains;NIEDERBRONN-LES-BAINS;67110;67;BAS RHIN;1
67325;;Niederhaslach;NIEDERHASLACH;67280;67;BAS RHIN;1
67326;;Niederhausbergen;NIEDERHAUSBERGEN;67207;67;BAS RHIN;1
67327;;Niederlauterbach;NIEDERLAUTERBACH;67630;67;BAS RHIN;1
67328;;Niedermodern;NIEDERMODERN;67350;67;BAS RHIN;1
67329;;Niedernai;NIEDERNAI;67210;67;BAS RHIN;1
67330;;Niederrœdern;NIEDERROEDERN;67470;67;BAS RHIN;1
67331;;Niederschaeffolsheim;NIEDERSCHAEFFOLSHEIM;67500;67;BAS RHIN;1
67333;;Niedersoultzbach;NIEDERSOULTZBACH;67330;67;BAS RHIN;1
67334;;Niedersteinbach;NIEDERSTEINBACH;67510;67;BAS RHIN;1
67335;;Nordheim;NORDHEIM;67520;67;BAS RHIN;1
67336;;Nordhouse;NORDHOUSE;67150;67;BAS RHIN;1
67337;;Nothalten;NOTHALTEN;67680;67;BAS RHIN;1
67338;;Obenheim;OBENHEIM;67230;67;BAS RHIN;1
67339;;Betschdorf;BETSCHDORF;67660;67;BAS RHIN;1
67340;;Oberbronn;OBERBRONN;67110;67;BAS RHIN;1
67341;;Oberdorf-Spachbach;OBERDORF-SPACHBACH;67360;67;BAS RHIN;1
67342;;Oberhaslach;OBERHASLACH;67280;67;BAS RHIN;1
67343;;Oberhausbergen;OBERHAUSBERGEN;67205;67;BAS RHIN;1
67344;;Oberhoffen-lès-Wissembourg;OBERHOFFEN-LES-WISSEMBOURG;67160;67;BAS RHIN;1
67345;;Oberhoffen-sur-Moder;OBERHOFFEN-SUR-MODER;67240;67;BAS RHIN;1
67346;;Oberlauterbach;OBERLAUTERBACH;67160;67;BAS RHIN;1
67347;;Obermodern-Zutzendorf;OBERMODERN-ZUTZENDORF;67330;67;BAS RHIN;1
67348;;Obernai;OBERNAI;67210;67;BAS RHIN;1
67349;;Oberrœdern;OBERROEDERN;67250;67;BAS RHIN;1
67350;;Oberschaeffolsheim;OBERSCHAEFFOLSHEIM;67203;67;BAS RHIN;1
67351;;Seebach;SEEBACH;67160;67;BAS RHIN;1
67352;;Obersoultzbach;OBERSOULTZBACH;67330;67;BAS RHIN;1
67353;;Obersteinbach;OBERSTEINBACH;67510;67;BAS RHIN;1
67354;;Odratzheim;ODRATZHEIM;67520;67;BAS RHIN;1
67355;;Oermingen;OERMINGEN;67970;67;BAS RHIN;1
67356;;Offendorf;OFFENDORF;67850;67;BAS RHIN;1
67358;;Offwiller;OFFWILLER;67340;67;BAS RHIN;1
67359;;Ohlungen;OHLUNGEN;67590;67;BAS RHIN;1
67360;;Ohnenheim;OHNENHEIM;67390;67;BAS RHIN;1
67361;;Olwisheim;OLWISHEIM;67170;67;BAS RHIN;1
67362;;Orschwiller;ORSCHWILLER;67600;67;BAS RHIN;1
67363;;Osthoffen;OSTHOFFEN;67990;67;BAS RHIN;1
67364;;Osthouse;OSTHOUSE;67150;67;BAS RHIN;1
67365;;Ostwald;OSTWALD;67540;67;BAS RHIN;1
67366;;Ottersthal;OTTERSTHAL;67700;67;BAS RHIN;1
67367;;Otterswiller;OTTERSWILLER;67700;67;BAS RHIN;1
67368;;Ottrott;OTTROTT;67530;67;BAS RHIN;1
67369;;Ottwiller;OTTWILLER;67320;67;BAS RHIN;1
67370;;Petersbach;PETERSBACH;67290;67;BAS RHIN;1
67371;La;Petite-Pierre;PETITE-PIERRE;67290;67;BAS RHIN;1
67372;;Pfaffenhoffen;PFAFFENHOFFEN;67350;67;BAS RHIN;1
67373;;Pfalzweyer;PFALZWEYER;67320;67;BAS RHIN;1
67374;;Pfettisheim;PFETTISHEIM;67370;67;BAS RHIN;1
67375;;Pfulgriesheim;PFULGRIESHEIM;67370;67;BAS RHIN;1
67377;;Plaine;PLAINE;67420;67;BAS RHIN;1
67378;;Plobsheim;PLOBSHEIM;67115;67;BAS RHIN;1
67379;;Preuschdorf;PREUSCHDORF;67250;67;BAS RHIN;1
67380;;Printzheim;PRINTZHEIM;67490;67;BAS RHIN;1
67381;;Puberg;PUBERG;67290;67;BAS RHIN;1
67382;;Quatzenheim;QUATZENHEIM;67117;67;BAS RHIN;1
67383;;Rangen;RANGEN;67310;67;BAS RHIN;1
67384;;Ranrupt;RANRUPT;67420;67;BAS RHIN;1
67385;;Ratzwiller;RATZWILLER;67430;67;BAS RHIN;1
67386;;Rauwiller;RAUWILLER;67320;67;BAS RHIN;1
67387;;Reichsfeld;REICHSFELD;67140;67;BAS RHIN;1
67388;;Reichshoffen;REICHSHOFFEN;67110;67;BAS RHIN;1
67389;;Reichstett;REICHSTETT;67116;67;BAS RHIN;1
67391;;Reinhardsmunster;REINHARDSMUNSTER;67440;67;BAS RHIN;1
67392;;Reipertswiller;REIPERTSWILLER;67340;67;BAS RHIN;1
67394;;Retschwiller;RETSCHWILLER;67250;67;BAS RHIN;1
67395;;Reutenbourg;REUTENBOURG;67440;67;BAS RHIN;1
67396;;Rexingen;REXINGEN;67320;67;BAS RHIN;1
67397;;Rhinau;RHINAU;67860;67;BAS RHIN;1
67398;;Richtolsheim;RICHTOLSHEIM;67390;67;BAS RHIN;1
67400;;Riedseltz;RIEDSELTZ;67160;67;BAS RHIN;1
67401;;Rimsdorf;RIMSDORF;67260;67;BAS RHIN;1
67402;;Ringeldorf;RINGELDORF;67350;67;BAS RHIN;1
67403;;Ringendorf;RINGENDORF;67350;67;BAS RHIN;1
67404;;Rittershoffen;RITTERSHOFFEN;67690;67;BAS RHIN;1
67405;;Rœschwoog;ROESCHWOOG;67480;67;BAS RHIN;1
67406;;Rohr;ROHR;67270;67;BAS RHIN;1
67407;;Rohrwiller;ROHRWILLER;67410;67;BAS RHIN;1
67408;;Romanswiller;ROMANSWILLER;67310;67;BAS RHIN;1
67409;;Roppenheim;ROPPENHEIM;67480;67;BAS RHIN;1
67410;;Rosenwiller;ROSENWILLER;67560;67;BAS RHIN;1
67411;;Rosheim;ROSHEIM;67560;67;BAS RHIN;1
67412;;Rossfeld;ROSSFELD;67230;67;BAS RHIN;1
67413;;Rosteig;ROSTEIG;67290;67;BAS RHIN;1
67414;;Rothau;ROTHAU;67570;67;BAS RHIN;1
67415;;Rothbach;ROTHBACH;67340;67;BAS RHIN;1
67416;;Rott;ROTT;67160;67;BAS RHIN;1
67417;;Rottelsheim;ROTTELSHEIM;67170;67;BAS RHIN;1
67418;;Rountzenheim;ROUNTZENHEIM;67480;67;BAS RHIN;1
67420;;Russ;RUSS;67130;67;BAS RHIN;1
67421;;Saales;SAALES;67420;67;BAS RHIN;1
67422;;Saasenheim;SAASENHEIM;67390;67;BAS RHIN;1
67423;;Saessolsheim;SAESSOLSHEIM;67270;67;BAS RHIN;1
67424;;Saint-Blaise-la-Roche;SAINT-BLAISE-LA-ROCHE;67420;67;BAS RHIN;1
67425;;Saint-Jean-Saverne;SAINT-JEAN-SAVERNE;67700;67;BAS RHIN;1
67426;;Saint-Martin;SAINT-MARTIN;67220;67;BAS RHIN;1
67427;;Saint-Maurice;SAINT-MAURICE;67220;67;BAS RHIN;1
67428;;Saint-Nabor;SAINT-NABOR;67530;67;BAS RHIN;1
67429;;Saint-Pierre;SAINT-PIERRE;67140;67;BAS RHIN;1
67430;;Saint-Pierre-Bois;SAINT-PIERRE-BOIS;67220;67;BAS RHIN;1
67431;;Salenthal;SALENTHAL;67440;67;BAS RHIN;1
67432;;Salmbach;SALMBACH;67160;67;BAS RHIN;1
67433;;Sand;SAND;67230;67;BAS RHIN;1
67434;;Sarre-Union;SARRE-UNION;67260;67;BAS RHIN;1
67435;;Sarrewerden;SARREWERDEN;67260;67;BAS RHIN;1
67436;;Saulxures;SAULXURES;67420;67;BAS RHIN;1
67437;;Saverne;SAVERNE;67700;67;BAS RHIN;1
67438;;Schaeffersheim;SCHAEFFERSHEIM;67150;67;BAS RHIN;1
67439;;Schaffhouse-sur-Zorn;SCHAFFHOUSE-SUR-ZORN;67270;67;BAS RHIN;1
67440;;Schaffhouse-près-Seltz;SCHAFFHOUSE-PRES-SELTZ;67470;67;BAS RHIN;1
67441;;Schalkendorf;SCHALKENDORF;67350;67;BAS RHIN;1
67442;;Scharrachbergheim-Irmstett;SCHARRACHBERGHEIM-IRMSTETT;67310;67;BAS RHIN;1
67443;;Scheibenhard;SCHEIBENHARD;67630;67;BAS RHIN;1
67444;;Scherlenheim;SCHERLENHEIM;67270;67;BAS RHIN;1
67445;;Scherwiller;SCHERWILLER;67750;67;BAS RHIN;1
67446;;Schillersdorf;SCHILLERSDORF;67340;67;BAS RHIN;1
67447;;Schiltigheim;SCHILTIGHEIM;67300;67;BAS RHIN;1
67448;;Schirmeck;SCHIRMECK;67130;67;BAS RHIN;1
67449;;Schirrhein;SCHIRRHEIN;67240;67;BAS RHIN;1
67450;;Schirrhoffen;SCHIRRHOFFEN;67240;67;BAS RHIN;1
67451;;Schleithal;SCHLEITHAL;67160;67;BAS RHIN;1
67452;;Schnersheim;SCHNERSHEIM;67370;67;BAS RHIN;1
67453;;Schœnau;SCHOENAU;67390;67;BAS RHIN;1
67454;;Schœnbourg;SCHOENBOURG;67320;67;BAS RHIN;1
67455;;Schœnenbourg;SCHOENENBOURG;67250;67;BAS RHIN;1
67456;;Schopperten;SCHOPPERTEN;67260;67;BAS RHIN;1
67458;;Schweighouse-sur-Moder;SCHWEIGHOUSE-SUR-MODER;67590;67;BAS RHIN;1
67459;;Schwenheim;SCHWENHEIM;67440;67;BAS RHIN;1
67460;;Schwindratzheim;SCHWINDRATZHEIM;67270;67;BAS RHIN;1
67461;;Schwobsheim;SCHWOBSHEIM;67390;67;BAS RHIN;1
67462;;Sélestat;SELESTAT;67600;67;BAS RHIN;1
67463;;Seltz;SELTZ;67470;67;BAS RHIN;1
67464;;Sermersheim;SERMERSHEIM;67230;67;BAS RHIN;1
67465;;Sessenheim;SESSENHEIM;67770;67;BAS RHIN;1
67466;;Siegen;SIEGEN;67160;67;BAS RHIN;1
67467;;Siewiller;SIEWILLER;67320;67;BAS RHIN;1
67468;;Siltzheim;SILTZHEIM;67260;67;BAS RHIN;1
67469;;Singrist;SINGRIST;67440;67;BAS RHIN;1
67470;;Solbach;SOLBACH;67130;67;BAS RHIN;1
67471;;Souffelweyersheim;SOUFFELWEYERSHEIM;67460;67;BAS RHIN;1
67472;;Soufflenheim;SOUFFLENHEIM;67620;67;BAS RHIN;1
67473;;Soultz-les-Bains;SOULTZ-LES-BAINS;67120;67;BAS RHIN;1
67474;;Soultz-sous-Forêts;SOULTZ-SOUS-FORETS;67250;67;BAS RHIN;1
67475;;Sparsbach;SPARSBACH;67340;67;BAS RHIN;1
67476;;Stattmatten;STATTMATTEN;67770;67;BAS RHIN;1
67477;;Steige;STEIGE;67220;67;BAS RHIN;1
67478;;Steinbourg;STEINBOURG;67790;67;BAS RHIN;1
67479;;Steinseltz;STEINSELTZ;67160;67;BAS RHIN;1
67480;;Still;STILL;67190;67;BAS RHIN;1
67481;;Stotzheim;STOTZHEIM;67140;67;BAS RHIN;1
67482;;Strasbourg;STRASBOURG;67000;67;BAS RHIN;1
67483;;Struth;STRUTH;67290;67;BAS RHIN;1
67484;;Stundwiller;STUNDWILLER;67250;67;BAS RHIN;1
67485;;Stutzheim-Offenheim;STUTZHEIM-OFFENHEIM;67370;67;BAS RHIN;1
67486;;Sundhouse;SUNDHOUSE;67920;67;BAS RHIN;1
67487;;Surbourg;SURBOURG;67250;67;BAS RHIN;1
67488;;Thal-Drulingen;THAL-DRULINGEN;67320;67;BAS RHIN;1
67489;;Thal-Marmoutier;THAL-MARMOUTIER;67440;67;BAS RHIN;1
67490;;Thanvillé;THANVILLE;67220;67;BAS RHIN;1
67491;;Tieffenbach;TIEFFENBACH;67290;67;BAS RHIN;1
67492;;Traenheim;TRAENHEIM;67310;67;BAS RHIN;1
67493;;Triembach-au-Val;TRIEMBACH-AU-VAL;67220;67;BAS RHIN;1
67494;;Trimbach;TRIMBACH;67470;67;BAS RHIN;1
67495;;Truchtersheim;TRUCHTERSHEIM;67370;67;BAS RHIN;1
67496;;Uberach;UBERACH;67350;67;BAS RHIN;1
67497;;Uhlwiller;UHLWILLER;67350;67;BAS RHIN;1
67498;;Uhrwiller;UHRWILLER;67350;67;BAS RHIN;1
67499;;Urbeis;URBEIS;67220;67;BAS RHIN;1
67500;;Urmatt;URMATT;67280;67;BAS RHIN;1
67501;;Uttenheim;UTTENHEIM;67150;67;BAS RHIN;1
67502;;Uttenhoffen;UTTENHOFFEN;67110;67;BAS RHIN;1
67503;;Uttwiller;UTTWILLER;67330;67;BAS RHIN;1
67504;;Valff;VALFF;67210;67;BAS RHIN;1
67505;La;Vancelle;VANCELLE;67730;67;BAS RHIN;1
67506;;Vendenheim;VENDENHEIM;67550;67;BAS RHIN;1
67507;;Villé;VILLE;67220;67;BAS RHIN;1
67508;;Vœllerdingen;VOELLERDINGEN;67430;67;BAS RHIN;1
67509;;Volksberg;VOLKSBERG;67290;67;BAS RHIN;1
67510;;Wahlenheim;WAHLENHEIM;67170;67;BAS RHIN;1
67511;;Walbourg;WALBOURG;67360;67;BAS RHIN;1
67512;La;Walck;WALCK;67350;67;BAS RHIN;1
67513;;Waldersbach;WALDERSBACH;67130;67;BAS RHIN;1
67514;;Waldhambach;WALDHAMBACH;67430;67;BAS RHIN;1
67515;;Waldolwisheim;WALDOLWISHEIM;67700;67;BAS RHIN;1
67516;;Waltenheim-sur-Zorn;WALTENHEIM-SUR-ZORN;67670;67;BAS RHIN;1
67517;;Wangen;WANGEN;67520;67;BAS RHIN;1
67519;La;Wantzenau;WANTZENAU;67610;67;BAS RHIN;1
67520;;Wasselonne;WASSELONNE;67310;67;BAS RHIN;1
67521;;Weinbourg;WEINBOURG;67340;67;BAS RHIN;1
67522;;Weislingen;WEISLINGEN;67290;67;BAS RHIN;1
67523;;Weitbruch;WEITBRUCH;67500;67;BAS RHIN;1
67524;;Weiterswiller;WEITERSWILLER;67340;67;BAS RHIN;1
67525;;Westhoffen;WESTHOFFEN;67310;67;BAS RHIN;1
67526;;Westhouse;WESTHOUSE;67230;67;BAS RHIN;1
67527;;Westhouse-Marmoutier;WESTHOUSE-MARMOUTIER;67440;67;BAS RHIN;1
67528;;Weyer;WEYER;67320;67;BAS RHIN;1
67529;;Weyersheim;WEYERSHEIM;67720;67;BAS RHIN;1
67530;;Wickersheim-Wilshausen;WICKERSHEIM-WILSHAUSEN;67270;67;BAS RHIN;1
67531;;Wildersbach;WILDERSBACH;67130;67;BAS RHIN;1
67532;;Willgottheim;WILLGOTTHEIM;67370;67;BAS RHIN;1
67534;;Wilwisheim;WILWISHEIM;67270;67;BAS RHIN;1
67535;;Wimmenau;WIMMENAU;67290;67;BAS RHIN;1
67536;;Windstein;WINDSTEIN;67110;67;BAS RHIN;1
67537;;Wingen;WINGEN;67510;67;BAS RHIN;1
67538;;Wingen-sur-Moder;WINGEN-SUR-MODER;67290;67;BAS RHIN;1
67539;;Wingersheim;WINGERSHEIM;67170;67;BAS RHIN;1
67540;;Wintershouse;WINTERSHOUSE;67590;67;BAS RHIN;1
67541;;Wintzenbach;WINTZENBACH;67470;67;BAS RHIN;1
67542;;Wintzenheim-Kochersberg;WINTZENHEIM-KOCHERSBERG;67370;67;BAS RHIN;1
67543;;Wisches;WISCHES;67130;67;BAS RHIN;1
67544;;Wissembourg;WISSEMBOURG;67160;67;BAS RHIN;1
67545;;Witternheim;WITTERNHEIM;67230;67;BAS RHIN;1
67546;;Wittersheim;WITTERSHEIM;67670;67;BAS RHIN;1
67547;;Wittisheim;WITTISHEIM;67820;67;BAS RHIN;1
67548;;Wiwersheim;WIWERSHEIM;67370;67;BAS RHIN;1
67550;;Wœrth;WOERTH;67360;67;BAS RHIN;1
67551;;Wolfisheim;WOLFISHEIM;67202;67;BAS RHIN;1
67552;;Wolfskirchen;WOLFSKIRCHEN;67260;67;BAS RHIN;1
67553;;Wolschheim;WOLSCHHEIM;67700;67;BAS RHIN;1
67554;;Wolxheim;WOLXHEIM;67120;67;BAS RHIN;1
67555;;Zehnacker;ZEHNACKER;67310;67;BAS RHIN;1
67556;;Zeinheim;ZEINHEIM;67310;67;BAS RHIN;1
67557;;Zellwiller;ZELLWILLER;67140;67;BAS RHIN;1
67558;;Zinswiller;ZINSWILLER;67110;67;BAS RHIN;1
67559;;Zittersheim;ZITTERSHEIM;67290;67;BAS RHIN;1
67560;;Zœbersdorf;ZOEBERSDORF;67270;67;BAS RHIN;1
68001;;Algolsheim;ALGOLSHEIM;68600;68;HAUT RHIN;1
68002;;Altenach;ALTENACH;68210;68;HAUT RHIN;1
68004;;Altkirch;ALTKIRCH;68130;68;HAUT RHIN;1
68005;;Ammerschwihr;AMMERSCHWIHR;68770;68;HAUT RHIN;1
68006;;Ammerzwiller;AMMERZWILLER;68210;68;HAUT RHIN;1
68007;;Andolsheim;ANDOLSHEIM;68280;68;HAUT RHIN;1
68008;;Appenwihr;APPENWIHR;68280;68;HAUT RHIN;1
68009;;Artzenheim;ARTZENHEIM;68320;68;HAUT RHIN;1
68010;;Aspach;ASPACH;68130;68;HAUT RHIN;1
68011;;Aspach-le-Bas;ASPACH-LE-BAS;68700;68;HAUT RHIN;1
68012;;Aspach-le-Haut;ASPACH-LE-HAUT;68700;68;HAUT RHIN;1
68013;;Attenschwiller;ATTENSCHWILLER;68220;68;HAUT RHIN;1
68014;;Aubure;AUBURE;68150;68;HAUT RHIN;1
68015;;Baldersheim;BALDERSHEIM;68390;68;HAUT RHIN;1
68016;;Balgau;BALGAU;68740;68;HAUT RHIN;1
68017;;Ballersdorf;BALLERSDORF;68210;68;HAUT RHIN;1
68018;;Balschwiller;BALSCHWILLER;68210;68;HAUT RHIN;1
68019;;Baltzenheim;BALTZENHEIM;68320;68;HAUT RHIN;1
68020;;Bantzenheim;BANTZENHEIM;68490;68;HAUT RHIN;1
68021;;Bartenheim;BARTENHEIM;68870;68;HAUT RHIN;1
68022;;Battenheim;BATTENHEIM;68390;68;HAUT RHIN;1
68023;;Beblenheim;BEBLENHEIM;68980;68;HAUT RHIN;1
68024;;Bellemagny;BELLEMAGNY;68210;68;HAUT RHIN;1
68025;;Bendorf;BENDORF;68480;68;HAUT RHIN;1
68026;;Bennwihr;BENNWIHR;68630;68;HAUT RHIN;1
68027;;Berentzwiller;BERENTZWILLER;68130;68;HAUT RHIN;1
68028;;Bergheim;BERGHEIM;68750;68;HAUT RHIN;1
68029;;Bergholtz;BERGHOLTZ;68500;68;HAUT RHIN;1
68030;;Bergholtzzell;BERGHOLTZZELL;68500;68;HAUT RHIN;1
68031;;Bernwiller;BERNWILLER;68210;68;HAUT RHIN;1
68032;;Berrwiller;BERRWILLER;68500;68;HAUT RHIN;1
68033;;Bettendorf;BETTENDORF;68560;68;HAUT RHIN;1
68034;;Bettlach;BETTLACH;68480;68;HAUT RHIN;1
68035;;Biederthal;BIEDERTHAL;68480;68;HAUT RHIN;1
68036;;Biesheim;BIESHEIM;68600;68;HAUT RHIN;1
68037;;Biltzheim;BILTZHEIM;68250;68;HAUT RHIN;1
68038;;Bischwihr;BISCHWIHR;68320;68;HAUT RHIN;1
68039;;Bisel;BISEL;68580;68;HAUT RHIN;1
68040;;Bitschwiller-lès-Thann;BITSCHWILLER-LES-THANN;68620;68;HAUT RHIN;1
68041;;Blodelsheim;BLODELSHEIM;68740;68;HAUT RHIN;1
68042;;Blotzheim;BLOTZHEIM;68730;68;HAUT RHIN;1
68043;;Bollwiller;BOLLWILLER;68540;68;HAUT RHIN;1
68044;Le;Bonhomme;BONHOMME;68650;68;HAUT RHIN;1
68045;;Bourbach-le-Bas;BOURBACH-LE-BAS;68290;68;HAUT RHIN;1
68046;;Bourbach-le-Haut;BOURBACH-LE-HAUT;68290;68;HAUT RHIN;1
68049;;Bouxwiller;BOUXWILLER;68480;68;HAUT RHIN;1
68050;;Bréchaumont;BRECHAUMONT;68210;68;HAUT RHIN;1
68051;;Breitenbach-Haut-Rhin;BREITENBACH-HAUT-RHIN;68380;68;HAUT RHIN;1
68052;;Bretten;BRETTEN;68780;68;HAUT RHIN;1
68054;;Brinckheim;BRINCKHEIM;68870;68;HAUT RHIN;1
68055;;Bruebach;BRUEBACH;68440;68;HAUT RHIN;1
68056;;Brunstatt;BRUNSTATT;68350;68;HAUT RHIN;1
68057;;Buethwiller;BUETHWILLER;68210;68;HAUT RHIN;1
68058;;Buhl;BUHL;68530;68;HAUT RHIN;1
68059;;Burnhaupt-le-Bas;BURNHAUPT-LE-BAS;68520;68;HAUT RHIN;1
68060;;Burnhaupt-le-Haut;BURNHAUPT-LE-HAUT;68520;68;HAUT RHIN;1
68061;;Buschwiller;BUSCHWILLER;68220;68;HAUT RHIN;1
68062;;Carspach;CARSPACH;68130;68;HAUT RHIN;1
68063;;Cernay;CERNAY;68700;68;HAUT RHIN;1
68064;;Chalampé;CHALAMPE;68490;68;HAUT RHIN;1
68065;;Chavannes-sur-l'Étang;CHAVANNES-SUR-L'ETANG;68210;68;HAUT RHIN;1
68066;;Colmar;COLMAR;68000;68;HAUT RHIN;1
68067;;Courtavon;COURTAVON;68480;68;HAUT RHIN;1
68068;;Dannemarie;DANNEMARIE;68210;68;HAUT RHIN;1
68069;;Dessenheim;DESSENHEIM;68600;68;HAUT RHIN;1
68070;;Didenheim;DIDENHEIM;68350;68;HAUT RHIN;1
68071;;Diefmatten;DIEFMATTEN;68780;68;HAUT RHIN;1
68072;;Dietwiller;DIETWILLER;68440;68;HAUT RHIN;1
68073;;Dolleren;DOLLEREN;68290;68;HAUT RHIN;1
68074;;Durlinsdorf;DURLINSDORF;68480;68;HAUT RHIN;1
68075;;Durmenach;DURMENACH;68480;68;HAUT RHIN;1
68076;;Durrenentzen;DURRENENTZEN;68320;68;HAUT RHIN;1
68077;;Eglingen;EGLINGEN;68720;68;HAUT RHIN;1
68078;;Eguisheim;EGUISHEIM;68420;68;HAUT RHIN;1
68079;;Elbach;ELBACH;68210;68;HAUT RHIN;1
68080;;Emlingen;EMLINGEN;68130;68;HAUT RHIN;1
68081;;Saint-Bernard;SAINT-BERNARD;68720;68;HAUT RHIN;1
68082;;Ensisheim;ENSISHEIM;68190;68;HAUT RHIN;1
68083;;Eschbach-au-Val;ESCHBACH-AU-VAL;68140;68;HAUT RHIN;1
68084;;Eschentzwiller;ESCHENTZWILLER;68440;68;HAUT RHIN;1
68085;;Eteimbes;ETEIMBES;68210;68;HAUT RHIN;1
68086;;Falkwiller;FALKWILLER;68210;68;HAUT RHIN;1
68087;;Feldbach;FELDBACH;68640;68;HAUT RHIN;1
68088;;Feldkirch;FELDKIRCH;68540;68;HAUT RHIN;1
68089;;Fellering;FELLERING;68470;68;HAUT RHIN;1
68090;;Ferrette;FERRETTE;68480;68;HAUT RHIN;1
68091;;Fessenheim;FESSENHEIM;68740;68;HAUT RHIN;1
68092;;Fislis;FISLIS;68480;68;HAUT RHIN;1
68093;;Flaxlanden;FLAXLANDEN;68720;68;HAUT RHIN;1
68094;;Folgensbourg;FOLGENSBOURG;68220;68;HAUT RHIN;1
68095;;Fortschwihr;FORTSCHWIHR;68320;68;HAUT RHIN;1
68096;;Franken;FRANKEN;68130;68;HAUT RHIN;1
68097;;Fréland;FRELAND;68240;68;HAUT RHIN;1
68098;;Friesen;FRIESEN;68580;68;HAUT RHIN;1
68099;;Frœningen;FROENINGEN;68720;68;HAUT RHIN;1
68100;;Fulleren;FULLEREN;68210;68;HAUT RHIN;1
68101;;Galfingue;GALFINGUE;68990;68;HAUT RHIN;1
68102;;Geishouse;GEISHOUSE;68690;68;HAUT RHIN;1
68103;;Geispitzen;GEISPITZEN;68510;68;HAUT RHIN;1
68104;;Geiswasser;GEISWASSER;68600;68;HAUT RHIN;1
68105;;Gildwiller;GILDWILLER;68210;68;HAUT RHIN;1
68106;;Goldbach-Altenbach;GOLDBACH-ALTENBACH;68760;68;HAUT RHIN;1
68107;;Gommersdorf;GOMMERSDORF;68210;68;HAUT RHIN;1
68108;;Grentzingen;GRENTZINGEN;68960;68;HAUT RHIN;1
68109;;Griesbach-au-Val;GRIESBACH-AU-VAL;68140;68;HAUT RHIN;1
68110;;Grussenheim;GRUSSENHEIM;68320;68;HAUT RHIN;1
68111;;Gueberschwihr;GUEBERSCHWIHR;68420;68;HAUT RHIN;1
68112;;Guebwiller;GUEBWILLER;68500;68;HAUT RHIN;1
68113;;Guémar;GUEMAR;68970;68;HAUT RHIN;1
68114;;Guevenatten;GUEVENATTEN;68210;68;HAUT RHIN;1
68115;;Guewenheim;GUEWENHEIM;68116;68;HAUT RHIN;1
68116;;Gundolsheim;GUNDOLSHEIM;68250;68;HAUT RHIN;1
68117;;Gunsbach;GUNSBACH;68140;68;HAUT RHIN;1
68118;;Habsheim;HABSHEIM;68440;68;HAUT RHIN;1
68119;;Hagenbach;HAGENBACH;68210;68;HAUT RHIN;1
68120;;Hagenthal-le-Bas;HAGENTHAL-LE-BAS;68220;68;HAUT RHIN;1
68121;;Hagenthal-le-Haut;HAGENTHAL-LE-HAUT;68220;68;HAUT RHIN;1
68122;;Hartmannswiller;HARTMANNSWILLER;68500;68;HAUT RHIN;1
68123;;Hattstatt;HATTSTATT;68420;68;HAUT RHIN;1
68124;;Hausgauen;HAUSGAUEN;68130;68;HAUT RHIN;1
68125;;Hecken;HECKEN;68210;68;HAUT RHIN;1
68126;;Hégenheim;HEGENHEIM;68220;68;HAUT RHIN;1
68127;;Heidwiller;HEIDWILLER;68720;68;HAUT RHIN;1
68128;;Heimersdorf;HEIMERSDORF;68560;68;HAUT RHIN;1
68129;;Heimsbrunn;HEIMSBRUNN;68990;68;HAUT RHIN;1
68130;;Heiteren;HEITEREN;68600;68;HAUT RHIN;1
68131;;Heiwiller;HEIWILLER;68130;68;HAUT RHIN;1
68132;;Helfrantzkirch;HELFRANTZKIRCH;68510;68;HAUT RHIN;1
68133;;Henflingen;HENFLINGEN;68960;68;HAUT RHIN;1
68134;;Herrlisheim-près-Colmar;HERRLISHEIM-PRES-COLMAR;68420;68;HAUT RHIN;1
68135;;Hésingue;HESINGUE;68220;68;HAUT RHIN;1
68136;;Hettenschlag;HETTENSCHLAG;68600;68;HAUT RHIN;1
68137;;Hindlingen;HINDLINGEN;68580;68;HAUT RHIN;1
68138;;Hirsingue;HIRSINGUE;68560;68;HAUT RHIN;1
68139;;Hirtzbach;HIRTZBACH;68118;68;HAUT RHIN;1
68140;;Hirtzfelden;HIRTZFELDEN;68740;68;HAUT RHIN;1
68141;;Hochstatt;HOCHSTATT;68720;68;HAUT RHIN;1
68142;;Hohrod;HOHROD;68140;68;HAUT RHIN;1
68143;;Holtzwihr;HOLTZWIHR;68320;68;HAUT RHIN;1
68144;;Hombourg;HOMBOURG;68490;68;HAUT RHIN;1
68145;;Horbourg-Wihr;HORBOURG-WIHR;68180;68;HAUT RHIN;1
68146;;Houssen;HOUSSEN;68125;68;HAUT RHIN;1
68147;;Hunawihr;HUNAWIHR;68150;68;HAUT RHIN;1
68148;;Hundsbach;HUNDSBACH;68130;68;HAUT RHIN;1
68149;;Huningue;HUNINGUE;68330;68;HAUT RHIN;1
68150;;Husseren-les-Châteaux;HUSSEREN-LES-CHATEAUX;68420;68;HAUT RHIN;1
68151;;Husseren-Wesserling;HUSSEREN-WESSERLING;68470;68;HAUT RHIN;1
68152;;Illfurth;ILLFURTH;68720;68;HAUT RHIN;1
68153;;Illhaeusern;ILLHAEUSERN;68970;68;HAUT RHIN;1
68154;;Illzach;ILLZACH;68110;68;HAUT RHIN;1
68155;;Ingersheim;INGERSHEIM;68040;68;HAUT RHIN;1
68156;;Issenheim;ISSENHEIM;68500;68;HAUT RHIN;1
68157;;Jebsheim;JEBSHEIM;68320;68;HAUT RHIN;1
68158;;Jettingen;JETTINGEN;68130;68;HAUT RHIN;1
68159;;Jungholtz;JUNGHOLTZ;68500;68;HAUT RHIN;1
68160;;Kappelen;KAPPELEN;68510;68;HAUT RHIN;1
68161;;Katzenthal;KATZENTHAL;68230;68;HAUT RHIN;1
68162;;Kaysersberg;KAYSERSBERG;68240;68;HAUT RHIN;1
68163;;Kembs;KEMBS;68680;68;HAUT RHIN;1
68164;;Kientzheim;KIENTZHEIM;68240;68;HAUT RHIN;1
68165;;Kiffis;KIFFIS;68480;68;HAUT RHIN;1
68166;;Kingersheim;KINGERSHEIM;68260;68;HAUT RHIN;1
68167;;Kirchberg;KIRCHBERG;68290;68;HAUT RHIN;1
68168;;Knœringue;KNOERINGUE;68220;68;HAUT RHIN;1
68169;;Kœstlach;KOESTLACH;68480;68;HAUT RHIN;1
68170;;Kœtzingue;KOETZINGUE;68510;68;HAUT RHIN;1
68171;;Kruth;KRUTH;68820;68;HAUT RHIN;1
68172;;Kunheim;KUNHEIM;68320;68;HAUT RHIN;1
68173;;Labaroche;LABAROCHE;68910;68;HAUT RHIN;1
68174;;Landser;LANDSER;68440;68;HAUT RHIN;1
68175;;Lapoutroie;LAPOUTROIE;68650;68;HAUT RHIN;1
68176;;Largitzen;LARGITZEN;68580;68;HAUT RHIN;1
68177;;Lautenbach;LAUTENBACH;68610;68;HAUT RHIN;1
68178;;Lautenbachzell;LAUTENBACHZELL;68610;68;HAUT RHIN;1
68179;;Lauw;LAUW;68290;68;HAUT RHIN;1
68180;;Leimbach;LEIMBACH;68800;68;HAUT RHIN;1
68181;;Levoncourt;LEVONCOURT;68480;68;HAUT RHIN;1
68182;;Leymen;LEYMEN;68220;68;HAUT RHIN;1
68183;;Liebenswiller;LIEBENSWILLER;68220;68;HAUT RHIN;1
68184;;Liebsdorf;LIEBSDORF;68480;68;HAUT RHIN;1
68185;;Lièpvre;LIEPVRE;68660;68;HAUT RHIN;1
68186;;Ligsdorf;LIGSDORF;68480;68;HAUT RHIN;1
68187;;Linsdorf;LINSDORF;68480;68;HAUT RHIN;1
68188;;Linthal;LINTHAL;68610;68;HAUT RHIN;1
68189;;Logelheim;LOGELHEIM;68280;68;HAUT RHIN;1
68190;;Lucelle;LUCELLE;68480;68;HAUT RHIN;1
68191;;Luemschwiller;LUEMSCHWILLER;68720;68;HAUT RHIN;1
68192;;Valdieu-Lutran;VALDIEU-LUTRAN;68210;68;HAUT RHIN;1
68193;;Luttenbach-près-Munster;LUTTENBACH-PRES-MUNSTER;68140;68;HAUT RHIN;1
68194;;Lutter;LUTTER;68480;68;HAUT RHIN;1
68195;;Lutterbach;LUTTERBACH;68460;68;HAUT RHIN;1
68196;;Magny;MAGNY;68210;68;HAUT RHIN;1
68197;;Magstatt-le-Bas;MAGSTATT-LE-BAS;68510;68;HAUT RHIN;1
68198;;Magstatt-le-Haut;MAGSTATT-LE-HAUT;68510;68;HAUT RHIN;1
68199;;Malmerspach;MALMERSPACH;68550;68;HAUT RHIN;1
68200;;Manspach;MANSPACH;68210;68;HAUT RHIN;1
68201;;Masevaux;MASEVAUX;68290;68;HAUT RHIN;1
68202;;Mertzen;MERTZEN;68210;68;HAUT RHIN;1
68203;;Merxheim;MERXHEIM;68500;68;HAUT RHIN;1
68204;;Metzeral;METZERAL;68380;68;HAUT RHIN;1
68205;;Meyenheim;MEYENHEIM;68890;68;HAUT RHIN;1
68206;;Michelbach;MICHELBACH;68700;68;HAUT RHIN;1
68207;;Michelbach-le-Bas;MICHELBACH-LE-BAS;68730;68;HAUT RHIN;1
68208;;Michelbach-le-Haut;MICHELBACH-LE-HAUT;68220;68;HAUT RHIN;1
68209;;Mittelwihr;MITTELWIHR;68630;68;HAUT RHIN;1
68210;;Mittlach;MITTLACH;68380;68;HAUT RHIN;1
68211;;Mitzach;MITZACH;68470;68;HAUT RHIN;1
68212;;Mœrnach;MOERNACH;68480;68;HAUT RHIN;1
68213;;Mollau;MOLLAU;68470;68;HAUT RHIN;1
68214;;Montreux-Jeune;MONTREUX-JEUNE;68210;68;HAUT RHIN;1
68215;;Montreux-Vieux;MONTREUX-VIEUX;68210;68;HAUT RHIN;1
68216;;Mooslargue;MOOSLARGUE;68580;68;HAUT RHIN;1
68217;;Moosch;MOOSCH;68690;68;HAUT RHIN;1
68218;;Morschwiller-le-Bas;MORSCHWILLER-LE-BAS;68790;68;HAUT RHIN;1
68219;;Mortzwiller;MORTZWILLER;68780;68;HAUT RHIN;1
68221;;Muespach;MUESPACH;68640;68;HAUT RHIN;1
68222;;Muespach-le-Haut;MUESPACH-LE-HAUT;68640;68;HAUT RHIN;1
68223;;Muhlbach-sur-Munster;MUHLBACH-SUR-MUNSTER;68380;68;HAUT RHIN;1
68224;;Mulhouse;MULHOUSE;68100;68;HAUT RHIN;1
68225;;Munchhouse;MUNCHHOUSE;68740;68;HAUT RHIN;1
68226;;Munster;MUNSTER;68140;68;HAUT RHIN;1
68227;;Muntzenheim;MUNTZENHEIM;68320;68;HAUT RHIN;1
68228;;Munwiller;MUNWILLER;68250;68;HAUT RHIN;1
68229;;Murbach;MURBACH;68530;68;HAUT RHIN;1
68230;;Nambsheim;NAMBSHEIM;68740;68;HAUT RHIN;1
68231;;Neuf-Brisach;NEUF-BRISACH;68600;68;HAUT RHIN;1
68232;;Neuwiller;NEUWILLER;68220;68;HAUT RHIN;1
68233;;Niederbruck;NIEDERBRUCK;68290;68;HAUT RHIN;1
68234;;Niederentzen;NIEDERENTZEN;68250;68;HAUT RHIN;1
68235;;Niederhergheim;NIEDERHERGHEIM;68250;68;HAUT RHIN;1
68237;;Niedermorschwihr;NIEDERMORSCHWIHR;68230;68;HAUT RHIN;1
68238;;Niffer;NIFFER;68680;68;HAUT RHIN;1
68239;;Oberbruck;OBERBRUCK;68290;68;HAUT RHIN;1
68240;;Oberdorf;OBERDORF;68960;68;HAUT RHIN;1
68241;;Oberentzen;OBERENTZEN;68250;68;HAUT RHIN;1
68242;;Oberhergheim;OBERHERGHEIM;68250;68;HAUT RHIN;1
68243;;Oberlarg;OBERLARG;68480;68;HAUT RHIN;1
68244;;Obermorschwihr;OBERMORSCHWIHR;68420;68;HAUT RHIN;1
68245;;Obermorschwiller;OBERMORSCHWILLER;68130;68;HAUT RHIN;1
68246;;Obersaasheim;OBERSAASHEIM;68600;68;HAUT RHIN;1
68247;;Oderen;ODEREN;68830;68;HAUT RHIN;1
68248;;Oltingue;OLTINGUE;68480;68;HAUT RHIN;1
68249;;Orbey;ORBEY;68370;68;HAUT RHIN;1
68250;;Orschwihr;ORSCHWIHR;68500;68;HAUT RHIN;1
68251;;Osenbach;OSENBACH;68570;68;HAUT RHIN;1
68252;;Ostheim;OSTHEIM;68150;68;HAUT RHIN;1
68253;;Ottmarsheim;OTTMARSHEIM;68490;68;HAUT RHIN;1
68254;;Petit-Landau;PETIT-LANDAU;68490;68;HAUT RHIN;1
68255;;Pfaffenheim;PFAFFENHEIM;68250;68;HAUT RHIN;1
68256;;Pfastatt;PFASTATT;68120;68;HAUT RHIN;1
68257;;Pfetterhouse;PFETTERHOUSE;68480;68;HAUT RHIN;1
68258;;Pulversheim;PULVERSHEIM;68840;68;HAUT RHIN;1
68259;;Raedersdorf;RAEDERSDORF;68480;68;HAUT RHIN;1
68260;;Raedersheim;RAEDERSHEIM;68190;68;HAUT RHIN;1
68261;;Rammersmatt;RAMMERSMATT;68800;68;HAUT RHIN;1
68262;;Ranspach;RANSPACH;68470;68;HAUT RHIN;1
68263;;Ranspach-le-Bas;RANSPACH-LE-BAS;68730;68;HAUT RHIN;1
68264;;Ranspach-le-Haut;RANSPACH-LE-HAUT;68220;68;HAUT RHIN;1
68265;;Rantzwiller;RANTZWILLER;68510;68;HAUT RHIN;1
68266;;Réguisheim;REGUISHEIM;68890;68;HAUT RHIN;1
68267;;Reiningue;REININGUE;68950;68;HAUT RHIN;1
68268;;Retzwiller;RETZWILLER;68210;68;HAUT RHIN;1
68269;;Ribeauvillé;RIBEAUVILLE;68150;68;HAUT RHIN;1
68270;;Richwiller;RICHWILLER;68120;68;HAUT RHIN;1
68271;;Riedisheim;RIEDISHEIM;68400;68;HAUT RHIN;1
68272;;Riedwihr;RIEDWIHR;68320;68;HAUT RHIN;1
68273;;Riespach;RIESPACH;68640;68;HAUT RHIN;1
68274;;Rimbach-près-Guebwiller;RIMBACH-PRES-GUEBWILLER;68500;68;HAUT RHIN;1
68275;;Rimbach-près-Masevaux;RIMBACH-PRES-MASEVAUX;68290;68;HAUT RHIN;1
68276;;Rimbachzell;RIMBACHZELL;68500;68;HAUT RHIN;1
68277;;Riquewihr;RIQUEWIHR;68340;68;HAUT RHIN;1
68278;;Rixheim;RIXHEIM;68170;68;HAUT RHIN;1
68279;;Roderen;RODEREN;68800;68;HAUT RHIN;1
68280;;Rodern;RODERN;68590;68;HAUT RHIN;1
68281;;Roggenhouse;ROGGENHOUSE;68740;68;HAUT RHIN;1
68282;;Romagny;ROMAGNY;68210;68;HAUT RHIN;1
68283;;Rombach-le-Franc;ROMBACH-LE-FRANC;68660;68;HAUT RHIN;1
68284;;Roppentzwiller;ROPPENTZWILLER;68480;68;HAUT RHIN;1
68285;;Rorschwihr;RORSCHWIHR;68590;68;HAUT RHIN;1
68286;;Rosenau;ROSENAU;68128;68;HAUT RHIN;1
68287;;Rouffach;ROUFFACH;68250;68;HAUT RHIN;1
68288;;Ruederbach;RUEDERBACH;68560;68;HAUT RHIN;1
68289;;Ruelisheim;RUELISHEIM;68270;68;HAUT RHIN;1
68290;;Rustenhart;RUSTENHART;68740;68;HAUT RHIN;1
68291;;Rumersheim-le-Haut;RUMERSHEIM-LE-HAUT;68740;68;HAUT RHIN;1
68292;;Saint-Amarin;SAINT-AMARIN;68550;68;HAUT RHIN;1
68293;;Saint-Cosme;SAINT-COSME;68210;68;HAUT RHIN;1
68294;;Sainte-Croix-aux-Mines;SAINTE-CROIX-AUX-MINES;68160;68;HAUT RHIN;1
68295;;Sainte-Croix-en-Plaine;SAINTE-CROIX-EN-PLAINE;68127;68;HAUT RHIN;1
68296;;Saint-Hippolyte;SAINT-HIPPOLYTE;68590;68;HAUT RHIN;1
68297;;Saint-Louis;SAINT-LOUIS;68300;68;HAUT RHIN;1
68298;;Sainte-Marie-aux-Mines;SAINTE-MARIE-AUX-MINES;68160;68;HAUT RHIN;1
68299;;Saint-Ulrich;SAINT-ULRICH;68210;68;HAUT RHIN;1
68300;;Sausheim;SAUSHEIM;68390;68;HAUT RHIN;1
68301;;Schlierbach;SCHLIERBACH;68440;68;HAUT RHIN;1
68302;;Schweighouse-Thann;SCHWEIGHOUSE-THANN;68520;68;HAUT RHIN;1
68303;;Schwoben;SCHWOBEN;68130;68;HAUT RHIN;1
68304;;Sentheim;SENTHEIM;68780;68;HAUT RHIN;1
68305;;Seppois-le-Bas;SEPPOIS-LE-BAS;68580;68;HAUT RHIN;1
68306;;Seppois-le-Haut;SEPPOIS-LE-HAUT;68580;68;HAUT RHIN;1
68307;;Sewen;SEWEN;68290;68;HAUT RHIN;1
68308;;Sickert;SICKERT;68290;68;HAUT RHIN;1
68309;;Sierentz;SIERENTZ;68510;68;HAUT RHIN;1
68310;;Sigolsheim;SIGOLSHEIM;68240;68;HAUT RHIN;1
68311;;Sondernach;SONDERNACH;68380;68;HAUT RHIN;1
68312;;Sondersdorf;SONDERSDORF;68480;68;HAUT RHIN;1
68313;;Soppe-le-Bas;SOPPE-LE-BAS;68780;68;HAUT RHIN;1
68314;;Soppe-le-Haut;SOPPE-LE-HAUT;68780;68;HAUT RHIN;1
68315;;Soultz-Haut-Rhin;SOULTZ-HAUT-RHIN;68360;68;HAUT RHIN;1
68316;;Soultzbach-les-Bains;SOULTZBACH-LES-BAINS;68230;68;HAUT RHIN;1
68317;;Soultzeren;SOULTZEREN;68140;68;HAUT RHIN;1
68318;;Soultzmatt;SOULTZMATT;68570;68;HAUT RHIN;1
68319;;Spechbach-le-Bas;SPECHBACH-LE-BAS;68720;68;HAUT RHIN;1
68320;;Spechbach-le-Haut;SPECHBACH-LE-HAUT;68720;68;HAUT RHIN;1
68321;;Staffelfelden;STAFFELFELDEN;68850;68;HAUT RHIN;1
68322;;Steinbach;STEINBACH;68700;68;HAUT RHIN;1
68323;;Steinbrunn-le-Bas;STEINBRUNN-LE-BAS;68440;68;HAUT RHIN;1
68324;;Steinbrunn-le-Haut;STEINBRUNN-LE-HAUT;68440;68;HAUT RHIN;1
68325;;Steinsoultz;STEINSOULTZ;68640;68;HAUT RHIN;1
68326;;Sternenberg;STERNENBERG;68780;68;HAUT RHIN;1
68327;;Stetten;STETTEN;68510;68;HAUT RHIN;1
68328;;Storckensohn;STORCKENSOHN;68470;68;HAUT RHIN;1
68329;;Stosswihr;STOSSWIHR;68140;68;HAUT RHIN;1
68330;;Strueth;STRUETH;68580;68;HAUT RHIN;1
68331;;Sundhoffen;SUNDHOFFEN;68280;68;HAUT RHIN;1
68332;;Tagolsheim;TAGOLSHEIM;68720;68;HAUT RHIN;1
68333;;Tagsdorf;TAGSDORF;68130;68;HAUT RHIN;1
68334;;Thann;THANN;68800;68;HAUT RHIN;1
68335;;Thannenkirch;THANNENKIRCH;68590;68;HAUT RHIN;1
68336;;Traubach-le-Bas;TRAUBACH-LE-BAS;68210;68;HAUT RHIN;1
68337;;Traubach-le-Haut;TRAUBACH-LE-HAUT;68210;68;HAUT RHIN;1
68338;;Turckheim;TURCKHEIM;68230;68;HAUT RHIN;1
68340;;Ueberstrass;UEBERSTRASS;68580;68;HAUT RHIN;1
68341;;Uffheim;UFFHEIM;68510;68;HAUT RHIN;1
68342;;Uffholtz;UFFHOLTZ;68700;68;HAUT RHIN;1
68343;;Ungersheim;UNGERSHEIM;68190;68;HAUT RHIN;1
68344;;Urbès;URBES;68121;68;HAUT RHIN;1
68345;;Urschenheim;URSCHENHEIM;68320;68;HAUT RHIN;1
68347;;Vieux-Ferrette;VIEUX-FERRETTE;68480;68;HAUT RHIN;1
68348;;Vieux-Thann;VIEUX-THANN;68800;68;HAUT RHIN;1
68349;;Village-Neuf;VILLAGE-NEUF;68128;68;HAUT RHIN;1
68350;;Vœgtlinshoffen;VOEGTLINSHOFFEN;68420;68;HAUT RHIN;1
68351;;Vogelgrun;VOGELGRUN;68600;68;HAUT RHIN;1
68352;;Volgelsheim;VOLGELSHEIM;68600;68;HAUT RHIN;1
68353;;Wahlbach;WAHLBACH;68130;68;HAUT RHIN;1
68354;;Walbach;WALBACH;68230;68;HAUT RHIN;1
68355;;Waldighofen;WALDIGHOFEN;68640;68;HAUT RHIN;1
68356;;Walheim;WALHEIM;68130;68;HAUT RHIN;1
68357;;Waltenheim;WALTENHEIM;68510;68;HAUT RHIN;1
68358;;Wasserbourg;WASSERBOURG;68230;68;HAUT RHIN;1
68359;;Wattwiller;WATTWILLER;68700;68;HAUT RHIN;1
68360;;Weckolsheim;WECKOLSHEIM;68600;68;HAUT RHIN;1
68361;;Wegscheid;WEGSCHEID;68290;68;HAUT RHIN;1
68362;;Wentzwiller;WENTZWILLER;68220;68;HAUT RHIN;1
68363;;Werentzhouse;WERENTZHOUSE;68480;68;HAUT RHIN;1
68364;;Westhalten;WESTHALTEN;68250;68;HAUT RHIN;1
68365;;Wettolsheim;WETTOLSHEIM;68920;68;HAUT RHIN;1
68366;;Wickerschwihr;WICKERSCHWIHR;68320;68;HAUT RHIN;1
68367;;Widensolen;WIDENSOLEN;68320;68;HAUT RHIN;1
68368;;Wihr-au-Val;WIHR-AU-VAL;68230;68;HAUT RHIN;1
68370;;Wildenstein;WILDENSTEIN;68820;68;HAUT RHIN;1
68371;;Willer;WILLER;68960;68;HAUT RHIN;1
68372;;Willer-sur-Thur;WILLER-SUR-THUR;68760;68;HAUT RHIN;1
68373;;Winkel;WINKEL;68480;68;HAUT RHIN;1
68374;;Wintzenheim;WINTZENHEIM;68920;68;HAUT RHIN;1
68375;;Wittelsheim;WITTELSHEIM;68310;68;HAUT RHIN;1
68376;;Wittenheim;WITTENHEIM;68270;68;HAUT RHIN;1
68377;;Wittersdorf;WITTERSDORF;68130;68;HAUT RHIN;1
68378;;Wolfersdorf;WOLFERSDORF;68210;68;HAUT RHIN;1
68379;;Wolfgantzen;WOLFGANTZEN;68600;68;HAUT RHIN;1
68380;;Wolschwiller;WOLSCHWILLER;68480;68;HAUT RHIN;1
68381;;Wuenheim;WUENHEIM;68500;68;HAUT RHIN;1
68382;;Zaessingue;ZAESSINGUE;68130;68;HAUT RHIN;1
68383;;Zellenberg;ZELLENBERG;68340;68;HAUT RHIN;1
68384;;Zillisheim;ZILLISHEIM;68720;68;HAUT RHIN;1
68385;;Zimmerbach;ZIMMERBACH;68230;68;HAUT RHIN;1
68386;;Zimmersheim;ZIMMERSHEIM;68440;68;HAUT RHIN;1
69001;;Affoux;AFFOUX;69170;69;RHONE;1
69002;;Aigueperse;AIGUEPERSE;69790;69;RHONE;1
69003;;Albigny-sur-Saône;ALBIGNY-SUR-SAONE;69250;69;RHONE;1
69004;;Alix;ALIX;69380;69;RHONE;1
69005;;Ambérieux;AMBERIEUX;69480;69;RHONE;1
69006;;Amplepuis;AMPLEPUIS;69550;69;RHONE;1
69007;;Ampuis;AMPUIS;69420;69;RHONE;1
69008;;Ancy;ANCY;69490;69;RHONE;1
69009;;Anse;ANSE;69480;69;RHONE;1
69010;L';Arbresle;ARBRESLE;69210;69;RHONE;1
69012;Les;Ardillats;ARDILLATS;69430;69;RHONE;1
69013;;Arnas;ARNAS;69400;69;RHONE;1
69014;;Aveize;AVEIZE;69610;69;RHONE;1
69015;;Avenas;AVENAS;69430;69;RHONE;1
69016;;Azolette;AZOLETTE;69790;69;RHONE;1
69017;;Bagnols;BAGNOLS;69620;69;RHONE;1
69018;;Beaujeu;BEAUJEU;69430;69;RHONE;1
69019;;Belleville;BELLEVILLE;69220;69;RHONE;1
69020;;Belmont-d'Azergues;BELMONT-D'AZERGUES;69380;69;RHONE;1
69021;;Bessenay;BESSENAY;69690;69;RHONE;1
69022;;Bibost;BIBOST;69690;69;RHONE;1
69023;;Blacé;BLACE;69460;69;RHONE;1
69024;Le;Bois-d'Oingt;BOIS-D'OINGT;69620;69;RHONE;1
69025;;Bourg-de-Thizy;BOURG-DE-THIZY;69240;69;RHONE;1
69026;Le;Breuil;BREUIL;69620;69;RHONE;1
69027;;Brignais;BRIGNAIS;69530;69;RHONE;1
69028;;Brindas;BRINDAS;69126;69;RHONE;1
69029;;Bron;BRON;69500;69;RHONE;1
69030;;Brullioles;BRULLIOLES;69690;69;RHONE;1
69031;;Brussieu;BRUSSIEU;69690;69;RHONE;1
69032;;Bully;BULLY;69210;69;RHONE;1
69033;;Cailloux-sur-Fontaines;CAILLOUX-SUR-FONTAINES;69270;69;RHONE;1
69034;;Caluire-et-Cuire;CALUIRE-ET-CUIRE;69300;69;RHONE;1
69035;;Cenves;CENVES;69840;69;RHONE;1
69036;;Cercié;CERCIE;69220;69;RHONE;1
69037;;Chambost-Allières;CHAMBOST-ALLIERES;69870;69;RHONE;1
69038;;Chambost-Longessaigne;CHAMBOST-LONGESSAIGNE;69770;69;RHONE;1
69039;;Chamelet;CHAMELET;69620;69;RHONE;1
69040;;Champagne-au-Mont-d'Or;CHAMPAGNE-AU-MONT-D'OR;69410;69;RHONE;1
69041;La;Chapelle-de-Mardore;CHAPELLE-DE-MARDORE;69240;69;RHONE;1
69042;La;Chapelle-sur-Coise;CHAPELLE-SUR-COISE;69590;69;RHONE;1
69043;;Chaponost;CHAPONOST;69630;69;RHONE;1
69044;;Charbonnières-les-Bains;CHARBONNIERES-LES-BAINS;69260;69;RHONE;1
69045;;Charentay;CHARENTAY;69220;69;RHONE;1
69046;;Charly;CHARLY;69390;69;RHONE;1
69047;;Charnay;CHARNAY;69380;69;RHONE;1
69048;;Chassagny;CHASSAGNY;69700;69;RHONE;1
69049;;Chasselay;CHASSELAY;69380;69;RHONE;1
69050;;Châtillon;CHATILLON;69380;69;RHONE;1
69051;;Chaussan;CHAUSSAN;69440;69;RHONE;1
69052;;Chazay-d'Azergues;CHAZAY-D'AZERGUES;69380;69;RHONE;1
69053;;Chénas;CHENAS;69840;69;RHONE;1
69054;;Chénelette;CHENELETTE;69430;69;RHONE;1
69055;Les;Chères;CHERES;69380;69;RHONE;1
69056;;Chessy;CHESSY;69380;69;RHONE;1
69057;;Chevinay;CHEVINAY;69210;69;RHONE;1
69058;;Chiroubles;CHIROUBLES;69115;69;RHONE;1
69059;;Civrieux-d'Azergues;CIVRIEUX-D'AZERGUES;69380;69;RHONE;1
69060;;Claveisolles;CLAVEISOLLES;69870;69;RHONE;1
69061;;Cogny;COGNY;69640;69;RHONE;1
69062;;Coise;COISE;69590;69;RHONE;1
69063;;Collonges-au-Mont-d'Or;COLLONGES-AU-MONT-D'OR;69660;69;RHONE;1
69064;;Condrieu;CONDRIEU;69420;69;RHONE;1
69065;;Corcelles-en-Beaujolais;CORCELLES-EN-BEAUJOLAIS;69220;69;RHONE;1
69066;;Cours-la-Ville;COURS-LA-VILLE;69470;69;RHONE;1
69067;;Courzieu;COURZIEU;69690;69;RHONE;1
69068;;Couzon-au-Mont-d'Or;COUZON-AU-MONT-D'OR;69270;69;RHONE;1
69069;;Craponne;CRAPONNE;69290;69;RHONE;1
69070;;Cublize;CUBLIZE;69550;69;RHONE;1
69071;;Curis-au-Mont-d'Or;CURIS-AU-MONT-D'OR;69250;69;RHONE;1
69072;;Dardilly;DARDILLY;69570;69;RHONE;1
69073;;Dareizé;DAREIZE;69490;69;RHONE;1
69074;;Denicé;DENICE;69640;69;RHONE;1
69075;;Dième;DIEME;69170;69;RHONE;1
69076;;Dommartin;DOMMARTIN;69380;69;RHONE;1
69077;;Dracé;DRACE;69220;69;RHONE;1
69078;;Duerne;DUERNE;69850;69;RHONE;1
69080;;Échalas;ECHALAS;69700;69;RHONE;1
69081;;Écully;ECULLY;69130;69;RHONE;1
69082;;Émeringes;EMERINGES;69840;69;RHONE;1
69083;;Éveux;EVEUX;69210;69;RHONE;1
69084;;Fleurie;FLEURIE;69820;69;RHONE;1
69085;;Fleurieu-sur-Saône;FLEURIEU-SUR-SAONE;69250;69;RHONE;1
69086;;Fleurieux-sur-l'Arbresle;FLEURIEUX-SUR-L'ARBRESLE;69210;69;RHONE;1
69087;;Fontaines-Saint-Martin;FONTAINES-SAINT-MARTIN;69270;69;RHONE;1
69088;;Fontaines-sur-Saône;FONTAINES-SUR-SAONE;69270;69;RHONE;1
69089;;Francheville;FRANCHEVILLE;69340;69;RHONE;1
69090;;Frontenas;FRONTENAS;69620;69;RHONE;1
69091;;Givors;GIVORS;69700;69;RHONE;1
69092;;Gleizé;GLEIZE;69400;69;RHONE;1
69093;;Grandris;GRANDRIS;69870;69;RHONE;1
69094;;Grézieu-la-Varenne;GREZIEU-LA-VARENNE;69290;69;RHONE;1
69095;;Grézieu-le-Marché;GREZIEU-LE-MARCHE;69610;69;RHONE;1
69096;;Grigny;GRIGNY;69520;69;RHONE;1
69097;Les;Haies;HAIES;69420;69;RHONE;1
69098;Les;Halles;HALLES;69610;69;RHONE;1
69099;;Haute-Rivoire;HAUTE-RIVOIRE;69610;69;RHONE;1
69100;;Irigny;IRIGNY;69540;69;RHONE;1
69101;;Jarnioux;JARNIOUX;69640;69;RHONE;1
69102;;Joux;JOUX;69170;69;RHONE;1
69103;;Juliénas;JULIENAS;69840;69;RHONE;1
69104;;Jullié;JULLIE;69840;69;RHONE;1
69105;;Lacenas;LACENAS;69640;69;RHONE;1
69106;;Lachassagne;LACHASSAGNE;69480;69;RHONE;1
69107;;Lamure-sur-Azergues;LAMURE-SUR-AZERGUES;69870;69;RHONE;1
69108;;Lancié;LANCIE;69220;69;RHONE;1
69109;;Lantignié;LANTIGNIE;69430;69;RHONE;1
69110;;Larajasse;LARAJASSE;69590;69;RHONE;1
69111;;Légny;LEGNY;69620;69;RHONE;1
69112;;Lentilly;LENTILLY;69210;69;RHONE;1
69113;;Létra;LETRA;69620;69;RHONE;1
69114;;Liergues;LIERGUES;69400;69;RHONE;1
69115;;Limas;LIMAS;69400;69;RHONE;1
69116;;Limonest;LIMONEST;69760;69;RHONE;1
69117;;Lissieu;LISSIEU;69380;69;RHONE;1
69118;;Loire-sur-Rhône;LOIRE-SUR-RHONE;69700;69;RHONE;1
69119;;Longes;LONGES;69420;69;RHONE;1
69120;;Longessaigne;LONGESSAIGNE;69770;69;RHONE;1
69121;;Lozanne;LOZANNE;69380;69;RHONE;1
69122;;Lucenay;LUCENAY;69480;69;RHONE;1
69123;;Lyon;LYON;;69;;
69124;;Marchampt;MARCHAMPT;69430;69;RHONE;1
69125;;Marcilly-d'Azergues;MARCILLY-D'AZERGUES;69380;69;RHONE;1
69126;;Marcy;MARCY;69480;69;RHONE;1
69127;;Marcy-l'Étoile;MARCY-L'ETOILE;69280;69;RHONE;1
69128;;Mardore;MARDORE;69240;69;RHONE;1
69129;;Marnand;MARNAND;69240;69;RHONE;1
69130;;Meaux-la-Montagne;MEAUX-LA-MONTAGNE;69550;69;RHONE;1
69131;;Messimy;MESSIMY;69510;69;RHONE;1
69132;;Meys;MEYS;69610;69;RHONE;1
69133;;Millery;MILLERY;69390;69;RHONE;1
69134;;Moiré;MOIRE;69620;69;RHONE;1
69135;;Monsols;MONSOLS;69860;69;RHONE;1
69136;;Montagny;MONTAGNY;69700;69;RHONE;1
69137;;Montmelas-Saint-Sorlin;MONTMELAS-SAINT-SORLIN;69640;69;RHONE;1
69138;;Montromant;MONTROMANT;69610;69;RHONE;1
69139;;Montrottier;MONTROTTIER;69770;69;RHONE;1
69140;;Morancé;MORANCE;69480;69;RHONE;1
69141;;Mornant;MORNANT;69440;69;RHONE;1
69142;La;Mulatière;MULATIERE;69350;69;RHONE;1
69143;;Neuville-sur-Saône;NEUVILLE-SUR-SAONE;69250;69;RHONE;1
69144;;Nuelles;NUELLES;69210;69;RHONE;1
69145;;Odenas;ODENAS;69460;69;RHONE;1
69146;;Oingt;OINGT;69620;69;RHONE;1
69147;Les;Olmes;OLMES;69490;69;RHONE;1
69148;;Orliénas;ORLIENAS;69530;69;RHONE;1
69149;;Oullins;OULLINS;69600;69;RHONE;1
69150;;Ouroux;OUROUX;69860;69;RHONE;1
69151;Le;Perréon;PERREON;69460;69;RHONE;1
69152;;Pierre-Bénite;PIERRE-BENITE;69310;69;RHONE;1
69153;;Poleymieux-au-Mont-d'Or;POLEYMIEUX-AU-MONT-D'OR;69250;69;RHONE;1
69154;;Pollionnay;POLLIONNAY;69290;69;RHONE;1
69155;;Pomeys;POMEYS;69590;69;RHONE;1
69156;;Pommiers;POMMIERS;69480;69;RHONE;1
69157;;Pontcharra-sur-Turdine;PONTCHARRA-SUR-TURDINE;69490;69;RHONE;1
69158;;Pont-Trambouze;PONT-TRAMBOUZE;69240;69;RHONE;1
69159;;Pouilly-le-Monial;POUILLY-LE-MONIAL;69400;69;RHONE;1
69160;;Poule-les-Écharmeaux;POULE-LES-ECHARMEAUX;69870;69;RHONE;1
69161;;Propières;PROPIERES;69790;69;RHONE;1
69162;;Quincié-en-Beaujolais;QUINCIE-EN-BEAUJOLAIS;69430;69;RHONE;1
69163;;Quincieux;QUINCIEUX;69650;69;RHONE;1
69164;;Ranchal;RANCHAL;69470;69;RHONE;1
69165;;Régnié-Durette;REGNIE-DURETTE;69430;69;RHONE;1
69166;;Riverie;RIVERIE;69440;69;RHONE;1
69167;;Rivolet;RIVOLET;69640;69;RHONE;1
69168;;Rochetaillée-sur-Saône;ROCHETAILLEE-SUR-SAONE;69270;69;RHONE;1
69169;;Ronno;RONNO;69550;69;RHONE;1
69170;;Rontalon;RONTALON;69510;69;RHONE;1
69171;;Sain-Bel;SAIN-BEL;69210;69;RHONE;1
69172;;Salles-Arbuissonnas-en-Beaujolais;SALLES-ARBUISSONNAS-EN-BEAUJOLAIS;69460;69;RHONE;1
69173;;Sarcey;SARCEY;69490;69;RHONE;1
69174;Les;Sauvages;SAUVAGES;69170;69;RHONE;1
69175;;Savigny;SAVIGNY;69210;69;RHONE;1
69176;;Soucieu-en-Jarrest;SOUCIEU-EN-JARREST;69510;69;RHONE;1
69177;;Sourcieux-les-Mines;SOURCIEUX-LES-MINES;69210;69;RHONE;1
69178;;Souzy;SOUZY;69610;69;RHONE;1
69179;;Saint-Andéol-le-Château;SAINT-ANDEOL-LE-CHATEAU;69700;69;RHONE;1
69180;;Saint-André-la-Côte;SAINT-ANDRE-LA-COTE;69440;69;RHONE;1
69181;;Saint-Appolinaire;SAINT-APPOLINAIRE;69170;69;RHONE;1
69182;;Saint-Bonnet-des-Bruyères;SAINT-BONNET-DES-BRUYERES;69790;69;RHONE;1
69183;;Saint-Bonnet-le-Troncy;SAINT-BONNET-LE-TRONCY;69870;69;RHONE;1
69184;;Sainte-Catherine;SAINTE-CATHERINE;69440;69;RHONE;1
69185;;Saint-Christophe;SAINT-CHRISTOPHE;69860;69;RHONE;1
69186;;Saint-Clément-de-Vers;SAINT-CLEMENT-DE-VERS;69790;69;RHONE;1
69187;;Saint-Clément-les-Places;SAINT-CLEMENT-LES-PLACES;69930;69;RHONE;1
69188;;Saint-Clément-sur-Valsonne;SAINT-CLEMENT-SUR-VALSONNE;69170;69;RHONE;1
69189;;Sainte-Colombe;SAINTE-COLOMBE;69560;69;RHONE;1
69190;;Sainte-Consorce;SAINTE-CONSORCE;69280;69;RHONE;1
69191;;Saint-Cyr-au-Mont-d'Or;SAINT-CYR-AU-MONT-D'OR;69450;69;RHONE;1
69192;;Saint-Cyr-le-Chatoux;SAINT-CYR-LE-CHATOUX;69870;69;RHONE;1
69193;;Saint-Cyr-sur-le-Rhône;SAINT-CYR-SUR-LE-RHONE;69560;69;RHONE;1
69194;;Saint-Didier-au-Mont-d'Or;SAINT-DIDIER-AU-MONT-D'OR;69370;69;RHONE;1
69195;;Saint-Didier-sous-Riverie;SAINT-DIDIER-SOUS-RIVERIE;69440;69;RHONE;1
69196;;Saint-Didier-sur-Beaujeu;SAINT-DIDIER-SUR-BEAUJEU;69430;69;RHONE;1
69197;;Saint-Étienne-des-Oullières;SAINT-ETIENNE-DES-OULLIERES;69460;69;RHONE;1
69198;;Saint-Étienne-la-Varenne;SAINT-ETIENNE-LA-VARENNE;69460;69;RHONE;1
69199;;Saint-Fons;SAINT-FONS;69190;69;RHONE;1
69200;;Saint-Forgeux;SAINT-FORGEUX;69490;69;RHONE;1
69201;;Sainte-Foy-l'Argentière;SAINTE-FOY-L'ARGENTIERE;69610;69;RHONE;1
69202;;Sainte-Foy-lès-Lyon;SAINTE-FOY-LES-LYON;69110;69;RHONE;1
69203;;Saint-Genis-l'Argentière;SAINT-GENIS-L'ARGENTIERE;69610;69;RHONE;1
69204;;Saint-Genis-Laval;SAINT-GENIS-LAVAL;69230;69;RHONE;1
69205;;Saint-Genis-les-Ollières;SAINT-GENIS-LES-OLLIERES;69290;69;RHONE;1
69206;;Saint-Georges-de-Reneins;SAINT-GEORGES-DE-RENEINS;69830;69;RHONE;1
69207;;Saint-Germain-au-Mont-d'Or;SAINT-GERMAIN-AU-MONT-D'OR;69650;69;RHONE;1
69208;;Saint-Germain-sur-l'Arbresle;SAINT-GERMAIN-SUR-L'ARBRESLE;69210;69;RHONE;1
69209;;Saint-Igny-de-Vers;SAINT-IGNY-DE-VERS;69790;69;RHONE;1
69210;;Saint-Jacques-des-Arrêts;SAINT-JACQUES-DES-ARRETS;69860;69;RHONE;1
69211;;Saint-Jean-d'Ardières;SAINT-JEAN-D'ARDIERES;69220;69;RHONE;1
69212;;Saint-Jean-des-Vignes;SAINT-JEAN-DES-VIGNES;69380;69;RHONE;1
69213;;Saint-Jean-de-Touslas;SAINT-JEAN-DE-TOUSLAS;69700;69;RHONE;1
69214;;Saint-Jean-la-Bussière;SAINT-JEAN-LA-BUSSIERE;69550;69;RHONE;1
69215;;Saint-Julien;SAINT-JULIEN;69640;69;RHONE;1
69216;;Saint-Julien-sur-Bibost;SAINT-JULIEN-SUR-BIBOST;69690;69;RHONE;1
69217;;Saint-Just-d'Avray;SAINT-JUST-D'AVRAY;69870;69;RHONE;1
69218;;Saint-Lager;SAINT-LAGER;69220;69;RHONE;1
69219;;Saint-Laurent-d'Agny;SAINT-LAURENT-D'AGNY;69440;69;RHONE;1
69220;;Saint-Laurent-de-Chamousset;SAINT-LAURENT-DE-CHAMOUSSET;69930;69;RHONE;1
69221;;Saint-Laurent-de-Vaux;SAINT-LAURENT-DE-VAUX;69670;69;RHONE;1
69222;;Saint-Laurent-d'Oingt;SAINT-LAURENT-D'OINGT;69620;69;RHONE;1
69223;;Saint-Loup;SAINT-LOUP;69490;69;RHONE;1
69224;;Saint-Mamert;SAINT-MAMERT;69860;69;RHONE;1
69225;;Saint-Marcel-l'Éclairé;SAINT-MARCEL-L'ECLAIRE;69170;69;RHONE;1
69227;;Saint-Martin-en-Haut;SAINT-MARTIN-EN-HAUT;69850;69;RHONE;1
69228;;Saint-Maurice-sur-Dargoire;SAINT-MAURICE-SUR-DARGOIRE;69440;69;LOIRE;1
69229;;Saint-Nizier-d'Azergues;SAINT-NIZIER-D'AZERGUES;69870;69;RHONE;1
69230;;Sainte-Paule;SAINTE-PAULE;69620;69;RHONE;1
69231;;Saint-Pierre-la-Palud;SAINT-PIERRE-LA-PALUD;69210;69;RHONE;1
69233;;Saint-Romain-au-Mont-d'Or;SAINT-ROMAIN-AU-MONT-D'OR;69270;69;RHONE;1
69234;;Saint-Romain-de-Popey;SAINT-ROMAIN-DE-POPEY;69490;69;RHONE;1
69235;;Saint-Romain-en-Gal;SAINT-ROMAIN-EN-GAL;69560;69;RHONE;1
69236;;Saint-Romain-en-Gier;SAINT-ROMAIN-EN-GIER;69700;69;RHONE;1
69237;;Saint-Sorlin;SAINT-SORLIN;69440;69;RHONE;1
69238;;Saint-Symphorien-sur-Coise;SAINT-SYMPHORIEN-SUR-COISE;69590;69;RHONE;1
69239;;Saint-Vérand;SAINT-VERAND;69620;69;RHONE;1
69240;;Saint-Vincent-de-Reins;SAINT-VINCENT-DE-REINS;69240;69;RHONE;1
69241;;Taluyers;TALUYERS;69440;69;RHONE;1
69242;;Taponas;TAPONAS;69220;69;RHONE;1
69243;;Tarare;TARARE;69170;69;RHONE;1
69244;;Tassin-la-Demi-Lune;TASSIN-LA-DEMI-LUNE;69160;69;RHONE;1
69245;;Ternand;TERNAND;69620;69;RHONE;1
69246;;Theizé;THEIZE;69620;69;RHONE;1
69247;;Thel;THEL;69470;69;RHONE;1
69248;;Thizy;THIZY;69240;69;RHONE;1
69249;;Thurins;THURINS;69510;69;RHONE;1
69250;La;Tour-de-Salvagny;TOUR-DE-SALVAGNY;69890;69;RHONE;1
69251;;Trades;TRADES;69860;69;RHONE;1
69252;;Trèves;TREVES;69420;69;RHONE;1
69253;;Tupin-et-Semons;TUPIN-ET-SEMONS;69420;69;RHONE;1
69254;;Valsonne;VALSONNE;69170;69;RHONE;1
69255;;Vaugneray;VAUGNERAY;69670;69;RHONE;1
69256;;Vaulx-en-Velin;VAULX-EN-VELIN;69120;69;RHONE;1
69257;;Vaux-en-Beaujolais;VAUX-EN-BEAUJOLAIS;69460;69;RHONE;1
69258;;Vauxrenard;VAUXRENARD;69820;69;RHONE;1
69259;;Vénissieux;VENISSIEUX;69200;69;RHONE;1
69260;;Vernaison;VERNAISON;69390;69;RHONE;1
69261;;Vernay;VERNAY;69430;69;RHONE;1
69263;;Villechenève;VILLECHENEVE;69770;69;RHONE;1
69264;;Villefranche-sur-Saône;VILLEFRANCHE-SUR-SAONE;69400;69;RHONE;1
69265;;Ville-sur-Jarnioux;VILLE-SUR-JARNIOUX;69640;69;RHONE;1
69266;;Villeurbanne;VILLEURBANNE;69100;69;RHONE;1
69267;;Villié-Morgon;VILLIE-MORGON;69910;69;RHONE;1
69268;;Vourles;VOURLES;69390;69;RHONE;1
69269;;Yzeron;YZERON;69510;69;RHONE;1
69270;;Chaponnay;CHAPONNAY;69970;69;RHONE;1
69271;;Chassieu;CHASSIEU;69680;69;RHONE;1
69272;;Communay;COMMUNAY;69360;69;RHONE;1
69273;;Corbas;CORBAS;69960;69;RHONE;1
69275;;Décines-Charpieu;DECINES-CHARPIEU;69150;69;RHONE;1
69276;;Feyzin;FEYZIN;69320;69;RHONE;1
69277;;Genas;GENAS;69740;69;RHONE;1
69278;;Genay;GENAY;69730;69;RHONE;1
69279;;Jonage;JONAGE;69330;69;RHONE;1
69280;;Jons;JONS;69330;69;RHONE;1
69281;;Marennes;MARENNES;69970;69;RHONE;1
69282;;Meyzieu;MEYZIEU;69330;69;RHONE;1
69283;;Mions;MIONS;69780;69;RHONE;1
69284;;Montanay;MONTANAY;69250;69;RHONE;1
69285;;Pusignan;PUSIGNAN;69330;69;RHONE;1
69286;;Rillieux-la-Pape;RILLIEUX-LA-PAPE;69140;69;RHONE;1
69287;;Saint-Bonnet-de-Mure;SAINT-BONNET-DE-MURE;69720;69;RHONE;1
69288;;Saint-Laurent-de-Mure;SAINT-LAURENT-DE-MURE;69720;69;RHONE;1
69289;;Saint-Pierre-de-Chandieu;SAINT-PIERRE-DE-CHANDIEU;69780;69;RHONE;1
69290;;Saint-Priest;SAINT-PRIEST;69800;69;RHONE;1
69291;;Saint-Symphorien-d'Ozon;SAINT-SYMPHORIEN-D'OZON;69360;69;RHONE;1
69292;;Sathonay-Camp;SATHONAY-CAMP;69580;69;RHONE;1
69293;;Sathonay-Village;SATHONAY-VILLAGE;69580;69;RHONE;1
69294;;Sérézin-du-Rhône;SEREZIN-DU-RHONE;69360;69;RHONE;1
69295;;Simandres;SIMANDRES;69360;69;RHONE;1
69296;;Solaize;SOLAIZE;69360;69;RHONE;1
69297;;Ternay;TERNAY;69360;69;RHONE;1
69298;;Toussieu;TOUSSIEU;69780;69;RHONE;1
69299;;Colombier-Saugnieu;COLOMBIER-SAUGNIEU;69124;69;RHONE;1
70001;;Abelcourt;ABELCOURT;70300;70;HAUTE SAONE;1
70002;;Aboncourt-Gesincourt;ABONCOURT-GESINCOURT;70500;70;HAUTE SAONE;1
70003;;Achey;ACHEY;70180;70;HAUTE SAONE;1
70004;;Adelans-et-le-Val-de-Bithaine;ADELANS-ET-LE-VAL-DE-BITHAINE;70200;70;HAUTE SAONE;1
70005;;Aillevans;AILLEVANS;70110;70;HAUTE SAONE;1
70006;;Aillevillers-et-Lyaumont;AILLEVILLERS-ET-LYAUMONT;70320;70;HAUTE SAONE;1
70007;;Ailloncourt;AILLONCOURT;70300;70;HAUTE SAONE;1
70008;;Ainvelle;AINVELLE;70800;70;HAUTE SAONE;1
70009;;Aisey-et-Richecourt;AISEY-ET-RICHECOURT;70500;70;HAUTE SAONE;1
70010;;Alaincourt;ALAINCOURT;70210;70;HAUTE SAONE;1
70011;;Amage;AMAGE;70280;70;HAUTE SAONE;1
70012;;Amance;AMANCE;70160;70;HAUTE SAONE;1
70013;;Ambiévillers;AMBIEVILLERS;70210;70;HAUTE SAONE;1
70014;;Amblans-et-Velotte;AMBLANS-ET-VELOTTE;70200;70;HAUTE SAONE;1
70015;;Amoncourt;AMONCOURT;70170;70;HAUTE SAONE;1
70016;;Amont-et-Effreney;AMONT-ET-EFFRENEY;70310;70;HAUTE SAONE;1
70017;;Anchenoncourt-et-Chazel;ANCHENONCOURT-ET-CHAZEL;70210;70;HAUTE SAONE;1
70018;;Ancier;ANCIER;70100;70;HAUTE SAONE;1
70019;;Andelarre;ANDELARRE;70000;70;HAUTE SAONE;1
70020;;Andelarrot;ANDELARROT;70000;70;HAUTE SAONE;1
70021;;Andornay;ANDORNAY;70200;70;HAUTE SAONE;1
70022;;Angirey;ANGIREY;70700;70;HAUTE SAONE;1
70023;;Anjeux;ANJEUX;70800;70;HAUTE SAONE;1
70024;;Apremont;APREMONT;70100;70;HAUTE SAONE;1
70025;;Arbecey;ARBECEY;70160;70;HAUTE SAONE;1
70026;;Arc-lès-Gray;ARC-LES-GRAY;70100;70;HAUTE SAONE;1
70027;;Argillières;ARGILLIERES;70600;70;HAUTE SAONE;1
70028;;Aroz;AROZ;70360;70;HAUTE SAONE;1
70029;;Arpenans;ARPENANS;70200;70;HAUTE SAONE;1
70030;;Arsans;ARSANS;70100;70;HAUTE SAONE;1
70031;;Athesans-Étroitefontaine;ATHESANS-ETROITEFONTAINE;70110;70;HAUTE SAONE;1
70032;;Attricourt;ATTRICOURT;70100;70;HAUTE SAONE;1
70035;;Augicourt;AUGICOURT;70500;70;HAUTE SAONE;1
70036;;Aulx-lès-Cromary;AULX-LES-CROMARY;70190;70;HAUTE SAONE;1
70037;;Autet;AUTET;70180;70;HAUTE SAONE;1
70038;;Authoison;AUTHOISON;70190;70;HAUTE SAONE;1
70039;;Autoreille;AUTOREILLE;70700;70;HAUTE SAONE;1
70040;;Autrey-lès-Cerre;AUTREY-LES-CERRE;70110;70;HAUTE SAONE;1
70041;;Autrey-lès-Gray;AUTREY-LES-GRAY;70100;70;HAUTE SAONE;1
70042;;Autrey-le-Vay;AUTREY-LE-VAY;70110;70;HAUTE SAONE;1
70043;;Auvet-et-la-Chapelotte;AUVET-ET-LA-CHAPELOTTE;70100;70;HAUTE SAONE;1
70044;;Auxon;AUXON;70000;70;HAUTE SAONE;1
70045;;Avrigney-Virey;AVRIGNEY-VIREY;70150;70;HAUTE SAONE;1
70046;Les;Aynans;AYNANS;70200;70;HAUTE SAONE;1
70047;;Baignes;BAIGNES;70000;70;HAUTE SAONE;1
70048;;Bard-lès-Pesmes;BARD-LES-PESMES;70140;70;HAUTE SAONE;1
70049;;Barges;BARGES;70500;70;HAUTE SAONE;1
70050;La;Barre;BARRE;70190;70;HAUTE SAONE;1
70051;La;Basse-Vaivre;BASSE-VAIVRE;70210;70;HAUTE SAONE;1
70052;;Bassigney;BASSIGNEY;70800;70;HAUTE SAONE;1
70053;Les;Bâties;BATIES;70130;70;HAUTE SAONE;1
70054;;Battrans;BATTRANS;70100;70;HAUTE SAONE;1
70055;;Baudoncourt;BAUDONCOURT;70300;70;HAUTE SAONE;1
70056;;Baulay;BAULAY;70160;70;HAUTE SAONE;1
70057;;Bay;BAY;70150;70;HAUTE SAONE;1
70058;;Beaujeu-Saint-Vallier-Pierrejux-et-Quitteur;BEAUJEU-SAINT-VALLIER-PIERREJUX-ET-QUITTEUR;70100;70;HAUTE SAONE;1
70059;;Beaumotte-Aubertans;BEAUMOTTE-AUBERTANS;70190;70;HAUTE SAONE;1
70060;;Beaumotte-lès-Pin;BEAUMOTTE-LES-PIN;70150;70;HAUTE SAONE;1
70061;;Belfahy;BELFAHY;70290;70;HAUTE SAONE;1
70062;;Belmont;BELMONT;70270;70;HAUTE SAONE;1
70063;;Belonchamp;BELONCHAMP;70270;70;HAUTE SAONE;1
70064;;Belverne;BELVERNE;70400;70;HAUTE SAONE;1
70065;;Besnans;BESNANS;70230;70;HAUTE SAONE;1
70066;;Betaucourt;BETAUCOURT;70500;70;HAUTE SAONE;1
70067;;Betoncourt-lès-Brotte;BETONCOURT-LES-BROTTE;70300;70;HAUTE SAONE;1
70069;;Betoncourt-Saint-Pancras;BETONCOURT-SAINT-PANCRAS;70210;70;HAUTE SAONE;1
70070;;Betoncourt-sur-Mance;BETONCOURT-SUR-MANCE;70500;70;HAUTE SAONE;1
70071;;Beulotte-Saint-Laurent;BEULOTTE-SAINT-LAURENT;70310;70;HAUTE SAONE;1
70072;;Beveuge;BEVEUGE;70110;70;HAUTE SAONE;1
70074;;Blondefontaine;BLONDEFONTAINE;70500;70;HAUTE SAONE;1
70075;;Bonboillon;BONBOILLON;70150;70;HAUTE SAONE;1
70076;;Bonnevent-Velloreille;BONNEVENT-VELLOREILLE;70700;70;HAUTE SAONE;1
70077;;Borey;BOREY;70110;70;HAUTE SAONE;1
70078;;Bougey;BOUGEY;70500;70;HAUTE SAONE;1
70079;;Bougnon;BOUGNON;70170;70;HAUTE SAONE;1
70080;;Bouhans-et-Feurg;BOUHANS-ET-FEURG;70100;70;HAUTE SAONE;1
70081;;Bouhans-lès-Lure;BOUHANS-LES-LURE;70200;70;HAUTE SAONE;1
70082;;Bouhans-lès-Montbozon;BOUHANS-LES-MONTBOZON;70230;70;HAUTE SAONE;1
70083;;Bouligney;BOULIGNEY;70800;70;HAUTE SAONE;1
70084;;Boulot;BOULOT;70190;70;HAUTE SAONE;1
70085;;Boult;BOULT;70190;70;HAUTE SAONE;1
70086;;Bourbévelle;BOURBEVELLE;70500;70;HAUTE SAONE;1
70087;;Bourguignon-lès-Conflans;BOURGUIGNON-LES-CONFLANS;70800;70;HAUTE SAONE;1
70088;;Bourguignon-lès-la-Charité;BOURGUIGNON-LES-LA-CHARITE;70190;70;HAUTE SAONE;1
70089;;Bourguignon-lès-Morey;BOURGUIGNON-LES-MOREY;70120;70;HAUTE SAONE;1
70090;;Boursières;BOURSIERES;70000;70;HAUTE SAONE;1
70091;;Bousseraucourt;BOUSSERAUCOURT;70500;70;HAUTE SAONE;1
70092;;Bresilley;BRESILLEY;70140;70;HAUTE SAONE;1
70093;;Breuches;BREUCHES;70300;70;HAUTE SAONE;1
70094;;Breuchotte;BREUCHOTTE;70280;70;HAUTE SAONE;1
70095;;Breurey-lès-Faverney;BREUREY-LES-FAVERNEY;70160;70;HAUTE SAONE;1
70096;;Brevilliers;BREVILLIERS;70400;70;HAUTE SAONE;1
70097;;Briaucourt;BRIAUCOURT;70800;70;HAUTE SAONE;1
70098;;Brotte-lès-Luxeuil;BROTTE-LES-LUXEUIL;70300;70;HAUTE SAONE;1
70099;;Brotte-lès-Ray;BROTTE-LES-RAY;70180;70;HAUTE SAONE;1
70100;;Broye-les-Loups-et-Verfontaine;BROYE-LES-LOUPS-ET-VERFONTAINE;70100;70;HAUTE SAONE;1
70101;;Broye-Aubigney-Montseugny;BROYE-AUBIGNEY-MONTSEUGNY;70140;70;HAUTE SAONE;1
70102;;Brussey;BRUSSEY;70150;70;HAUTE SAONE;1
70103;La;Bruyère;BRUYERE;70280;70;HAUTE SAONE;1
70104;;Bucey-lès-Gy;BUCEY-LES-GY;70700;70;HAUTE SAONE;1
70105;;Bucey-lès-Traves;BUCEY-LES-TRAVES;70360;70;HAUTE SAONE;1
70106;;Buffignécourt;BUFFIGNECOURT;70500;70;HAUTE SAONE;1
70107;;Bussières;BUSSIERES;70190;70;HAUTE SAONE;1
70109;;Buthiers;BUTHIERS;70190;70;HAUTE SAONE;1
70111;;Calmoutier;CALMOUTIER;70240;70;HAUTE SAONE;1
70112;;Cemboing;CEMBOING;70500;70;HAUTE SAONE;1
70113;;Cenans;CENANS;70230;70;HAUTE SAONE;1
70114;;Cendrecourt;CENDRECOURT;70500;70;HAUTE SAONE;1
70115;;Cerre-lès-Noroy;CERRE-LES-NOROY;70000;70;HAUTE SAONE;1
70116;;Chagey;CHAGEY;70400;70;HAUTE SAONE;1
70117;;Châlonvillars;CHALONVILLARS;70400;70;HAUTE SAONE;1
70118;;Chambornay-lès-Bellevaux;CHAMBORNAY-LES-BELLEVAUX;70190;70;HAUTE SAONE;1
70119;;Chambornay-lès-Pin;CHAMBORNAY-LES-PIN;70150;70;HAUTE SAONE;1
70120;;Champagney;CHAMPAGNEY;70290;70;HAUTE SAONE;1
70121;;Champey;CHAMPEY;70400;70;HAUTE SAONE;1
70122;;Champlitte;CHAMPLITTE;70600;70;HAUTE SAONE;1
70124;;Champtonnay;CHAMPTONNAY;70100;70;HAUTE SAONE;1
70125;;Champvans;CHAMPVANS;70100;70;HAUTE SAONE;1
70126;;Chancey;CHANCEY;70140;70;HAUTE SAONE;1
70127;;Chantes;CHANTES;70360;70;HAUTE SAONE;1
70128;La;Chapelle-lès-Luxeuil;CHAPELLE-LES-LUXEUIL;70300;70;HAUTE SAONE;1
70129;La;Chapelle-Saint-Quillain;CHAPELLE-SAINT-QUILLAIN;70700;70;HAUTE SAONE;1
70130;;Charcenne;CHARCENNE;70700;70;HAUTE SAONE;1
70132;;Chargey-lès-Gray;CHARGEY-LES-GRAY;70100;70;HAUTE SAONE;1
70133;;Chargey-lès-Port;CHARGEY-LES-PORT;70170;70;HAUTE SAONE;1
70134;;Chariez;CHARIEZ;70000;70;HAUTE SAONE;1
70135;;Charmes-Saint-Valbert;CHARMES-SAINT-VALBERT;70120;70;HAUTE SAONE;1
70136;;Charmoille;CHARMOILLE;70000;70;HAUTE SAONE;1
70137;;Chassey-lès-Montbozon;CHASSEY-LES-MONTBOZON;70230;70;HAUTE SAONE;1
70138;;Chassey-lès-Scey;CHASSEY-LES-SCEY;70360;70;HAUTE SAONE;1
70140;;Châteney;CHATENEY;70240;70;HAUTE SAONE;1
70141;;Châtenois;CHATENOIS;70240;70;HAUTE SAONE;1
70142;;Chaumercenne;CHAUMERCENNE;70140;70;HAUTE SAONE;1
70143;;Chauvirey-le-Châtel;CHAUVIREY-LE-CHATEL;70500;70;HAUTE SAONE;1
70144;;Chauvirey-le-Vieil;CHAUVIREY-LE-VIEIL;70500;70;HAUTE SAONE;1
70145;;Chaux-la-Lotière;CHAUX-LA-LOTIERE;70190;70;HAUTE SAONE;1
70146;;Chaux-lès-Port;CHAUX-LES-PORT;70170;70;HAUTE SAONE;1
70147;;Chavanne;CHAVANNE;70400;70;HAUTE SAONE;1
70148;;Chemilly;CHEMILLY;70360;70;HAUTE SAONE;1
70149;;Chenebier;CHENEBIER;70400;70;HAUTE SAONE;1
70150;;Chenevrey-et-Morogne;CHENEVREY-ET-MOROGNE;70150;70;HAUTE SAONE;1
70151;;Chevigney;CHEVIGNEY;70140;70;HAUTE SAONE;1
70152;;Choye;CHOYE;70700;70;HAUTE SAONE;1
70153;;Cintrey;CINTREY;70120;70;HAUTE SAONE;1
70154;;Cirey;CIREY;70190;70;HAUTE SAONE;1
70155;;Citers;CITERS;70300;70;HAUTE SAONE;1
70156;;Citey;CITEY;70700;70;HAUTE SAONE;1
70157;;Clairegoutte;CLAIREGOUTTE;70200;70;HAUTE SAONE;1
70158;;Clans;CLANS;70000;70;HAUTE SAONE;1
70159;;Cognières;COGNIERES;70230;70;HAUTE SAONE;1
70160;;Coisevaux;COISEVAUX;70400;70;HAUTE SAONE;1
70162;;Colombe-lès-Vesoul;COLOMBE-LES-VESOUL;70000;70;HAUTE SAONE;1
70163;;Colombier;COLOMBIER;70000;70;HAUTE SAONE;1
70164;;Colombotte;COLOMBOTTE;70240;70;HAUTE SAONE;1
70165;;Combeaufontaine;COMBEAUFONTAINE;70120;70;HAUTE SAONE;1
70166;;Comberjon;COMBERJON;70000;70;HAUTE SAONE;1
70167;;Conflandey;CONFLANDEY;70170;70;HAUTE SAONE;1
70168;;Conflans-sur-Lanterne;CONFLANS-SUR-LANTERNE;70800;70;HAUTE SAONE;1
70169;;Confracourt;CONFRACOURT;70120;70;HAUTE SAONE;1
70170;;Contréglise;CONTREGLISE;70160;70;HAUTE SAONE;1
70171;;Corbenay;CORBENAY;70320;70;HAUTE SAONE;1
70172;La;Corbière;CORBIERE;70300;70;HAUTE SAONE;1
70174;;Cordonnet;CORDONNET;70190;70;HAUTE SAONE;1
70175;;Cornot;CORNOT;70120;70;HAUTE SAONE;1
70176;;Corravillers;CORRAVILLERS;70310;70;HAUTE SAONE;1
70177;;Corre;CORRE;70500;70;HAUTE SAONE;1
70178;La;Côte;COTE;70200;70;HAUTE SAONE;1
70179;;Coulevon;COULEVON;70000;70;HAUTE SAONE;1
70180;;Courchaton;COURCHATON;70110;70;HAUTE SAONE;1
70181;;Courcuire;COURCUIRE;70150;70;HAUTE SAONE;1
70182;;Courmont;COURMONT;70400;70;HAUTE SAONE;1
70183;;Courtesoult-et-Gatey;COURTESOULT-ET-GATEY;70600;70;HAUTE SAONE;1
70184;;Couthenans;COUTHENANS;70400;70;HAUTE SAONE;1
70185;;Cresancey;CRESANCEY;70100;70;HAUTE SAONE;1
70186;La;Creuse;CREUSE;70240;70;HAUTE SAONE;1
70187;;Crevans-et-la-Chapelle-lès-Granges;CREVANS-ET-LA-CHAPELLE-LES-GRANGES;70400;70;HAUTE SAONE;1
70188;;Creveney;CREVENEY;70240;70;HAUTE SAONE;1
70189;;Cromary;CROMARY;70190;70;HAUTE SAONE;1
70190;;Cubry-lès-Faverney;CUBRY-LES-FAVERNEY;70160;70;HAUTE SAONE;1
70192;;Cugney;CUGNEY;70700;70;HAUTE SAONE;1
70193;;Cult;CULT;70150;70;HAUTE SAONE;1
70194;;Cuve;CUVE;70800;70;HAUTE SAONE;1
70195;;Dambenoît-lès-Colombe;DAMBENOIT-LES-COLOMBE;70200;70;HAUTE SAONE;1
70196;;Dampierre-lès-Conflans;DAMPIERRE-LES-CONFLANS;70800;70;HAUTE SAONE;1
70197;;Dampierre-sur-Linotte;DAMPIERRE-SUR-LINOTTE;70230;70;HAUTE SAONE;1
70198;;Dampierre-sur-Salon;DAMPIERRE-SUR-SALON;70180;70;HAUTE SAONE;1
70199;;Dampvalley-lès-Colombe;DAMPVALLEY-LES-COLOMBE;70000;70;HAUTE SAONE;1
70200;;Dampvalley-Saint-Pancras;DAMPVALLEY-SAINT-PANCRAS;70210;70;HAUTE SAONE;1
70201;;Delain;DELAIN;70180;70;HAUTE SAONE;1
70202;;Demangevelle;DEMANGEVELLE;70210;70;HAUTE SAONE;1
70203;La;Demie;DEMIE;70000;70;HAUTE SAONE;1
70204;;Denèvre;DENEVRE;70180;70;HAUTE SAONE;1
70205;;Échavanne;ECHAVANNE;70400;70;HAUTE SAONE;1
70206;;Échenans-sous-Mont-Vaudois;ECHENANS-SOUS-MONT-VAUDOIS;70400;70;HAUTE SAONE;1
70207;;Échenoz-la-Méline;ECHENOZ-LA-MELINE;70000;70;HAUTE SAONE;1
70208;;Échenoz-le-Sec;ECHENOZ-LE-SEC;70000;70;HAUTE SAONE;1
70210;;Écromagny;ECROMAGNY;70270;70;HAUTE SAONE;1
70211;;Écuelle;ECUELLE;70600;70;HAUTE SAONE;1
70213;;Éhuns;EHUNS;70300;70;HAUTE SAONE;1
70214;;Équevilley;EQUEVILLEY;70160;70;HAUTE SAONE;1
70215;;Errevet;ERREVET;70400;70;HAUTE SAONE;1
70216;;Esboz-Brest;ESBOZ-BREST;70300;70;HAUTE SAONE;1
70217;;Esmoulières;ESMOULIERES;70310;70;HAUTE SAONE;1
70218;;Esmoulins;ESMOULINS;70100;70;HAUTE SAONE;1
70219;;Esprels;ESPRELS;70110;70;HAUTE SAONE;1
70220;;Essertenne-et-Cecey;ESSERTENNE-ET-CECEY;70100;70;HAUTE SAONE;1
70221;;Étobon;ETOBON;70400;70;HAUTE SAONE;1
70222;;Étrelles-et-la-Montbleuse;ETRELLES-ET-LA-MONTBLEUSE;70700;70;HAUTE SAONE;1
70224;;Étuz;ETUZ;70150;70;HAUTE SAONE;1
70225;;Fahy-lès-Autrey;FAHY-LES-AUTREY;70100;70;HAUTE SAONE;1
70226;;Fallon;FALLON;70110;70;HAUTE SAONE;1
70227;;Faucogney-et-la-Mer;FAUCOGNEY-ET-LA-MER;70310;70;HAUTE SAONE;1
70228;;Faverney;FAVERNEY;70160;70;HAUTE SAONE;1
70229;;Faymont;FAYMONT;70200;70;HAUTE SAONE;1
70230;;Fédry;FEDRY;70120;70;HAUTE SAONE;1
70231;;Ferrières-lès-Ray;FERRIERES-LES-RAY;70130;70;HAUTE SAONE;1
70232;;Ferrières-lès-Scey;FERRIERES-LES-SCEY;70360;70;HAUTE SAONE;1
70233;Les;Fessey;FESSEY;70310;70;HAUTE SAONE;1
70234;;Filain;FILAIN;70230;70;HAUTE SAONE;1
70235;;Flagy;FLAGY;70000;70;HAUTE SAONE;1
70236;;Fleurey-lès-Faverney;FLEUREY-LES-FAVERNEY;70160;70;HAUTE SAONE;1
70237;;Fleurey-lès-Lavoncourt;FLEUREY-LES-LAVONCOURT;70120;70;HAUTE SAONE;1
70238;;Fleurey-lès-Saint-Loup;FLEUREY-LES-SAINT-LOUP;70800;70;HAUTE SAONE;1
70239;;Fondremand;FONDREMAND;70190;70;HAUTE SAONE;1
70240;;Fontaine-lès-Luxeuil;FONTAINE-LES-LUXEUIL;70800;70;HAUTE SAONE;1
70242;;Fontenois-la-Ville;FONTENOIS-LA-VILLE;70210;70;HAUTE SAONE;1
70243;;Fontenois-lès-Montbozon;FONTENOIS-LES-MONTBOZON;70230;70;HAUTE SAONE;1
70244;;Fouchécourt;FOUCHECOURT;70160;70;HAUTE SAONE;1
70245;;Fougerolles;FOUGEROLLES;70220;70;HAUTE SAONE;1
70247;;Fouvent-Saint-Andoche;FOUVENT-SAINT-ANDOCHE;70600;70;HAUTE SAONE;1
70248;;Frahier-et-Chatebier;FRAHIER-ET-CHATEBIER;70400;70;HAUTE SAONE;1
70249;;Francalmont;FRANCALMONT;70800;70;HAUTE SAONE;1
70250;;Franchevelle;FRANCHEVELLE;70200;70;HAUTE SAONE;1
70251;;Francourt;FRANCOURT;70180;70;HAUTE SAONE;1
70252;;Framont;FRAMONT;70600;70;HAUTE SAONE;1
70253;;Frasne-le-Château;FRASNE-LE-CHATEAU;70700;70;HAUTE SAONE;1
70254;;Frédéric-Fontaine;FREDERIC-FONTAINE;70200;70;HAUTE SAONE;1
70255;;Fresne-Saint-Mamès;FRESNE-SAINT-MAMES;70130;70;HAUTE SAONE;1
70256;;Fresse;FRESSE;70270;70;HAUTE SAONE;1
70257;;Fretigney-et-Velloreille;FRETIGNEY-ET-VELLOREILLE;70130;70;HAUTE SAONE;1
70258;;Froideconche;FROIDECONCHE;70300;70;HAUTE SAONE;1
70259;;Froideterre;FROIDETERRE;70200;70;HAUTE SAONE;1
70260;;Frotey-lès-Lure;FROTEY-LES-LURE;70200;70;HAUTE SAONE;1
70261;;Frotey-lès-Vesoul;FROTEY-LES-VESOUL;70000;70;HAUTE SAONE;1
70262;;Genevreuille;GENEVREUILLE;70240;70;HAUTE SAONE;1
70263;;Genevrey;GENEVREY;70240;70;HAUTE SAONE;1
70264;;Georfans;GEORFANS;70110;70;HAUTE SAONE;1
70265;;Germigney;GERMIGNEY;70100;70;HAUTE SAONE;1
70267;;Gevigney-et-Mercey;GEVIGNEY-ET-MERCEY;70500;70;HAUTE SAONE;1
70268;;Gézier-et-Fontenelay;GEZIER-ET-FONTENELAY;70700;70;HAUTE SAONE;1
70269;;Girefontaine;GIREFONTAINE;70210;70;HAUTE SAONE;1
70271;;Gouhenans;GOUHENANS;70110;70;HAUTE SAONE;1
70272;;Gourgeon;GOURGEON;70120;70;HAUTE SAONE;1
70273;;Grammont;GRAMMONT;70110;70;HAUTE SAONE;1
70274;;Grandecourt;GRANDECOURT;70120;70;HAUTE SAONE;1
70275;;Grandvelle-et-le-Perrenot;GRANDVELLE-ET-LE-PERRENOT;70190;70;HAUTE SAONE;1
70276;;Granges-la-Ville;GRANGES-LA-VILLE;70400;70;HAUTE SAONE;1
70277;;Granges-le-Bourg;GRANGES-LE-BOURG;70400;70;HAUTE SAONE;1
70278;;Grattery;GRATTERY;70170;70;HAUTE SAONE;1
70279;;Gray;GRAY;70100;70;HAUTE SAONE;1
70280;;Gray-la-Ville;GRAY-LA-VILLE;70100;70;HAUTE SAONE;1
70281;;Greucourt;GREUCOURT;70130;70;HAUTE SAONE;1
70282;;Gy;GY;70700;70;HAUTE SAONE;1
70283;;Haut-du-Them-Château-Lambert;HAUT-DU-THEM-CHATEAU-LAMBERT;70440;70;HAUTE SAONE;1
70284;;Hautevelle;HAUTEVELLE;70800;70;HAUTE SAONE;1
70285;;Héricourt;HERICOURT;70400;70;HAUTE SAONE;1
70286;;Hugier;HUGIER;70150;70;HAUTE SAONE;1
70287;;Hurecourt;HURECOURT;70210;70;HAUTE SAONE;1
70288;;Hyet;HYET;70190;70;HAUTE SAONE;1
70289;;Igny;IGNY;70700;70;HAUTE SAONE;1
70290;;Jasney;JASNEY;70800;70;HAUTE SAONE;1
70291;;Jonvelle;JONVELLE;70500;70;HAUTE SAONE;1
70292;;Jussey;JUSSEY;70500;70;HAUTE SAONE;1
70293;;Lambrey;LAMBREY;70500;70;HAUTE SAONE;1
70294;;Lantenot;LANTENOT;70200;70;HAUTE SAONE;1
70295;La;Lanterne-et-les-Armonts;LANTERNE-ET-LES-ARMONTS;70270;70;HAUTE SAONE;1
70296;;Larians-et-Munans;LARIANS-ET-MUNANS;70230;70;HAUTE SAONE;1
70297;;Larret;LARRET;70600;70;HAUTE SAONE;1
70298;;Lavigney;LAVIGNEY;70120;70;HAUTE SAONE;1
70299;;Lavoncourt;LAVONCOURT;70120;70;HAUTE SAONE;1
70301;;Lieffrans;LIEFFRANS;70190;70;HAUTE SAONE;1
70302;;Lieucourt;LIEUCOURT;70140;70;HAUTE SAONE;1
70303;;Liévans;LIEVANS;70240;70;HAUTE SAONE;1
70304;;Linexert;LINEXERT;70200;70;HAUTE SAONE;1
70305;;Lœuilley;LOEUILLEY;70100;70;HAUTE SAONE;1
70306;;Lomont;LOMONT;70200;70;HAUTE SAONE;1
70307;;Longevelle;LONGEVELLE;70110;70;HAUTE SAONE;1
70308;La;Longine;LONGINE;70310;70;HAUTE SAONE;1
70309;;Loulans-Verchamp;LOULANS-VERCHAMP;70230;70;HAUTE SAONE;1
70310;;Lure;LURE;70200;70;HAUTE SAONE;1
70311;;Luxeuil-les-Bains;LUXEUIL-LES-BAINS;70300;70;HAUTE SAONE;1
70312;;Luze;LUZE;70400;70;HAUTE SAONE;1
70313;;Lyoffans;LYOFFANS;70200;70;HAUTE SAONE;1
70314;;Magnivray;MAGNIVRAY;70300;70;HAUTE SAONE;1
70315;;Magnoncourt;MAGNONCOURT;70800;70;HAUTE SAONE;1
70316;Le;Magnoray;MAGNORAY;70000;70;HAUTE SAONE;1
70317;Les;Magny;MAGNY;70110;70;HAUTE SAONE;1
70318;;Magny-Danigon;MAGNY-DANIGON;70200;70;HAUTE SAONE;1
70319;;Magny-Jobert;MAGNY-JOBERT;70200;70;HAUTE SAONE;1
70320;;Magny-lès-Jussey;MAGNY-LES-JUSSEY;70500;70;HAUTE SAONE;1
70321;;Magny-Vernois;MAGNY-VERNOIS;70200;70;HAUTE SAONE;1
70322;;Mailleroncourt-Charette;MAILLERONCOURT-CHARETTE;70240;70;HAUTE SAONE;1
70323;;Mailleroncourt-Saint-Pancras;MAILLERONCOURT-SAINT-PANCRAS;70210;70;HAUTE SAONE;1
70324;;Mailley-et-Chazelot;MAILLEY-ET-CHAZELOT;70000;70;HAUTE SAONE;1
70325;;Maizières;MAIZIERES;70190;70;HAUTE SAONE;1
70326;La;Malachère;MALACHERE;70190;70;HAUTE SAONE;1
70327;;Malans;MALANS;70140;70;HAUTE SAONE;1
70328;;Malbouhans;MALBOUHANS;70200;70;HAUTE SAONE;1
70329;;Malvillers;MALVILLERS;70120;70;HAUTE SAONE;1
70330;;Mandrevillars;MANDREVILLARS;70400;70;HAUTE SAONE;1
70331;;Mantoche;MANTOCHE;70100;70;HAUTE SAONE;1
70332;;Marast;MARAST;70110;70;HAUTE SAONE;1
70334;;Marnay;MARNAY;70150;70;HAUTE SAONE;1
70335;;Maussans;MAUSSANS;70230;70;HAUTE SAONE;1
70336;;Mélecey;MELECEY;70110;70;HAUTE SAONE;1
70337;;Melin;MELIN;70120;70;HAUTE SAONE;1
70338;;Melincourt;MELINCOURT;70210;70;HAUTE SAONE;1
70339;;Mélisey;MELISEY;70270;70;HAUTE SAONE;1
70340;;Membrey;MEMBREY;70180;70;HAUTE SAONE;1
70341;;Menoux;MENOUX;70160;70;HAUTE SAONE;1
70342;;Mercey-sur-Saône;MERCEY-SUR-SAONE;70130;70;HAUTE SAONE;1
70343;;Mersuay;MERSUAY;70160;70;HAUTE SAONE;1
70344;;Meurcourt;MEURCOURT;70300;70;HAUTE SAONE;1
70345;;Miellin;MIELLIN;70440;70;HAUTE SAONE;1
70347;;Mignavillers;MIGNAVILLERS;70400;70;HAUTE SAONE;1
70348;;Moffans-et-Vacheresse;MOFFANS-ET-VACHERESSE;70200;70;HAUTE SAONE;1
70349;;Moimay;MOIMAY;70110;70;HAUTE SAONE;1
70350;;Molay;MOLAY;70120;70;HAUTE SAONE;1
70351;;Mollans;MOLLANS;70240;70;HAUTE SAONE;1
70352;La;Montagne;MONTAGNE;70310;70;HAUTE SAONE;1
70353;;Montagney;MONTAGNEY;70140;70;HAUTE SAONE;1
70355;;Montarlot-lès-Rioz;MONTARLOT-LES-RIOZ;70190;70;HAUTE SAONE;1
70356;;Montboillon;MONTBOILLON;70700;70;HAUTE SAONE;1
70357;;Montbozon;MONTBOZON;70230;70;HAUTE SAONE;1
70358;;Montcey;MONTCEY;70000;70;HAUTE SAONE;1
70359;;Montcourt;MONTCOURT;70500;70;HAUTE SAONE;1
70360;;Montdoré;MONTDORE;70210;70;HAUTE SAONE;1
70361;;Montessaux;MONTESSAUX;70270;70;HAUTE SAONE;1
70362;;Montigny-lès-Cherlieu;MONTIGNY-LES-CHERLIEU;70500;70;HAUTE SAONE;1
70363;;Montigny-lès-Vesoul;MONTIGNY-LES-VESOUL;70000;70;HAUTE SAONE;1
70364;;Montjustin-et-Velotte;MONTJUSTIN-ET-VELOTTE;70110;70;HAUTE SAONE;1
70366;;Villers-Chemin-et-Mont-lès-Étrelles;VILLERS-CHEMIN-ET-MONT-LES-ETRELLES;70700;70;HAUTE SAONE;1
70367;;Mont-le-Vernois;MONT-LE-VERNOIS;70000;70;HAUTE SAONE;1
70368;;Montot;MONTOT;70180;70;HAUTE SAONE;1
70369;;Mont-Saint-Léger;MONT-SAINT-LEGER;70120;70;HAUTE SAONE;1
70371;;Montureux-et-Prantigny;MONTUREUX-ET-PRANTIGNY;70100;70;HAUTE SAONE;1
70372;;Montureux-lès-Baulay;MONTUREUX-LES-BAULAY;70500;70;HAUTE SAONE;1
70373;La;Roche-Morey;ROCHE-MOREY;70120;70;HAUTE SAONE;1
70374;;Motey-Besuche;MOTEY-BESUCHE;70140;70;HAUTE SAONE;1
70375;;Motey-sur-Saône;MOTEY-SUR-SAONE;70130;70;HAUTE SAONE;1
70376;;Nantilly;NANTILLY;70100;70;HAUTE SAONE;1
70378;;Navenne;NAVENNE;70000;70;HAUTE SAONE;1
70380;;Neurey-en-Vaux;NEUREY-EN-VAUX;70160;70;HAUTE SAONE;1
70381;;Neurey-lès-la-Demie;NEUREY-LES-LA-DEMIE;70000;70;HAUTE SAONE;1
70383;;Neuvelle-lès-Cromary;NEUVELLE-LES-CROMARY;70190;70;HAUTE SAONE;1
70384;;Neuvelle-lès-la-Charité;NEUVELLE-LES-LA-CHARITE;70130;70;HAUTE SAONE;1
70385;La;Neuvelle-lès-Lure;NEUVELLE-LES-LURE;70200;70;HAUTE SAONE;1
70386;La;Neuvelle-lès-Scey;NEUVELLE-LES-SCEY;70360;70;HAUTE SAONE;1
70387;;Noidans-le-Ferroux;NOIDANS-LE-FERROUX;70130;70;HAUTE SAONE;1
70388;;Noidans-lès-Vesoul;NOIDANS-LES-VESOUL;70000;70;HAUTE SAONE;1
70389;;Noiron;NOIRON;70100;70;HAUTE SAONE;1
70390;;Noroy-le-Bourg;NOROY-LE-BOURG;70000;70;HAUTE SAONE;1
70392;;Oigney;OIGNEY;70120;70;HAUTE SAONE;1
70393;;Oiselay-et-Grachaux;OISELAY-ET-GRACHAUX;70700;70;HAUTE SAONE;1
70394;;Onay;ONAY;70100;70;HAUTE SAONE;1
70395;;Oppenans;OPPENANS;70110;70;HAUTE SAONE;1
70396;;Oricourt;ORICOURT;70110;70;HAUTE SAONE;1
70397;;Ormenans;ORMENANS;70230;70;HAUTE SAONE;1
70398;;Ormoiche;ORMOICHE;70300;70;HAUTE SAONE;1
70399;;Ormoy;ORMOY;70500;70;HAUTE SAONE;1
70400;;Ouge;OUGE;70500;70;HAUTE SAONE;1
70401;;Ovanches;OVANCHES;70360;70;HAUTE SAONE;1
70402;;Oyrières;OYRIERES;70600;70;HAUTE SAONE;1
70403;;Palante;PALANTE;70200;70;HAUTE SAONE;1
70404;;Passavant-la-Rochère;PASSAVANT-LA-ROCHERE;70210;70;HAUTE SAONE;1
70405;;Pennesières;PENNESIERES;70190;70;HAUTE SAONE;1
70406;;Percey-le-Grand;PERCEY-LE-GRAND;70600;70;HAUTE SAONE;1
70407;;Perrouse;PERROUSE;70190;70;HAUTE SAONE;1
70408;;Pesmes;PESMES;70140;70;HAUTE SAONE;1
70409;;Pierrecourt;PIERRECOURT;70600;70;HAUTE SAONE;1
70410;;Pin;PIN;70150;70;HAUTE SAONE;1
70411;La;Pisseure;PISSEURE;70800;70;HAUTE SAONE;1
70412;;Plainemont;PLAINEMONT;70800;70;HAUTE SAONE;1
70413;;Plancher-Bas;PLANCHER-BAS;70290;70;HAUTE SAONE;1
70414;;Plancher-les-Mines;PLANCHER-LES-MINES;70290;70;HAUTE SAONE;1
70415;;Polaincourt-et-Clairefontaine;POLAINCOURT-ET-CLAIREFONTAINE;70210;70;HAUTE SAONE;1
70416;;Pomoy;POMOY;70240;70;HAUTE SAONE;1
70417;;Pontcey;PONTCEY;70360;70;HAUTE SAONE;1
70418;Le;Pont-de-Planches;PONT-DE-PLANCHES;70130;70;HAUTE SAONE;1
70419;;Pont-du-Bois;PONT-DU-BOIS;70210;70;HAUTE SAONE;1
70420;;Pont-sur-l'Ognon;PONT-SUR-L'OGNON;70110;70;HAUTE SAONE;1
70421;;Port-sur-Saône;PORT-SUR-SAONE;70170;70;HAUTE SAONE;1
70422;;Poyans;POYANS;70100;70;HAUTE SAONE;1
70423;;Preigney;PREIGNEY;70120;70;HAUTE SAONE;1
70425;La;Proiselière-et-Langle;PROISELIERE-ET-LANGLE;70310;70;HAUTE SAONE;1
70426;;Provenchère;PROVENCHERE;70170;70;HAUTE SAONE;1
70427;;Purgerot;PURGEROT;70160;70;HAUTE SAONE;1
70428;;Pusey;PUSEY;70000;70;HAUTE SAONE;1
70429;;Pusy-et-Épenoux;PUSY-ET-EPENOUX;70000;70;HAUTE SAONE;1
70430;La;Quarte;QUARTE;70120;70;HAUTE SAONE;1
70431;;Quenoche;QUENOCHE;70190;70;HAUTE SAONE;1
70432;;Quers;QUERS;70200;70;HAUTE SAONE;1
70433;;Quincey;QUINCEY;70000;70;HAUTE SAONE;1
70435;;Raddon-et-Chapendu;RADDON-ET-CHAPENDU;70280;70;HAUTE SAONE;1
70436;;Raincourt;RAINCOURT;70500;70;HAUTE SAONE;1
70437;;Ranzevelle;RANZEVELLE;70500;70;HAUTE SAONE;1
70438;;Ray-sur-Saône;RAY-SUR-SAONE;70130;70;HAUTE SAONE;1
70439;;Raze;RAZE;70000;70;HAUTE SAONE;1
70440;;Recologne;RECOLOGNE;70130;70;HAUTE SAONE;1
70441;;Recologne-lès-Rioz;RECOLOGNE-LES-RIOZ;70190;70;HAUTE SAONE;1
70442;;Renaucourt;RENAUCOURT;70120;70;HAUTE SAONE;1
70443;La;Grande-Résie;GRANDE-RESIE;70140;70;HAUTE SAONE;1
70444;La;Résie-Saint-Martin;RESIE-SAINT-MARTIN;70140;70;HAUTE SAONE;1
70445;;Rignovelle;RIGNOVELLE;70200;70;HAUTE SAONE;1
70446;;Rigny;RIGNY;70100;70;HAUTE SAONE;1
70447;;Rioz;RIOZ;70190;70;HAUTE SAONE;1
70448;;Roche-et-Raucourt;ROCHE-ET-RAUCOURT;70180;70;HAUTE SAONE;1
70449;;Roche-sur-Linotte-et-Sorans-les-Cordiers;ROCHE-SUR-LINOTTE-ET-SORANS-LES-CORDIERS;70230;70;HAUTE SAONE;1
70450;La;Rochelle;ROCHELLE;70120;70;HAUTE SAONE;1
70451;;Ronchamp;RONCHAMP;70250;70;HAUTE SAONE;1
70452;;Rosey;ROSEY;70000;70;HAUTE SAONE;1
70453;La;Rosière;ROSIERE;70310;70;HAUTE SAONE;1
70454;;Rosières-sur-Mance;ROSIERES-SUR-MANCE;70500;70;HAUTE SAONE;1
70455;;Roye;ROYE;70200;70;HAUTE SAONE;1
70456;;Ruhans;RUHANS;70190;70;HAUTE SAONE;1
70457;;Rupt-sur-Saône;RUPT-SUR-SAONE;70360;70;HAUTE SAONE;1
70459;;Saint-Barthélemy;SAINT-BARTHELEMY;70270;70;HAUTE SAONE;1
70460;;Saint-Bresson;SAINT-BRESSON;70280;70;HAUTE SAONE;1
70461;;Saint-Broing;SAINT-BROING;70100;70;HAUTE SAONE;1
70462;;Saint-Ferjeux;SAINT-FERJEUX;70110;70;HAUTE SAONE;1
70463;;Saint-Gand;SAINT-GAND;70130;70;HAUTE SAONE;1
70464;;Saint-Germain;SAINT-GERMAIN;70200;70;HAUTE SAONE;1
70466;;Saint-Loup-Nantouard;SAINT-LOUP-NANTOUARD;70100;70;HAUTE SAONE;1
70467;;Saint-Loup-sur-Semouse;SAINT-LOUP-SUR-SEMOUSE;70800;70;HAUTE SAONE;1
70468;;Saint-Marcel;SAINT-MARCEL;70500;70;HAUTE SAONE;1
70469;;Sainte-Marie-en-Chanois;SAINTE-MARIE-EN-CHANOIS;70310;70;HAUTE SAONE;1
70470;;Sainte-Marie-en-Chaux;SAINTE-MARIE-EN-CHAUX;70300;70;HAUTE SAONE;1
70471;;Sainte-Reine;SAINTE-REINE;70700;70;HAUTE SAONE;1
70472;;Saint-Remy;SAINT-REMY;70160;70;HAUTE SAONE;1
70473;;Saint-Sauveur;SAINT-SAUVEUR;70300;70;HAUTE SAONE;1
70474;;Saint-Sulpice;SAINT-SULPICE;70110;70;HAUTE SAONE;1
70475;;Saint-Valbert;SAINT-VALBERT;70300;70;HAUTE SAONE;1
70476;;Saponcourt;SAPONCOURT;70210;70;HAUTE SAONE;1
70477;;Saulnot;SAULNOT;70400;70;HAUTE SAONE;1
70478;;Saulx;SAULX;70240;70;HAUTE SAONE;1
70479;;Sauvigney-lès-Gray;SAUVIGNEY-LES-GRAY;70100;70;HAUTE SAONE;1
70480;;Sauvigney-lès-Pesmes;SAUVIGNEY-LES-PESMES;70140;70;HAUTE SAONE;1
70481;;Savoyeux;SAVOYEUX;70130;70;HAUTE SAONE;1
70482;;Scey-sur-Saône-et-Saint-Albin;SCEY-SUR-SAONE-ET-SAINT-ALBIN;70360;70;HAUTE SAONE;1
70483;;Scye;SCYE;70170;70;HAUTE SAONE;1
70484;;Secenans;SECENANS;70400;70;HAUTE SAONE;1
70485;;Selles;SELLES;70210;70;HAUTE SAONE;1
70486;;Semmadon;SEMMADON;70120;70;HAUTE SAONE;1
70487;;Senargent-Mignafans;SENARGENT-MIGNAFANS;70110;70;HAUTE SAONE;1
70488;;Senoncourt;SENONCOURT;70160;70;HAUTE SAONE;1
70489;;Servance;SERVANCE;70440;70;HAUTE SAONE;1
70490;;Servigney;SERVIGNEY;70240;70;HAUTE SAONE;1
70491;;Seveux;SEVEUX;70130;70;HAUTE SAONE;1
70492;;Soing-Cubry-Charentenay;SOING-CUBRY-CHARENTENAY;70130;70;HAUTE SAONE;1
70493;;Sorans-lès-Breurey;SORANS-LES-BREUREY;70190;70;HAUTE SAONE;1
70494;;Sornay;SORNAY;70150;70;HAUTE SAONE;1
70496;;Tartécourt;TARTECOURT;70500;70;HAUTE SAONE;1
70497;;Tavey;TAVEY;70400;70;HAUTE SAONE;1
70498;;Ternuay-Melay-et-Saint-Hilaire;TERNUAY-MELAY-ET-SAINT-HILAIRE;70270;70;HAUTE SAONE;1
70499;;Theuley;THEULEY;70120;70;HAUTE SAONE;1
70500;;Thieffrans;THIEFFRANS;70230;70;HAUTE SAONE;1
70501;;Thiénans;THIENANS;70230;70;HAUTE SAONE;1
70502;;Tincey-et-Pontrebeau;TINCEY-ET-PONTREBEAU;70120;70;HAUTE SAONE;1
70503;;Traitiéfontaine;TRAITIEFONTAINE;70190;70;HAUTE SAONE;1
70504;;Traves;TRAVES;70360;70;HAUTE SAONE;1
70505;Le;Tremblois;TREMBLOIS;70100;70;HAUTE SAONE;1
70506;;Trémoins;TREMOINS;70400;70;HAUTE SAONE;1
70507;;Trésilley;TRESILLEY;70190;70;HAUTE SAONE;1
70509;;Tromarey;TROMAREY;70150;70;HAUTE SAONE;1
70510;;Vadans;VADANS;70140;70;HAUTE SAONE;1
70511;;Vaite;VAITE;70180;70;HAUTE SAONE;1
70512;La;Vaivre;VAIVRE;70320;70;HAUTE SAONE;1
70513;;Vaivre-et-Montoille;VAIVRE-ET-MONTOILLE;70000;70;HAUTE SAONE;1
70514;;Valay;VALAY;70140;70;HAUTE SAONE;1
70515;Le;Val-de-Gouhenans;VAL-DE-GOUHENANS;70200;70;HAUTE SAONE;1
70516;;Vallerois-le-Bois;VALLEROIS-LE-BOIS;70000;70;HAUTE SAONE;1
70517;;Vallerois-Lorioz;VALLEROIS-LORIOZ;70000;70;HAUTE SAONE;1
70518;Le;Val-Saint-Éloi;VAL-SAINT-ELOI;70160;70;HAUTE SAONE;1
70519;;Vandelans;VANDELANS;70190;70;HAUTE SAONE;1
70520;;Vanne;VANNE;70130;70;HAUTE SAONE;1
70521;;Vantoux-et-Longevelle;VANTOUX-ET-LONGEVELLE;70700;70;HAUTE SAONE;1
70522;;Varogne;VAROGNE;70240;70;HAUTE SAONE;1
70523;;Vars;VARS;70600;70;HAUTE SAONE;1
70524;;Vauchoux;VAUCHOUX;70170;70;HAUTE SAONE;1
70525;;Vauconcourt-Nervezain;VAUCONCOURT-NERVEZAIN;70120;70;HAUTE SAONE;1
70526;;Vauvillers;VAUVILLERS;70210;70;HAUTE SAONE;1
70527;;Vaux-le-Moncelot;VAUX-LE-MONCELOT;70700;70;HAUTE SAONE;1
70528;;Velesmes-Échevanne;VELESMES-ECHEVANNE;70100;70;HAUTE SAONE;1
70529;;Velet;VELET;70100;70;HAUTE SAONE;1
70530;;Vellechevreux-et-Courbenans;VELLECHEVREUX-ET-COURBENANS;70110;70;HAUTE SAONE;1
70531;;Velleclaire;VELLECLAIRE;70700;70;HAUTE SAONE;1
70532;;Vellefaux;VELLEFAUX;70000;70;HAUTE SAONE;1
70533;;Vellefrey-et-Vellefrange;VELLEFREY-ET-VELLEFRANGE;70700;70;HAUTE SAONE;1
70534;;Vellefrie;VELLEFRIE;70240;70;HAUTE SAONE;1
70535;;Velleguindry-et-Levrecey;VELLEGUINDRY-ET-LEVRECEY;70000;70;HAUTE SAONE;1
70536;;Velle-le-Châtel;VELLE-LE-CHATEL;70000;70;HAUTE SAONE;1
70537;;Velleminfroy;VELLEMINFROY;70240;70;HAUTE SAONE;1
70538;;Vellemoz;VELLEMOZ;70700;70;HAUTE SAONE;1
70539;;Vellexon-Queutrey-et-Vaudey;VELLEXON-QUEUTREY-ET-VAUDEY;70130;70;HAUTE SAONE;1
70540;;Velloreille-lès-Choye;VELLOREILLE-LES-CHOYE;70700;70;HAUTE SAONE;1
70541;;Velorcey;VELORCEY;70300;70;HAUTE SAONE;1
70542;;Venère;VENERE;70100;70;HAUTE SAONE;1
70544;La;Vergenne;VERGENNE;70200;70;HAUTE SAONE;1
70545;;Venisey;VENISEY;70500;70;HAUTE SAONE;1
70546;;Vereux;VEREUX;70180;70;HAUTE SAONE;1
70547;;Verlans;VERLANS;70400;70;HAUTE SAONE;1
70548;;Vernois-sur-Mance;VERNOIS-SUR-MANCE;70500;70;HAUTE SAONE;1
70549;La;Vernotte;VERNOTTE;70130;70;HAUTE SAONE;1
70550;;Vesoul;VESOUL;70000;70;HAUTE SAONE;1
70551;;Vezet;VEZET;70130;70;HAUTE SAONE;1
70552;;Villafans;VILLAFANS;70110;70;HAUTE SAONE;1
70553;;Villargent;VILLARGENT;70110;70;HAUTE SAONE;1
70554;;Villars-le-Pautel;VILLARS-LE-PAUTEL;70500;70;HAUTE SAONE;1
70555;La;Villedieu-en-Fontenette;VILLEDIEU-EN-FONTENETTE;70160;70;HAUTE SAONE;1
70557;;Villefrancon;VILLEFRANCON;70700;70;HAUTE SAONE;1
70558;La;Villeneuve-Bellenoye-et-la-Maize;VILLENEUVE-BELLENOYE-ET-LA-MAIZE;70240;70;HAUTE SAONE;1
70559;;Villeparois;VILLEPAROIS;70000;70;HAUTE SAONE;1
70560;;Villers-Bouton;VILLERS-BOUTON;70190;70;HAUTE SAONE;1
70561;;Villersexel;VILLERSEXEL;70110;70;HAUTE SAONE;1
70562;;Villers-la-Ville;VILLERS-LA-VILLE;70110;70;HAUTE SAONE;1
70563;;Villers-le-Sec;VILLERS-LE-SEC;70000;70;HAUTE SAONE;1
70564;;Villers-lès-Luxeuil;VILLERS-LES-LUXEUIL;70300;70;HAUTE SAONE;1
70565;;Villers-Pater;VILLERS-PATER;70190;70;HAUTE SAONE;1
70566;;Villers-sur-Port;VILLERS-SUR-PORT;70170;70;HAUTE SAONE;1
70567;;Villers-sur-Saulnot;VILLERS-SUR-SAULNOT;70400;70;HAUTE SAONE;1
70568;;Villers-Vaudey;VILLERS-VAUDEY;70120;70;HAUTE SAONE;1
70569;;Vilory;VILORY;70240;70;HAUTE SAONE;1
70571;;Visoncourt;VISONCOURT;70300;70;HAUTE SAONE;1
70572;;Vitrey-sur-Mance;VITREY-SUR-MANCE;70500;70;HAUTE SAONE;1
70573;La;Voivre;VOIVRE;70310;70;HAUTE SAONE;1
70574;;Volon;VOLON;70180;70;HAUTE SAONE;1
70575;;Voray-sur-l'Ognon;VORAY-SUR-L'OGNON;70190;70;HAUTE SAONE;1
70576;;Vougécourt;VOUGECOURT;70500;70;HAUTE SAONE;1
70577;;Vouhenans;VOUHENANS;70200;70;HAUTE SAONE;1
70578;;Vregille;VREGILLE;70150;70;HAUTE SAONE;1
70579;;Vyans-le-Val;VYANS-LE-VAL;70400;70;HAUTE SAONE;1
70580;;Vy-le-Ferroux;VY-LE-FERROUX;70130;70;HAUTE SAONE;1
70581;;Vy-lès-Lure;VY-LES-LURE;70200;70;HAUTE SAONE;1
70582;;Vy-lès-Rupt;VY-LES-RUPT;70120;70;HAUTE SAONE;1
70583;;Vy-lès-Filain;VY-LES-FILAIN;70230;70;HAUTE SAONE;1
71001;L';Abergement-de-Cuisery;ABERGEMENT-DE-CUISERY;71290;71;SAONE ET LOIRE;1
71002;L';Abergement-Sainte-Colombe;ABERGEMENT-SAINTE-COLOMBE;71370;71;SAONE ET LOIRE;1
71003;;Allerey-sur-Saône;ALLEREY-SUR-SAONE;71350;71;SAONE ET LOIRE;1
71004;;Allériot;ALLERIOT;71380;71;SAONE ET LOIRE;1
71005;;Aluze;ALUZE;71510;71;SAONE ET LOIRE;1
71006;;Amanzé;AMANZE;71610;71;SAONE ET LOIRE;1
71007;;Ameugny;AMEUGNY;71460;71;SAONE ET LOIRE;1
71008;;Anglure-sous-Dun;ANGLURE-SOUS-DUN;71170;71;SAONE ET LOIRE;1
71009;;Anost;ANOST;71550;71;SAONE ET LOIRE;1
71010;;Antully;ANTULLY;71400;71;SAONE ET LOIRE;1
71011;;Anzy-le-Duc;ANZY-LE-DUC;71110;71;SAONE ET LOIRE;1
71012;;Artaix;ARTAIX;71110;71;SAONE ET LOIRE;1
71013;;Authumes;AUTHUMES;71270;71;SAONE ET LOIRE;1
71014;;Autun;AUTUN;71400;71;SAONE ET LOIRE;1
71015;;Auxy;AUXY;71400;71;SAONE ET LOIRE;1
71016;;Azé;AZE;71260;71;SAONE ET LOIRE;1
71017;;Ballore;BALLORE;71220;71;SAONE ET LOIRE;1
71018;;Bantanges;BANTANGES;71500;71;SAONE ET LOIRE;1
71019;;Barizey;BARIZEY;71640;71;SAONE ET LOIRE;1
71020;;Barnay;BARNAY;71540;71;SAONE ET LOIRE;1
71021;;Baron;BARON;71120;71;SAONE ET LOIRE;1
71022;;Baudemont;BAUDEMONT;71800;71;SAONE ET LOIRE;1
71023;;Baudrières;BAUDRIERES;71370;71;SAONE ET LOIRE;1
71024;;Baugy;BAUGY;71110;71;SAONE ET LOIRE;1
71025;;Beaubery;BEAUBERY;71220;71;SAONE ET LOIRE;1
71026;;Beaumont-sur-Grosne;BEAUMONT-SUR-GROSNE;71240;71;SAONE ET LOIRE;1
71027;;Beaurepaire-en-Bresse;BEAUREPAIRE-EN-BRESSE;71580;71;SAONE ET LOIRE;1
71028;;Beauvernois;BEAUVERNOIS;71270;71;SAONE ET LOIRE;1
71029;;Bellevesvre;BELLEVESVRE;71270;71;SAONE ET LOIRE;1
71030;;Bergesserin;BERGESSERIN;71250;71;SAONE ET LOIRE;1
71031;;Berzé-le-Châtel;BERZE-LE-CHATEL;71960;71;SAONE ET LOIRE;1
71032;;Berzé-la-Ville;BERZE-LA-VILLE;71960;71;SAONE ET LOIRE;1
71033;;Bey;BEY;71620;71;SAONE ET LOIRE;1
71034;;Bissey-sous-Cruchaud;BISSEY-SOUS-CRUCHAUD;71390;71;SAONE ET LOIRE;1
71035;;Bissy-la-Mâconnaise;BISSY-LA-MACONNAISE;71260;71;SAONE ET LOIRE;1
71036;;Bissy-sous-Uxelles;BISSY-SOUS-UXELLES;71460;71;SAONE ET LOIRE;1
71037;;Bissy-sur-Fley;BISSY-SUR-FLEY;71460;71;SAONE ET LOIRE;1
71038;Les;Bizots;BIZOTS;71710;71;SAONE ET LOIRE;1
71039;;Blanot;BLANOT;71250;71;SAONE ET LOIRE;1
71040;;Blanzy;BLANZY;71450;71;SAONE ET LOIRE;1
71041;;Bois-Sainte-Marie;BOIS-SAINTE-MARIE;71800;71;SAONE ET LOIRE;1
71042;;Bonnay;BONNAY;71460;71;SAONE ET LOIRE;1
71043;Les;Bordes;BORDES;71350;71;SAONE ET LOIRE;1
71044;;Bosjean;BOSJEAN;71330;71;SAONE ET LOIRE;1
71045;;Bouhans;BOUHANS;71330;71;SAONE ET LOIRE;1
71046;La;Boulaye;BOULAYE;71320;71;SAONE ET LOIRE;1
71047;;Bourbon-Lancy;BOURBON-LANCY;71140;71;SAONE ET LOIRE;1
71048;;Bourg-le-Comte;BOURG-LE-COMTE;71110;71;SAONE ET LOIRE;1
71050;;Bourgvilain;BOURGVILAIN;71630;71;SAONE ET LOIRE;1
71051;;Bouzeron;BOUZERON;71150;71;SAONE ET LOIRE;1
71052;;Boyer;BOYER;71700;71;SAONE ET LOIRE;1
71054;;Bragny-sur-Saône;BRAGNY-SUR-SAONE;71350;71;SAONE ET LOIRE;1
71055;;Brandon;BRANDON;71520;71;SAONE ET LOIRE;1
71056;;Branges;BRANGES;71500;71;SAONE ET LOIRE;1
71057;;Bray;BRAY;71250;71;SAONE ET LOIRE;1
71058;;Bresse-sur-Grosne;BRESSE-SUR-GROSNE;71460;71;SAONE ET LOIRE;1
71059;Le;Breuil;BREUIL;71670;71;SAONE ET LOIRE;1
71060;;Briant;BRIANT;71110;71;SAONE ET LOIRE;1
71061;;Brienne;BRIENNE;71290;71;SAONE ET LOIRE;1
71062;;Brion;BRION;71190;71;SAONE ET LOIRE;1
71063;;Broye;BROYE;71190;71;SAONE ET LOIRE;1
71064;;Bruailles;BRUAILLES;71500;71;SAONE ET LOIRE;1
71065;;Buffières;BUFFIERES;71250;71;SAONE ET LOIRE;1
71066;;Burgy;BURGY;71260;71;SAONE ET LOIRE;1
71067;;Burnand;BURNAND;71460;71;SAONE ET LOIRE;1
71068;;Burzy;BURZY;71460;71;SAONE ET LOIRE;1
71069;;Bussières;BUSSIERES;71960;71;SAONE ET LOIRE;1
71070;;Buxy;BUXY;71390;71;SAONE ET LOIRE;1
71071;;Céron;CERON;71110;71;SAONE ET LOIRE;1
71072;;Cersot;CERSOT;71390;71;SAONE ET LOIRE;1
71073;;Chagny;CHAGNY;71150;71;SAONE ET LOIRE;1
71074;;Chaintré;CHAINTRE;71570;71;SAONE ET LOIRE;1
71075;;Chalmoux;CHALMOUX;71140;71;SAONE ET LOIRE;1
71076;;Chalon-sur-Saône;CHALON-SUR-SAONE;71100;71;SAONE ET LOIRE;1
71077;;Chambilly;CHAMBILLY;71110;71;SAONE ET LOIRE;1
71078;;Chamilly;CHAMILLY;71510;71;SAONE ET LOIRE;1
71079;;Champagnat;CHAMPAGNAT;71480;71;SAONE ET LOIRE;1
71080;;Champagny-sous-Uxelles;CHAMPAGNY-SOUS-UXELLES;71460;71;SAONE ET LOIRE;1
71081;;Champforgeuil;CHAMPFORGEUIL;71530;71;SAONE ET LOIRE;1
71082;;Champlecy;CHAMPLECY;71120;71;SAONE ET LOIRE;1
71084;;Chânes;CHANES;71570;71;SAONE ET LOIRE;1
71085;;Change;CHANGE;21340;71;COTE D'OR;1
71086;;Changy;CHANGY;71120;71;SAONE ET LOIRE;1
71087;;Chapaize;CHAPAIZE;71460;71;SAONE ET LOIRE;1
71088;La;Chapelle-au-Mans;CHAPELLE-AU-MANS;71130;71;SAONE ET LOIRE;1
71089;La;Chapelle-de-Bragny;CHAPELLE-DE-BRAGNY;71240;71;SAONE ET LOIRE;1
71090;La;Chapelle-de-Guinchay;CHAPELLE-DE-GUINCHAY;71570;71;SAONE ET LOIRE;1
71091;La;Chapelle-du-Mont-de-France;CHAPELLE-DU-MONT-DE-FRANCE;71520;71;SAONE ET LOIRE;1
71092;La;Chapelle-Naude;CHAPELLE-NAUDE;71500;71;SAONE ET LOIRE;1
71093;La;Chapelle-Saint-Sauveur;CHAPELLE-SAINT-SAUVEUR;71310;71;SAONE ET LOIRE;1
71094;La;Chapelle-sous-Brancion;CHAPELLE-SOUS-BRANCION;71700;71;SAONE ET LOIRE;1
71095;La;Chapelle-sous-Dun;CHAPELLE-SOUS-DUN;71800;71;SAONE ET LOIRE;1
71096;La;Chapelle-sous-Uchon;CHAPELLE-SOUS-UCHON;71190;71;SAONE ET LOIRE;1
71097;La;Chapelle-Thècle;CHAPELLE-THECLE;71470;71;SAONE ET LOIRE;1
71098;;Charbonnat;CHARBONNAT;71320;71;SAONE ET LOIRE;1
71099;;Charbonnières;CHARBONNIERES;71260;71;SAONE ET LOIRE;1
71100;;Chardonnay;CHARDONNAY;71700;71;SAONE ET LOIRE;1
71101;;Charette-Varennes;CHARETTE-VARENNES;71270;71;SAONE ET LOIRE;1
71102;La;Charmée;CHARMEE;71100;71;SAONE ET LOIRE;1
71103;;Charmoy;CHARMOY;71710;71;SAONE ET LOIRE;1
71104;;Charnay-lès-Chalon;CHARNAY-LES-CHALON;71350;71;SAONE ET LOIRE;1
71105;;Charnay-lès-Mâcon;CHARNAY-LES-MACON;71850;71;SAONE ET LOIRE;1
71106;;Charolles;CHAROLLES;71120;71;SAONE ET LOIRE;1
71107;;Charrecey;CHARRECEY;71510;71;SAONE ET LOIRE;1
71108;;Chasselas;CHASSELAS;71570;71;SAONE ET LOIRE;1
71109;;Chassey-le-Camp;CHASSEY-LE-CAMP;71150;71;SAONE ET LOIRE;1
71110;;Chassigny-sous-Dun;CHASSIGNY-SOUS-DUN;71170;71;SAONE ET LOIRE;1
71111;;Chassy;CHASSY;71130;71;SAONE ET LOIRE;1
71112;;Château;CHATEAU;71250;71;SAONE ET LOIRE;1
71113;;Châteauneuf;CHATEAUNEUF;71740;71;SAONE ET LOIRE;1
71115;;Châtel-Moron;CHATEL-MORON;71510;71;SAONE ET LOIRE;1
71116;;Châtenay;CHATENAY;71800;71;SAONE ET LOIRE;1
71117;;Châtenoy-en-Bresse;CHATENOY-EN-BRESSE;71380;71;SAONE ET LOIRE;1
71118;;Châtenoy-le-Royal;CHATENOY-LE-ROYAL;71880;71;SAONE ET LOIRE;1
71119;;Chaudenay;CHAUDENAY;71150;71;SAONE ET LOIRE;1
71120;;Chauffailles;CHAUFFAILLES;71170;71;SAONE ET LOIRE;1
71121;La;Chaux;CHAUX;71310;71;SAONE ET LOIRE;1
71122;;Cheilly-lès-Maranges;CHEILLY-LES-MARANGES;71150;71;SAONE ET LOIRE;1
71123;;Chenay-le-Châtel;CHENAY-LE-CHATEL;71340;71;SAONE ET LOIRE;1
71124;;Chenôves;CHENOVES;71940;71;SAONE ET LOIRE;1
71125;;Chérizet;CHERIZET;71250;71;SAONE ET LOIRE;1
71126;;Chevagny-les-Chevrières;CHEVAGNY-LES-CHEVRIERES;71960;71;SAONE ET LOIRE;1
71127;;Chevagny-sur-Guye;CHEVAGNY-SUR-GUYE;71220;71;SAONE ET LOIRE;1
71128;;Chiddes;CHIDDES;71220;71;SAONE ET LOIRE;1
71129;;Chissey-en-Morvan;CHISSEY-EN-MORVAN;71540;71;SAONE ET LOIRE;1
71130;;Chissey-lès-Mâcon;CHISSEY-LES-MACON;71460;71;SAONE ET LOIRE;1
71131;;Ciel;CIEL;71350;71;SAONE ET LOIRE;1
71132;;Ciry-le-Noble;CIRY-LE-NOBLE;71420;71;SAONE ET LOIRE;1
71133;La;Clayette;CLAYETTE;71800;71;SAONE ET LOIRE;1
71134;;Clermain;CLERMAIN;71520;71;SAONE ET LOIRE;1
71135;;Clessé;CLESSE;71260;71;SAONE ET LOIRE;1
71136;;Clessy;CLESSY;71130;71;SAONE ET LOIRE;1
71137;;Cluny;CLUNY;71250;71;SAONE ET LOIRE;1
71138;;Clux;CLUX;71270;71;SAONE ET LOIRE;1
71139;;Collonge-en-Charollais;COLLONGE-EN-CHAROLLAIS;71460;71;SAONE ET LOIRE;1
71140;;Collonge-la-Madeleine;COLLONGE-LA-MADELEINE;71360;71;SAONE ET LOIRE;1
71141;;Colombier-en-Brionnais;COLOMBIER-EN-BRIONNAIS;71800;71;SAONE ET LOIRE;1
71142;La;Comelle;COMELLE;71990;71;SAONE ET LOIRE;1
71143;;Condal;CONDAL;71480;71;SAONE ET LOIRE;1
71144;;Cordesse;CORDESSE;71540;71;SAONE ET LOIRE;1
71145;;Cormatin;CORMATIN;71460;71;SAONE ET LOIRE;1
71146;;Cortambert;CORTAMBERT;71250;71;SAONE ET LOIRE;1
71147;;Cortevaix;CORTEVAIX;71460;71;SAONE ET LOIRE;1
71148;;Coublanc;COUBLANC;71170;71;SAONE ET LOIRE;1
71149;;Couches;COUCHES;71490;71;SAONE ET LOIRE;1
71150;;Crêches-sur-Saône;CRECHES-SUR-SAONE;71680;71;SAONE ET LOIRE;1
71151;;Créot;CREOT;71490;71;SAONE ET LOIRE;1
71152;;Cressy-sur-Somme;CRESSY-SUR-SOMME;71760;71;SAONE ET LOIRE;1
71153;Le;Creusot;CREUSOT;71200;71;SAONE ET LOIRE;1
71154;;Crissey;CRISSEY;71530;71;SAONE ET LOIRE;1
71155;;Cronat;CRONAT;71140;71;SAONE ET LOIRE;1
71156;;Cruzille;CRUZILLE;71260;71;SAONE ET LOIRE;1
71157;;Cuiseaux;CUISEAUX;71480;71;SAONE ET LOIRE;1
71158;;Cuisery;CUISERY;71290;71;SAONE ET LOIRE;1
71159;;Culles-les-Roches;CULLES-LES-ROCHES;71460;71;SAONE ET LOIRE;1
71160;;Curbigny;CURBIGNY;71800;71;SAONE ET LOIRE;1
71161;;Curdin;CURDIN;71130;71;SAONE ET LOIRE;1
71162;;Curgy;CURGY;71400;71;SAONE ET LOIRE;1
71163;;Curtil-sous-Buffières;CURTIL-SOUS-BUFFIERES;71520;71;SAONE ET LOIRE;1
71164;;Curtil-sous-Burnand;CURTIL-SOUS-BURNAND;71460;71;SAONE ET LOIRE;1
71165;;Cussy-en-Morvan;CUSSY-EN-MORVAN;71550;71;SAONE ET LOIRE;1
71166;;Cuzy;CUZY;71320;71;SAONE ET LOIRE;1
71167;;Damerey;DAMEREY;71620;71;SAONE ET LOIRE;1
71168;;Dampierre-en-Bresse;DAMPIERRE-EN-BRESSE;71310;71;SAONE ET LOIRE;1
71169;;Davayé;DAVAYE;71960;71;SAONE ET LOIRE;1
71170;;Demigny;DEMIGNY;71150;71;SAONE ET LOIRE;1
71171;;Dennevy;DENNEVY;71510;71;SAONE ET LOIRE;1
71172;;Dettey;DETTEY;71190;71;SAONE ET LOIRE;1
71173;;Devrouze;DEVROUZE;71330;71;SAONE ET LOIRE;1
71174;;Dezize-lès-Maranges;DEZIZE-LES-MARANGES;71150;71;SAONE ET LOIRE;1
71175;;Diconne;DICONNE;71330;71;SAONE ET LOIRE;1
71176;;Digoin;DIGOIN;71160;71;SAONE ET LOIRE;1
71177;;Dommartin-lès-Cuiseaux;DOMMARTIN-LES-CUISEAUX;71480;71;SAONE ET LOIRE;1
71178;;Dompierre-les-Ormes;DOMPIERRE-LES-ORMES;71520;71;SAONE ET LOIRE;1
71179;;Dompierre-sous-Sanvignes;DOMPIERRE-SOUS-SANVIGNES;71420;71;SAONE ET LOIRE;1
71180;;Donzy-le-National;DONZY-LE-NATIONAL;71250;71;SAONE ET LOIRE;1
71181;;Donzy-le-Pertuis;DONZY-LE-PERTUIS;71250;71;SAONE ET LOIRE;1
71182;;Dracy-le-Fort;DRACY-LE-FORT;71640;71;SAONE ET LOIRE;1
71183;;Dracy-lès-Couches;DRACY-LES-COUCHES;71490;71;SAONE ET LOIRE;1
71184;;Dracy-Saint-Loup;DRACY-SAINT-LOUP;71400;71;SAONE ET LOIRE;1
71185;;Dyo;DYO;71610;71;SAONE ET LOIRE;1
71186;;Écuelles;ECUELLES;71350;71;SAONE ET LOIRE;1
71187;;Écuisses;ECUISSES;71210;71;SAONE ET LOIRE;1
71188;;Épertully;EPERTULLY;71360;71;SAONE ET LOIRE;1
71189;;Épervans;EPERVANS;71380;71;SAONE ET LOIRE;1
71190;;Épinac;EPINAC;71360;71;SAONE ET LOIRE;1
71191;;Essertenne;ESSERTENNE;71510;71;SAONE ET LOIRE;1
71192;;Étang-sur-Arroux;ETANG-SUR-ARROUX;71190;71;SAONE ET LOIRE;1
71193;;Étrigny;ETRIGNY;71240;71;SAONE ET LOIRE;1
71194;;Farges-lès-Chalon;FARGES-LES-CHALON;71150;71;SAONE ET LOIRE;1
71195;;Farges-lès-Mâcon;FARGES-LES-MACON;71700;71;SAONE ET LOIRE;1
71196;Le;Fay;FAY;71580;71;SAONE ET LOIRE;1
71198;;Flacey-en-Bresse;FLACEY-EN-BRESSE;71580;71;SAONE ET LOIRE;1
71199;;Flagy;FLAGY;71250;71;SAONE ET LOIRE;1
71200;;Fleury-la-Montagne;FLEURY-LA-MONTAGNE;71340;71;SAONE ET LOIRE;1
71201;;Fley;FLEY;71390;71;SAONE ET LOIRE;1
71202;;Fontaines;FONTAINES;71150;71;SAONE ET LOIRE;1
71203;;Fontenay;FONTENAY;71120;71;SAONE ET LOIRE;1
71204;;Fragnes;FRAGNES;71530;71;SAONE ET LOIRE;1
71205;;Frangy-en-Bresse;FRANGY-EN-BRESSE;71330;71;SAONE ET LOIRE;1
71206;La;Frette;FRETTE;71440;71;SAONE ET LOIRE;1
71207;;Fretterans;FRETTERANS;71270;71;SAONE ET LOIRE;1
71208;;Frontenard;FRONTENARD;71270;71;SAONE ET LOIRE;1
71209;;Frontenaud;FRONTENAUD;71580;71;SAONE ET LOIRE;1
71210;;Fuissé;FUISSE;71960;71;SAONE ET LOIRE;1
71212;;Génelard;GENELARD;71420;71;SAONE ET LOIRE;1
71213;La;Genête;GENETE;71290;71;SAONE ET LOIRE;1
71214;;Genouilly;GENOUILLY;71460;71;SAONE ET LOIRE;1
71215;;Gergy;GERGY;71590;71;SAONE ET LOIRE;1
71216;;Germagny;GERMAGNY;71460;71;SAONE ET LOIRE;1
71217;;Germolles-sur-Grosne;GERMOLLES-SUR-GROSNE;71630;71;SAONE ET LOIRE;1
71218;;Gibles;GIBLES;71800;71;SAONE ET LOIRE;1
71219;;Gigny-sur-Saône;GIGNY-SUR-SAONE;71240;71;SAONE ET LOIRE;1
71220;;Gilly-sur-Loire;GILLY-SUR-LOIRE;71160;71;SAONE ET LOIRE;1
71221;;Givry;GIVRY;71640;71;SAONE ET LOIRE;1
71222;;Gourdon;GOURDON;71690;71;SAONE ET LOIRE;1
71223;La;Grande-Verrière;GRANDE-VERRIERE;71990;71;SAONE ET LOIRE;1
71224;;Grandvaux;GRANDVAUX;71430;71;SAONE ET LOIRE;1
71225;;Granges;GRANGES;71390;71;SAONE ET LOIRE;1
71226;;Grevilly;GREVILLY;71700;71;SAONE ET LOIRE;1
71227;;Grury;GRURY;71760;71;SAONE ET LOIRE;1
71228;;Guerfand;GUERFAND;71620;71;SAONE ET LOIRE;1
71229;Les;Guerreaux;GUERREAUX;71160;71;SAONE ET LOIRE;1
71230;;Gueugnon;GUEUGNON;71130;71;SAONE ET LOIRE;1
71231;La;Guiche;GUICHE;71220;71;SAONE ET LOIRE;1
71232;;Hautefond;HAUTEFOND;71600;71;SAONE ET LOIRE;1
71233;L';Hôpital-le-Mercier;HOPITAL-LE-MERCIER;71600;71;SAONE ET LOIRE;1
71234;;Huilly-sur-Seille;HUILLY-SUR-SEILLE;71290;71;SAONE ET LOIRE;1
71235;;Hurigny;HURIGNY;71870;71;SAONE ET LOIRE;1
71236;;Igé;IGE;71960;71;SAONE ET LOIRE;1
71237;;Igornay;IGORNAY;71540;71;SAONE ET LOIRE;1
71238;;Iguerande;IGUERANDE;71340;71;SAONE ET LOIRE;1
71239;;Issy-l'Évêque;ISSY-L'EVEQUE;71760;71;SAONE ET LOIRE;1
71240;;Jalogny;JALOGNY;71250;71;SAONE ET LOIRE;1
71241;;Jambles;JAMBLES;71640;71;SAONE ET LOIRE;1
71242;;Joncy;JONCY;71460;71;SAONE ET LOIRE;1
71243;;Joudes;JOUDES;71480;71;SAONE ET LOIRE;1
71244;;Jouvençon;JOUVENCON;71290;71;SAONE ET LOIRE;1
71245;;Jugy;JUGY;71240;71;SAONE ET LOIRE;1
71246;;Juif;JUIF;71440;71;SAONE ET LOIRE;1
71247;;Jully-lès-Buxy;JULLY-LES-BUXY;71390;71;SAONE ET LOIRE;1
71248;;Lacrost;LACROST;71700;71;SAONE ET LOIRE;1
71249;;Laives;LAIVES;71240;71;SAONE ET LOIRE;1
71250;;Laizé;LAIZE;71870;71;SAONE ET LOIRE;1
71251;;Laizy;LAIZY;71190;71;SAONE ET LOIRE;1
71252;;Lalheue;LALHEUE;71240;71;SAONE ET LOIRE;1
71253;;Lans;LANS;71380;71;SAONE ET LOIRE;1
71254;;Lays-sur-le-Doubs;LAYS-SUR-LE-DOUBS;71270;71;SAONE ET LOIRE;1
71255;;Lesme;LESME;71140;71;SAONE ET LOIRE;1
71256;;Lessard-en-Bresse;LESSARD-EN-BRESSE;71440;71;SAONE ET LOIRE;1
71257;;Lessard-le-National;LESSARD-LE-NATIONAL;71530;71;SAONE ET LOIRE;1
71258;;Leynes;LEYNES;71570;71;SAONE ET LOIRE;1
71259;;Ligny-en-Brionnais;LIGNY-EN-BRIONNAIS;71110;71;SAONE ET LOIRE;1
71261;;Loisy;LOISY;71290;71;SAONE ET LOIRE;1
71262;;Longepierre;LONGEPIERRE;71270;71;SAONE ET LOIRE;1
71263;;Louhans;LOUHANS;71500;71;SAONE ET LOIRE;1
71264;;Lournand;LOURNAND;71250;71;SAONE ET LOIRE;1
71265;La;Loyère;LOYERE;71530;71;SAONE ET LOIRE;1
71266;;Lucenay-l'Évêque;LUCENAY-L'EVEQUE;71540;71;SAONE ET LOIRE;1
71267;;Lugny;LUGNY;71260;71;SAONE ET LOIRE;1
71268;;Lugny-lès-Charolles;LUGNY-LES-CHAROLLES;71120;71;SAONE ET LOIRE;1
71269;;Lux;LUX;71100;71;SAONE ET LOIRE;1
71270;;Mâcon;MACON;71870;71;SAONE ET LOIRE;1
71271;;Mailly;MAILLY;71340;71;SAONE ET LOIRE;1
71272;;Malay;MALAY;71460;71;SAONE ET LOIRE;1
71273;;Maltat;MALTAT;71140;71;SAONE ET LOIRE;1
71274;;Mancey;MANCEY;71240;71;SAONE ET LOIRE;1
71275;;Marcigny;MARCIGNY;71110;71;SAONE ET LOIRE;1
71276;;Marcilly-la-Gueurce;MARCILLY-LA-GUEURCE;71120;71;SAONE ET LOIRE;1
71277;;Marcilly-lès-Buxy;MARCILLY-LES-BUXY;71390;71;SAONE ET LOIRE;1
71278;;Marigny;MARIGNY;71690;71;SAONE ET LOIRE;1
71279;;Marizy;MARIZY;71220;71;SAONE ET LOIRE;1
71280;;Marly-sous-Issy;MARLY-SOUS-ISSY;71760;71;SAONE ET LOIRE;1
71281;;Marly-sur-Arroux;MARLY-SUR-ARROUX;71420;71;SAONE ET LOIRE;1
71282;;Marmagne;MARMAGNE;71710;71;SAONE ET LOIRE;1
71283;;Marnay;MARNAY;71240;71;SAONE ET LOIRE;1
71284;;Martailly-lès-Brancion;MARTAILLY-LES-BRANCION;71700;71;SAONE ET LOIRE;1
71285;;Martigny-le-Comte;MARTIGNY-LE-COMTE;71220;71;SAONE ET LOIRE;1
71286;;Mary;MARY;71690;71;SAONE ET LOIRE;1
71287;;Massilly;MASSILLY;71250;71;SAONE ET LOIRE;1
71288;;Massy;MASSY;71250;71;SAONE ET LOIRE;1
71289;;Matour;MATOUR;71520;71;SAONE ET LOIRE;1
71290;;Mazille;MAZILLE;71250;71;SAONE ET LOIRE;1
71291;;Melay;MELAY;71340;71;SAONE ET LOIRE;1
71292;;Mellecey;MELLECEY;71640;71;SAONE ET LOIRE;1
71293;;Ménetreuil;MENETREUIL;71470;71;SAONE ET LOIRE;1
71294;;Mercurey;MERCUREY;71640;71;SAONE ET LOIRE;1
71295;;Mervans;MERVANS;71310;71;SAONE ET LOIRE;1
71296;;Messey-sur-Grosne;MESSEY-SUR-GROSNE;71940;71;SAONE ET LOIRE;1
71297;;Mesvres;MESVRES;71190;71;SAONE ET LOIRE;1
71299;;Milly-Lamartine;MILLY-LAMARTINE;71960;71;SAONE ET LOIRE;1
71300;Le;Miroir;MIROIR;71480;71;SAONE ET LOIRE;1
71301;;Mont;MONT;71140;71;SAONE ET LOIRE;1
71302;;Montagny-lès-Buxy;MONTAGNY-LES-BUXY;71390;71;SAONE ET LOIRE;1
71303;;Montagny-près-Louhans;MONTAGNY-PRES-LOUHANS;71500;71;SAONE ET LOIRE;1
71304;;Montagny-sur-Grosne;MONTAGNY-SUR-GROSNE;71520;71;SAONE ET LOIRE;1
71305;;Montbellet;MONTBELLET;71260;71;SAONE ET LOIRE;1
71306;;Montceau-les-Mines;MONTCEAU-LES-MINES;71300;71;SAONE ET LOIRE;1
71307;;Montceaux-l'Étoile;MONTCEAUX-L'ETOILE;71110;71;SAONE ET LOIRE;1
71308;;Montceaux-Ragny;MONTCEAUX-RAGNY;71240;71;SAONE ET LOIRE;1
71309;;Montcenis;MONTCENIS;71710;71;SAONE ET LOIRE;1
71310;;Montchanin;MONTCHANIN;71210;71;SAONE ET LOIRE;1
71311;;Montcony;MONTCONY;71500;71;SAONE ET LOIRE;1
71312;;Montcoy;MONTCOY;71620;71;SAONE ET LOIRE;1
71313;;Monthelon;MONTHELON;71400;71;SAONE ET LOIRE;1
71314;;Montjay;MONTJAY;71310;71;SAONE ET LOIRE;1
71315;;Mont-lès-Seurre;MONT-LES-SEURRE;71270;71;SAONE ET LOIRE;1
71316;;Montmelard;MONTMELARD;71520;71;SAONE ET LOIRE;1
71317;;Montmort;MONTMORT;71320;71;SAONE ET LOIRE;1
71318;;Montpont-en-Bresse;MONTPONT-EN-BRESSE;71470;71;SAONE ET LOIRE;1
71319;;Montret;MONTRET;71440;71;SAONE ET LOIRE;1
71320;;Mont-Saint-Vincent;MONT-SAINT-VINCENT;71690;71;SAONE ET LOIRE;1
71321;;Morey;MOREY;71510;71;SAONE ET LOIRE;1
71322;;Morlet;MORLET;71360;71;SAONE ET LOIRE;1
71323;;Mornay;MORNAY;71220;71;SAONE ET LOIRE;1
71324;;Moroges;MOROGES;71390;71;SAONE ET LOIRE;1
71325;La;Motte-Saint-Jean;MOTTE-SAINT-JEAN;71160;71;SAONE ET LOIRE;1
71326;;Mouthier-en-Bresse;MOUTHIER-EN-BRESSE;71270;71;SAONE ET LOIRE;1
71327;;Mussy-sous-Dun;MUSSY-SOUS-DUN;71170;71;SAONE ET LOIRE;1
71328;;Nanton;NANTON;71240;71;SAONE ET LOIRE;1
71329;;Navilly;NAVILLY;71270;71;SAONE ET LOIRE;1
71330;;Neuvy-Grandchamp;NEUVY-GRANDCHAMP;71130;71;SAONE ET LOIRE;1
71331;;Nochize;NOCHIZE;71600;71;SAONE ET LOIRE;1
71332;;Ormes;ORMES;71290;71;SAONE ET LOIRE;1
71333;;Oslon;OSLON;71380;71;SAONE ET LOIRE;1
71334;;Oudry;OUDRY;71420;71;SAONE ET LOIRE;1
71335;;Ouroux-sous-le-Bois-Sainte-Marie;OUROUX-SOUS-LE-BOIS-SAINTE-MARIE;71800;71;SAONE ET LOIRE;1
71336;;Ouroux-sur-Saône;OUROUX-SUR-SAONE;71370;71;SAONE ET LOIRE;1
71337;;Oyé;OYE;71610;71;SAONE ET LOIRE;1
71338;;Ozenay;OZENAY;71700;71;SAONE ET LOIRE;1
71339;;Ozolles;OZOLLES;71120;71;SAONE ET LOIRE;1
71340;;Palinges;PALINGES;71430;71;SAONE ET LOIRE;1
71341;;Palleau;PALLEAU;71350;71;SAONE ET LOIRE;1
71342;;Paray-le-Monial;PARAY-LE-MONIAL;71600;71;SAONE ET LOIRE;1
71343;;Paris-l'Hôpital;PARIS-L'HOPITAL;71150;71;SAONE ET LOIRE;1
71344;;Passy;PASSY;71220;71;SAONE ET LOIRE;1
71345;;Péronne;PERONNE;71260;71;SAONE ET LOIRE;1
71346;;Perrecy-les-Forges;PERRECY-LES-FORGES;71420;71;SAONE ET LOIRE;1
71347;;Perreuil;PERREUIL;71510;71;SAONE ET LOIRE;1
71348;;Perrigny-sur-Loire;PERRIGNY-SUR-LOIRE;71160;71;SAONE ET LOIRE;1
71349;La;Petite-Verrière;PETITE-VERRIERE;71400;71;SAONE ET LOIRE;1
71350;;Pierreclos;PIERRECLOS;71960;71;SAONE ET LOIRE;1
71351;;Pierre-de-Bresse;PIERRE-DE-BRESSE;71270;71;SAONE ET LOIRE;1
71352;Le;Planois;PLANOIS;71330;71;SAONE ET LOIRE;1
71353;;Plottes;PLOTTES;71700;71;SAONE ET LOIRE;1
71354;;Poisson;POISSON;71600;71;SAONE ET LOIRE;1
71355;;Pontoux;PONTOUX;71270;71;SAONE ET LOIRE;1
71356;;Pouilloux;POUILLOUX;71230;71;SAONE ET LOIRE;1
71357;;Pourlans;POURLANS;71270;71;SAONE ET LOIRE;1
71358;;Pressy-sous-Dondin;PRESSY-SOUS-DONDIN;71220;71;SAONE ET LOIRE;1
71359;;Préty;PRETY;71290;71;SAONE ET LOIRE;1
71360;;Prissé;PRISSE;71960;71;SAONE ET LOIRE;1
71361;;Prizy;PRIZY;71610;71;SAONE ET LOIRE;1
71362;;Pruzilly;PRUZILLY;71570;71;SAONE ET LOIRE;1
71363;Le;Puley;PULEY;71460;71;SAONE ET LOIRE;1
71364;La;Racineuse;RACINEUSE;71310;71;SAONE ET LOIRE;1
71365;;Rancy;RANCY;71290;71;SAONE ET LOIRE;1
71366;;Ratenelle;RATENELLE;71290;71;SAONE ET LOIRE;1
71367;;Ratte;RATTE;71500;71;SAONE ET LOIRE;1
71368;;Reclesne;RECLESNE;71540;71;SAONE ET LOIRE;1
71369;;Remigny;REMIGNY;71150;71;SAONE ET LOIRE;1
71370;;Rigny-sur-Arroux;RIGNY-SUR-ARROUX;71160;71;SAONE ET LOIRE;1
71371;La;Roche-Vineuse;ROCHE-VINEUSE;71960;71;SAONE ET LOIRE;1
71372;;Romanèche-Thorins;ROMANECHE-THORINS;71570;71;SAONE ET LOIRE;1
71373;;Romenay;ROMENAY;71470;71;SAONE ET LOIRE;1
71374;;Rosey;ROSEY;71390;71;SAONE ET LOIRE;1
71375;Le;Rousset;ROUSSET;71220;71;SAONE ET LOIRE;1
71376;;Roussillon-en-Morvan;ROUSSILLON-EN-MORVAN;71550;71;SAONE ET LOIRE;1
71377;;Royer;ROYER;71700;71;SAONE ET LOIRE;1
71378;;Rully;RULLY;71150;71;SAONE ET LOIRE;1
71379;;Sagy;SAGY;71580;71;SAONE ET LOIRE;1
71380;;Saillenard;SAILLENARD;71580;71;SAONE ET LOIRE;1
71381;;Sailly;SAILLY;71250;71;SAONE ET LOIRE;1
71382;;Saint-Agnan;SAINT-AGNAN;71160;71;SAONE ET LOIRE;1
71383;;Saint-Albain;SAINT-ALBAIN;71260;71;SAONE ET LOIRE;1
71384;;Saint-Ambreuil;SAINT-AMBREUIL;71240;71;SAONE ET LOIRE;1
71385;;Saint-Amour-Bellevue;SAINT-AMOUR-BELLEVUE;71570;71;SAONE ET LOIRE;1
71386;;Saint-André-en-Bresse;SAINT-ANDRE-EN-BRESSE;71440;71;SAONE ET LOIRE;1
71387;;Saint-André-le-Désert;SAINT-ANDRE-LE-DESERT;71220;71;SAONE ET LOIRE;1
71388;;Saint-Aubin-en-Charollais;SAINT-AUBIN-EN-CHAROLLAIS;71430;71;SAONE ET LOIRE;1
71389;;Saint-Aubin-sur-Loire;SAINT-AUBIN-SUR-LOIRE;71140;71;SAONE ET LOIRE;1
71390;;Saint-Berain-sous-Sanvignes;SAINT-BERAIN-SOUS-SANVIGNES;71300;71;SAONE ET LOIRE;1
71391;;Saint-Bérain-sur-Dheune;SAINT-BERAIN-SUR-DHEUNE;71510;71;SAONE ET LOIRE;1
71392;;Saint-Boil;SAINT-BOIL;71940;71;SAONE ET LOIRE;1
71393;;Saint-Bonnet-de-Cray;SAINT-BONNET-DE-CRAY;71340;71;SAONE ET LOIRE;1
71394;;Saint-Bonnet-de-Joux;SAINT-BONNET-DE-JOUX;71220;71;SAONE ET LOIRE;1
71395;;Saint-Bonnet-de-Vieille-Vigne;SAINT-BONNET-DE-VIEILLE-VIGNE;71430;71;SAONE ET LOIRE;1
71396;;Saint-Bonnet-en-Bresse;SAINT-BONNET-EN-BRESSE;71310;71;SAONE ET LOIRE;1
71397;;Sainte-Cécile;SAINTE-CECILE;71250;71;SAONE ET LOIRE;1
71398;;Saint-Christophe-en-Bresse;SAINT-CHRISTOPHE-EN-BRESSE;71370;71;SAONE ET LOIRE;1
71399;;Saint-Christophe-en-Brionnais;SAINT-CHRISTOPHE-EN-BRIONNAIS;71800;71;SAONE ET LOIRE;1
71400;;Saint-Clément-sur-Guye;SAINT-CLEMENT-SUR-GUYE;71460;71;SAONE ET LOIRE;1
71401;;Sainte-Croix;SAINTE-CROIX;71470;71;SAONE ET LOIRE;1
71402;;Saint-Cyr;SAINT-CYR;71240;71;SAONE ET LOIRE;1
71403;;Saint-Denis-de-Vaux;SAINT-DENIS-DE-VAUX;71640;71;SAONE ET LOIRE;1
71404;;Saint-Désert;SAINT-DESERT;71390;71;SAONE ET LOIRE;1
71405;;Saint-Didier-en-Bresse;SAINT-DIDIER-EN-BRESSE;71620;71;SAONE ET LOIRE;1
71406;;Saint-Didier-en-Brionnais;SAINT-DIDIER-EN-BRIONNAIS;71110;71;SAONE ET LOIRE;1
71407;;Saint-Didier-sur-Arroux;SAINT-DIDIER-SUR-ARROUX;71190;71;SAONE ET LOIRE;1
71408;;Saint-Edmond;SAINT-EDMOND;71740;71;SAONE ET LOIRE;1
71409;;Saint-Émiland;SAINT-EMILAND;71490;71;SAONE ET LOIRE;1
71410;;Saint-Étienne-en-Bresse;SAINT-ETIENNE-EN-BRESSE;71370;71;SAONE ET LOIRE;1
71411;;Saint-Eugène;SAINT-EUGENE;71190;71;SAONE ET LOIRE;1
71412;;Saint-Eusèbe;SAINT-EUSEBE;71210;71;SAONE ET LOIRE;1
71413;;Saint-Firmin;SAINT-FIRMIN;71670;71;SAONE ET LOIRE;1
71414;;Saint-Forgeot;SAINT-FORGEOT;71400;71;SAONE ET LOIRE;1
71415;;Sainte-Foy;SAINTE-FOY;71110;71;SAONE ET LOIRE;1
71416;;Saint-Gengoux-de-Scissé;SAINT-GENGOUX-DE-SCISSE;71260;71;SAONE ET LOIRE;1
71417;;Saint-Gengoux-le-National;SAINT-GENGOUX-LE-NATIONAL;71460;71;SAONE ET LOIRE;1
71419;;Saint-Germain-du-Bois;SAINT-GERMAIN-DU-BOIS;71330;71;SAONE ET LOIRE;1
71420;;Saint-Germain-du-Plain;SAINT-GERMAIN-DU-PLAIN;71370;71;SAONE ET LOIRE;1
71421;;Saint-Germain-en-Brionnais;SAINT-GERMAIN-EN-BRIONNAIS;71610;71;SAONE ET LOIRE;1
71422;;Saint-Germain-lès-Buxy;SAINT-GERMAIN-LES-BUXY;71390;71;SAONE ET LOIRE;1
71423;;Saint-Gervais-en-Vallière;SAINT-GERVAIS-EN-VALLIERE;71350;71;SAONE ET LOIRE;1
71424;;Saint-Gervais-sur-Couches;SAINT-GERVAIS-SUR-COUCHES;71490;71;SAONE ET LOIRE;1
71425;;Saint-Gilles;SAINT-GILLES;71510;71;SAONE ET LOIRE;1
71426;;Sainte-Hélène;SAINTE-HELENE;71390;71;SAONE ET LOIRE;1
71427;;Saint-Huruge;SAINT-HURUGE;71460;71;SAONE ET LOIRE;1
71428;;Saint-Igny-de-Roche;SAINT-IGNY-DE-ROCHE;71170;71;SAONE ET LOIRE;1
71430;;Saint-Jean-de-Vaux;SAINT-JEAN-DE-VAUX;71640;71;SAONE ET LOIRE;1
71431;;Saint-Jean-de-Trézy;SAINT-JEAN-DE-TREZY;71490;71;SAONE ET LOIRE;1
71433;;Saint-Julien-de-Civry;SAINT-JULIEN-DE-CIVRY;71610;71;SAONE ET LOIRE;1
71434;;Saint-Julien-de-Jonzy;SAINT-JULIEN-DE-JONZY;71110;71;SAONE ET LOIRE;1
71435;;Saint-Julien-sur-Dheune;SAINT-JULIEN-SUR-DHEUNE;71210;71;SAONE ET LOIRE;1
71436;;Saint-Laurent-d'Andenay;SAINT-LAURENT-D'ANDENAY;71210;71;SAONE ET LOIRE;1
71437;;Saint-Laurent-en-Brionnais;SAINT-LAURENT-EN-BRIONNAIS;71800;71;SAONE ET LOIRE;1
71438;;Saint-Léger-du-Bois;SAINT-LEGER-DU-BOIS;71360;71;SAONE ET LOIRE;1
71439;;Saint-Léger-lès-Paray;SAINT-LEGER-LES-PARAY;71600;71;SAONE ET LOIRE;1
71440;;Saint-Léger-sous-Beuvray;SAINT-LEGER-SOUS-BEUVRAY;71990;71;SAONE ET LOIRE;1
71441;;Saint-Léger-sous-la-Bussière;SAINT-LEGER-SOUS-LA-BUSSIERE;71520;71;SAONE ET LOIRE;1
71442;;Saint-Léger-sur-Dheune;SAINT-LEGER-SUR-DHEUNE;71510;71;SAONE ET LOIRE;1
71443;;Saint-Loup-Géanges;SAINT-LOUP-GEANGES;71133;71;SAONE ET LOIRE;1
71444;;Saint-Loup-de-Varennes;SAINT-LOUP-DE-VARENNES;71240;71;SAONE ET LOIRE;1
71445;;Saint-Marcel;SAINT-MARCEL;71380;71;SAONE ET LOIRE;1
71446;;Saint-Marcelin-de-Cray;SAINT-MARCELIN-DE-CRAY;71460;71;SAONE ET LOIRE;1
71447;;Saint-Mard-de-Vaux;SAINT-MARD-DE-VAUX;71640;71;SAONE ET LOIRE;1
71448;;Saint-Martin-Belle-Roche;SAINT-MARTIN-BELLE-ROCHE;71118;71;SAONE ET LOIRE;1
71449;;Saint-Martin-d'Auxy;SAINT-MARTIN-D'AUXY;71390;71;SAONE ET LOIRE;1
71450;;Saint-Martin-de-Commune;SAINT-MARTIN-DE-COMMUNE;71490;71;SAONE ET LOIRE;1
71451;;Saint-Martin-de-Lixy;SAINT-MARTIN-DE-LIXY;71740;71;SAONE ET LOIRE;1
71452;;Saint-Martin-de-Salencey;SAINT-MARTIN-DE-SALENCEY;71220;71;SAONE ET LOIRE;1
71453;;Saint-Martin-du-Lac;SAINT-MARTIN-DU-LAC;71110;71;SAONE ET LOIRE;1
71454;;Saint-Martin-du-Mont;SAINT-MARTIN-DU-MONT;71580;71;SAONE ET LOIRE;1
71455;;Saint-Martin-du-Tartre;SAINT-MARTIN-DU-TARTRE;71460;71;SAONE ET LOIRE;1
71456;;Saint-Martin-en-Bresse;SAINT-MARTIN-EN-BRESSE;71620;71;SAONE ET LOIRE;1
71457;;Saint-Martin-en-Gâtinois;SAINT-MARTIN-EN-GATINOIS;71350;71;SAONE ET LOIRE;1
71458;;Saint-Martin-la-Patrouille;SAINT-MARTIN-LA-PATROUILLE;71460;71;SAONE ET LOIRE;1
71459;;Saint-Martin-sous-Montaigu;SAINT-MARTIN-SOUS-MONTAIGU;71640;71;SAONE ET LOIRE;1
71460;;Saint-Maurice-de-Satonnay;SAINT-MAURICE-DE-SATONNAY;71260;71;SAONE ET LOIRE;1
71461;;Saint-Maurice-des-Champs;SAINT-MAURICE-DES-CHAMPS;71460;71;SAONE ET LOIRE;1
71462;;Saint-Maurice-en-Rivière;SAINT-MAURICE-EN-RIVIERE;71620;71;SAONE ET LOIRE;1
71463;;Saint-Maurice-lès-Châteauneuf;SAINT-MAURICE-LES-CHATEAUNEUF;71740;71;SAONE ET LOIRE;1
71464;;Saint-Maurice-lès-Couches;SAINT-MAURICE-LES-COUCHES;71490;71;SAONE ET LOIRE;1
71465;;Saint-Micaud;SAINT-MICAUD;71460;71;SAONE ET LOIRE;1
71466;;Saint-Nizier-sur-Arroux;SAINT-NIZIER-SUR-ARROUX;71190;71;SAONE ET LOIRE;1
71468;;Saint-Pierre-de-Varennes;SAINT-PIERRE-DE-VARENNES;71670;71;SAONE ET LOIRE;1
71469;;Saint-Pierre-le-Vieux;SAINT-PIERRE-LE-VIEUX;71520;71;SAONE ET LOIRE;1
71470;;Saint-Point;SAINT-POINT;71630;71;SAONE ET LOIRE;1
71471;;Saint-Privé;SAINT-PRIVE;71390;71;SAONE ET LOIRE;1
71472;;Saint-Prix;SAINT-PRIX;71990;71;SAONE ET LOIRE;1
71473;;Saint-Racho;SAINT-RACHO;71800;71;SAONE ET LOIRE;1
71474;;Sainte-Radegonde;SAINTE-RADEGONDE;71320;71;SAONE ET LOIRE;1
71475;;Saint-Rémy;SAINT-REMY;71100;71;SAONE ET LOIRE;1
71477;;Saint-Romain-sous-Gourdon;SAINT-ROMAIN-SOUS-GOURDON;71230;71;SAONE ET LOIRE;1
71478;;Saint-Romain-sous-Versigny;SAINT-ROMAIN-SOUS-VERSIGNY;71420;71;SAONE ET LOIRE;1
71479;;Saint-Sernin-du-Bois;SAINT-SERNIN-DU-BOIS;71200;71;SAONE ET LOIRE;1
71480;;Saint-Sernin-du-Plain;SAINT-SERNIN-DU-PLAIN;71510;71;SAONE ET LOIRE;1
71481;;Saint-Symphorien-d'Ancelles;SAINT-SYMPHORIEN-D'ANCELLES;71570;71;SAONE ET LOIRE;1
71482;;Saint-Symphorien-de-Marmagne;SAINT-SYMPHORIEN-DE-MARMAGNE;71710;71;SAONE ET LOIRE;1
71483;;Saint-Symphorien-des-Bois;SAINT-SYMPHORIEN-DES-BOIS;71800;71;SAONE ET LOIRE;1
71484;;Saint-Usuge;SAINT-USUGE;71500;71;SAONE ET LOIRE;1
71485;;Saint-Vallerin;SAINT-VALLERIN;71390;71;SAONE ET LOIRE;1
71486;;Saint-Vallier;SAINT-VALLIER;71230;71;SAONE ET LOIRE;1
71487;;Saint-Vérand;SAINT-VERAND;71570;71;SAONE ET LOIRE;1
71488;;Saint-Vincent-des-Prés;SAINT-VINCENT-DES-PRES;71250;71;SAONE ET LOIRE;1
71489;;Saint-Vincent-en-Bresse;SAINT-VINCENT-EN-BRESSE;71440;71;SAONE ET LOIRE;1
71490;;Saint-Vincent-Bragny;SAINT-VINCENT-BRAGNY;71430;71;SAONE ET LOIRE;1
71491;;Saint-Yan;SAINT-YAN;71600;71;SAONE ET LOIRE;1
71492;;Saint-Ythaire;SAINT-YTHAIRE;71460;71;SAONE ET LOIRE;1
71493;;Saisy;SAISY;71360;71;SAONE ET LOIRE;1
71494;La;Salle;SALLE;71260;71;SAONE ET LOIRE;1
71495;;Salornay-sur-Guye;SALORNAY-SUR-GUYE;71250;71;SAONE ET LOIRE;1
71496;;Sampigny-lès-Maranges;SAMPIGNY-LES-MARANGES;71150;71;SAONE ET LOIRE;1
71497;;Sancé;SANCE;71000;71;SAONE ET LOIRE;1
71498;;Santilly;SANTILLY;71460;71;SAONE ET LOIRE;1
71499;;Sanvignes-les-Mines;SANVIGNES-LES-MINES;71410;71;SAONE ET LOIRE;1
71500;;Sarry;SARRY;71110;71;SAONE ET LOIRE;1
71501;;Sassangy;SASSANGY;71390;71;SAONE ET LOIRE;1
71502;;Sassenay;SASSENAY;71530;71;SAONE ET LOIRE;1
71503;;Saules;SAULES;71940;71;SAONE ET LOIRE;1
71504;;Saunières;SAUNIERES;71350;71;SAONE ET LOIRE;1
71505;;Savianges;SAVIANGES;71460;71;SAONE ET LOIRE;1
71506;;Savigny-en-Revermont;SAVIGNY-EN-REVERMONT;71580;71;SAONE ET LOIRE;1
71507;;Savigny-sur-Grosne;SAVIGNY-SUR-GROSNE;71460;71;SAONE ET LOIRE;1
71508;;Savigny-sur-Seille;SAVIGNY-SUR-SEILLE;71440;71;SAONE ET LOIRE;1
71509;La;Celle-en-Morvan;CELLE-EN-MORVAN;71400;71;SAONE ET LOIRE;1
71510;;Semur-en-Brionnais;SEMUR-EN-BRIONNAIS;71110;71;SAONE ET LOIRE;1
71512;;Sennecey-le-Grand;SENNECEY-LE-GRAND;71240;71;SAONE ET LOIRE;1
71513;;Senozan;SENOZAN;71260;71;SAONE ET LOIRE;1
71514;;Sens-sur-Seille;SENS-SUR-SEILLE;71330;71;SAONE ET LOIRE;1
71515;;Sercy;SERCY;71460;71;SAONE ET LOIRE;1
71516;;Serley;SERLEY;71310;71;SAONE ET LOIRE;1
71517;;Sermesse;SERMESSE;71350;71;SAONE ET LOIRE;1
71518;;Serrières;SERRIERES;71960;71;SAONE ET LOIRE;1
71519;;Serrigny-en-Bresse;SERRIGNY-EN-BRESSE;71310;71;SAONE ET LOIRE;1
71520;;Sevrey;SEVREY;71100;71;SAONE ET LOIRE;1
71521;;Sigy-le-Châtel;SIGY-LE-CHATEL;71250;71;SAONE ET LOIRE;1
71522;;Simandre;SIMANDRE;71290;71;SAONE ET LOIRE;1
71523;;Simard;SIMARD;71330;71;SAONE ET LOIRE;1
71524;;Sivignon;SIVIGNON;71220;71;SAONE ET LOIRE;1
71525;;Sologny;SOLOGNY;71960;71;SAONE ET LOIRE;1
71526;;Solutré-Pouilly;SOLUTRE-POUILLY;71960;71;SAONE ET LOIRE;1
71527;;Sommant;SOMMANT;71540;71;SAONE ET LOIRE;1
71528;;Sornay;SORNAY;71500;71;SAONE ET LOIRE;1
71529;;Suin;SUIN;71220;71;SAONE ET LOIRE;1
71530;;Sully;SULLY;71360;71;SAONE ET LOIRE;1
71531;La;Tagnière;TAGNIERE;71190;71;SAONE ET LOIRE;1
71532;;Taizé;TAIZE;71250;71;SAONE ET LOIRE;1
71533;;Tancon;TANCON;71740;71;SAONE ET LOIRE;1
71534;Le;Tartre;TARTRE;71330;71;SAONE ET LOIRE;1
71535;;Tavernay;TAVERNAY;71400;71;SAONE ET LOIRE;1
71537;;Thil-sur-Arroux;THIL-SUR-ARROUX;71190;71;SAONE ET LOIRE;1
71538;;Thurey;THUREY;71440;71;SAONE ET LOIRE;1
71539;;Tintry;TINTRY;71490;71;SAONE ET LOIRE;1
71540;;Torcy;TORCY;71210;71;SAONE ET LOIRE;1
71541;;Torpes;TORPES;71270;71;SAONE ET LOIRE;1
71542;;Toulon-sur-Arroux;TOULON-SUR-ARROUX;71320;71;SAONE ET LOIRE;1
71543;;Tournus;TOURNUS;71700;71;SAONE ET LOIRE;1
71544;;Toutenant;TOUTENANT;71350;71;SAONE ET LOIRE;1
71545;;Tramayes;TRAMAYES;71520;71;SAONE ET LOIRE;1
71546;;Trambly;TRAMBLY;71520;71;SAONE ET LOIRE;1
71547;;Trivy;TRIVY;71520;71;SAONE ET LOIRE;1
71548;;Tronchy;TRONCHY;71440;71;SAONE ET LOIRE;1
71549;La;Truchère;TRUCHERE;71290;71;SAONE ET LOIRE;1
71550;;Uchizy;UCHIZY;71700;71;SAONE ET LOIRE;1
71551;;Uchon;UCHON;71190;71;SAONE ET LOIRE;1
71552;;Uxeau;UXEAU;71130;71;SAONE ET LOIRE;1
71553;;Vareilles;VAREILLES;71800;71;SAONE ET LOIRE;1
71554;;Varenne-l'Arconce;VARENNE-L'ARCONCE;71110;71;SAONE ET LOIRE;1
71555;;Varennes-le-Grand;VARENNES-LE-GRAND;71240;71;SAONE ET LOIRE;1
71556;;Varennes-lès-Mâcon;VARENNES-LES-MACON;71000;71;SAONE ET LOIRE;1
71557;;Varenne-Saint-Germain;VARENNE-SAINT-GERMAIN;71600;71;SAONE ET LOIRE;1
71558;;Varennes-Saint-Sauveur;VARENNES-SAINT-SAUVEUR;71480;71;SAONE ET LOIRE;1
71559;;Varennes-sous-Dun;VARENNES-SOUS-DUN;71800;71;SAONE ET LOIRE;1
71561;;Vauban;VAUBAN;71800;71;SAONE ET LOIRE;1
71562;;Vaudebarrier;VAUDEBARRIER;71120;71;SAONE ET LOIRE;1
71563;;Vaux-en-Pré;VAUX-EN-PRE;71460;71;SAONE ET LOIRE;1
71564;;Vendenesse-lès-Charolles;VENDENESSE-LES-CHAROLLES;71120;71;SAONE ET LOIRE;1
71565;;Vendenesse-sur-Arroux;VENDENESSE-SUR-ARROUX;71130;71;SAONE ET LOIRE;1
71566;;Verdun-sur-le-Doubs;VERDUN-SUR-LE-DOUBS;71350;71;SAONE ET LOIRE;1
71567;;Vergisson;VERGISSON;71960;71;SAONE ET LOIRE;1
71568;;Vérissey;VERISSEY;71440;71;SAONE ET LOIRE;1
71570;;Verjux;VERJUX;71590;71;SAONE ET LOIRE;1
71571;;Verosvres;VEROSVRES;71220;71;SAONE ET LOIRE;1
71572;;Vers;VERS;71240;71;SAONE ET LOIRE;1
71573;;Versaugues;VERSAUGUES;71110;71;SAONE ET LOIRE;1
71574;;Verzé;VERZE;71960;71;SAONE ET LOIRE;1
71576;Le;Villars;VILLARS;71700;71;SAONE ET LOIRE;1
71577;;Villegaudin;VILLEGAUDIN;71620;71;SAONE ET LOIRE;1
71578;La;Villeneuve;VILLENEUVE;71270;71;SAONE ET LOIRE;1
71579;;Villeneuve-en-Montagne;VILLENEUVE-EN-MONTAGNE;71390;71;SAONE ET LOIRE;1
71580;;Vincelles;VINCELLES;71500;71;SAONE ET LOIRE;1
71581;;Vindecy;VINDECY;71110;71;SAONE ET LOIRE;1
71582;La;Vineuse;VINEUSE;71250;71;SAONE ET LOIRE;1
71583;;Vinzelles;VINZELLES;71680;71;SAONE ET LOIRE;1
71584;;Viré;VIRE;71260;71;SAONE ET LOIRE;1
71585;;Virey-le-Grand;VIREY-LE-GRAND;71530;71;SAONE ET LOIRE;1
71586;;Viry;VIRY;71120;71;SAONE ET LOIRE;1
71587;;Vitry-lès-Cluny;VITRY-LES-CLUNY;71250;71;SAONE ET LOIRE;1
71588;;Vitry-en-Charollais;VITRY-EN-CHAROLLAIS;71600;71;SAONE ET LOIRE;1
71589;;Vitry-sur-Loire;VITRY-SUR-LOIRE;71140;71;SAONE ET LOIRE;1
71590;;Volesvres;VOLESVRES;71600;71;SAONE ET LOIRE;1
71591;;Fleurville;FLEURVILLE;71260;71;SAONE ET LOIRE;1
72001;;Aigné;AIGNE;72650;72;SARTHE;1
72002;;Aillières-Beauvoir;AILLIERES-BEAUVOIR;72600;72;SARTHE;1
72003;;Allonnes;ALLONNES;72700;72;SARTHE;1
72004;;Amné;AMNE;72540;72;SARTHE;1
72005;;Ancinnes;ANCINNES;72610;72;SARTHE;1
72006;;Arçonnay;ARCONNAY;72610;72;SARTHE;1
72007;;Ardenay-sur-Mérize;ARDENAY-SUR-MERIZE;72370;72;SARTHE;1
72008;;Arnage;ARNAGE;72230;72;SARTHE;1
72009;;Arthezé;ARTHEZE;72270;72;SARTHE;1
72010;;Asnières-sur-Vègre;ASNIERES-SUR-VEGRE;72430;72;SARTHE;1
72011;;Assé-le-Boisne;ASSE-LE-BOISNE;72130;72;SARTHE;1
72012;;Assé-le-Riboul;ASSE-LE-RIBOUL;72170;72;SARTHE;1
72013;;Aubigné-Racan;AUBIGNE-RACAN;72800;72;SARTHE;1
72015;Les;Aulneaux;AULNEAUX;72670;72;SARTHE;1
72016;;Auvers-le-Hamon;AUVERS-LE-HAMON;72300;72;SARTHE;1
72017;;Auvers-sous-Montfaucon;AUVERS-SOUS-MONTFAUCON;72540;72;SARTHE;1
72018;;Avesnes-en-Saosnois;AVESNES-EN-SAOSNOIS;72260;72;SARTHE;1
72019;;Avessé;AVESSE;72350;72;SARTHE;1
72020;;Avezé;AVEZE;72400;72;SARTHE;1
72021;;Avoise;AVOISE;72430;72;SARTHE;1
72022;Le;Bailleul;BAILLEUL;72200;72;SARTHE;1
72023;;Ballon;BALLON;72290;72;SARTHE;1
72024;La;Bazoge;BAZOGE;72650;72;SARTHE;1
72025;;Bazouges-sur-le-Loir;BAZOUGES-SUR-LE-LOIR;72200;72;SARTHE;1
72026;;Beaufay;BEAUFAY;72110;72;SARTHE;1
72027;;Beaumont-sur-Dême;BEAUMONT-SUR-DEME;72340;72;SARTHE;1
72028;;Beaumont-Pied-de-Bœuf;BEAUMONT-PIED-DE-BOEUF;72500;72;SARTHE;1
72029;;Beaumont-sur-Sarthe;BEAUMONT-SUR-SARTHE;72170;72;SARTHE;1
72031;;Beillé;BEILLE;72160;72;SARTHE;1
72032;;Berfay;BERFAY;72320;72;SARTHE;1
72033;;Bernay-en-Champagne;BERNAY-EN-CHAMPAGNE;72240;72;SARTHE;1
72034;;Bérus;BERUS;72610;72;SARTHE;1
72035;;Bessé-sur-Braye;BESSE-SUR-BRAYE;72310;72;SARTHE;1
72036;;Béthon;BETHON;72610;72;SARTHE;1
72037;;Blèves;BLEVES;72670;72;SARTHE;1
72038;;Boëssé-le-Sec;BOESSE-LE-SEC;72400;72;SARTHE;1
72039;;Bonnétable;BONNETABLE;72110;72;SARTHE;1
72040;La;Bosse;BOSSE;72400;72;SARTHE;1
72041;;Bouër;BOUER;72390;72;SARTHE;1
72042;;Bouloire;BOULOIRE;72440;72;SARTHE;1
72043;;Bourg-le-Roi;BOURG-LE-ROI;72610;72;SARTHE;1
72044;;Bousse;BOUSSE;72270;72;SARTHE;1
72045;;Brains-sur-Gée;BRAINS-SUR-GEE;72550;72;SARTHE;1
72046;Le;Breil-sur-Mérize;BREIL-SUR-MERIZE;72370;72;SARTHE;1
72047;;Brette-les-Pins;BRETTE-LES-PINS;72250;72;SARTHE;1
72048;;Briosne-lès-Sables;BRIOSNE-LES-SABLES;72110;72;SARTHE;1
72049;La;Bruère-sur-Loir;BRUERE-SUR-LOIR;72500;72;SARTHE;1
72050;;Brûlon;BRULON;72350;72;SARTHE;1
72051;;Cérans-Foulletourte;CERANS-FOULLETOURTE;72330;72;SARTHE;1
72052;;Chahaignes;CHAHAIGNES;72340;72;SARTHE;1
72053;;Challes;CHALLES;72250;72;SARTHE;1
72054;;Champagné;CHAMPAGNE;72470;72;SARTHE;1
72056;;Champfleur;CHAMPFLEUR;72610;72;SARTHE;1
72057;;Champrond;CHAMPROND;72320;72;SARTHE;1
72058;;Changé;CHANGE;72560;72;SARTHE;1
72059;;Chantenay-Villedieu;CHANTENAY-VILLEDIEU;72430;72;SARTHE;1
72060;La;Chapelle-aux-Choux;CHAPELLE-AUX-CHOUX;72800;72;SARTHE;1
72061;La;Chapelle-d'Aligné;CHAPELLE-D'ALIGNE;72300;72;SARTHE;1
72062;La;Chapelle-du-Bois;CHAPELLE-DU-BOIS;72400;72;SARTHE;1
72063;La;Chapelle-Gaugain;CHAPELLE-GAUGAIN;72310;72;SARTHE;1
72064;La;Chapelle-Huon;CHAPELLE-HUON;72310;72;SARTHE;1
72065;La;Chapelle-Saint-Aubin;CHAPELLE-SAINT-AUBIN;72650;72;SARTHE;1
72066;La;Chapelle-Saint-Fray;CHAPELLE-SAINT-FRAY;72240;72;SARTHE;1
72067;La;Chapelle-Saint-Rémy;CHAPELLE-SAINT-REMY;72160;72;SARTHE;1
72068;La;Chartre-sur-le-Loir;CHARTRE-SUR-LE-LOIR;72340;72;SARTHE;1
72069;;Chassé;CHASSE;72670;72;SARTHE;1
72070;;Chassillé;CHASSILLE;72540;72;SARTHE;1
72071;;Château-du-Loir;CHATEAU-DU-LOIR;72500;72;SARTHE;1
72072;;Château-l'Hermitage;CHATEAU-L'HERMITAGE;72510;72;SARTHE;1
72073;;Chaufour-Notre-Dame;CHAUFOUR-NOTRE-DAME;72550;72;SARTHE;1
72074;;Chemiré-en-Charnie;CHEMIRE-EN-CHARNIE;72540;72;SARTHE;1
72075;;Chemiré-le-Gaudin;CHEMIRE-LE-GAUDIN;72210;72;SARTHE;1
72076;;Chenay;CHENAY;72610;72;SARTHE;1
72077;;Chenu;CHENU;72500;72;SARTHE;1
72078;;Chérancé;CHERANCE;72170;72;SARTHE;1
72079;;Chérisay;CHERISAY;72610;72;SARTHE;1
72080;;Cherré;CHERRE;72400;72;SARTHE;1
72081;;Cherreau;CHERREAU;72400;72;SARTHE;1
72082;Le;Chevain;CHEVAIN;72610;72;SARTHE;1
72083;;Chevillé;CHEVILLE;72350;72;SARTHE;1
72084;;Clermont-Créans;CLERMONT-CREANS;72200;72;SARTHE;1
72085;;Cogners;COGNERS;72310;72;SARTHE;1
72086;;Commerveil;COMMERVEIL;72600;72;SARTHE;1
72087;;Conflans-sur-Anille;CONFLANS-SUR-ANILLE;72120;72;SARTHE;1
72088;;Congé-sur-Orne;CONGE-SUR-ORNE;72290;72;SARTHE;1
72089;;Conlie;CONLIE;72240;72;SARTHE;1
72090;;Connerré;CONNERRE;72160;72;SARTHE;1
72091;;Contilly;CONTILLY;72600;72;SARTHE;1
72093;;Cormes;CORMES;72400;72;SARTHE;1
72094;;Coudrecieux;COUDRECIEUX;72440;72;SARTHE;1
72095;;Coulaines;COULAINES;72190;72;SARTHE;1
72096;;Coulans-sur-Gée;COULANS-SUR-GEE;72550;72;SARTHE;1
72097;;Coulombiers;COULOMBIERS;72130;72;SARTHE;1
72098;;Coulongé;COULONGE;72800;72;SARTHE;1
72099;;Courcebœufs;COURCEBOEUFS;72290;72;SARTHE;1
72100;;Courcelles-la-Forêt;COURCELLES-LA-FORET;72270;72;SARTHE;1
72101;;Courcemont;COURCEMONT;72110;72;SARTHE;1
72102;;Courcival;COURCIVAL;72110;72;SARTHE;1
72103;;Courdemanche;COURDEMANCHE;72150;72;SARTHE;1
72104;;Courgains;COURGAINS;72260;72;SARTHE;1
72105;;Courgenard;COURGENARD;72320;72;SARTHE;1
72106;;Courtillers;COURTILLERS;72300;72;SARTHE;1
72107;;Crannes-en-Champagne;CRANNES-EN-CHAMPAGNE;72540;72;SARTHE;1
72108;;Cré;CRE;72200;72;SARTHE;1
72109;;Crissé;CRISSE;72140;72;SARTHE;1
72110;;Crosmières;CROSMIERES;72200;72;SARTHE;1
72111;;Cures;CURES;72240;72;SARTHE;1
72112;;Dangeul;DANGEUL;72260;72;SARTHE;1
72113;;Degré;DEGRE;72550;72;SARTHE;1
72114;;Dehault;DEHAULT;72400;72;SARTHE;1
72115;;Dissay-sous-Courcillon;DISSAY-SOUS-COURCILLON;72500;72;SARTHE;1
72116;;Dissé-sous-Ballon;DISSE-SOUS-BALLON;72260;72;SARTHE;1
72117;;Dissé-sous-le-Lude;DISSE-SOUS-LE-LUDE;72800;72;SARTHE;1
72118;;Dollon;DOLLON;72390;72;SARTHE;1
72119;;Domfront-en-Champagne;DOMFRONT-EN-CHAMPAGNE;72240;72;SARTHE;1
72120;;Doucelles;DOUCELLES;72170;72;SARTHE;1
72121;;Douillet;DOUILLET;72590;72;SARTHE;1
72122;;Duneau;DUNEAU;72160;72;SARTHE;1
72123;;Dureil;DUREIL;72270;72;SARTHE;1
72124;;Écommoy;ECOMMOY;72220;72;SARTHE;1
72125;;Écorpain;ECORPAIN;72120;72;SARTHE;1
72126;;Épineu-le-Chevreuil;EPINEU-LE-CHEVREUIL;72540;72;SARTHE;1
72127;;Étival-lès-le-Mans;ETIVAL-LES-LE-MANS;72700;72;SARTHE;1
72128;;Évaillé;EVAILLE;72120;72;SARTHE;1
72129;;Fatines;FATINES;72470;72;SARTHE;1
72130;;Fay;FAY;72550;72;SARTHE;1
72131;;Fercé-sur-Sarthe;FERCE-SUR-SARTHE;72430;72;SARTHE;1
72132;La;Ferté-Bernard;FERTE-BERNARD;72400;72;SARTHE;1
72133;;Fillé;FILLE;72210;72;SARTHE;1
72134;;Flée;FLEE;72500;72;SARTHE;1
72135;La;Fontaine-Saint-Martin;FONTAINE-SAINT-MARTIN;72330;72;SARTHE;1
72136;;Fontenay-sur-Vègre;FONTENAY-SUR-VEGRE;72350;72;SARTHE;1
72137;La;Fresnaye-sur-Chédouet;FRESNAYE-SUR-CHEDOUET;72670;72;SARTHE;1
72138;;Fresnay-sur-Sarthe;FRESNAY-SUR-SARTHE;72130;72;SARTHE;1
72139;;Fyé;FYE;72610;72;SARTHE;1
72141;;Gesnes-le-Gandelin;GESNES-LE-GANDELIN;72130;72;SARTHE;1
72142;;Grandchamp;GRANDCHAMP;72610;72;SARTHE;1
72143;Le;Grand-Lucé;GRAND-LUCE;72150;72;SARTHE;1
72144;;Gréez-sur-Roc;GREEZ-SUR-ROC;72320;72;SARTHE;1
72145;Le;Grez;GREZ;72140;72;SARTHE;1
72146;;Guécélard;GUECELARD;72230;72;SARTHE;1
72147;La;Guierche;GUIERCHE;72380;72;SARTHE;1
72148;;Jauzé;JAUZE;72110;72;SARTHE;1
72149;;Joué-en-Charnie;JOUE-EN-CHARNIE;72540;72;SARTHE;1
72150;;Joué-l'Abbé;JOUE-L'ABBE;72380;72;SARTHE;1
72151;;Juigné-sur-Sarthe;JUIGNE-SUR-SARTHE;72300;72;SARTHE;1
72152;;Juillé;JUILLE;72170;72;SARTHE;1
72153;;Jupilles;JUPILLES;72500;72;SARTHE;1
72154;La;Flèche;FLECHE;72200;72;SARTHE;1
72155;;Laigné-en-Belin;LAIGNE-EN-BELIN;72220;72;SARTHE;1
72156;;Lamnay;LAMNAY;72320;72;SARTHE;1
72157;;Lavardin;LAVARDIN;72240;72;SARTHE;1
72158;;Lavaré;LAVARE;72390;72;SARTHE;1
72159;;Lavenay;LAVENAY;72310;72;SARTHE;1
72160;;Lavernat;LAVERNAT;72500;72;SARTHE;1
72161;;Lhomme;LHOMME;72340;72;SARTHE;1
72162;;Lignières-la-Carelle;LIGNIERES-LA-CARELLE;72610;72;SARTHE;1
72163;;Ligron;LIGRON;72270;72;SARTHE;1
72164;;Livet-en-Saosnois;LIVET-EN-SAOSNOIS;72610;72;SARTHE;1
72165;;Lombron;LOMBRON;72450;72;SARTHE;1
72166;;Longnes;LONGNES;72540;72;SARTHE;1
72167;;Louailles;LOUAILLES;72300;72;SARTHE;1
72168;;Loué;LOUE;72540;72;SARTHE;1
72169;;Louplande;LOUPLANDE;72210;72;SARTHE;1
72170;;Louvigny;LOUVIGNY;72600;72;SARTHE;1
72171;;Louzes;LOUZES;72670;72;SARTHE;1
72172;Le;Luart;LUART;72390;72;SARTHE;1
72173;;Luceau;LUCEAU;72500;72;SARTHE;1
72174;;Lucé-sous-Ballon;LUCE-SOUS-BALLON;72290;72;SARTHE;1
72175;;Luché-Pringé;LUCHE-PRINGE;72800;72;SARTHE;1
72176;Le;Lude;LUDE;72800;72;SARTHE;1
72177;;Maigné;MAIGNE;72210;72;SARTHE;1
72178;;Maisoncelles;MAISONCELLES;72440;72;SARTHE;1
72179;;Malicorne-sur-Sarthe;MALICORNE-SUR-SARTHE;72270;72;SARTHE;1
72180;;Mamers;MAMERS;72600;72;SARTHE;1
72181;Le;Mans;MANS;72000;72;SARTHE;1
72182;;Mansigné;MANSIGNE;72510;72;SARTHE;1
72183;;Marçon;MARCON;72340;72;SARTHE;1
72184;;Mareil-en-Champagne;MAREIL-EN-CHAMPAGNE;72540;72;SARTHE;1
72185;;Mareil-sur-Loir;MAREIL-SUR-LOIR;72200;72;SARTHE;1
72186;;Maresché;MARESCHE;72170;72;SARTHE;1
72187;;Marigné-Laillé;MARIGNE-LAILLE;72220;72;SARTHE;1
72188;;Marollette;MAROLLETTE;72600;72;SARTHE;1
72189;;Marolles-les-Braults;MAROLLES-LES-BRAULTS;72260;72;SARTHE;1
72190;;Marolles-lès-Saint-Calais;MAROLLES-LES-SAINT-CALAIS;72120;72;SARTHE;1
72191;;Mayet;MAYET;72360;72;SARTHE;1
72192;Les;Mées;MEES;72260;72;SARTHE;1
72193;;Melleray;MELLERAY;72320;72;SARTHE;1
72194;;Meurcé;MEURCE;72170;72;SARTHE;1
72195;;Mézeray;MEZERAY;72270;72;SARTHE;1
72196;;Mézières-sur-Ponthouin;MEZIERES-SUR-PONTHOUIN;72290;72;SARTHE;1
72197;;Mézières-sous-Lavardin;MEZIERES-SOUS-LAVARDIN;72240;72;SARTHE;1
72198;La;Milesse;MILESSE;72650;72;SARTHE;1
72199;;Moitron-sur-Sarthe;MOITRON-SUR-SARTHE;72170;72;SARTHE;1
72200;;Moncé-en-Belin;MONCE-EN-BELIN;72230;72;SARTHE;1
72201;;Moncé-en-Saosnois;MONCE-EN-SAOSNOIS;72260;72;SARTHE;1
72202;;Monhoudou;MONHOUDOU;72260;72;SARTHE;1
72203;;Montabon;MONTABON;72500;72;SARTHE;1
72204;;Montaillé;MONTAILLE;72120;72;SARTHE;1
72205;;Montbizot;MONTBIZOT;72380;72;SARTHE;1
72207;;Montigny;MONTIGNY;72670;72;SARTHE;1
72208;;Montmirail;MONTMIRAIL;72320;72;SARTHE;1
72209;;Montreuil-le-Chétif;MONTREUIL-LE-CHETIF;72130;72;SARTHE;1
72210;;Montreuil-le-Henri;MONTREUIL-LE-HENRI;72150;72;SARTHE;1
72211;;Mont-Saint-Jean;MONT-SAINT-JEAN;72140;72;SARTHE;1
72212;;Moulins-le-Carbonnel;MOULINS-LE-CARBONNEL;72130;72;SARTHE;1
72213;;Mulsanne;MULSANNE;72230;72;SARTHE;1
72214;;Nauvay;NAUVAY;72260;72;SARTHE;1
72215;;Neufchâtel-en-Saosnois;NEUFCHATEL-EN-SAOSNOIS;72600;72;SARTHE;1
72216;;Neuvillalais;NEUVILLALAIS;72240;72;SARTHE;1
72217;;Neuville-sur-Sarthe;NEUVILLE-SUR-SARTHE;72190;72;SARTHE;1
72218;;Neuvillette-en-Charnie;NEUVILLETTE-EN-CHARNIE;72140;72;SARTHE;1
72219;;Neuvy-en-Champagne;NEUVY-EN-CHAMPAGNE;72240;72;SARTHE;1
72220;;Nogent-le-Bernard;NOGENT-LE-BERNARD;72110;72;SARTHE;1
72221;;Nogent-sur-Loir;NOGENT-SUR-LOIR;72500;72;SARTHE;1
72222;;Nouans;NOUANS;72260;72;SARTHE;1
72223;;Noyen-sur-Sarthe;NOYEN-SUR-SARTHE;72430;72;SARTHE;1
72224;;Nuillé-le-Jalais;NUILLE-LE-JALAIS;72370;72;SARTHE;1
72225;;Oisseau-le-Petit;OISSEAU-LE-PETIT;72610;72;SARTHE;1
72226;;Oizé;OIZE;72330;72;SARTHE;1
72227;;Panon;PANON;72600;72;SARTHE;1
72228;;Parcé-sur-Sarthe;PARCE-SUR-SARTHE;72300;72;SARTHE;1
72229;;Parennes;PARENNES;72140;72;SARTHE;1
72230;;Parigné-le-Pôlin;PARIGNE-LE-POLIN;72330;72;SARTHE;1
72231;;Parigné-l'Évêque;PARIGNE-L'EVEQUE;72250;72;SARTHE;1
72232;;Notre-Dame-du-Pé;NOTRE-DAME-DU-PE;72300;72;SARTHE;1
72233;;Peray;PERAY;72260;72;SARTHE;1
72234;;Pezé-le-Robert;PEZE-LE-ROBERT;72140;72;SARTHE;1
72235;;Piacé;PIACE;72170;72;SARTHE;1
72236;;Pincé;PINCE;72300;72;SARTHE;1
72237;;Pirmil;PIRMIL;72430;72;SARTHE;1
72238;;Pizieux;PIZIEUX;72600;72;SARTHE;1
72239;;Poillé-sur-Vègre;POILLE-SUR-VEGRE;72350;72;SARTHE;1
72240;;Poncé-sur-le-Loir;PONCE-SUR-LE-LOIR;72340;72;SARTHE;1
72241;;Montfort-le-Gesnois;MONTFORT-LE-GESNOIS;72450;72;SARTHE;1
72243;;Pontvallain;PONTVALLAIN;72510;72;SARTHE;1
72244;;Précigné;PRECIGNE;72300;72;SARTHE;1
72245;;Préval;PREVAL;72400;72;SARTHE;1
72246;;Prévelles;PREVELLES;72110;72;SARTHE;1
72247;;Pruillé-le-Chétif;PRUILLE-LE-CHETIF;72700;72;SARTHE;1
72248;;Pruillé-l'Éguillé;PRUILLE-L'EGUILLE;72150;72;SARTHE;1
72249;La;Quinte;QUINTE;72550;72;SARTHE;1
72250;;Rahay;RAHAY;72120;72;SARTHE;1
72251;;René;RENE;72260;72;SARTHE;1
72252;;Requeil;REQUEIL;72510;72;SARTHE;1
72253;;Roézé-sur-Sarthe;ROEZE-SUR-SARTHE;72210;72;SARTHE;1
72254;;Rouessé-Fontaine;ROUESSE-FONTAINE;72610;72;SARTHE;1
72255;;Rouessé-Vassé;ROUESSE-VASSE;72140;72;SARTHE;1
72256;;Rouez;ROUEZ;72140;72;SARTHE;1
72257;;Rouillon;ROUILLON;72700;72;SARTHE;1
72258;;Roullée;ROULLEE;72670;72;SARTHE;1
72259;;Rouperroux-le-Coquet;ROUPERROUX-LE-COQUET;72110;72;SARTHE;1
72260;;Ruaudin;RUAUDIN;72230;72;SARTHE;1
72261;;Ruillé-en-Champagne;RUILLE-EN-CHAMPAGNE;72240;72;SARTHE;1
72262;;Ruillé-sur-Loir;RUILLE-SUR-LOIR;72340;72;SARTHE;1
72264;;Sablé-sur-Sarthe;SABLE-SUR-SARTHE;72300;72;SARTHE;1
72265;;Saint-Aignan;SAINT-AIGNAN;72110;72;SARTHE;1
72266;;Saint-Aubin-de-Locquenay;SAINT-AUBIN-DE-LOCQUENAY;72130;72;SARTHE;1
72267;;Saint-Aubin-des-Coudrais;SAINT-AUBIN-DES-COUDRAIS;72400;72;SARTHE;1
72268;;Saint-Biez-en-Belin;SAINT-BIEZ-EN-BELIN;72220;72;SARTHE;1
72269;;Saint-Calais;SAINT-CALAIS;72120;72;SARTHE;1
72270;;Saint-Calez-en-Saosnois;SAINT-CALEZ-EN-SAOSNOIS;72600;72;SARTHE;1
72271;;Saint-Célerin;SAINT-CELERIN;72110;72;SARTHE;1
72272;;Sainte-Cérotte;SAINTE-CEROTTE;72120;72;SARTHE;1
72273;;Saint-Christophe-du-Jambet;SAINT-CHRISTOPHE-DU-JAMBET;72170;72;SARTHE;1
72274;;Saint-Christophe-en-Champagne;SAINT-CHRISTOPHE-EN-CHAMPAGNE;72540;72;SARTHE;1
72275;;Saint-Corneille;SAINT-CORNEILLE;72460;72;SARTHE;1
72276;;Saint-Cosme-en-Vairais;SAINT-COSME-EN-VAIRAIS;72110;72;SARTHE;1
72277;;Saint-Denis-des-Coudrais;SAINT-DENIS-DES-COUDRAIS;72110;72;SARTHE;1
72278;;Saint-Denis-d'Orques;SAINT-DENIS-D'ORQUES;72350;72;SARTHE;1
72279;;Saint-Georges-de-la-Couée;SAINT-GEORGES-DE-LA-COUEE;72150;72;SARTHE;1
72280;;Saint-Georges-du-Bois;SAINT-GEORGES-DU-BOIS;72700;72;SARTHE;1
72281;;Saint-Georges-du-Rosay;SAINT-GEORGES-DU-ROSAY;72110;72;SARTHE;1
72282;;Saint-Georges-le-Gaultier;SAINT-GEORGES-LE-GAULTIER;72590;72;SARTHE;1
72283;;Saint-Germain-d'Arcé;SAINT-GERMAIN-D'ARCE;72500;72;SARTHE;1
72284;;Saint-Germain-sur-Sarthe;SAINT-GERMAIN-SUR-SARTHE;72130;72;SARTHE;1
72286;;Saint-Gervais-de-Vic;SAINT-GERVAIS-DE-VIC;72120;72;SARTHE;1
72287;;Saint-Gervais-en-Belin;SAINT-GERVAIS-EN-BELIN;72220;72;SARTHE;1
72288;;Saint-Hilaire-le-Lierru;SAINT-HILAIRE-LE-LIERRU;72160;72;SARTHE;1
72289;;Sainte-Jamme-sur-Sarthe;SAINTE-JAMME-SUR-SARTHE;72380;72;SARTHE;1
72290;;Saint-Jean-d'Assé;SAINT-JEAN-D'ASSE;72380;72;SARTHE;1
72291;;Saint-Jean-de-la-Motte;SAINT-JEAN-DE-LA-MOTTE;72510;72;SARTHE;1
72292;;Saint-Jean-des-Échelles;SAINT-JEAN-DES-ECHELLES;72320;72;SARTHE;1
72293;;Saint-Jean-du-Bois;SAINT-JEAN-DU-BOIS;72430;72;SARTHE;1
72294;;Saint-Léonard-des-Bois;SAINT-LEONARD-DES-BOIS;72590;72;SARTHE;1
72295;;Saint-Longis;SAINT-LONGIS;72600;72;SARTHE;1
72296;;Saint-Maixent;SAINT-MAIXENT;72320;72;SARTHE;1
72297;;Saint-Marceau;SAINT-MARCEAU;72170;72;SARTHE;1
72298;;Saint-Mars-de-Locquenay;SAINT-MARS-DE-LOCQUENAY;72440;72;SARTHE;1
72299;;Saint-Mars-d'Outillé;SAINT-MARS-D'OUTILLE;72220;72;SARTHE;1
72300;;Saint-Mars-la-Brière;SAINT-MARS-LA-BRIERE;72470;72;SARTHE;1
72301;;Saint-Mars-sous-Ballon;SAINT-MARS-SOUS-BALLON;72290;72;SARTHE;1
72302;;Saint-Martin-des-Monts;SAINT-MARTIN-DES-MONTS;72400;72;SARTHE;1
72303;;Saint-Michel-de-Chavaignes;SAINT-MICHEL-DE-CHAVAIGNES;72440;72;SARTHE;1
72304;;Sainte-Osmane;SAINTE-OSMANE;72120;72;SARTHE;1
72305;;Saint-Ouen-de-Mimbré;SAINT-OUEN-DE-MIMBRE;72130;72;SARTHE;1
72306;;Saint-Ouen-en-Belin;SAINT-OUEN-EN-BELIN;72220;72;SARTHE;1
72307;;Saint-Ouen-en-Champagne;SAINT-OUEN-EN-CHAMPAGNE;72350;72;SARTHE;1
72308;;Saint-Paterne;SAINT-PATERNE;72610;72;SARTHE;1
72309;;Saint-Paul-le-Gaultier;SAINT-PAUL-LE-GAULTIER;72590;72;SARTHE;1
72310;;Saint-Pavace;SAINT-PAVACE;72190;72;SARTHE;1
72311;;Saint-Pierre-de-Chevillé;SAINT-PIERRE-DE-CHEVILLE;72500;72;SARTHE;1
72312;;Saint-Pierre-des-Bois;SAINT-PIERRE-DES-BOIS;72430;72;SARTHE;1
72313;;Saint-Pierre-des-Ormes;SAINT-PIERRE-DES-ORMES;72600;72;SARTHE;1
72314;;Saint-Pierre-du-Lorouër;SAINT-PIERRE-DU-LOROUER;72150;72;SARTHE;1
72315;;Saint-Rémy-de-Sillé;SAINT-REMY-DE-SILLE;72140;72;SARTHE;1
72316;;Saint-Rémy-des-Monts;SAINT-REMY-DES-MONTS;72600;72;SARTHE;1
72317;;Saint-Rémy-du-Val;SAINT-REMY-DU-VAL;72600;72;SARTHE;1
72318;;Saint-Rigomer-des-Bois;SAINT-RIGOMER-DES-BOIS;72610;72;SARTHE;1
72319;;Sainte-Sabine-sur-Longève;SAINTE-SABINE-SUR-LONGEVE;72380;72;SARTHE;1
72320;;Saint-Saturnin;SAINT-SATURNIN;72650;72;SARTHE;1
72321;;Saint-Symphorien;SAINT-SYMPHORIEN;72240;72;SARTHE;1
72322;;Saint-Ulphace;SAINT-ULPHACE;72320;72;SARTHE;1
72323;;Saint-Victeur;SAINT-VICTEUR;72130;72;SARTHE;1
72324;;Saint-Vincent-des-Prés;SAINT-VINCENT-DES-PRES;72600;72;SARTHE;1
72325;;Saint-Vincent-du-Lorouër;SAINT-VINCENT-DU-LOROUER;72150;72;SARTHE;1
72326;;Saosnes;SAOSNES;72600;72;SARTHE;1
72327;;Sarcé;SARCE;72360;72;SARTHE;1
72328;;Sargé-lès-le-Mans;SARGE-LES-LE-MANS;72190;72;SARTHE;1
72329;;Savigné-l'Évêque;SAVIGNE-L'EVEQUE;72460;72;SARTHE;1
72330;;Savigné-sous-le-Lude;SAVIGNE-SOUS-LE-LUDE;72800;72;SARTHE;1
72331;;Sceaux-sur-Huisne;SCEAUX-SUR-HUISNE;72160;72;SARTHE;1
72332;;Ségrie;SEGRIE;72170;72;SARTHE;1
72333;;Semur-en-Vallon;SEMUR-EN-VALLON;72390;72;SARTHE;1
72334;;Sillé-le-Guillaume;SILLE-LE-GUILLAUME;72140;72;SARTHE;1
72335;;Sillé-le-Philippe;SILLE-LE-PHILIPPE;72460;72;SARTHE;1
72336;;Solesmes;SOLESMES;72300;72;SARTHE;1
72337;;Sougé-le-Ganelon;SOUGE-LE-GANELON;72130;72;SARTHE;1
72338;;Souillé;SOUILLE;72380;72;SARTHE;1
72339;;Souligné-Flacé;SOULIGNE-FLACE;72210;72;SARTHE;1
72340;;Souligné-sous-Ballon;SOULIGNE-SOUS-BALLON;72290;72;SARTHE;1
72341;;Soulitré;SOULITRE;72370;72;SARTHE;1
72342;;Souvigné-sur-Même;SOUVIGNE-SUR-MEME;72400;72;SARTHE;1
72343;;Souvigné-sur-Sarthe;SOUVIGNE-SUR-SARTHE;72300;72;SARTHE;1
72344;;Spay;SPAY;72700;72;SARTHE;1
72345;;Surfonds;SURFONDS;72370;72;SARTHE;1
72346;La;Suze-sur-Sarthe;SUZE-SUR-SARTHE;72210;72;SARTHE;1
72347;;Tassé;TASSE;72430;72;SARTHE;1
72348;;Tassillé;TASSILLE;72540;72;SARTHE;1
72349;;Teillé;TEILLE;72290;72;SARTHE;1
72350;;Teloché;TELOCHE;72220;72;SARTHE;1
72351;;Tennie;TENNIE;72240;72;SARTHE;1
72352;;Terrehault;TERREHAULT;72110;72;SARTHE;1
72353;;Théligny;THELIGNY;72320;72;SARTHE;1
72354;;Thoigné;THOIGNE;72260;72;SARTHE;1
72355;;Thoiré-sous-Contensor;THOIRE-SOUS-CONTENSOR;72610;72;SARTHE;1
72356;;Thoiré-sur-Dinan;THOIRE-SUR-DINAN;72500;72;SARTHE;1
72357;;Thorée-les-Pins;THOREE-LES-PINS;72800;72;SARTHE;1
72358;;Thorigné-sur-Dué;THORIGNE-SUR-DUE;72160;72;SARTHE;1
72359;;Torcé-en-Vallée;TORCE-EN-VALLEE;72110;72;SARTHE;1
72360;;Trangé;TRANGE;72650;72;SARTHE;1
72361;;Tresson;TRESSON;72440;72;SARTHE;1
72362;Le;Tronchet;TRONCHET;72170;72;SARTHE;1
72363;;Tuffé;TUFFE;72160;72;SARTHE;1
72364;;Vaas;VAAS;72500;72;SARTHE;1
72366;;Valennes;VALENNES;72320;72;SARTHE;1
72367;;Vallon-sur-Gée;VALLON-SUR-GEE;72540;72;SARTHE;1
72368;;Vancé;VANCE;72310;72;SARTHE;1
72369;;Verneil-le-Chétif;VERNEIL-LE-CHETIF;72360;72;SARTHE;1
72370;;Vernie;VERNIE;72170;72;SARTHE;1
72372;;Vezot;VEZOT;72600;72;SARTHE;1
72373;;Vibraye;VIBRAYE;72320;72;SARTHE;1
72374;;Villaines-la-Carelle;VILLAINES-LA-CARELLE;72600;72;SARTHE;1
72375;;Villaines-la-Gonais;VILLAINES-LA-GONAIS;72400;72;SARTHE;1
72376;;Villaines-sous-Lucé;VILLAINES-SOUS-LUCE;72150;72;SARTHE;1
72377;;Villaines-sous-Malicorne;VILLAINES-SOUS-MALICORNE;72270;72;SARTHE;1
72378;;Vion;VION;72300;72;SARTHE;1
72379;;Viré-en-Champagne;VIRE-EN-CHAMPAGNE;72350;72;SARTHE;1
72380;;Vivoin;VIVOIN;72170;72;SARTHE;1
72381;;Voivres-lès-le-Mans;VOIVRES-LES-LE-MANS;72210;72;SARTHE;1
72382;;Volnay;VOLNAY;72440;72;SARTHE;1
72383;;Vouvray-sur-Huisne;VOUVRAY-SUR-HUISNE;72160;72;SARTHE;1
72384;;Vouvray-sur-Loir;VOUVRAY-SUR-LOIR;72500;72;SARTHE;1
72385;;Yvré-le-Pôlin;YVRE-LE-POLIN;72330;72;SARTHE;1
72386;;Yvré-l'Évêque;YVRE-L'EVEQUE;72530;72;SARTHE;1
73001;;Aiguebelette-le-Lac;AIGUEBELETTE-LE-LAC;73610;73;SAVOIE;1
73002;;Aiguebelle;AIGUEBELLE;73220;73;SAVOIE;1
73003;;Aigueblanche;AIGUEBLANCHE;73260;73;SAVOIE;1
73004;;Aillon-le-Jeune;AILLON-LE-JEUNE;73340;73;SAVOIE;1
73005;;Aillon-le-Vieux;AILLON-LE-VIEUX;73340;73;SAVOIE;1
73006;;Aime;AIME;73210;73;SAVOIE;1
73007;;Aiton;AITON;73220;73;SAVOIE;1
73008;;Aix-les-Bains;AIX-LES-BAINS;73100;73;SAVOIE;1
73010;;Albens;ALBENS;73410;73;SAVOIE;1
73011;;Albertville;ALBERTVILLE;73200;73;SAVOIE;1
73012;;Albiez-le-Jeune;ALBIEZ-LE-JEUNE;73300;73;SAVOIE;1
73013;;Albiez-Montrond;ALBIEZ-MONTROND;73300;73;SAVOIE;1
73014;;Allondaz;ALLONDAZ;73200;73;SAVOIE;1
73015;Les;Allues;ALLUES;73550;73;SAVOIE;1
73017;;Apremont;APREMONT;73190;73;SAVOIE;1
73018;;Arbin;ARBIN;73800;73;SAVOIE;1
73019;;Argentine;ARGENTINE;73220;73;SAVOIE;1
73020;;Arith;ARITH;73340;73;SAVOIE;1
73021;;Arvillard;ARVILLARD;73110;73;SAVOIE;1
73022;;Attignat-Oncin;ATTIGNAT-ONCIN;73610;73;SAVOIE;1
73023;;Aussois;AUSSOIS;73500;73;SAVOIE;1
73024;Les;Avanchers-Valmorel;AVANCHERS-VALMOREL;73260;73;SAVOIE;1
73025;;Avressieux;AVRESSIEUX;73240;73;SAVOIE;1
73026;;Avrieux;AVRIEUX;73500;73;SAVOIE;1
73027;;Ayn;AYN;73470;73;SAVOIE;1
73028;La;Balme;BALME;73170;73;SAVOIE;1
73029;;Barberaz;BARBERAZ;73000;73;SAVOIE;1
73030;;Barby;BARBY;73230;73;SAVOIE;1
73031;;Bassens;BASSENS;73000;73;SAVOIE;1
73032;La;Bâthie;BATHIE;73540;73;SAVOIE;1
73033;La;Bauche;BAUCHE;73360;73;SAVOIE;1
73034;;Beaufort;BEAUFORT;73270;73;SAVOIE;1
73036;;Bellecombe-en-Bauges;BELLECOMBE-EN-BAUGES;73340;73;SAVOIE;1
73038;;Bellentre;BELLENTRE;73210;73;SAVOIE;1
73039;;Belmont-Tramonet;BELMONT-TRAMONET;73330;73;SAVOIE;1
73040;;Bessans;BESSANS;73480;73;SAVOIE;1
73041;;Betton-Bettonet;BETTON-BETTONET;73390;73;SAVOIE;1
73042;;Billième;BILLIEME;73170;73;SAVOIE;1
73043;La;Biolle;BIOLLE;73410;73;SAVOIE;1
73045;Le;Bois;BOIS;73260;73;SAVOIE;1
73046;;Bonneval;BONNEVAL;73260;73;SAVOIE;1
73047;;Bonneval-sur-Arc;BONNEVAL-SUR-ARC;73480;73;SAVOIE;1
73048;;Bonvillard;BONVILLARD;73460;73;SAVOIE;1
73049;;Bonvillaret;BONVILLARET;73220;73;SAVOIE;1
73050;;Bourdeau;BOURDEAU;73370;73;SAVOIE;1
73051;Le;Bourget-du-Lac;BOURGET-DU-LAC;73370;73;SAVOIE;1
73052;;Bourget-en-Huile;BOURGET-EN-HUILE;73110;73;SAVOIE;1
73053;;Bourgneuf;BOURGNEUF;73390;73;SAVOIE;1
73054;;Bourg-Saint-Maurice;BOURG-SAINT-MAURICE;73700;73;SAVOIE;1
73055;;Bozel;BOZEL;73350;73;SAVOIE;1
73056;;Bramans;BRAMANS;73500;73;SAVOIE;1
73057;;Brides-les-Bains;BRIDES-LES-BAINS;73570;73;SAVOIE;1
73058;La;Bridoire;BRIDOIRE;73520;73;SAVOIE;1
73059;;Brison-Saint-Innocent;BRISON-SAINT-INNOCENT;73100;73;SAVOIE;1
73061;;Césarches;CESARCHES;73200;73;SAVOIE;1
73062;;Cessens;CESSENS;73410;73;SAVOIE;1
73063;;Cevins;CEVINS;73730;73;SAVOIE;1
73064;;Challes-les-Eaux;CHALLES-LES-EAUX;73190;73;SAVOIE;1
73065;;Chambéry;CHAMBERY;73000;73;SAVOIE;1
73067;La;Chambre;CHAMBRE;73130;73;SAVOIE;1
73068;;Chamousset;CHAMOUSSET;73390;73;SAVOIE;1
73069;;Chamoux-sur-Gelon;CHAMOUX-SUR-GELON;73390;73;SAVOIE;1
73070;;Champagneux;CHAMPAGNEUX;73240;73;SAVOIE;1
73071;;Champagny-en-Vanoise;CHAMPAGNY-EN-VANOISE;73350;73;SAVOIE;1
73072;;Champ-Laurent;CHAMP-LAURENT;73390;73;SAVOIE;1
73073;;Chanaz;CHANAZ;73310;73;SAVOIE;1
73074;La;Chapelle;CHAPELLE;73660;73;SAVOIE;1
73075;La;Chapelle-Blanche;CHAPELLE-BLANCHE;73110;73;SAVOIE;1
73076;La;Chapelle-du-Mont-du-Chat;CHAPELLE-DU-MONT-DU-CHAT;73370;73;SAVOIE;1
73077;Les;Chapelles;CHAPELLES;73700;73;SAVOIE;1
73078;La;Chapelle-Saint-Martin;CHAPELLE-SAINT-MARTIN;73170;73;SAVOIE;1
73079;;Châteauneuf;CHATEAUNEUF;73390;73;SAVOIE;1
73080;Le;Châtel;CHATEL;73300;73;SAVOIE;1
73081;Le;Châtelard;CHATELARD;73630;73;SAVOIE;1
73082;La;Chavanne;CHAVANNE;73800;73;SAVOIE;1
73083;Les;Chavannes-en-Maurienne;CHAVANNES-EN-MAURIENNE;73660;73;SAVOIE;1
73084;;Chignin;CHIGNIN;73800;73;SAVOIE;1
73085;;Chindrieux;CHINDRIEUX;73310;73;SAVOIE;1
73086;;Cléry;CLERY;73460;73;SAVOIE;1
73087;;Cognin;COGNIN;73160;73;SAVOIE;1
73088;;Cohennoz;COHENNOZ;73400;73;SAVOIE;1
73089;;Coise-Saint-Jean-Pied-Gauthier;COISE-SAINT-JEAN-PIED-GAUTHIER;73800;73;SAVOIE;1
73090;La;Compôte;COMPOTE;73630;73;SAVOIE;1
73091;;Conjux;CONJUX;73310;73;SAVOIE;1
73092;;Corbel;CORBEL;73160;73;SAVOIE;1
73093;La;Côte-d'Aime;COTE-D'AIME;73210;73;SAVOIE;1
73094;;Crest-Voland;CREST-VOLAND;73590;73;SAVOIE;1
73095;La;Croix-de-la-Rochette;CROIX-DE-LA-ROCHETTE;73110;73;SAVOIE;1
73096;;Cruet;CRUET;73800;73;SAVOIE;1
73097;;Curienne;CURIENNE;73190;73;SAVOIE;1
73098;Les;Déserts;DESERTS;73230;73;SAVOIE;1
73099;;Détrier;DETRIER;73110;73;SAVOIE;1
73100;;Domessin;DOMESSIN;73330;73;SAVOIE;1
73101;;Doucy-en-Bauges;DOUCY-EN-BAUGES;73630;73;SAVOIE;1
73103;;Drumettaz-Clarafond;DRUMETTAZ-CLARAFOND;73420;73;SAVOIE;1
73104;;Dullin;DULLIN;73610;73;SAVOIE;1
73105;Les;Échelles;ECHELLES;73360;73;SAVOIE;1
73106;;École;ECOLE;73630;73;SAVOIE;1
73107;;Entremont-le-Vieux;ENTREMONT-LE-VIEUX;73670;73;SAVOIE;1
73108;;Épersy;EPERSY;73410;73;SAVOIE;1
73109;;Épierre;EPIERRE;73220;73;SAVOIE;1
73110;;Esserts-Blay;ESSERTS-BLAY;73540;73;SAVOIE;1
73111;;Étable;ETABLE;73110;73;SAVOIE;1
73112;;Feissons-sur-Isère;FEISSONS-SUR-ISERE;73260;73;SAVOIE;1
73113;;Feissons-sur-Salins;FEISSONS-SUR-SALINS;73350;73;SAVOIE;1
73114;;Flumet;FLUMET;73590;73;SAVOIE;1
73115;;Fontaine-le-Puits;FONTAINE-LE-PUITS;73600;73;SAVOIE;1
73116;;Fontcouverte-la-Toussuire;FONTCOUVERTE-LA-TOUSSUIRE;73300;73;SAVOIE;1
73117;;Fourneaux;FOURNEAUX;73500;73;SAVOIE;1
73118;;Francin;FRANCIN;73800;73;SAVOIE;1
73119;;Freney;FRENEY;73500;73;SAVOIE;1
73120;;Fréterive;FRETERIVE;73250;73;SAVOIE;1
73121;;Frontenex;FRONTENEX;73460;73;SAVOIE;1
73122;;Gerbaix;GERBAIX;73470;73;SAVOIE;1
73123;La;Giettaz;GIETTAZ;73590;73;SAVOIE;1
73124;;Gilly-sur-Isère;GILLY-SUR-ISERE;73200;73;SAVOIE;1
73126;;Granier;GRANIER;73210;73;SAVOIE;1
73127;;Gresin;GRESIN;73240;73;SAVOIE;1
73128;;Grésy-sur-Aix;GRESY-SUR-AIX;73100;73;SAVOIE;1
73129;;Grésy-sur-Isère;GRESY-SUR-ISERE;73460;73;SAVOIE;1
73130;;Grignon;GRIGNON;73200;73;SAVOIE;1
73131;;Hautecour;HAUTECOUR;73600;73;SAVOIE;1
73132;;Hauteluce;HAUTELUCE;73620;73;SAVOIE;1
73133;;Hauteville;HAUTEVILLE;73390;73;SAVOIE;1
73135;;Hermillon;HERMILLON;73300;73;SAVOIE;1
73137;;Jacob-Bellecombette;JACOB-BELLECOMBETTE;73000;73;SAVOIE;1
73138;;Jarrier;JARRIER;73300;73;SAVOIE;1
73139;;Jarsy;JARSY;73630;73;SAVOIE;1
73140;;Jongieux;JONGIEUX;73170;73;SAVOIE;1
73141;;Laissaud;LAISSAUD;73800;73;SAVOIE;1
73142;;Landry;LANDRY;73210;73;SAVOIE;1
73143;;Lanslebourg-Mont-Cenis;LANSLEBOURG-MONT-CENIS;73480;73;SAVOIE;1
73144;;Lanslevillard;LANSLEVILLARD;73480;73;SAVOIE;1
73145;;Lépin-le-Lac;LEPIN-LE-LAC;73610;73;SAVOIE;1
73146;;Lescheraines;LESCHERAINES;73340;73;SAVOIE;1
73147;;Loisieux;LOISIEUX;73170;73;SAVOIE;1
73149;;Lucey;LUCEY;73170;73;SAVOIE;1
73150;;Mâcot-la-Plagne;MACOT-LA-PLAGNE;73210;73;SAVOIE;1
73151;Les;Marches;MARCHES;73800;73;SAVOIE;1
73152;;Marcieux;MARCIEUX;73470;73;SAVOIE;1
73153;;Marthod;MARTHOD;73400;73;SAVOIE;1
73154;;Mercury;MERCURY;73200;73;SAVOIE;1
73155;;Méry;MERY;73420;73;SAVOIE;1
73156;;Meyrieux-Trouet;MEYRIEUX-TROUET;73170;73;SAVOIE;1
73157;;Modane;MODANE;73500;73;SAVOIE;1
73158;;Mognard;MOGNARD;73410;73;SAVOIE;1
73159;Les;Mollettes;MOLLETTES;73800;73;SAVOIE;1
73160;;Montagnole;MONTAGNOLE;73000;73;SAVOIE;1
73161;;Montagny;MONTAGNY;73350;73;SAVOIE;1
73162;;Montailleur;MONTAILLEUR;73460;73;SAVOIE;1
73163;;Montaimont;MONTAIMONT;73130;73;SAVOIE;1
73164;;Montcel;MONTCEL;73100;73;SAVOIE;1
73166;;Montendry;MONTENDRY;73390;73;SAVOIE;1
73167;;Montgellafrey;MONTGELLAFREY;73130;73;SAVOIE;1
73168;;Montgilbert;MONTGILBERT;73220;73;SAVOIE;1
73169;;Montgirod;MONTGIROD;73210;73;SAVOIE;1
73170;;Monthion;MONTHION;73200;73;SAVOIE;1
73171;;Montmélian;MONTMELIAN;73800;73;SAVOIE;1
73173;;Montricher-Albanne;MONTRICHER-ALBANNE;73870;73;SAVOIE;1
73175;;Montsapey;MONTSAPEY;73220;73;SAVOIE;1
73176;;Montvalezan;MONTVALEZAN;73700;73;SAVOIE;1
73177;;Montvernier;MONTVERNIER;73300;73;SAVOIE;1
73178;La;Motte-en-Bauges;MOTTE-EN-BAUGES;73340;73;SAVOIE;1
73179;La;Motte-Servolex;MOTTE-SERVOLEX;73290;73;SAVOIE;1
73180;;Motz;MOTZ;73310;73;SAVOIE;1
73181;;Moûtiers;MOUTIERS;73600;73;SAVOIE;1
73182;;Mouxy;MOUXY;73100;73;SAVOIE;1
73183;;Myans;MYANS;73800;73;SAVOIE;1
73184;;Nances;NANCES;73470;73;SAVOIE;1
73186;;Notre-Dame-de-Bellecombe;NOTRE-DAME-DE-BELLECOMBE;73590;73;SAVOIE;1
73187;La;Léchère;LECHERE;73260;73;SAVOIE;1
73188;;Notre-Dame-des-Millières;NOTRE-DAME-DES-MILLIERES;73460;73;SAVOIE;1
73189;;Notre-Dame-du-Cruet;NOTRE-DAME-DU-CRUET;73130;73;SAVOIE;1
73190;;Notre-Dame-du-Pré;NOTRE-DAME-DU-PRE;73600;73;SAVOIE;1
73191;;Novalaise;NOVALAISE;73470;73;SAVOIE;1
73192;Le;Noyer;NOYER;73340;73;SAVOIE;1
73193;;Ontex;ONTEX;73310;73;SAVOIE;1
73194;;Orelle;ORELLE;73140;73;SAVOIE;1
73196;;Pallud;PALLUD;73200;73;SAVOIE;1
73197;;Peisey-Nancroix;PEISEY-NANCROIX;73210;73;SAVOIE;1
73198;La;Perrière;PERRIERE;73120;73;SAVOIE;1
73200;;Planaise;PLANAISE;73800;73;SAVOIE;1
73201;;Planay;PLANAY;73350;73;SAVOIE;1
73202;;Plancherine;PLANCHERINE;73200;73;SAVOIE;1
73203;;Pontamafrey-Montpascal;PONTAMAFREY-MONTPASCAL;73300;73;SAVOIE;1
73204;Le;Pont-de-Beauvoisin;PONT-DE-BEAUVOISIN;73330;73;SAVOIE;1
73205;Le;Pontet;PONTET;73110;73;SAVOIE;1
73206;;Pralognan-la-Vanoise;PRALOGNAN-LA-VANOISE;73710;73;SAVOIE;1
73207;;Presle;PRESLE;73110;73;SAVOIE;1
73208;;Pugny-Chatenod;PUGNY-CHATENOD;73100;73;SAVOIE;1
73210;;Puygros;PUYGROS;73190;73;SAVOIE;1
73211;;Queige;QUEIGE;73720;73;SAVOIE;1
73212;;Randens;RANDENS;73220;73;SAVOIE;1
73213;La;Ravoire;RAVOIRE;73490;73;SAVOIE;1
73214;;Rochefort;ROCHEFORT;73240;73;SAVOIE;1
73215;La;Rochette;ROCHETTE;73110;73;SAVOIE;1
73216;;Rognaix;ROGNAIX;73730;73;SAVOIE;1
73217;;Rotherens;ROTHERENS;73110;73;SAVOIE;1
73218;;Ruffieux;RUFFIEUX;73310;73;SAVOIE;1
73219;;Saint-Alban-de-Montbel;SAINT-ALBAN-DE-MONTBEL;73610;73;SAVOIE;1
73220;;Saint-Alban-des-Hurtières;SAINT-ALBAN-DES-HURTIERES;73220;73;SAVOIE;1
73221;;Saint-Alban-des-Villards;SAINT-ALBAN-DES-VILLARDS;73130;73;SAVOIE;1
73222;;Saint-Alban-Leysse;SAINT-ALBAN-LEYSSE;73230;73;SAVOIE;1
73223;;Saint-André;SAINT-ANDRE;73500;73;SAVOIE;1
73224;;Saint-Avre;SAINT-AVRE;73130;73;SAVOIE;1
73225;;Saint-Baldoph;SAINT-BALDOPH;73190;73;SAVOIE;1
73226;;Saint-Béron;SAINT-BERON;73520;73;SAVOIE;1
73227;;Saint-Bon-Tarentaise;SAINT-BON-TARENTAISE;73120;73;SAVOIE;1
73228;;Saint-Cassin;SAINT-CASSIN;73160;73;SAVOIE;1
73229;;Saint-Christophe;SAINT-CHRISTOPHE;73360;73;SAVOIE;1
73230;;Saint-Colomban-des-Villards;SAINT-COLOMBAN-DES-VILLARDS;73130;73;SAVOIE;1
73231;;Saint-Étienne-de-Cuines;SAINT-ETIENNE-DE-CUINES;73130;73;SAVOIE;1
73232;;Sainte-Foy-Tarentaise;SAINTE-FOY-TARENTAISE;73640;73;SAVOIE;1
73233;;Saint-Franc;SAINT-FRANC;73360;73;SAVOIE;1
73234;;Saint-François-de-Sales;SAINT-FRANCOIS-DE-SALES;73340;73;SAVOIE;1
73235;;Saint-François-Longchamp;SAINT-FRANCOIS-LONGCHAMP;73130;73;SAVOIE;1
73236;;Saint-Genix-sur-Guiers;SAINT-GENIX-SUR-GUIERS;73240;73;SAVOIE;1
73237;;Saint-Georges-des-Hurtières;SAINT-GEORGES-DES-HURTIERES;73220;73;SAVOIE;1
73238;;Saint-Germain-la-Chambotte;SAINT-GERMAIN-LA-CHAMBOTTE;73410;73;SAVOIE;1
73239;;Saint-Girod;SAINT-GIROD;73410;73;SAVOIE;1
73240;;Sainte-Hélène-du-Lac;SAINTE-HELENE-DU-LAC;73800;73;SAVOIE;1
73241;;Sainte-Hélène-sur-Isère;SAINTE-HELENE-SUR-ISERE;73460;73;SAVOIE;1
73242;;Saint-Jean-d'Arves;SAINT-JEAN-D'ARVES;73530;73;SAVOIE;1
73243;;Saint-Jean-d'Arvey;SAINT-JEAN-D'ARVEY;73230;73;SAVOIE;1
73244;;Saint-Jean-de-Belleville;SAINT-JEAN-DE-BELLEVILLE;73440;73;SAVOIE;1
73245;;Saint-Jean-de-Chevelu;SAINT-JEAN-DE-CHEVELU;73170;73;SAVOIE;1
73246;;Saint-Jean-de-Couz;SAINT-JEAN-DE-COUZ;73160;73;SAVOIE;1
73247;;Saint-Jean-de-la-Porte;SAINT-JEAN-DE-LA-PORTE;73250;73;SAVOIE;1
73248;;Saint-Jean-de-Maurienne;SAINT-JEAN-DE-MAURIENNE;73300;73;SAVOIE;1
73249;;Saint-Jeoire-Prieuré;SAINT-JEOIRE-PRIEURE;73190;73;SAVOIE;1
73250;;Saint-Julien-Mont-Denis;SAINT-JULIEN-MONT-DENIS;73870;73;SAVOIE;1
73252;;Saint-Léger;SAINT-LEGER;73220;73;SAVOIE;1
73253;;Saint-Marcel;SAINT-MARCEL;73600;73;SAVOIE;1
73254;;Sainte-Marie-d'Alvey;SAINTE-MARIE-D'ALVEY;73240;73;SAVOIE;1
73255;;Sainte-Marie-de-Cuines;SAINTE-MARIE-DE-CUINES;73130;73;SAVOIE;1
73256;;Saint-Martin-d'Arc;SAINT-MARTIN-D'ARC;73140;73;SAVOIE;1
73257;;Saint-Martin-de-Belleville;SAINT-MARTIN-DE-BELLEVILLE;73440;73;SAVOIE;1
73258;;Saint-Martin-de-la-Porte;SAINT-MARTIN-DE-LA-PORTE;73140;73;SAVOIE;1
73259;;Saint-Martin-sur-la-Chambre;SAINT-MARTIN-SUR-LA-CHAMBRE;73130;73;SAVOIE;1
73260;;Saint-Maurice-de-Rotherens;SAINT-MAURICE-DE-ROTHERENS;73240;73;SAVOIE;1
73261;;Saint-Michel-de-Maurienne;SAINT-MICHEL-DE-MAURIENNE;73140;73;SAVOIE;1
73262;;Saint-Nicolas-la-Chapelle;SAINT-NICOLAS-LA-CHAPELLE;73590;73;SAVOIE;1
73263;;Saint-Offenge-Dessous;SAINT-OFFENGE-DESSOUS;73100;73;SAVOIE;1
73264;;Saint-Offenge-Dessus;SAINT-OFFENGE-DESSUS;73100;73;SAVOIE;1
73265;;Saint-Ours;SAINT-OURS;73410;73;SAVOIE;1
73266;;Saint-Oyen;SAINT-OYEN;73260;73;SAVOIE;1
73267;;Saint-Pancrace;SAINT-PANCRACE;73300;73;SAVOIE;1
73268;;Saint-Paul-sur-Isère;SAINT-PAUL-SUR-ISERE;73730;73;SAVOIE;1
73269;;Saint-Paul;SAINT-PAUL;73170;73;SAVOIE;1
73270;;Saint-Pierre-d'Albigny;SAINT-PIERRE-D'ALBIGNY;73250;73;SAVOIE;1
73271;;Saint-Pierre-d'Alvey;SAINT-PIERRE-D'ALVEY;73170;73;SAVOIE;1
73272;;Saint-Pierre-de-Belleville;SAINT-PIERRE-DE-BELLEVILLE;73220;73;SAVOIE;1
73273;;Saint-Pierre-de-Curtille;SAINT-PIERRE-DE-CURTILLE;73310;73;SAVOIE;1
73274;;Saint-Pierre-d'Entremont;SAINT-PIERRE-D'ENTREMONT;73670;73;SAVOIE;1
73275;;Saint-Pierre-de-Genebroz;SAINT-PIERRE-DE-GENEBROZ;73360;73;SAVOIE;1
73276;;Saint-Pierre-de-Soucy;SAINT-PIERRE-DE-SOUCY;73800;73;SAVOIE;1
73277;;Sainte-Reine;SAINTE-REINE;73630;73;SAVOIE;1
73278;;Saint-Rémy-de-Maurienne;SAINT-REMY-DE-MAURIENNE;73660;73;SAVOIE;1
73280;;Saint-Sorlin-d'Arves;SAINT-SORLIN-D'ARVES;73530;73;SAVOIE;1
73281;;Saint-Sulpice;SAINT-SULPICE;73160;73;SAVOIE;1
73282;;Saint-Thibaud-de-Couz;SAINT-THIBAUD-DE-COUZ;73160;73;SAVOIE;1
73283;;Saint-Vital;SAINT-VITAL;73460;73;SAVOIE;1
73284;;Salins-les-Thermes;SALINS-LES-THERMES;73600;73;SAVOIE;1
73285;;Séez;SEEZ;73700;73;SAVOIE;1
73286;;Serrières-en-Chautagne;SERRIERES-EN-CHAUTAGNE;73310;73;SAVOIE;1
73287;;Sollières-Sardières;SOLLIERES-SARDIERES;73500;73;SAVOIE;1
73288;;Sonnaz;SONNAZ;73000;73;SAVOIE;1
73289;La;Table;TABLE;73110;73;SAVOIE;1
73290;;Termignon;TERMIGNON;73500;73;SAVOIE;1
73292;;Thénésol;THENESOL;73200;73;SAVOIE;1
73293;;Thoiry;THOIRY;73230;73;SAVOIE;1
73294;La;Thuile;THUILE;73190;73;SAVOIE;1
73296;;Tignes;TIGNES;73320;73;SAVOIE;1
73297;;Tournon;TOURNON;73460;73;SAVOIE;1
73298;;Tours-en-Savoie;TOURS-EN-SAVOIE;73790;73;SAVOIE;1
73299;;Traize;TRAIZE;73170;73;SAVOIE;1
73300;;Tresserve;TRESSERVE;73100;73;SAVOIE;1
73301;;Trévignin;TREVIGNIN;73100;73;SAVOIE;1
73302;La;Trinité;TRINITE;73110;73;SAVOIE;1
73303;;Ugine;UGINE;73400;73;SAVOIE;1
73304;;Val-d'Isère;VAL-D'ISERE;73150;73;SAVOIE;1
73305;;Valezan;VALEZAN;73210;73;SAVOIE;1
73306;;Valloire;VALLOIRE;73450;73;SAVOIE;1
73307;;Valmeinier;VALMEINIER;73450;73;SAVOIE;1
73308;;Venthon;VENTHON;73200;73;SAVOIE;1
73309;;Verel-de-Montbel;VEREL-DE-MONTBEL;73330;73;SAVOIE;1
73310;;Verel-Pragondran;VEREL-PRAGONDRAN;73230;73;SAVOIE;1
73311;Le;Verneil;VERNEIL;73110;73;SAVOIE;1
73312;;Verrens-Arvey;VERRENS-ARVEY;73460;73;SAVOIE;1
73313;;Verthemex;VERTHEMEX;73170;73;SAVOIE;1
73314;;Villard-d'Héry;VILLARD-D'HERY;73800;73;SAVOIE;1
73315;;Villard-Léger;VILLARD-LEGER;73390;73;SAVOIE;1
73316;;Villard-Sallet;VILLARD-SALLET;73110;73;SAVOIE;1
73317;;Villard-sur-Doron;VILLARD-SUR-DORON;73270;73;SAVOIE;1
73318;;Villarembert;VILLAREMBERT;73300;73;SAVOIE;1
73320;;Villargondran;VILLARGONDRAN;73300;73;SAVOIE;1
73321;;Villarlurin;VILLARLURIN;73600;73;SAVOIE;1
73322;;Villarodin-Bourget;VILLARODIN-BOURGET;73500;73;SAVOIE;1
73323;;Villaroger;VILLAROGER;73640;73;SAVOIE;1
73324;;Villaroux;VILLAROUX;73110;73;SAVOIE;1
73326;;Vimines;VIMINES;73160;73;SAVOIE;1
73327;;Vions;VIONS;73310;73;SAVOIE;1
73328;;Viviers-du-Lac;VIVIERS-DU-LAC;73420;73;SAVOIE;1
73329;;Voglans;VOGLANS;73420;73;SAVOIE;1
73330;;Yenne;YENNE;73170;73;SAVOIE;1
74001;;Abondance;ABONDANCE;74360;74;HAUTE SAVOIE;1
74002;;Alby-sur-Chéran;ALBY-SUR-CHERAN;74540;74;HAUTE SAVOIE;1
74003;;Alex;ALEX;74290;74;HAUTE SAVOIE;1
74004;;Allèves;ALLEVES;74540;74;HAUTE SAVOIE;1
74005;;Allinges;ALLINGES;74200;74;HAUTE SAVOIE;1
74006;;Allonzier-la-Caille;ALLONZIER-LA-CAILLE;74350;74;HAUTE SAVOIE;1
74007;;Amancy;AMANCY;74800;74;HAUTE SAVOIE;1
74008;;Ambilly;AMBILLY;74100;74;HAUTE SAVOIE;1
74009;;Andilly;ANDILLY;74350;74;HAUTE SAVOIE;1
74010;;Annecy;ANNECY;74000;74;HAUTE SAVOIE;1
74011;;Annecy-le-Vieux;ANNECY-LE-VIEUX;74940;74;HAUTE SAVOIE;1
74012;;Annemasse;ANNEMASSE;74100;74;HAUTE SAVOIE;1
74013;;Anthy-sur-Léman;ANTHY-SUR-LEMAN;74200;74;HAUTE SAVOIE;1
74014;;Arâches-la-Frasse;ARACHES-LA-FRASSE;74300;74;HAUTE SAVOIE;1
74015;;Arbusigny;ARBUSIGNY;74930;74;HAUTE SAVOIE;1
74016;;Archamps;ARCHAMPS;74160;74;HAUTE SAVOIE;1
74018;;Arenthon;ARENTHON;74800;74;HAUTE SAVOIE;1
74019;;Argonay;ARGONAY;74370;74;HAUTE SAVOIE;1
74020;;Armoy;ARMOY;74200;74;HAUTE SAVOIE;1
74021;;Arthaz-Pont-Notre-Dame;ARTHAZ-PONT-NOTRE-DAME;74380;74;HAUTE SAVOIE;1
74022;;Aviernoz;AVIERNOZ;74570;74;HAUTE SAVOIE;1
74024;;Ayse;AYSE;74130;74;HAUTE SAVOIE;1
74025;;Ballaison;BALLAISON;74140;74;HAUTE SAVOIE;1
74026;La;Balme-de-Sillingy;BALME-DE-SILLINGY;74330;74;HAUTE SAVOIE;1
74027;La;Balme-de-Thuy;BALME-DE-THUY;74230;74;HAUTE SAVOIE;1
74029;;Bassy;BASSY;74910;74;HAUTE SAVOIE;1
74030;La;Baume;BAUME;74430;74;HAUTE SAVOIE;1
74031;;Beaumont;BEAUMONT;74160;74;HAUTE SAVOIE;1
74032;;Bellevaux;BELLEVAUX;74470;74;HAUTE SAVOIE;1
74033;;Bernex;BERNEX;74500;74;HAUTE SAVOIE;1
74034;Le;Biot;BIOT;74430;74;HAUTE SAVOIE;1
74035;;Bloye;BLOYE;74150;74;HAUTE SAVOIE;1
74036;;Bluffy;BLUFFY;74290;74;HAUTE SAVOIE;1
74037;;Boëge;BOEGE;74420;74;HAUTE SAVOIE;1
74038;;Bogève;BOGEVE;74250;74;HAUTE SAVOIE;1
74040;;Bonne;BONNE;74380;74;HAUTE SAVOIE;1
74041;;Bonnevaux;BONNEVAUX;74360;74;HAUTE SAVOIE;1
74042;;Bonneville;BONNEVILLE;74130;74;HAUTE SAVOIE;1
74043;;Bons-en-Chablais;BONS-EN-CHABLAIS;74890;74;HAUTE SAVOIE;1
74044;;Bossey;BOSSEY;74160;74;HAUTE SAVOIE;1
74045;Le;Bouchet;BOUCHET;74230;74;HAUTE SAVOIE;1
74046;;Boussy;BOUSSY;74150;74;HAUTE SAVOIE;1
74048;;Brenthonne;BRENTHONNE;74890;74;HAUTE SAVOIE;1
74049;;Brizon;BRIZON;74130;74;HAUTE SAVOIE;1
74050;;Burdignin;BURDIGNIN;74420;74;HAUTE SAVOIE;1
74051;;Cercier;CERCIER;74350;74;HAUTE SAVOIE;1
74052;;Cernex;CERNEX;74350;74;HAUTE SAVOIE;1
74053;;Cervens;CERVENS;74550;74;HAUTE SAVOIE;1
74054;;Chainaz-les-Frasses;CHAINAZ-LES-FRASSES;74540;74;HAUTE SAVOIE;1
74055;;Challonges;CHALLONGES;74910;74;HAUTE SAVOIE;1
74056;;Chamonix-Mont-Blanc;CHAMONIX-MONT-BLANC;74400;74;HAUTE SAVOIE;1
74057;;Champanges;CHAMPANGES;74500;74;HAUTE SAVOIE;1
74058;La;Chapelle-d'Abondance;CHAPELLE-D'ABONDANCE;74360;74;HAUTE SAVOIE;1
74059;La;Chapelle-Rambaud;CHAPELLE-RAMBAUD;74800;74;HAUTE SAVOIE;1
74060;La;Chapelle-Saint-Maurice;CHAPELLE-SAINT-MAURICE;74410;74;HAUTE SAVOIE;1
74061;;Chapeiry;CHAPEIRY;74540;74;HAUTE SAVOIE;1
74062;;Charvonnex;CHARVONNEX;74370;74;HAUTE SAVOIE;1
74063;;Châtel;CHATEL;74390;74;HAUTE SAVOIE;1
74064;;Châtillon-sur-Cluses;CHATILLON-SUR-CLUSES;74300;74;HAUTE SAVOIE;1
74065;;Chaumont;CHAUMONT;74270;74;HAUTE SAVOIE;1
74066;;Chavannaz;CHAVANNAZ;74270;74;HAUTE SAVOIE;1
74067;;Chavanod;CHAVANOD;74650;74;HAUTE SAVOIE;1
74068;;Chêne-en-Semine;CHENE-EN-SEMINE;74270;74;HAUTE SAVOIE;1
74069;;Chênex;CHENEX;74520;74;HAUTE SAVOIE;1
74070;;Chens-sur-Léman;CHENS-SUR-LEMAN;74140;74;HAUTE SAVOIE;1
74071;;Chessenaz;CHESSENAZ;74270;74;HAUTE SAVOIE;1
74072;;Chevaline;CHEVALINE;74210;74;HAUTE SAVOIE;1
74073;;Chevenoz;CHEVENOZ;74500;74;HAUTE SAVOIE;1
74074;;Chevrier;CHEVRIER;74520;74;HAUTE SAVOIE;1
74075;;Chilly;CHILLY;74270;74;HAUTE SAVOIE;1
74076;;Choisy;CHOISY;74330;74;HAUTE SAVOIE;1
74077;;Clarafond-Arcine;CLARAFOND-ARCINE;74270;74;HAUTE SAVOIE;1
74078;;Clermont;CLERMONT;74270;74;HAUTE SAVOIE;1
74079;Les;Clefs;CLEFS;74230;74;HAUTE SAVOIE;1
74080;La;Clusaz;CLUSAZ;74220;74;HAUTE SAVOIE;1
74081;;Cluses;CLUSES;74300;74;HAUTE SAVOIE;1
74082;;Collonges-sous-Salève;COLLONGES-SOUS-SALEVE;74160;74;HAUTE SAVOIE;1
74083;;Combloux;COMBLOUX;74920;74;HAUTE SAVOIE;1
74084;;Cons-Sainte-Colombe;CONS-SAINTE-COLOMBE;74210;74;HAUTE SAVOIE;1
74085;Les;Contamines-Montjoie;CONTAMINES-MONTJOIE;74170;74;HAUTE SAVOIE;1
74086;;Contamine-Sarzin;CONTAMINE-SARZIN;74270;74;HAUTE SAVOIE;1
74087;;Contamine-sur-Arve;CONTAMINE-SUR-ARVE;74130;74;HAUTE SAVOIE;1
74088;;Copponex;COPPONEX;74350;74;HAUTE SAVOIE;1
74089;;Cordon;CORDON;74700;74;HAUTE SAVOIE;1
74090;;Cornier;CORNIER;74800;74;HAUTE SAVOIE;1
74091;La;Côte-d'Arbroz;COTE-D'ARBROZ;74110;74;HAUTE SAVOIE;1
74093;;Cran-Gevrier;CRAN-GEVRIER;74960;74;HAUTE SAVOIE;1
74094;;Cranves-Sales;CRANVES-SALES;74380;74;HAUTE SAVOIE;1
74095;;Crempigny-Bonneguête;CREMPIGNY-BONNEGUETE;74150;74;HAUTE SAVOIE;1
74096;;Cruseilles;CRUSEILLES;74350;74;HAUTE SAVOIE;1
74097;;Cusy;CUSY;74540;74;HAUTE SAVOIE;1
74098;;Cuvat;CUVAT;74350;74;HAUTE SAVOIE;1
74099;;Demi-Quartier;DEMI-QUARTIER;74120;74;HAUTE SAVOIE;1
74100;;Desingy;DESINGY;74270;74;HAUTE SAVOIE;1
74101;;Dingy-en-Vuache;DINGY-EN-VUACHE;74520;74;HAUTE SAVOIE;1
74102;;Dingy-Saint-Clair;DINGY-SAINT-CLAIR;74230;74;HAUTE SAVOIE;1
74103;;Domancy;DOMANCY;74700;74;HAUTE SAVOIE;1
74104;;Doussard;DOUSSARD;74210;74;HAUTE SAVOIE;1
74105;;Douvaine;DOUVAINE;74140;74;HAUTE SAVOIE;1
74106;;Draillant;DRAILLANT;74550;74;HAUTE SAVOIE;1
74107;;Droisy;DROISY;74270;74;HAUTE SAVOIE;1
74108;;Duingt;DUINGT;74410;74;HAUTE SAVOIE;1
74109;;Éloise;ELOISE;01200;74;AIN;1
74110;;Entremont;ENTREMONT;74130;74;HAUTE SAVOIE;1
74111;;Entrevernes;ENTREVERNES;74410;74;HAUTE SAVOIE;1
74112;;Épagny;EPAGNY;74330;74;HAUTE SAVOIE;1
74114;;Essert-Romand;ESSERT-ROMAND;74110;74;HAUTE SAVOIE;1
74116;;Etaux;ETAUX;74800;74;HAUTE SAVOIE;1
74117;;Étercy;ETERCY;74150;74;HAUTE SAVOIE;1
74118;;Étrembières;ETREMBIERES;74100;74;HAUTE SAVOIE;1
74119;;Évian-les-Bains;EVIAN-LES-BAINS;74500;74;HAUTE SAVOIE;1
74120;;Évires;EVIRES;74570;74;HAUTE SAVOIE;1
74121;;Excenevex;EXCENEVEX;74140;74;HAUTE SAVOIE;1
74122;;Faucigny;FAUCIGNY;74130;74;HAUTE SAVOIE;1
74123;;Faverges;FAVERGES;74210;74;HAUTE SAVOIE;1
74124;;Feigères;FEIGERES;74160;74;HAUTE SAVOIE;1
74126;;Fessy;FESSY;74890;74;HAUTE SAVOIE;1
74127;;Féternes;FETERNES;74500;74;HAUTE SAVOIE;1
74128;;Fillinges;FILLINGES;74250;74;HAUTE SAVOIE;1
74129;La;Forclaz;FORCLAZ;74200;74;HAUTE SAVOIE;1
74130;;Franclens;FRANCLENS;74910;74;HAUTE SAVOIE;1
74131;;Frangy;FRANGY;74270;74;HAUTE SAVOIE;1
74133;;Gaillard;GAILLARD;74240;74;HAUTE SAVOIE;1
74134;Les;Gets;GETS;74260;74;HAUTE SAVOIE;1
74135;;Giez;GIEZ;74210;74;HAUTE SAVOIE;1
74136;Le;Grand-Bornand;GRAND-BORNAND;74450;74;HAUTE SAVOIE;1
74137;;Groisy;GROISY;74570;74;HAUTE SAVOIE;1
74138;;Gruffy;GRUFFY;74540;74;HAUTE SAVOIE;1
74139;;Habère-Lullin;HABERE-LULLIN;74420;74;HAUTE SAVOIE;1
74140;;Habère-Poche;HABERE-POCHE;74420;74;HAUTE SAVOIE;1
74141;;Hauteville-sur-Fier;HAUTEVILLE-SUR-FIER;74150;74;HAUTE SAVOIE;1
74142;;Héry-sur-Alby;HERY-SUR-ALBY;74540;74;HAUTE SAVOIE;1
74143;Les;Houches;HOUCHES;74310;74;HAUTE SAVOIE;1
74144;;Jonzier-Épagny;JONZIER-EPAGNY;74520;74;HAUTE SAVOIE;1
74145;;Juvigny;JUVIGNY;74100;74;HAUTE SAVOIE;1
74146;;Larringes;LARRINGES;74500;74;HAUTE SAVOIE;1
74147;;Lathuile;LATHUILE;74210;74;HAUTE SAVOIE;1
74148;;Leschaux;LESCHAUX;74320;74;HAUTE SAVOIE;1
74150;;Loisin;LOISIN;74140;74;HAUTE SAVOIE;1
74151;;Lornay;LORNAY;74150;74;HAUTE SAVOIE;1
74152;;Lovagny;LOVAGNY;74330;74;HAUTE SAVOIE;1
74153;;Lucinges;LUCINGES;74380;74;HAUTE SAVOIE;1
74154;;Lugrin;LUGRIN;74500;74;HAUTE SAVOIE;1
74155;;Lullin;LULLIN;74470;74;HAUTE SAVOIE;1
74156;;Lully;LULLY;74890;74;HAUTE SAVOIE;1
74157;;Lyaud;LYAUD;74200;74;HAUTE SAVOIE;1
74158;;Machilly;MACHILLY;74140;74;HAUTE SAVOIE;1
74159;;Magland;MAGLAND;74300;74;HAUTE SAVOIE;1
74160;;Manigod;MANIGOD;74230;74;HAUTE SAVOIE;1
74161;;Marcellaz-Albanais;MARCELLAZ-ALBANAIS;74150;74;HAUTE SAVOIE;1
74162;;Marcellaz;MARCELLAZ;74250;74;HAUTE SAVOIE;1
74163;;Margencel;MARGENCEL;74200;74;HAUTE SAVOIE;1
74164;;Marignier;MARIGNIER;74970;74;HAUTE SAVOIE;1
74165;;Marigny-Saint-Marcel;MARIGNY-SAINT-MARCEL;74150;74;HAUTE SAVOIE;1
74166;;Marin;MARIN;74200;74;HAUTE SAVOIE;1
74167;;Marlens;MARLENS;74210;74;HAUTE SAVOIE;1
74168;;Marlioz;MARLIOZ;74270;74;HAUTE SAVOIE;1
74169;;Marnaz;MARNAZ;74460;74;HAUTE SAVOIE;1
74170;;Massingy;MASSINGY;74150;74;HAUTE SAVOIE;1
74171;;Massongy;MASSONGY;74140;74;HAUTE SAVOIE;1
74172;;Maxilly-sur-Léman;MAXILLY-SUR-LEMAN;74500;74;HAUTE SAVOIE;1
74173;;Megève;MEGEVE;74120;74;HAUTE SAVOIE;1
74174;;Mégevette;MEGEVETTE;74490;74;HAUTE SAVOIE;1
74175;;Meillerie;MEILLERIE;74500;74;HAUTE SAVOIE;1
74176;;Menthon-Saint-Bernard;MENTHON-SAINT-BERNARD;74290;74;HAUTE SAVOIE;1
74177;;Menthonnex-en-Bornes;MENTHONNEX-EN-BORNES;74350;74;HAUTE SAVOIE;1
74178;;Menthonnex-sous-Clermont;MENTHONNEX-SOUS-CLERMONT;74270;74;HAUTE SAVOIE;1
74179;;Mésigny;MESIGNY;74330;74;HAUTE SAVOIE;1
74180;;Messery;MESSERY;74140;74;HAUTE SAVOIE;1
74181;;Metz-Tessy;METZ-TESSY;74370;74;HAUTE SAVOIE;1
74182;;Meythet;MEYTHET;74960;74;HAUTE SAVOIE;1
74183;;Mieussy;MIEUSSY;74440;74;HAUTE SAVOIE;1
74184;;Minzier;MINZIER;74270;74;HAUTE SAVOIE;1
74185;;Monnetier-Mornex;MONNETIER-MORNEX;74560;74;HAUTE SAVOIE;1
74186;;Montagny-les-Lanches;MONTAGNY-LES-LANCHES;74600;74;HAUTE SAVOIE;1
74187;;Montmin;MONTMIN;74210;74;HAUTE SAVOIE;1
74188;;Montriond;MONTRIOND;74110;74;HAUTE SAVOIE;1
74189;;Mont-Saxonnex;MONT-SAXONNEX;74130;74;HAUTE SAVOIE;1
74190;;Morillon;MORILLON;74440;74;HAUTE SAVOIE;1
74191;;Morzine;MORZINE;74110;74;HAUTE SAVOIE;1
74192;;Moye;MOYE;74150;74;HAUTE SAVOIE;1
74193;La;Muraz;MURAZ;74560;74;HAUTE SAVOIE;1
74194;;Mûres;MURES;74540;74;HAUTE SAVOIE;1
74195;;Musièges;MUSIEGES;74270;74;HAUTE SAVOIE;1
74196;;Nancy-sur-Cluses;NANCY-SUR-CLUSES;74300;74;HAUTE SAVOIE;1
74197;;Nangy;NANGY;74380;74;HAUTE SAVOIE;1
74198;;Nâves-Parmelan;NAVES-PARMELAN;74370;74;HAUTE SAVOIE;1
74199;;Nernier;NERNIER;74140;74;HAUTE SAVOIE;1
74200;;Neuvecelle;NEUVECELLE;74500;74;HAUTE SAVOIE;1
74201;;Neydens;NEYDENS;74160;74;HAUTE SAVOIE;1
74202;;Nonglard;NONGLARD;74330;74;HAUTE SAVOIE;1
74203;;Novel;NOVEL;74500;74;HAUTE SAVOIE;1
74204;Les;Ollières;OLLIERES;74370;74;HAUTE SAVOIE;1
74205;;Onnion;ONNION;74490;74;HAUTE SAVOIE;1
74206;;Orcier;ORCIER;74550;74;HAUTE SAVOIE;1
74208;;Passy;PASSY;74190;74;HAUTE SAVOIE;1
74209;;Peillonnex;PEILLONNEX;74250;74;HAUTE SAVOIE;1
74210;;Perrignier;PERRIGNIER;74550;74;HAUTE SAVOIE;1
74211;;Pers-Jussy;PERS-JUSSY;74930;74;HAUTE SAVOIE;1
74212;Le;Petit-Bornand-les-Glières;PETIT-BORNAND-LES-GLIERES;74130;74;HAUTE SAVOIE;1
74213;;Poisy;POISY;74330;74;HAUTE SAVOIE;1
74215;;Praz-sur-Arly;PRAZ-SUR-ARLY;74120;74;HAUTE SAVOIE;1
74216;;Présilly;PRESILLY;74160;74;HAUTE SAVOIE;1
74217;;Pringy;PRINGY;74370;74;HAUTE SAVOIE;1
74218;;Publier;PUBLIER;74500;74;HAUTE SAVOIE;1
74219;;Quintal;QUINTAL;74600;74;HAUTE SAVOIE;1
74220;;Reignier-Ésery;REIGNIER-ESERY;74930;74;HAUTE SAVOIE;1
74221;Le;Reposoir;REPOSOIR;74950;74;HAUTE SAVOIE;1
74222;;Reyvroz;REYVROZ;74200;74;HAUTE SAVOIE;1
74223;La;Rivière-Enverse;RIVIERE-ENVERSE;74440;74;HAUTE SAVOIE;1
74224;La;Roche-sur-Foron;ROCHE-SUR-FORON;74800;74;HAUTE SAVOIE;1
74225;;Rumilly;RUMILLY;74150;74;HAUTE SAVOIE;1
74226;;Saint-André-de-Boëge;SAINT-ANDRE-DE-BOEGE;74420;74;HAUTE SAVOIE;1
74228;;Saint-Blaise;SAINT-BLAISE;74350;74;HAUTE SAVOIE;1
74229;;Saint-Cergues;SAINT-CERGUES;74140;74;HAUTE SAVOIE;1
74231;;Saint-Eusèbe;SAINT-EUSEBE;74150;74;HAUTE SAVOIE;1
74232;;Saint-Eustache;SAINT-EUSTACHE;74410;74;HAUTE SAVOIE;1
74233;;Saint-Félix;SAINT-FELIX;74540;74;HAUTE SAVOIE;1
74234;;Saint-Ferréol;SAINT-FERREOL;74210;74;HAUTE SAVOIE;1
74235;;Saint-Germain-sur-Rhône;SAINT-GERMAIN-SUR-RHONE;01200;74;AIN;1
74236;;Saint-Gervais-les-Bains;SAINT-GERVAIS-LES-BAINS;74170;74;HAUTE SAVOIE;1
74237;;Saint-Gingolph;SAINT-GINGOLPH;74500;74;HAUTE SAVOIE;1
74238;;Saint-Jean-d'Aulps;SAINT-JEAN-D'AULPS;74430;74;HAUTE SAVOIE;1
74239;;Saint-Jean-de-Sixt;SAINT-JEAN-DE-SIXT;74450;74;HAUTE SAVOIE;1
74240;;Saint-Jean-de-Tholome;SAINT-JEAN-DE-THOLOME;74250;74;HAUTE SAVOIE;1
74241;;Saint-Jeoire;SAINT-JEOIRE;74490;74;HAUTE SAVOIE;1
74242;;Saint-Jorioz;SAINT-JORIOZ;74410;74;HAUTE SAVOIE;1
74243;;Saint-Julien-en-Genevois;SAINT-JULIEN-EN-GENEVOIS;74160;74;HAUTE SAVOIE;1
74244;;Saint-Laurent;SAINT-LAURENT;74800;74;HAUTE SAVOIE;1
74245;;Saint-Martin-Bellevue;SAINT-MARTIN-BELLEVUE;74370;74;HAUTE SAVOIE;1
74249;;Saint-Paul-en-Chablais;SAINT-PAUL-EN-CHABLAIS;74500;74;HAUTE SAVOIE;1
74250;;Saint-Pierre-en-Faucigny;SAINT-PIERRE-EN-FAUCIGNY;74800;74;HAUTE SAVOIE;1
74252;;Saint-Sigismond;SAINT-SIGISMOND;74300;74;HAUTE SAVOIE;1
74253;;Saint-Sixt;SAINT-SIXT;74800;74;HAUTE SAVOIE;1
74254;;Saint-Sylvestre;SAINT-SYLVESTRE;74540;74;HAUTE SAVOIE;1
74255;;Sales;SALES;74150;74;HAUTE SAVOIE;1
74256;;Sallanches;SALLANCHES;74700;74;HAUTE SAVOIE;1
74257;;Sallenôves;SALLENOVES;74270;74;HAUTE SAVOIE;1
74258;;Samoëns;SAMOENS;74340;74;HAUTE SAVOIE;1
74259;Le;Sappey;SAPPEY;74350;74;HAUTE SAVOIE;1
74260;;Savigny;SAVIGNY;74520;74;HAUTE SAVOIE;1
74261;;Saxel;SAXEL;74420;74;HAUTE SAVOIE;1
74262;;Scientrier;SCIENTRIER;74930;74;HAUTE SAVOIE;1
74263;;Sciez;SCIEZ;74140;74;HAUTE SAVOIE;1
74264;;Scionzier;SCIONZIER;74950;74;HAUTE SAVOIE;1
74265;;Serraval;SERRAVAL;74230;74;HAUTE SAVOIE;1
74266;;Servoz;SERVOZ;74310;74;HAUTE SAVOIE;1
74267;;Sévrier;SEVRIER;74320;74;HAUTE SAVOIE;1
74268;;Seynod;SEYNOD;74600;74;HAUTE SAVOIE;1
74269;;Seyssel;SEYSSEL;74910;74;HAUTE SAVOIE;1
74270;;Seythenex;SEYTHENEX;74210;74;HAUTE SAVOIE;1
74271;;Seytroux;SEYTROUX;74430;74;HAUTE SAVOIE;1
74272;;Sillingy;SILLINGY;74330;74;HAUTE SAVOIE;1
74273;;Sixt-Fer-à-Cheval;SIXT-FER-A-CHEVAL;74740;74;HAUTE SAVOIE;1
74274;;Val-de-Fier;VAL-DE-FIER;74150;74;HAUTE SAVOIE;1
74275;;Talloires;TALLOIRES;74290;74;HAUTE SAVOIE;1
74276;;Taninges;TANINGES;74440;74;HAUTE SAVOIE;1
74278;;Thyez;THYEZ;74300;74;HAUTE SAVOIE;1
74279;;Thollon-les-Mémises;THOLLON-LES-MEMISES;74500;74;HAUTE SAVOIE;1
74280;;Thônes;THONES;74230;74;HAUTE SAVOIE;1
74281;;Thonon-les-Bains;THONON-LES-BAINS;74200;74;HAUTE SAVOIE;1
74282;;Thorens-Glières;THORENS-GLIERES;74570;74;HAUTE SAVOIE;1
74283;;Thusy;THUSY;74150;74;HAUTE SAVOIE;1
74284;La;Tour;TOUR;74250;74;HAUTE SAVOIE;1
74285;;Usinens;USINENS;74910;74;HAUTE SAVOIE;1
74286;;Vacheresse;VACHERESSE;74360;74;HAUTE SAVOIE;1
74287;;Vailly;VAILLY;74470;74;HAUTE SAVOIE;1
74288;;Valleiry;VALLEIRY;74520;74;HAUTE SAVOIE;1
74289;;Vallières;VALLIERES;74150;74;HAUTE SAVOIE;1
74290;;Vallorcine;VALLORCINE;74660;74;HAUTE SAVOIE;1
74291;;Vanzy;VANZY;74270;74;HAUTE SAVOIE;1
74292;;Vaulx;VAULX;74150;74;HAUTE SAVOIE;1
74293;;Veigy-Foncenex;VEIGY-FONCENEX;74140;74;HAUTE SAVOIE;1
74294;;Verchaix;VERCHAIX;74440;74;HAUTE SAVOIE;1
74295;La;Vernaz;VERNAZ;74200;74;HAUTE SAVOIE;1
74296;;Vers;VERS;74160;74;HAUTE SAVOIE;1
74297;;Versonnex;VERSONNEX;74150;74;HAUTE SAVOIE;1
74298;;Vétraz-Monthoux;VETRAZ-MONTHOUX;74100;74;HAUTE SAVOIE;1
74299;;Veyrier-du-Lac;VEYRIER-DU-LAC;74290;74;HAUTE SAVOIE;1
74301;;Villard;VILLARD;74420;74;HAUTE SAVOIE;1
74302;Les;Villards-sur-Thônes;VILLARDS-SUR-THONES;74230;74;HAUTE SAVOIE;1
74303;;Villaz;VILLAZ;74370;74;HAUTE SAVOIE;1
74304;;Ville-en-Sallaz;VILLE-EN-SALLAZ;74250;74;HAUTE SAVOIE;1
74305;;Ville-la-Grand;VILLE-LA-GRAND;74100;74;HAUTE SAVOIE;1
74306;;Villy-le-Bouveret;VILLY-LE-BOUVERET;74350;74;HAUTE SAVOIE;1
74307;;Villy-le-Pelloux;VILLY-LE-PELLOUX;74350;74;HAUTE SAVOIE;1
74308;;Vinzier;VINZIER;74500;74;HAUTE SAVOIE;1
74309;;Viry;VIRY;74580;74;HAUTE SAVOIE;1
74310;;Viuz-la-Chiésaz;VIUZ-LA-CHIESAZ;74540;74;HAUTE SAVOIE;1
74311;;Viuz-en-Sallaz;VIUZ-EN-SALLAZ;74250;74;HAUTE SAVOIE;1
74312;;Vougy;VOUGY;74130;74;HAUTE SAVOIE;1
74313;;Vovray-en-Bornes;VOVRAY-EN-BORNES;74350;74;HAUTE SAVOIE;1
74314;;Vulbens;VULBENS;74520;74;HAUTE SAVOIE;1
74315;;Yvoire;YVOIRE;74140;74;HAUTE SAVOIE;1
75056;;Paris;PARIS;;75;;
76001;;Allouville-Bellefosse;ALLOUVILLE-BELLEFOSSE;76190;76;SEINE MARITIME;1
76002;;Alvimare;ALVIMARE;76640;76;SEINE MARITIME;1
76004;;Ambrumesnil;AMBRUMESNIL;76550;76;SEINE MARITIME;1
76005;;Amfreville-la-Mi-Voie;AMFREVILLE-LA-MI-VOIE;76920;76;SEINE MARITIME;1
76006;;Amfreville-les-Champs;AMFREVILLE-LES-CHAMPS;76560;76;SEINE MARITIME;1
76007;;Anceaumeville;ANCEAUMEVILLE;76710;76;SEINE MARITIME;1
76008;;Ancourt;ANCOURT;76370;76;SEINE MARITIME;1
76009;;Ancourteville-sur-Héricourt;ANCOURTEVILLE-SUR-HERICOURT;76560;76;SEINE MARITIME;1
76010;;Ancretiéville-Saint-Victor;ANCRETIEVILLE-SAINT-VICTOR;76760;76;SEINE MARITIME;1
76011;;Ancretteville-sur-Mer;ANCRETTEVILLE-SUR-MER;76540;76;SEINE MARITIME;1
76012;;Angerville-Bailleul;ANGERVILLE-BAILLEUL;76110;76;SEINE MARITIME;1
76013;;Angerville-la-Martel;ANGERVILLE-LA-MARTEL;76540;76;SEINE MARITIME;1
76014;;Angerville-l'Orcher;ANGERVILLE-L'ORCHER;76280;76;SEINE MARITIME;1
76015;;Angiens;ANGIENS;76740;76;SEINE MARITIME;1
76016;;Anglesqueville-la-Bras-Long;ANGLESQUEVILLE-LA-BRAS-LONG;76740;76;SEINE MARITIME;1
76017;;Anglesqueville-l'Esneval;ANGLESQUEVILLE-L'ESNEVAL;76280;76;SEINE MARITIME;1
76018;;Val-de-Saâne;VAL-DE-SAANE;76890;76;SEINE MARITIME;1
76019;;Anneville-sur-Scie;ANNEVILLE-SUR-SCIE;76590;76;SEINE MARITIME;1
76020;;Anneville-Ambourville;ANNEVILLE-AMBOURVILLE;76480;76;SEINE MARITIME;1
76021;;Annouville-Vilmesnil;ANNOUVILLE-VILMESNIL;76110;76;SEINE MARITIME;1
76022;;Anquetierville;ANQUETIERVILLE;76490;76;SEINE MARITIME;1
76023;;Anvéville;ANVEVILLE;76560;76;SEINE MARITIME;1
76024;;Ardouval;ARDOUVAL;76680;76;SEINE MARITIME;1
76025;;Argueil;ARGUEIL;76780;76;SEINE MARITIME;1
76026;;Arques-la-Bataille;ARQUES-LA-BATAILLE;76880;76;SEINE MARITIME;1
76027;;Assigny;ASSIGNY;76630;76;SEINE MARITIME;1
76028;;Aubéguimont;AUBEGUIMONT;76390;76;SEINE MARITIME;1
76029;;Aubermesnil-aux-Érables;AUBERMESNIL-AUX-ERABLES;76340;76;SEINE MARITIME;1
76030;;Aubermesnil-Beaumais;AUBERMESNIL-BEAUMAIS;76550;76;SEINE MARITIME;1
76031;;Auberville-la-Campagne;AUBERVILLE-LA-CAMPAGNE;76170;76;SEINE MARITIME;1
76032;;Auberville-la-Manuel;AUBERVILLE-LA-MANUEL;76450;76;SEINE MARITIME;1
76033;;Auberville-la-Renault;AUBERVILLE-LA-RENAULT;76110;76;SEINE MARITIME;1
76034;;Auffay;AUFFAY;76720;76;SEINE MARITIME;1
76035;;Aumale;AUMALE;76390;76;SEINE MARITIME;1
76036;;Auppegard;AUPPEGARD;76730;76;SEINE MARITIME;1
76037;;Auquemesnil;AUQUEMESNIL;76630;76;SEINE MARITIME;1
76038;;Authieux-Ratiéville;AUTHIEUX-RATIEVILLE;76690;76;SEINE MARITIME;1
76039;Les;Authieux-sur-le-Port-Saint-Ouen;AUTHIEUX-SUR-LE-PORT-SAINT-OUEN;76520;76;SEINE MARITIME;1
76040;;Autigny;AUTIGNY;76740;76;SEINE MARITIME;1
76041;;Autretot;AUTRETOT;76190;76;SEINE MARITIME;1
76042;;Auvilliers;AUVILLIERS;76270;76;SEINE MARITIME;1
76043;;Auzebosc;AUZEBOSC;76190;76;SEINE MARITIME;1
76044;;Auzouville-Auberbosc;AUZOUVILLE-AUBERBOSC;76640;76;SEINE MARITIME;1
76045;;Auzouville-l'Esneval;AUZOUVILLE-L'ESNEVAL;76760;76;SEINE MARITIME;1
76046;;Auzouville-sur-Ry;AUZOUVILLE-SUR-RY;76116;76;SEINE MARITIME;1
76047;;Auzouville-sur-Saâne;AUZOUVILLE-SUR-SAANE;76730;76;SEINE MARITIME;1
76048;;Avesnes-en-Bray;AVESNES-EN-BRAY;76220;76;SEINE MARITIME;1
76049;;Avesnes-en-Val;AVESNES-EN-VAL;76630;76;SEINE MARITIME;1
76050;;Avremesnil;AVREMESNIL;76730;76;SEINE MARITIME;1
76051;;Bacqueville-en-Caux;BACQUEVILLE-EN-CAUX;76730;76;SEINE MARITIME;1
76052;;Bailleul-Neuville;BAILLEUL-NEUVILLE;76660;76;SEINE MARITIME;1
76053;;Baillolet;BAILLOLET;76660;76;SEINE MARITIME;1
76054;;Bailly-en-Rivière;BAILLY-EN-RIVIERE;76630;76;SEINE MARITIME;1
76055;;Baons-le-Comte;BAONS-LE-COMTE;76190;76;SEINE MARITIME;1
76056;;Bardouville;BARDOUVILLE;76480;76;SEINE MARITIME;1
76057;;Barentin;BARENTIN;76360;76;SEINE MARITIME;1
76058;;Baromesnil;BAROMESNIL;76260;76;SEINE MARITIME;1
76059;;Bazinval;BAZINVAL;76340;76;SEINE MARITIME;1
76060;;Beaubec-la-Rosière;BEAUBEC-LA-ROSIERE;76440;76;SEINE MARITIME;1
76062;;Beaumont-le-Hareng;BEAUMONT-LE-HARENG;76850;76;SEINE MARITIME;1
76063;;Beauval-en-Caux;BEAUVAL-EN-CAUX;76890;76;SEINE MARITIME;1
76064;;Beaurepaire;BEAUREPAIRE;76280;76;SEINE MARITIME;1
76065;;Beaussault;BEAUSSAULT;76870;76;SEINE MARITIME;1
76066;;Beautot;BEAUTOT;76890;76;SEINE MARITIME;1
76067;;Beauvoir-en-Lyons;BEAUVOIR-EN-LYONS;76220;76;SEINE MARITIME;1
76068;;Bec-de-Mortagne;BEC-DE-MORTAGNE;76110;76;SEINE MARITIME;1
76069;;Belbeuf;BELBEUF;76240;76;SEINE MARITIME;1
76070;;Bellencombre;BELLENCOMBRE;76680;76;SEINE MARITIME;1
76071;;Bellengreville;BELLENGREVILLE;76630;76;SEINE MARITIME;1
76072;;Belleville-en-Caux;BELLEVILLE-EN-CAUX;76890;76;SEINE MARITIME;1
76073;;Belleville-sur-Mer;BELLEVILLE-SUR-MER;76370;76;SEINE MARITIME;1
76074;La;Bellière;BELLIERE;76440;76;SEINE MARITIME;1
76075;;Belmesnil;BELMESNIL;76590;76;SEINE MARITIME;1
76076;;Bénarville;BENARVILLE;76110;76;SEINE MARITIME;1
76077;;Bénesville;BENESVILLE;76560;76;SEINE MARITIME;1
76078;;Bennetot;BENNETOT;76640;76;SEINE MARITIME;1
76079;;Bénouville;BENOUVILLE;76790;76;SEINE MARITIME;1
76080;;Bermonville;BERMONVILLE;76640;76;SEINE MARITIME;1
76081;;Berneval-le-Grand;BERNEVAL-LE-GRAND;76370;76;SEINE MARITIME;1
76082;;Bernières;BERNIERES;76210;76;SEINE MARITIME;1
76083;;Bertheauville;BERTHEAUVILLE;76450;76;SEINE MARITIME;1
76084;;Bertreville;BERTREVILLE;76450;76;SEINE MARITIME;1
76085;;Bertreville-Saint-Ouen;BERTREVILLE-SAINT-OUEN;76590;76;SEINE MARITIME;1
76086;;Bertrimont;BERTRIMONT;76890;76;SEINE MARITIME;1
76087;;Berville;BERVILLE;76560;76;SEINE MARITIME;1
76088;;Berville-sur-Seine;BERVILLE-SUR-SEINE;76480;76;SEINE MARITIME;1
76089;;Betteville;BETTEVILLE;76190;76;SEINE MARITIME;1
76090;;Beuzeville-la-Grenier;BEUZEVILLE-LA-GRENIER;76210;76;SEINE MARITIME;1
76091;;Beuzeville-la-Guérard;BEUZEVILLE-LA-GUERARD;76450;76;SEINE MARITIME;1
76092;;Beuzevillette;BEUZEVILLETTE;76210;76;SEINE MARITIME;1
76093;;Bézancourt;BEZANCOURT;76220;76;SEINE MARITIME;1
76094;;Bierville;BIERVILLE;76750;76;SEINE MARITIME;1
76096;;Biville-la-Baignarde;BIVILLE-LA-BAIGNARDE;76890;76;SEINE MARITIME;1
76097;;Biville-la-Rivière;BIVILLE-LA-RIVIERE;76730;76;SEINE MARITIME;1
76098;;Biville-sur-Mer;BIVILLE-SUR-MER;76630;76;SEINE MARITIME;1
76099;;Blacqueville;BLACQUEVILLE;76190;76;SEINE MARITIME;1
76100;;Blainville-Crevon;BLAINVILLE-CREVON;76116;76;SEINE MARITIME;1
76101;;Blangy-sur-Bresle;BLANGY-SUR-BRESLE;76340;76;SEINE MARITIME;1
76103;;Bonsecours;BONSECOURS;76240;76;SEINE MARITIME;1
76104;;Blosseville;BLOSSEVILLE;76460;76;SEINE MARITIME;1
76105;Le;Bocasse;BOCASSE;76690;76;SEINE MARITIME;1
76106;;Bois-d'Ennebourg;BOIS-D'ENNEBOURG;76160;76;SEINE MARITIME;1
76107;;Bois-Guilbert;BOIS-GUILBERT;76750;76;SEINE MARITIME;1
76108;;-;BOIS-GUILLAUME;76230;76;SEINE MARITIME;1
76109;;Bois-Héroult;BOIS-HEROULT;76750;76;SEINE MARITIME;1
76110;;Bois-Himont;BOIS-HIMONT;76190;76;SEINE MARITIME;1
76111;;Bois-l'Évêque;BOIS-L'EVEQUE;76160;76;SEINE MARITIME;1
76112;Le;Bois-Robert;BOIS-ROBERT;76590;76;SEINE MARITIME;1
76113;;Boissay;BOISSAY;76750;76;SEINE MARITIME;1
76114;;Bolbec;BOLBEC;76210;76;SEINE MARITIME;1
76115;;Bolleville;BOLLEVILLE;76210;76;SEINE MARITIME;1
76116;;Boos;BOOS;76520;76;SEINE MARITIME;1
76117;;Bordeaux-Saint-Clair;BORDEAUX-SAINT-CLAIR;76790;76;SEINE MARITIME;1
76118;;Bornambusc;BORNAMBUSC;76110;76;SEINE MARITIME;1
76119;;Bosc-Bérenger;BOSC-BERENGER;76680;76;SEINE MARITIME;1
76120;;Bosc-Bordel;BOSC-BORDEL;76750;76;SEINE MARITIME;1
76121;;Bosc-Édeline;BOSC-EDELINE;76750;76;SEINE MARITIME;1
76122;;Callengeville;CALLENGEVILLE;76270;76;SEINE MARITIME;1
76123;;Bosc-Guérard-Saint-Adrien;BOSC-GUERARD-SAINT-ADRIEN;76710;76;SEINE MARITIME;1
76124;;Bosc-Hyons;BOSC-HYONS;76220;76;SEINE MARITIME;1
76125;;Bosc-le-Hard;BOSC-LE-HARD;76850;76;SEINE MARITIME;1
76126;;Bosc-Mesnil;BOSC-MESNIL;76680;76;SEINE MARITIME;1
76127;;Bosc-Roger-sur-Buchy;BOSC-ROGER-SUR-BUCHY;76750;76;SEINE MARITIME;1
76128;;Bosville;BOSVILLE;76450;76;SEINE MARITIME;1
76129;;Boudeville;BOUDEVILLE;76560;76;SEINE MARITIME;1
76130;;Bouelles;BOUELLES;76270;76;SEINE MARITIME;1
76131;La;Bouille;BOUILLE;76530;76;SEINE MARITIME;1
76132;;Bourdainville;BOURDAINVILLE;76760;76;SEINE MARITIME;1
76133;Le;Bourg-Dun;BOURG-DUN;76740;76;SEINE MARITIME;1
76134;;Bourville;BOURVILLE;76740;76;SEINE MARITIME;1
76135;;Bouville;BOUVILLE;76360;76;SEINE MARITIME;1
76136;;Brachy;BRACHY;76730;76;SEINE MARITIME;1
76137;;Bracquemont;BRACQUEMONT;76370;76;SEINE MARITIME;1
76138;;Bracquetuit;BRACQUETUIT;76850;76;SEINE MARITIME;1
76139;;Bradiancourt;BRADIANCOURT;76680;76;SEINE MARITIME;1
76140;;Brametot;BRAMETOT;76740;76;SEINE MARITIME;1
76141;;Bréauté;BREAUTE;76110;76;SEINE MARITIME;1
76142;;Brémontier-Merval;BREMONTIER-MERVAL;76220;76;SEINE MARITIME;1
76143;;Bretteville-du-Grand-Caux;BRETTEVILLE-DU-GRAND-CAUX;76110;76;SEINE MARITIME;1
76144;;Bretteville-Saint-Laurent;BRETTEVILLE-SAINT-LAURENT;76560;76;SEINE MARITIME;1
76145;;Brunville;BRUNVILLE;76630;76;SEINE MARITIME;1
76146;;Buchy;BUCHY;76750;76;SEINE MARITIME;1
76147;;Bully;BULLY;76270;76;SEINE MARITIME;1
76148;;Bures-en-Bray;BURES-EN-BRAY;76660;76;SEINE MARITIME;1
76149;;Butot;BUTOT;76890;76;SEINE MARITIME;1
76151;;Cailleville;CAILLEVILLE;76460;76;SEINE MARITIME;1
76152;;Cailly;CAILLY;76690;76;SEINE MARITIME;1
76153;;Calleville-les-Deux-Églises;CALLEVILLE-LES-DEUX-EGLISES;76890;76;SEINE MARITIME;1
76154;;Campneuseville;CAMPNEUSEVILLE;76340;76;SEINE MARITIME;1
76155;;Canehan;CANEHAN;76260;76;SEINE MARITIME;1
76156;;Canouville;CANOUVILLE;76450;76;SEINE MARITIME;1
76157;;Canteleu;CANTELEU;76380;76;SEINE MARITIME;1
76158;;Canville-les-Deux-Églises;CANVILLE-LES-DEUX-EGLISES;76560;76;SEINE MARITIME;1
76159;;Cany-Barville;CANY-BARVILLE;76450;76;SEINE MARITIME;1
76160;;Carville-la-Folletière;CARVILLE-LA-FOLLETIERE;76190;76;SEINE MARITIME;1
76161;;Carville-Pot-de-Fer;CARVILLE-POT-DE-FER;76560;76;SEINE MARITIME;1
76162;Le;Catelier;CATELIER;76590;76;SEINE MARITIME;1
76163;;Catenay;CATENAY;76116;76;SEINE MARITIME;1
76164;;Caudebec-en-Caux;CAUDEBEC-EN-CAUX;76490;76;SEINE MARITIME;1
76165;;Caudebec-lès-Elbeuf;CAUDEBEC-LES-ELBEUF;76320;76;SEINE MARITIME;1
76166;Le;Caule-Sainte-Beuve;CAULE-SAINTE-BEUVE;76390;76;SEINE MARITIME;1
76167;;Cauville-sur-Mer;CAUVILLE-SUR-MER;76930;76;SEINE MARITIME;1
76168;Les;Cent-Acres;CENT-ACRES;76590;76;SEINE MARITIME;1
76169;La;Cerlangue;CERLANGUE;76430;76;SEINE MARITIME;1
76170;La;Chapelle-du-Bourgay;CHAPELLE-DU-BOURGAY;76590;76;SEINE MARITIME;1
76171;La;Chapelle-Saint-Ouen;CHAPELLE-SAINT-OUEN;76780;76;SEINE MARITIME;1
76172;La;Chapelle-sur-Dun;CHAPELLE-SUR-DUN;76740;76;SEINE MARITIME;1
76173;La;Chaussée;CHAUSSEE;76590;76;SEINE MARITIME;1
76174;;Cideville;CIDEVILLE;76570;76;SEINE MARITIME;1
76175;;Clais;CLAIS;76660;76;SEINE MARITIME;1
76176;;Clasville;CLASVILLE;76450;76;SEINE MARITIME;1
76177;;Claville-Motteville;CLAVILLE-MOTTEVILLE;76690;76;SEINE MARITIME;1
76178;;Cléon;CLEON;76410;76;SEINE MARITIME;1
76179;;Clères;CLERES;76690;76;SEINE MARITIME;1
76180;;Cleuville;CLEUVILLE;76450;76;SEINE MARITIME;1
76181;;Cléville;CLEVILLE;76640;76;SEINE MARITIME;1
76182;;Cliponville;CLIPONVILLE;76640;76;SEINE MARITIME;1
76183;;Colleville;COLLEVILLE;76400;76;SEINE MARITIME;1
76184;;Colmesnil-Manneville;COLMESNIL-MANNEVILLE;76550;76;SEINE MARITIME;1
76185;;Compainville;COMPAINVILLE;76440;76;SEINE MARITIME;1
76186;;Conteville;CONTEVILLE;76390;76;SEINE MARITIME;1
76187;;Contremoulins;CONTREMOULINS;76400;76;SEINE MARITIME;1
76188;;Cottévrard;COTTEVRARD;76850;76;SEINE MARITIME;1
76189;;Crasville-la-Mallet;CRASVILLE-LA-MALLET;76450;76;SEINE MARITIME;1
76190;;Crasville-la-Rocquefort;CRASVILLE-LA-ROCQUEFORT;76740;76;SEINE MARITIME;1
76191;;Cressy;CRESSY;76720;76;SEINE MARITIME;1
76192;;Criel-sur-Mer;CRIEL-SUR-MER;76910;76;SEINE MARITIME;1
76193;La;Crique;CRIQUE;76850;76;SEINE MARITIME;1
76194;;Criquebeuf-en-Caux;CRIQUEBEUF-EN-CAUX;76111;76;SEINE MARITIME;1
76195;;Criquetot-le-Mauconduit;CRIQUETOT-LE-MAUCONDUIT;76540;76;SEINE MARITIME;1
76196;;Criquetot-l'Esneval;CRIQUETOT-L'ESNEVAL;76280;76;SEINE MARITIME;1
76197;;Criquetot-sur-Longueville;CRIQUETOT-SUR-LONGUEVILLE;76590;76;SEINE MARITIME;1
76198;;Criquetot-sur-Ouville;CRIQUETOT-SUR-OUVILLE;76760;76;SEINE MARITIME;1
76199;;Criquiers;CRIQUIERS;76390;76;SEINE MARITIME;1
76200;;Critot;CRITOT;76680;76;SEINE MARITIME;1
76201;;Croisy-sur-Andelle;CROISY-SUR-ANDELLE;76780;76;SEINE MARITIME;1
76202;;Croixdalle;CROIXDALLE;76660;76;SEINE MARITIME;1
76203;;Croix-Mare;CROIX-MARE;76190;76;SEINE MARITIME;1
76204;;Cropus;CROPUS;76720;76;SEINE MARITIME;1
76205;;Crosville-sur-Scie;CROSVILLE-SUR-SCIE;76590;76;SEINE MARITIME;1
76206;;Cuverville;CUVERVILLE;76280;76;SEINE MARITIME;1
76207;;Cuverville-sur-Yères;CUVERVILLE-SUR-YERES;76260;76;SEINE MARITIME;1
76208;;Cuy-Saint-Fiacre;CUY-SAINT-FIACRE;76220;76;SEINE MARITIME;1
76209;;Dampierre-en-Bray;DAMPIERRE-EN-BRAY;76220;76;SEINE MARITIME;1
76210;;Dampierre-Saint-Nicolas;DAMPIERRE-SAINT-NICOLAS;76510;76;SEINE MARITIME;1
76211;;Dancourt;DANCOURT;76340;76;SEINE MARITIME;1
76212;;Darnétal;DARNETAL;76160;76;SEINE MARITIME;1
76213;;Daubeuf-Serville;DAUBEUF-SERVILLE;76110;76;SEINE MARITIME;1
76214;;Dénestanville;DENESTANVILLE;76590;76;SEINE MARITIME;1
76215;;Derchigny;DERCHIGNY;76370;76;SEINE MARITIME;1
76216;;Déville-lès-Rouen;DEVILLE-LES-ROUEN;76250;76;SEINE MARITIME;1
76217;;Dieppe;DIEPPE;76200;76;SEINE MARITIME;1
76218;;Doudeauville;DOUDEAUVILLE;76220;76;SEINE MARITIME;1
76219;;Doudeville;DOUDEVILLE;76560;76;SEINE MARITIME;1
76220;;Douvrend;DOUVREND;76630;76;SEINE MARITIME;1
76221;;Drosay;DROSAY;76460;76;SEINE MARITIME;1
76222;;Duclair;DUCLAIR;76480;76;SEINE MARITIME;1
76223;;Écalles-Alix;ECALLES-ALIX;76190;76;SEINE MARITIME;1
76224;;Écrainville;ECRAINVILLE;76110;76;SEINE MARITIME;1
76225;;Écretteville-lès-Baons;ECRETTEVILLE-LES-BAONS;76190;76;SEINE MARITIME;1
76226;;Écretteville-sur-Mer;ECRETTEVILLE-SUR-MER;76540;76;SEINE MARITIME;1
76227;;Ectot-l'Auber;ECTOT-L'AUBER;76760;76;SEINE MARITIME;1
76228;;Ectot-lès-Baons;ECTOT-LES-BAONS;76970;76;SEINE MARITIME;1
76229;;Elbeuf-en-Bray;ELBEUF-EN-BRAY;76220;76;SEINE MARITIME;1
76230;;Elbeuf-sur-Andelle;ELBEUF-SUR-ANDELLE;76780;76;SEINE MARITIME;1
76231;;Elbeuf;ELBEUF;76500;76;SEINE MARITIME;1
76232;;Életot;ELETOT;76540;76;SEINE MARITIME;1
76233;;Ellecourt;ELLECOURT;76390;76;SEINE MARITIME;1
76234;;Émanville;EMANVILLE;76570;76;SEINE MARITIME;1
76235;;Envermeu;ENVERMEU;76630;76;SEINE MARITIME;1
76236;;Envronville;ENVRONVILLE;76640;76;SEINE MARITIME;1
76237;;Épinay-sur-Duclair;EPINAY-SUR-DUCLAIR;76480;76;SEINE MARITIME;1
76238;;Épouville;EPOUVILLE;76133;76;SEINE MARITIME;1
76239;;Épretot;EPRETOT;76430;76;SEINE MARITIME;1
76240;;Épreville;EPREVILLE;76400;76;SEINE MARITIME;1
76241;;Ermenouville;ERMENOUVILLE;76740;76;SEINE MARITIME;1
76242;;Ernemont-la-Villette;ERNEMONT-LA-VILLETTE;76220;76;SEINE MARITIME;1
76243;;Ernemont-sur-Buchy;ERNEMONT-SUR-BUCHY;76750;76;SEINE MARITIME;1
76244;;Esclavelles;ESCLAVELLES;76270;76;SEINE MARITIME;1
76245;;Eslettes;ESLETTES;76710;76;SEINE MARITIME;1
76247;;Esteville;ESTEVILLE;76690;76;SEINE MARITIME;1
76248;;Estouteville-Écalles;ESTOUTEVILLE-ECALLES;76750;76;SEINE MARITIME;1
76249;;Étaimpuis;ETAIMPUIS;76850;76;SEINE MARITIME;1
76250;;Étainhus;ETAINHUS;76430;76;SEINE MARITIME;1
76251;;Étalleville;ETALLEVILLE;76560;76;SEINE MARITIME;1
76252;;Étalondes;ETALONDES;76260;76;SEINE MARITIME;1
76253;;Étoutteville;ETOUTTEVILLE;76190;76;SEINE MARITIME;1
76254;;Étretat;ETRETAT;76790;76;SEINE MARITIME;1
76255;;Eu;EU;76260;76;SEINE MARITIME;1
76257;;Fallencourt;FALLENCOURT;76340;76;SEINE MARITIME;1
76258;;Fauville-en-Caux;FAUVILLE-EN-CAUX;76640;76;SEINE MARITIME;1
76259;;Fécamp;FECAMP;76400;76;SEINE MARITIME;1
76260;;Ferrières-en-Bray;FERRIERES-EN-BRAY;76220;76;SEINE MARITIME;1
76261;La;Ferté-Saint-Samson;FERTE-SAINT-SAMSON;76440;76;SEINE MARITIME;1
76262;;Fesques;FESQUES;76270;76;SEINE MARITIME;1
76263;La;Feuillie;FEUILLIE;76220;76;SEINE MARITIME;1
76264;;Flamanville;FLAMANVILLE;76970;76;SEINE MARITIME;1
76265;;Flamets-Frétils;FLAMETS-FRETILS;76270;76;SEINE MARITIME;1
76266;;Flocques;FLOCQUES;76260;76;SEINE MARITIME;1
76267;La;Folletière;FOLLETIERE;76190;76;SEINE MARITIME;1
76268;;Fongueusemare;FONGUEUSEMARE;76280;76;SEINE MARITIME;1
76269;;Fontaine-en-Bray;FONTAINE-EN-BRAY;76440;76;SEINE MARITIME;1
76270;;Fontaine-la-Mallet;FONTAINE-LA-MALLET;76290;76;SEINE MARITIME;1
76271;;Fontaine-le-Bourg;FONTAINE-LE-BOURG;76690;76;SEINE MARITIME;1
76272;;Fontaine-le-Dun;FONTAINE-LE-DUN;76740;76;SEINE MARITIME;1
76273;;Fontaine-sous-Préaux;FONTAINE-SOUS-PREAUX;76160;76;SEINE MARITIME;1
76274;La;Fontelaye;FONTELAYE;76890;76;SEINE MARITIME;1
76275;;Fontenay;FONTENAY;76290;76;SEINE MARITIME;1
76276;;Forges-les-Eaux;FORGES-LES-EAUX;76440;76;SEINE MARITIME;1
76277;Le;Fossé;FOSSE;76440;76;SEINE MARITIME;1
76278;;Foucarmont;FOUCARMONT;76340;76;SEINE MARITIME;1
76279;;Foucart;FOUCART;76640;76;SEINE MARITIME;1
76280;;Fréauville;FREAUVILLE;76660;76;SEINE MARITIME;1
76281;La;Frénaye;FRENAYE;76170;76;SEINE MARITIME;1
76282;;Freneuse;FRENEUSE;76410;76;SEINE MARITIME;1
76283;;Fresles;FRESLES;76270;76;SEINE MARITIME;1
76284;;Fresnay-le-Long;FRESNAY-LE-LONG;76850;76;SEINE MARITIME;1
76285;;Fresne-le-Plan;FRESNE-LE-PLAN;76520;76;SEINE MARITIME;1
76286;;Fresnoy-Folny;FRESNOY-FOLNY;76660;76;SEINE MARITIME;1
76287;;Fresquiennes;FRESQUIENNES;76570;76;SEINE MARITIME;1
76288;;Freulleville;FREULLEVILLE;76510;76;SEINE MARITIME;1
76289;;Fréville;FREVILLE;76190;76;SEINE MARITIME;1
76290;;Frichemesnil;FRICHEMESNIL;76690;76;SEINE MARITIME;1
76291;;Froberville;FROBERVILLE;76400;76;SEINE MARITIME;1
76292;;Fry;FRY;76780;76;SEINE MARITIME;1
76293;;Fultot;FULTOT;76560;76;SEINE MARITIME;1
76294;La;Gaillarde;GAILLARDE;76740;76;SEINE MARITIME;1
76295;;Gaillefontaine;GAILLEFONTAINE;76870;76;SEINE MARITIME;1
76296;;Gainneville;GAINNEVILLE;76700;76;SEINE MARITIME;1
76297;;Gancourt-Saint-Étienne;GANCOURT-SAINT-ETIENNE;76220;76;SEINE MARITIME;1
76298;;Ganzeville;GANZEVILLE;76400;76;SEINE MARITIME;1
76299;;Gerponville;GERPONVILLE;76540;76;SEINE MARITIME;1
76300;;Gerville;GERVILLE;76790;76;SEINE MARITIME;1
76301;;Glicourt;GLICOURT;76630;76;SEINE MARITIME;1
76302;;Goderville;GODERVILLE;76110;76;SEINE MARITIME;1
76303;;Gommerville;GOMMERVILLE;76430;76;SEINE MARITIME;1
76304;;Gonfreville-Caillot;GONFREVILLE-CAILLOT;76110;76;SEINE MARITIME;1
76305;;Gonfreville-l'Orcher;GONFREVILLE-L'ORCHER;76700;76;SEINE MARITIME;1
76306;;Gonnetot;GONNETOT;76730;76;SEINE MARITIME;1
76307;;Gonneville-la-Mallet;GONNEVILLE-LA-MALLET;76280;76;SEINE MARITIME;1
76308;;Gonneville-sur-Scie;GONNEVILLE-SUR-SCIE;76590;76;SEINE MARITIME;1
76309;;Gonzeville;GONZEVILLE;76560;76;SEINE MARITIME;1
76310;;Gouchaupre;GOUCHAUPRE;76630;76;SEINE MARITIME;1
76311;;Goupillières;GOUPILLIERES;76570;76;SEINE MARITIME;1
76312;;Gournay-en-Bray;GOURNAY-EN-BRAY;76220;76;SEINE MARITIME;1
76313;;Gouy;GOUY;76520;76;SEINE MARITIME;1
76314;;Graimbouville;GRAIMBOUVILLE;76430;76;SEINE MARITIME;1
76315;;Grainville-la-Teinturière;GRAINVILLE-LA-TEINTURIERE;76450;76;SEINE MARITIME;1
76316;;Grainville-sur-Ry;GRAINVILLE-SUR-RY;76116;76;SEINE MARITIME;1
76317;;Grainville-Ymauville;GRAINVILLE-YMAUVILLE;76110;76;SEINE MARITIME;1
76318;;Grand-Camp;GRAND-CAMP;76170;76;SEINE MARITIME;1
76319;;Grand-Couronne;GRAND-COURONNE;76530;76;SEINE MARITIME;1
76320;;Grandcourt;GRANDCOURT;76660;76;SEINE MARITIME;1
76321;Les;Grandes-Ventes;GRANDES-VENTES;76950;76;SEINE MARITIME;1
76322;Le;Grand-Quevilly;GRAND-QUEVILLY;76120;76;SEINE MARITIME;1
76323;;Graval;GRAVAL;76270;76;SEINE MARITIME;1
76324;;Grèges;GREGES;76370;76;SEINE MARITIME;1
76325;;Grémonville;GREMONVILLE;76970;76;SEINE MARITIME;1
76326;;Greny;GRENY;76630;76;SEINE MARITIME;1
76327;;Greuville;GREUVILLE;76810;76;SEINE MARITIME;1
76328;;Grigneuseville;GRIGNEUSEVILLE;76850;76;SEINE MARITIME;1
76329;;Gruchet-le-Valasse;GRUCHET-LE-VALASSE;76210;76;SEINE MARITIME;1
76330;;Gruchet-Saint-Siméon;GRUCHET-SAINT-SIMEON;76810;76;SEINE MARITIME;1
76331;;Grugny;GRUGNY;76690;76;SEINE MARITIME;1
76332;;Grumesnil;GRUMESNIL;76440;76;SEINE MARITIME;1
76333;;Guerville;GUERVILLE;76340;76;SEINE MARITIME;1
76334;;Gueures;GUEURES;76730;76;SEINE MARITIME;1
76335;;Gueutteville;GUEUTTEVILLE;76890;76;SEINE MARITIME;1
76336;;Gueutteville-les-Grès;GUEUTTEVILLE-LES-GRES;76460;76;SEINE MARITIME;1
76337;;Guilmécourt;GUILMECOURT;76630;76;SEINE MARITIME;1
76338;La;Hallotière;HALLOTIERE;76780;76;SEINE MARITIME;1
76339;Le;Hanouard;HANOUARD;76450;76;SEINE MARITIME;1
76340;;Harcanville;HARCANVILLE;76560;76;SEINE MARITIME;1
76341;;Harfleur;HARFLEUR;76700;76;SEINE MARITIME;1
76342;;Hattenville;HATTENVILLE;76640;76;SEINE MARITIME;1
76343;;Haucourt;HAUCOURT;76440;76;SEINE MARITIME;1
76344;;Haudricourt;HAUDRICOURT;76390;76;SEINE MARITIME;1
76345;;Haussez;HAUSSEZ;76440;76;SEINE MARITIME;1
76346;;Hautot-l'Auvray;HAUTOT-L'AUVRAY;76450;76;SEINE MARITIME;1
76347;;Hautot-le-Vatois;HAUTOT-LE-VATOIS;76190;76;SEINE MARITIME;1
76348;;Hautot-Saint-Sulpice;HAUTOT-SAINT-SULPICE;76190;76;SEINE MARITIME;1
76349;;Hautot-sur-Mer;HAUTOT-SUR-MER;76550;76;SEINE MARITIME;1
76350;;Hautot-sur-Seine;HAUTOT-SUR-SEINE;76113;76;SEINE MARITIME;1
76351;Le;Havre;HAVRE;76600;76;SEINE MARITIME;1
76352;La;Haye;HAYE;76780;76;SEINE MARITIME;1
76353;;Héberville;HEBERVILLE;76740;76;SEINE MARITIME;1
76354;;Hénouville;HENOUVILLE;76840;76;SEINE MARITIME;1
76355;;Héricourt-en-Caux;HERICOURT-EN-CAUX;76560;76;SEINE MARITIME;1
76356;;Hermanville;HERMANVILLE;76730;76;SEINE MARITIME;1
76357;;Hermeville;HERMEVILLE;76280;76;SEINE MARITIME;1
76358;Le;Héron;HERON;76780;76;SEINE MARITIME;1
76359;;Héronchelles;HERONCHELLES;76750;76;SEINE MARITIME;1
76360;;Heugleville-sur-Scie;HEUGLEVILLE-SUR-SCIE;76720;76;SEINE MARITIME;1
76361;;Heuqueville;HEUQUEVILLE;76280;76;SEINE MARITIME;1
76362;;Heurteauville;HEURTEAUVILLE;76940;76;SEINE MARITIME;1
76363;;Hodeng-au-Bosc;HODENG-AU-BOSC;76340;76;SEINE MARITIME;1
76364;;Hodeng-Hodenger;HODENG-HODENGER;76780;76;SEINE MARITIME;1
76365;;Houdetot;HOUDETOT;76740;76;SEINE MARITIME;1
76366;Le;Houlme;HOULME;76770;76;SEINE MARITIME;1
76367;;Houppeville;HOUPPEVILLE;76770;76;SEINE MARITIME;1
76368;;Houquetot;HOUQUETOT;76110;76;SEINE MARITIME;1
76369;La;Houssaye-Béranger;HOUSSAYE-BERANGER;76690;76;SEINE MARITIME;1
76370;;Hugleville-en-Caux;HUGLEVILLE-EN-CAUX;76570;76;SEINE MARITIME;1
76371;Les;Ifs;IFS;76630;76;SEINE MARITIME;1
76372;;Illois;ILLOIS;76390;76;SEINE MARITIME;1
76373;;Imbleville;IMBLEVILLE;76890;76;SEINE MARITIME;1
76374;;Incheville;INCHEVILLE;76117;76;SEINE MARITIME;1
76375;;Ingouville;INGOUVILLE;76460;76;SEINE MARITIME;1
76376;;Intraville;INTRAVILLE;76630;76;SEINE MARITIME;1
76377;;Isneauville;ISNEAUVILLE;76230;76;SEINE MARITIME;1
76378;;Jumièges;JUMIEGES;76480;76;SEINE MARITIME;1
76379;;Lamberville;LAMBERVILLE;76730;76;SEINE MARITIME;1
76380;;Lammerville;LAMMERVILLE;76730;76;SEINE MARITIME;1
76381;;Landes-Vieilles-et-Neuves;LANDES-VIEILLES-ET-NEUVES;76390;76;SEINE MARITIME;1
76382;;Lanquetot;LANQUETOT;76210;76;SEINE MARITIME;1
76383;;Lestanville;LESTANVILLE;76730;76;SEINE MARITIME;1
76384;;Lillebonne;LILLEBONNE;76170;76;SEINE MARITIME;1
76385;;Limésy;LIMESY;76570;76;SEINE MARITIME;1
76386;;Limpiville;LIMPIVILLE;76540;76;SEINE MARITIME;1
76387;;Lindebeuf;LINDEBEUF;76760;76;SEINE MARITIME;1
76388;;Lintot;LINTOT;76210;76;SEINE MARITIME;1
76389;;Lintot-les-Bois;LINTOT-LES-BOIS;76590;76;SEINE MARITIME;1
76390;Les;Loges;LOGES;76790;76;SEINE MARITIME;1
76391;La;Londe;LONDE;76500;76;SEINE MARITIME;1
76392;;Londinières;LONDINIERES;76660;76;SEINE MARITIME;1
76393;;Longmesnil;LONGMESNIL;76440;76;SEINE MARITIME;1
76394;;Longroy;LONGROY;76260;76;SEINE MARITIME;1
76395;;Longueil;LONGUEIL;76860;76;SEINE MARITIME;1
76396;;Longuerue;LONGUERUE;76750;76;SEINE MARITIME;1
76397;;Longueville-sur-Scie;LONGUEVILLE-SUR-SCIE;76590;76;SEINE MARITIME;1
76398;;Louvetot;LOUVETOT;76490;76;SEINE MARITIME;1
76399;;Lucy;LUCY;76270;76;SEINE MARITIME;1
76400;;Luneray;LUNERAY;76810;76;SEINE MARITIME;1
76401;La;Mailleraye-sur-Seine;MAILLERAYE-SUR-SEINE;76940;76;SEINE MARITIME;1
76402;;Malaunay;MALAUNAY;76770;76;SEINE MARITIME;1
76403;;Malleville-les-Grès;MALLEVILLE-LES-GRES;76450;76;SEINE MARITIME;1
76404;;Manéglise;MANEGLISE;76133;76;SEINE MARITIME;1
76405;;Manéhouville;MANEHOUVILLE;76590;76;SEINE MARITIME;1
76406;;Maniquerville;MANIQUERVILLE;76400;76;SEINE MARITIME;1
76407;;Manneville-ès-Plains;MANNEVILLE-ES-PLAINS;76460;76;SEINE MARITIME;1
76408;;Manneville-la-Goupil;MANNEVILLE-LA-GOUPIL;76110;76;SEINE MARITIME;1
76409;;Mannevillette;MANNEVILLETTE;76290;76;SEINE MARITIME;1
76410;;Maromme;MAROMME;76150;76;SEINE MARITIME;1
76411;;Marques;MARQUES;76390;76;SEINE MARITIME;1
76412;;Martainville-Épreville;MARTAINVILLE-EPREVILLE;76116;76;SEINE MARITIME;1
76413;;Martigny;MARTIGNY;76880;76;SEINE MARITIME;1
76414;;Martin-Église;MARTIN-EGLISE;76370;76;SEINE MARITIME;1
76415;;Massy;MASSY;76270;76;SEINE MARITIME;1
76416;;Mathonville;MATHONVILLE;76680;76;SEINE MARITIME;1
76417;;Maucomble;MAUCOMBLE;76680;76;SEINE MARITIME;1
76418;;Maulévrier-Sainte-Gertrude;MAULEVRIER-SAINTE-GERTRUDE;76490;76;SEINE MARITIME;1
76419;;Mauny;MAUNY;76530;76;SEINE MARITIME;1
76420;;Mauquenchy;MAUQUENCHY;76440;76;SEINE MARITIME;1
76421;;Mélamare;MELAMARE;76170;76;SEINE MARITIME;1
76422;;Melleville;MELLEVILLE;76260;76;SEINE MARITIME;1
76423;;Ménerval;MENERVAL;76220;76;SEINE MARITIME;1
76424;;Ménonval;MENONVAL;76270;76;SEINE MARITIME;1
76425;;Mentheville;MENTHEVILLE;76110;76;SEINE MARITIME;1
76426;;Mésangueville;MESANGUEVILLE;76780;76;SEINE MARITIME;1
76427;;Mesnières-en-Bray;MESNIERES-EN-BRAY;76270;76;SEINE MARITIME;1
76428;Le;Mesnil-Durdent;MESNIL-DURDENT;76460;76;SEINE MARITIME;1
76429;Le;Mesnil-Esnard;MESNIL-ESNARD;76240;76;SEINE MARITIME;1
76430;;Mesnil-Follemprise;MESNIL-FOLLEMPRISE;76660;76;SEINE MARITIME;1
76431;Le;Mesnil-Lieubray;MESNIL-LIEUBRAY;76780;76;SEINE MARITIME;1
76432;;Mesnil-Mauger;MESNIL-MAUGER;76440;76;SEINE MARITIME;1
76433;;Mesnil-Panneville;MESNIL-PANNEVILLE;76570;76;SEINE MARITIME;1
76434;;Mesnil-Raoul;MESNIL-RAOUL;76520;76;SEINE MARITIME;1
76435;Le;Mesnil-Réaume;MESNIL-REAUME;76260;76;SEINE MARITIME;1
76436;Le;Mesnil-sous-Jumièges;MESNIL-SOUS-JUMIEGES;76480;76;SEINE MARITIME;1
76437;;Meulers;MEULERS;76510;76;SEINE MARITIME;1
76438;;Millebosc;MILLEBOSC;76260;76;SEINE MARITIME;1
76439;;Mirville;MIRVILLE;76210;76;SEINE MARITIME;1
76440;;Molagnies;MOLAGNIES;76220;76;SEINE MARITIME;1
76441;;Monchaux-Soreng;MONCHAUX-SORENG;76340;76;SEINE MARITIME;1
76442;;Monchy-sur-Eu;MONCHY-SUR-EU;76260;76;SEINE MARITIME;1
76443;;Mont-Cauvaire;MONT-CAUVAIRE;76690;76;SEINE MARITIME;1
76444;;Mont-de-l'If;MONT-DE-L'IF;76190;76;SEINE MARITIME;1
76445;;Montérolier;MONTEROLIER;76680;76;SEINE MARITIME;1
76446;;Montigny;MONTIGNY;76380;76;SEINE MARITIME;1
76447;;Montivilliers;MONTIVILLIERS;76290;76;SEINE MARITIME;1
76448;;Montmain;MONTMAIN;76520;76;SEINE MARITIME;1
76449;;Montreuil-en-Caux;MONTREUIL-EN-CAUX;76850;76;SEINE MARITIME;1
76450;;Montroty;MONTROTY;76220;76;SEINE MARITIME;1
76451;;Mont-Saint-Aignan;MONT-SAINT-AIGNAN;76130;76;SEINE MARITIME;1
76452;;Montville;MONTVILLE;76710;76;SEINE MARITIME;1
76453;;Morgny-la-Pommeraye;MORGNY-LA-POMMERAYE;76750;76;SEINE MARITIME;1
76454;;Mortemer;MORTEMER;76270;76;SEINE MARITIME;1
76455;;Morville-sur-Andelle;MORVILLE-SUR-ANDELLE;76780;76;SEINE MARITIME;1
76456;;Motteville;MOTTEVILLE;76970;76;SEINE MARITIME;1
76457;;Moulineaux;MOULINEAUX;76530;76;SEINE MARITIME;1
76458;;Muchedent;MUCHEDENT;76590;76;SEINE MARITIME;1
76459;;Nesle-Hodeng;NESLE-HODENG;76270;76;SEINE MARITIME;1
76460;;Nesle-Normandeuse;NESLE-NORMANDEUSE;76340;76;SEINE MARITIME;1
76461;;Neufbosc;NEUFBOSC;76680;76;SEINE MARITIME;1
76462;;Neufchâtel-en-Bray;NEUFCHATEL-EN-BRAY;76270;76;SEINE MARITIME;1
76463;;Neuf-Marché;NEUF-MARCHE;76220;76;SEINE MARITIME;1
76464;La;Neuville-Chant-d'Oisel;NEUVILLE-CHANT-D'OISEL;76520;76;SEINE MARITIME;1
76465;;Neuville-Ferrières;NEUVILLE-FERRIERES;76270;76;SEINE MARITIME;1
76467;;Néville;NEVILLE;76460;76;SEINE MARITIME;1
76468;;Nointot;NOINTOT;76210;76;SEINE MARITIME;1
76469;;Nolléval;NOLLEVAL;76780;76;SEINE MARITIME;1
76470;;Normanville;NORMANVILLE;76640;76;SEINE MARITIME;1
76471;;Norville;NORVILLE;76330;76;SEINE MARITIME;1
76472;;Notre-Dame-d'Aliermont;NOTRE-DAME-D'ALIERMONT;76510;76;SEINE MARITIME;1
76473;;Notre-Dame-de-Bliquetuit;NOTRE-DAME-DE-BLIQUETUIT;76940;76;SEINE MARITIME;1
76474;;Notre-Dame-de-Bondeville;NOTRE-DAME-DE-BONDEVILLE;76960;76;SEINE MARITIME;1
76475;;Franqueville-Saint-Pierre;FRANQUEVILLE-SAINT-PIERRE;76520;76;SEINE MARITIME;1
76476;;Notre-Dame-de-Gravenchon;NOTRE-DAME-DE-GRAVENCHON;76330;76;SEINE MARITIME;1
76477;;Notre-Dame-du-Bec;NOTRE-DAME-DU-BEC;76133;76;SEINE MARITIME;1
76478;;Notre-Dame-du-Parc;NOTRE-DAME-DU-PARC;76590;76;SEINE MARITIME;1
76479;;Nullemont;NULLEMONT;76390;76;SEINE MARITIME;1
76480;;Ocqueville;OCQUEVILLE;76450;76;SEINE MARITIME;1
76481;;Octeville-sur-Mer;OCTEVILLE-SUR-MER;76930;76;SEINE MARITIME;1
76482;;Offranville;OFFRANVILLE;76550;76;SEINE MARITIME;1
76483;;Oherville;OHERVILLE;76560;76;SEINE MARITIME;1
76484;;Oissel;OISSEL;76350;76;SEINE MARITIME;1
76485;;Omonville;OMONVILLE;76730;76;SEINE MARITIME;1
76486;;Orival;ORIVAL;76500;76;SEINE MARITIME;1
76487;;Osmoy-Saint-Valery;OSMOY-SAINT-VALERY;76660;76;SEINE MARITIME;1
76488;;Ouainville;OUAINVILLE;76450;76;SEINE MARITIME;1
76489;;Oudalle;OUDALLE;76430;76;SEINE MARITIME;1
76490;;Ourville-en-Caux;OURVILLE-EN-CAUX;76450;76;SEINE MARITIME;1
76491;;Ouville-l'Abbaye;OUVILLE-L'ABBAYE;76760;76;SEINE MARITIME;1
76492;;Ouville-la-Rivière;OUVILLE-LA-RIVIERE;76860;76;SEINE MARITIME;1
76493;;Paluel;PALUEL;76450;76;SEINE MARITIME;1
76494;;Parc-d'Anxtot;PARC-D'ANXTOT;76210;76;SEINE MARITIME;1
76495;;Pavilly;PAVILLY;76570;76;SEINE MARITIME;1
76496;;Penly;PENLY;76630;76;SEINE MARITIME;1
76497;;Petit-Couronne;PETIT-COURONNE;76650;76;SEINE MARITIME;1
76498;Le;Petit-Quevilly;PETIT-QUEVILLY;76140;76;SEINE MARITIME;1
76499;;Petiville;PETIVILLE;76330;76;SEINE MARITIME;1
76500;;Pierrecourt;PIERRECOURT;76340;76;SEINE MARITIME;1
76501;;Pierrefiques;PIERREFIQUES;76280;76;SEINE MARITIME;1
76502;;Pierreval;PIERREVAL;76750;76;SEINE MARITIME;1
76503;;Pissy-Pôville;PISSY-POVILLE;76360;76;SEINE MARITIME;1
76504;;Pleine-Sève;PLEINE-SEVE;76460;76;SEINE MARITIME;1
76505;;Pommereux;POMMEREUX;76440;76;SEINE MARITIME;1
76506;;Pommeréval;POMMEREVAL;76680;76;SEINE MARITIME;1
76507;;Ponts-et-Marais;PONTS-ET-MARAIS;76260;76;SEINE MARITIME;1
76508;La;Poterie-Cap-d'Antifer;POTERIE-CAP-D'ANTIFER;76280;76;SEINE MARITIME;1
76509;;Préaux;PREAUX;76160;76;SEINE MARITIME;1
76510;;Prétot-Vicquemare;PRETOT-VICQUEMARE;76560;76;SEINE MARITIME;1
76511;;Preuseville;PREUSEVILLE;76660;76;SEINE MARITIME;1
76512;;Puisenval;PUISENVAL;76660;76;SEINE MARITIME;1
76513;;Quevillon;QUEVILLON;76840;76;SEINE MARITIME;1
76514;;Quévreville-la-Poterie;QUEVREVILLE-LA-POTERIE;76520;76;SEINE MARITIME;1
76515;;Quiberville;QUIBERVILLE;76860;76;SEINE MARITIME;1
76516;;Quièvrecourt;QUIEVRECOURT;76270;76;SEINE MARITIME;1
76517;;Quincampoix;QUINCAMPOIX;76230;76;SEINE MARITIME;1
76518;;Raffetot;RAFFETOT;76210;76;SEINE MARITIME;1
76519;;Rainfreville;RAINFREVILLE;76730;76;SEINE MARITIME;1
76520;;Réalcamp;REALCAMP;76340;76;SEINE MARITIME;1
76521;;Rebets;REBETS;76750;76;SEINE MARITIME;1
76522;La;Remuée;REMUEE;76430;76;SEINE MARITIME;1
76523;;Rétonval;RETONVAL;76340;76;SEINE MARITIME;1
76524;;Reuville;REUVILLE;76560;76;SEINE MARITIME;1
76525;;Ricarville;RICARVILLE;76640;76;SEINE MARITIME;1
76526;;Ricarville-du-Val;RICARVILLE-DU-VAL;76510;76;SEINE MARITIME;1
76527;;Richemont;RICHEMONT;76390;76;SEINE MARITIME;1
76528;;Rieux;RIEUX;76340;76;SEINE MARITIME;1
76529;;Riville;RIVILLE;76540;76;SEINE MARITIME;1
76530;;Robertot;ROBERTOT;76560;76;SEINE MARITIME;1
76531;;Rocquefort;ROCQUEFORT;76640;76;SEINE MARITIME;1
76532;;Rocquemont;ROCQUEMONT;76680;76;SEINE MARITIME;1
76533;;Rogerville;ROGERVILLE;76700;76;SEINE MARITIME;1
76534;;Rolleville;ROLLEVILLE;76133;76;SEINE MARITIME;1
76535;;Roncherolles-en-Bray;RONCHEROLLES-EN-BRAY;76440;76;SEINE MARITIME;1
76536;;Roncherolles-sur-le-Vivier;RONCHEROLLES-SUR-LE-VIVIER;76160;76;SEINE MARITIME;1
76537;;Ronchois;RONCHOIS;76390;76;SEINE MARITIME;1
76538;;Rosay;ROSAY;76680;76;SEINE MARITIME;1
76540;;Rouen;ROUEN;76000;76;SEINE MARITIME;1
76541;;Roumare;ROUMARE;76480;76;SEINE MARITIME;1
76542;;Routes;ROUTES;76560;76;SEINE MARITIME;1
76543;;Rouville;ROUVILLE;76210;76;SEINE MARITIME;1
76544;;Rouvray-Catillon;ROUVRAY-CATILLON;76440;76;SEINE MARITIME;1
76545;;Rouxmesnil-Bouteilles;ROUXMESNIL-BOUTEILLES;76370;76;SEINE MARITIME;1
76546;;Royville;ROYVILLE;76730;76;SEINE MARITIME;1
76547;La;Rue-Saint-Pierre;RUE-SAINT-PIERRE;76690;76;SEINE MARITIME;1
76548;;Ry;RY;76116;76;SEINE MARITIME;1
76549;;Saâne-Saint-Just;SAANE-SAINT-JUST;76730;76;SEINE MARITIME;1
76550;;Sahurs;SAHURS;76113;76;SEINE MARITIME;1
76551;;Sainneville;SAINNEVILLE;76430;76;SEINE MARITIME;1
76552;;Sainte-Adresse;SAINTE-ADRESSE;76310;76;SEINE MARITIME;1
76553;;Sainte-Agathe-d'Aliermont;SAINTE-AGATHE-D'ALIERMONT;76660;76;SEINE MARITIME;1
76554;;Saint-Aignan-sur-Ry;SAINT-AIGNAN-SUR-RY;76116;76;SEINE MARITIME;1
76555;;Saint-André-sur-Cailly;SAINT-ANDRE-SUR-CAILLY;76690;76;SEINE MARITIME;1
76556;;Saint-Antoine-la-Forêt;SAINT-ANTOINE-LA-FORET;76170;76;SEINE MARITIME;1
76557;;Saint-Arnoult;SAINT-ARNOULT;76490;76;SEINE MARITIME;1
76558;;Saint-Aubin-Celloville;SAINT-AUBIN-CELLOVILLE;76520;76;SEINE MARITIME;1
76559;;Saint-Aubin-de-Crétot;SAINT-AUBIN-DE-CRETOT;76190;76;SEINE MARITIME;1
76560;;Saint-Aubin-Épinay;SAINT-AUBIN-EPINAY;76160;76;SEINE MARITIME;1
76561;;Saint-Aubin-lès-Elbeuf;SAINT-AUBIN-LES-ELBEUF;76410;76;SEINE MARITIME;1
76562;;Saint-Aubin-le-Cauf;SAINT-AUBIN-LE-CAUF;76510;76;SEINE MARITIME;1
76563;;Saint-Aubin-Routot;SAINT-AUBIN-ROUTOT;76430;76;SEINE MARITIME;1
76564;;Saint-Aubin-sur-Mer;SAINT-AUBIN-SUR-MER;76740;76;SEINE MARITIME;1
76565;;Saint-Aubin-sur-Scie;SAINT-AUBIN-SUR-SCIE;76550;76;SEINE MARITIME;1
76566;;Sainte-Austreberthe;SAINTE-AUSTREBERTHE;76570;76;SEINE MARITIME;1
76567;;Sainte-Beuve-en-Rivière;SAINTE-BEUVE-EN-RIVIERE;76270;76;SEINE MARITIME;1
76568;;Saint-Clair-sur-les-Monts;SAINT-CLAIR-SUR-LES-MONTS;76190;76;SEINE MARITIME;1
76569;;Sainte-Colombe;SAINTE-COLOMBE;76460;76;SEINE MARITIME;1
76570;;Saint-Crespin;SAINT-CRESPIN;76590;76;SEINE MARITIME;1
76571;;Sainte-Croix-sur-Buchy;SAINTE-CROIX-SUR-BUCHY;76750;76;SEINE MARITIME;1
76572;;Saint-Denis-d'Aclon;SAINT-DENIS-D'ACLON;76860;76;SEINE MARITIME;1
76573;;Saint-Denis-le-Thiboult;SAINT-DENIS-LE-THIBOULT;76116;76;SEINE MARITIME;1
76574;;Saint-Denis-sur-Scie;SAINT-DENIS-SUR-SCIE;76890;76;SEINE MARITIME;1
76575;;Saint-Étienne-du-Rouvray;SAINT-ETIENNE-DU-ROUVRAY;76800;76;SEINE MARITIME;1
76576;;Saint-Eustache-la-Forêt;SAINT-EUSTACHE-LA-FORET;76210;76;SEINE MARITIME;1
76577;;Sainte-Foy;SAINTE-FOY;76590;76;SEINE MARITIME;1
76578;;Sainte-Geneviève;SAINTE-GENEVIEVE;76440;76;SEINE MARITIME;1
76580;;Saint-Georges-sur-Fontaine;SAINT-GEORGES-SUR-FONTAINE;76690;76;SEINE MARITIME;1
76581;;Saint-Germain-des-Essourts;SAINT-GERMAIN-DES-ESSOURTS;76750;76;SEINE MARITIME;1
76582;;Saint-Germain-d'Étables;SAINT-GERMAIN-D'ETABLES;76590;76;SEINE MARITIME;1
76583;;Saint-Germain-sous-Cailly;SAINT-GERMAIN-SOUS-CAILLY;76690;76;SEINE MARITIME;1
76584;;Saint-Germain-sur-Eaulne;SAINT-GERMAIN-SUR-EAULNE;76270;76;SEINE MARITIME;1
76585;;Saint-Gilles-de-Crétot;SAINT-GILLES-DE-CRETOT;76490;76;SEINE MARITIME;1
76586;;Saint-Gilles-de-la-Neuville;SAINT-GILLES-DE-LA-NEUVILLE;76430;76;SEINE MARITIME;1
76587;;Sainte-Hélène-Bondeville;SAINTE-HELENE-BONDEVILLE;76400;76;SEINE MARITIME;1
76588;;Saint-Hellier;SAINT-HELLIER;76680;76;SEINE MARITIME;1
76589;;Saint-Honoré;SAINT-HONORE;76590;76;SEINE MARITIME;1
76590;;Saint-Jacques-d'Aliermont;SAINT-JACQUES-D'ALIERMONT;76510;76;SEINE MARITIME;1
76591;;Saint-Jacques-sur-Darnétal;SAINT-JACQUES-SUR-DARNETAL;76160;76;SEINE MARITIME;1
76592;;Saint-Jean-de-Folleville;SAINT-JEAN-DE-FOLLEVILLE;76170;76;SEINE MARITIME;1
76593;;Saint-Jean-de-la-Neuville;SAINT-JEAN-DE-LA-NEUVILLE;76210;76;SEINE MARITIME;1
76594;;Saint-Jean-du-Cardonnay;SAINT-JEAN-DU-CARDONNAY;76150;76;SEINE MARITIME;1
76595;;Saint-Jouin-Bruneval;SAINT-JOUIN-BRUNEVAL;76280;76;SEINE MARITIME;1
76596;;Saint-Laurent-de-Brèvedent;SAINT-LAURENT-DE-BREVEDENT;76700;76;SEINE MARITIME;1
76597;;Saint-Laurent-en-Caux;SAINT-LAURENT-EN-CAUX;76560;76;SEINE MARITIME;1
76598;;Saint-Léger-aux-Bois;SAINT-LEGER-AUX-BOIS;76340;76;SEINE MARITIME;1
76599;;Saint-Léger-du-Bourg-Denis;SAINT-LEGER-DU-BOURG-DENIS;76160;76;SEINE MARITIME;1
76600;;Saint-Léonard;SAINT-LEONARD;76400;76;SEINE MARITIME;1
76602;;Saint-Maclou-de-Folleville;SAINT-MACLOU-DE-FOLLEVILLE;76890;76;SEINE MARITIME;1
76603;;Saint-Maclou-la-Brière;SAINT-MACLOU-LA-BRIERE;76110;76;SEINE MARITIME;1
76604;;Saint-Mards;SAINT-MARDS;76730;76;SEINE MARITIME;1
76605;;Sainte-Marguerite-sur-Mer;SAINTE-MARGUERITE-SUR-MER;76119;76;SEINE MARITIME;1
76606;;Morienne;MORIENNE;76390;76;SEINE MARITIME;1
76607;;Sainte-Marguerite-sur-Fauville;SAINTE-MARGUERITE-SUR-FAUVILLE;76640;76;SEINE MARITIME;1
76608;;Sainte-Marguerite-sur-Duclair;SAINTE-MARGUERITE-SUR-DUCLAIR;76480;76;SEINE MARITIME;1
76609;;Sainte-Marie-au-Bosc;SAINTE-MARIE-AU-BOSC;76280;76;SEINE MARITIME;1
76610;;Sainte-Marie-des-Champs;SAINTE-MARIE-DES-CHAMPS;76190;76;SEINE MARITIME;1
76611;;Saint-Martin-aux-Arbres;SAINT-MARTIN-AUX-ARBRES;76760;76;SEINE MARITIME;1
76612;;Saint-Martin-au-Bosc;SAINT-MARTIN-AU-BOSC;76340;76;SEINE MARITIME;1
76613;;Saint-Martin-aux-Buneaux;SAINT-MARTIN-AUX-BUNEAUX;76540;76;SEINE MARITIME;1
76614;;Saint-Martin-de-Boscherville;SAINT-MARTIN-DE-BOSCHERVILLE;76840;76;SEINE MARITIME;1
76615;;Saint-Martin-du-Bec;SAINT-MARTIN-DU-BEC;76133;76;SEINE MARITIME;1
76616;;Saint-Martin-du-Manoir;SAINT-MARTIN-DU-MANOIR;76290;76;SEINE MARITIME;1
76617;;Saint-Martin-du-Vivier;SAINT-MARTIN-DU-VIVIER;76160;76;SEINE MARITIME;1
76618;;Saint-Martin-en-Campagne;SAINT-MARTIN-EN-CAMPAGNE;76370;76;SEINE MARITIME;1
76619;;Saint-Martin-le-Gaillard;SAINT-MARTIN-LE-GAILLARD;76260;76;SEINE MARITIME;1
76620;;Saint-Martin-l'Hortier;SAINT-MARTIN-L'HORTIER;76270;76;SEINE MARITIME;1
76621;;Saint-Martin-Osmonville;SAINT-MARTIN-OSMONVILLE;76680;76;SEINE MARITIME;1
76622;;Saint-Maurice-d'Ételan;SAINT-MAURICE-D'ETELAN;76330;76;SEINE MARITIME;1
76623;;Saint-Michel-d'Halescourt;SAINT-MICHEL-D'HALESCOURT;76440;76;SEINE MARITIME;1
76624;;Saint-Nicolas-d'Aliermont;SAINT-NICOLAS-D'ALIERMONT;76510;76;SEINE MARITIME;1
76625;;Saint-Nicolas-de-Bliquetuit;SAINT-NICOLAS-DE-BLIQUETUIT;76940;76;SEINE MARITIME;1
76626;;Saint-Nicolas-de-la-Haie;SAINT-NICOLAS-DE-LA-HAIE;76490;76;SEINE MARITIME;1
76627;;Saint-Nicolas-de-la-Taille;SAINT-NICOLAS-DE-LA-TAILLE;76170;76;SEINE MARITIME;1
76628;;Saint-Ouen-du-Breuil;SAINT-OUEN-DU-BREUIL;76890;76;SEINE MARITIME;1
76629;;Saint-Ouen-le-Mauger;SAINT-OUEN-LE-MAUGER;76730;76;SEINE MARITIME;1
76630;;Saint-Ouen-sous-Bailly;SAINT-OUEN-SOUS-BAILLY;76630;76;SEINE MARITIME;1
76631;;Saint-Paër;SAINT-PAER;76480;76;SEINE MARITIME;1
76632;;Saint-Pierre-Bénouville;SAINT-PIERRE-BENOUVILLE;76890;76;SEINE MARITIME;1
76634;;Saint-Pierre-de-Manneville;SAINT-PIERRE-DE-MANNEVILLE;76113;76;SEINE MARITIME;1
76635;;Saint-Pierre-des-Jonquières;SAINT-PIERRE-DES-JONQUIERES;76660;76;SEINE MARITIME;1
76636;;Saint-Pierre-de-Varengeville;SAINT-PIERRE-DE-VARENGEVILLE;76480;76;SEINE MARITIME;1
76637;;Saint-Pierre-en-Port;SAINT-PIERRE-EN-PORT;76540;76;SEINE MARITIME;1
76638;;Saint-Pierre-en-Val;SAINT-PIERRE-EN-VAL;76260;76;SEINE MARITIME;1
76639;;Saint-Pierre-Lavis;SAINT-PIERRE-LAVIS;76640;76;SEINE MARITIME;1
76640;;Saint-Pierre-lès-Elbeuf;SAINT-PIERRE-LES-ELBEUF;76320;76;SEINE MARITIME;1
76641;;Saint-Pierre-le-Vieux;SAINT-PIERRE-LE-VIEUX;76740;76;SEINE MARITIME;1
76642;;Saint-Pierre-le-Viger;SAINT-PIERRE-LE-VIGER;76740;76;SEINE MARITIME;1
76643;;Saint-Quentin-au-Bosc;SAINT-QUENTIN-AU-BOSC;76630;76;SEINE MARITIME;1
76644;;Saint-Rémy-Boscrocourt;SAINT-REMY-BOSCROCOURT;76260;76;SEINE MARITIME;1
76645;;Saint-Riquier-en-Rivière;SAINT-RIQUIER-EN-RIVIERE;76340;76;SEINE MARITIME;1
76646;;Saint-Riquier-ès-Plains;SAINT-RIQUIER-ES-PLAINS;76460;76;SEINE MARITIME;1
76647;;Saint-Romain-de-Colbosc;SAINT-ROMAIN-DE-COLBOSC;76430;76;SEINE MARITIME;1
76648;;Saint-Saëns;SAINT-SAENS;76680;76;SEINE MARITIME;1
76649;;Saint-Saire;SAINT-SAIRE;76270;76;SEINE MARITIME;1
76650;;Saint-Sauveur-d'Émalleville;SAINT-SAUVEUR-D'EMALLEVILLE;76110;76;SEINE MARITIME;1
76651;;Saint-Sylvain;SAINT-SYLVAIN;76460;76;SEINE MARITIME;1
76652;;Saint-Vaast-d'Équiqueville;SAINT-VAAST-D'EQUIQUEVILLE;76510;76;SEINE MARITIME;1
76653;;Saint-Vaast-Dieppedalle;SAINT-VAAST-DIEPPEDALLE;76450;76;SEINE MARITIME;1
76654;;Saint-Vaast-du-Val;SAINT-VAAST-DU-VAL;76890;76;SEINE MARITIME;1
76655;;Saint-Valery-en-Caux;SAINT-VALERY-EN-CAUX;76460;76;SEINE MARITIME;1
76656;;Saint-Victor-l'Abbaye;SAINT-VICTOR-L'ABBAYE;76890;76;SEINE MARITIME;1
76657;;Saint-Vigor-d'Ymonville;SAINT-VIGOR-D'YMONVILLE;76430;76;SEINE MARITIME;1
76658;;Saint-Vincent-Cramesnil;SAINT-VINCENT-CRAMESNIL;76430;76;SEINE MARITIME;1
76659;;Saint-Wandrille-Rançon;SAINT-WANDRILLE-RANCON;76490;76;SEINE MARITIME;1
76660;;Sandouville;SANDOUVILLE;76430;76;SEINE MARITIME;1
76662;;Sassetot-le-Malgardé;SASSETOT-LE-MALGARDE;76730;76;SEINE MARITIME;1
76663;;Sassetot-le-Mauconduit;SASSETOT-LE-MAUCONDUIT;76540;76;SEINE MARITIME;1
76664;;Sasseville;SASSEVILLE;76450;76;SEINE MARITIME;1
76665;;Sauchay;SAUCHAY;76630;76;SEINE MARITIME;1
76666;;Saumont-la-Poterie;SAUMONT-LA-POTERIE;76440;76;SEINE MARITIME;1
76667;;Sauqueville;SAUQUEVILLE;76550;76;SEINE MARITIME;1
76668;;Saussay;SAUSSAY;76760;76;SEINE MARITIME;1
76669;;Sausseuzemare-en-Caux;SAUSSEUZEMARE-EN-CAUX;76110;76;SEINE MARITIME;1
76670;;Senneville-sur-Fécamp;SENNEVILLE-SUR-FECAMP;76400;76;SEINE MARITIME;1
76671;;Sept-Meules;SEPT-MEULES;76260;76;SEINE MARITIME;1
76672;;Serqueux;SERQUEUX;76440;76;SEINE MARITIME;1
76673;;Servaville-Salmonville;SERVAVILLE-SALMONVILLE;76116;76;SEINE MARITIME;1
76674;;Sévis;SEVIS;76850;76;SEINE MARITIME;1
76675;;Sierville;SIERVILLE;76690;76;SEINE MARITIME;1
76676;;Sigy-en-Bray;SIGY-EN-BRAY;76780;76;SEINE MARITIME;1
76677;;Smermesnil;SMERMESNIL;76660;76;SEINE MARITIME;1
76678;;Sommery;SOMMERY;76440;76;SEINE MARITIME;1
76679;;Sommesnil;SOMMESNIL;76560;76;SEINE MARITIME;1
76680;;Sorquainville;SORQUAINVILLE;76540;76;SEINE MARITIME;1
76681;;Sotteville-lès-Rouen;SOTTEVILLE-LES-ROUEN;76300;76;SEINE MARITIME;1
76682;;Sotteville-sous-le-Val;SOTTEVILLE-SOUS-LE-VAL;76410;76;SEINE MARITIME;1
76683;;Sotteville-sur-Mer;SOTTEVILLE-SUR-MER;76740;76;SEINE MARITIME;1
76684;;Tancarville;TANCARVILLE;76430;76;SEINE MARITIME;1
76685;;Thérouldeville;THEROULDEVILLE;76540;76;SEINE MARITIME;1
76686;;Theuville-aux-Maillots;THEUVILLE-AUX-MAILLOTS;76540;76;SEINE MARITIME;1
76688;;Thiergeville;THIERGEVILLE;76540;76;SEINE MARITIME;1
76689;;Thiétreville;THIETREVILLE;76540;76;SEINE MARITIME;1
76690;;Thil-Manneville;THIL-MANNEVILLE;76730;76;SEINE MARITIME;1
76691;Le;Thil-Riberpré;THIL-RIBERPRE;76440;76;SEINE MARITIME;1
76692;;Thiouville;THIOUVILLE;76450;76;SEINE MARITIME;1
76693;Le;Tilleul;TILLEUL;76790;76;SEINE MARITIME;1
76694;;Tocqueville-en-Caux;TOCQUEVILLE-EN-CAUX;76730;76;SEINE MARITIME;1
76695;;Tocqueville-les-Murs;TOCQUEVILLE-LES-MURS;76110;76;SEINE MARITIME;1
76696;;Tocqueville-sur-Eu;TOCQUEVILLE-SUR-EU;76910;76;SEINE MARITIME;1
76697;;Torcy-le-Grand;TORCY-LE-GRAND;76590;76;SEINE MARITIME;1
76698;;Torcy-le-Petit;TORCY-LE-PETIT;76590;76;SEINE MARITIME;1
76699;Le;Torp-Mesnil;TORP-MESNIL;76560;76;SEINE MARITIME;1
76700;;Tôtes;TOTES;76890;76;SEINE MARITIME;1
76701;;Touffreville-la-Cable;TOUFFREVILLE-LA-CABLE;76170;76;SEINE MARITIME;1
76702;;Touffreville-la-Corbeline;TOUFFREVILLE-LA-CORBELINE;76190;76;SEINE MARITIME;1
76703;;Touffreville-sur-Eu;TOUFFREVILLE-SUR-EU;76910;76;SEINE MARITIME;1
76704;;Tourville-la-Chapelle;TOURVILLE-LA-CHAPELLE;76630;76;SEINE MARITIME;1
76705;;Tourville-la-Rivière;TOURVILLE-LA-RIVIERE;76410;76;SEINE MARITIME;1
76706;;Tourville-les-Ifs;TOURVILLE-LES-IFS;76400;76;SEINE MARITIME;1
76707;;Tourville-sur-Arques;TOURVILLE-SUR-ARQUES;76550;76;SEINE MARITIME;1
76708;;Toussaint;TOUSSAINT;76400;76;SEINE MARITIME;1
76709;Le;Trait;TRAIT;76580;76;SEINE MARITIME;1
76710;;Trémauville;TREMAUVILLE;76640;76;SEINE MARITIME;1
76711;Le;Tréport;TREPORT;76470;76;SEINE MARITIME;1
76712;La;Trinité-du-Mont;TRINITE-DU-MONT;76170;76;SEINE MARITIME;1
76713;;Triquerville;TRIQUERVILLE;76170;76;SEINE MARITIME;1
76714;Les;Trois-Pierres;TROIS-PIERRES;76430;76;SEINE MARITIME;1
76715;;Trouville;TROUVILLE;76210;76;SEINE MARITIME;1
76716;;Turretot;TURRETOT;76280;76;SEINE MARITIME;1
76717;;Val-de-la-Haye;VAL-DE-LA-HAYE;76380;76;SEINE MARITIME;1
76718;;Valliquerville;VALLIQUERVILLE;76190;76;SEINE MARITIME;1
76719;;Valmont;VALMONT;76540;76;SEINE MARITIME;1
76720;;Varengeville-sur-Mer;VARENGEVILLE-SUR-MER;76119;76;SEINE MARITIME;1
76721;;Varneville-Bretteville;VARNEVILLE-BRETTEVILLE;76890;76;SEINE MARITIME;1
76723;;Vassonville;VASSONVILLE;76890;76;SEINE MARITIME;1
76724;;Vatierville;VATIERVILLE;76270;76;SEINE MARITIME;1
76725;;Vattetot-sous-Beaumont;VATTETOT-SOUS-BEAUMONT;76110;76;SEINE MARITIME;1
76726;;Vattetot-sur-Mer;VATTETOT-SUR-MER;76111;76;SEINE MARITIME;1
76727;;Vatteville-la-Rue;VATTEVILLE-LA-RUE;76940;76;SEINE MARITIME;1
76728;La;Vaupalière;VAUPALIERE;76150;76;SEINE MARITIME;1
76729;;Veauville-lès-Baons;VEAUVILLE-LES-BAONS;76190;76;SEINE MARITIME;1
76730;;Veauville-lès-Quelles;VEAUVILLE-LES-QUELLES;76560;76;SEINE MARITIME;1
76731;;Vénestanville;VENESTANVILLE;76730;76;SEINE MARITIME;1
76732;;Butot-Vénesville;BUTOT-VENESVILLE;76450;76;SEINE MARITIME;1
76733;;Ventes-Saint-Rémy;VENTES-SAINT-REMY;76680;76;SEINE MARITIME;1
76734;;Vergetot;VERGETOT;76280;76;SEINE MARITIME;1
76735;;Veules-les-Roses;VEULES-LES-ROSES;76980;76;SEINE MARITIME;1
76736;;Veulettes-sur-Mer;VEULETTES-SUR-MER;76450;76;SEINE MARITIME;1
76737;;Vibeuf;VIBEUF;76760;76;SEINE MARITIME;1
76738;;Vieux-Manoir;VIEUX-MANOIR;76750;76;SEINE MARITIME;1
76739;;Vieux-Rouen-sur-Bresle;VIEUX-ROUEN-SUR-BRESLE;76390;76;SEINE MARITIME;1
76740;La;Vieux-Rue;VIEUX-RUE;76160;76;SEINE MARITIME;1
76741;;Villainville;VILLAINVILLE;76280;76;SEINE MARITIME;1
76742;;Villequier;VILLEQUIER;76490;76;SEINE MARITIME;1
76743;;Villers-Écalles;VILLERS-ECALLES;76360;76;SEINE MARITIME;1
76744;;Villers-sous-Foucarmont;VILLERS-SOUS-FOUCARMONT;76340;76;SEINE MARITIME;1
76745;;Villy-sur-Yères;VILLY-SUR-YERES;76260;76;SEINE MARITIME;1
76746;;Vinnemerville;VINNEMERVILLE;76540;76;SEINE MARITIME;1
76747;;Virville;VIRVILLE;76110;76;SEINE MARITIME;1
76748;;Vittefleur;VITTEFLEUR;76450;76;SEINE MARITIME;1
76749;;Wanchy-Capval;WANCHY-CAPVAL;76660;76;SEINE MARITIME;1
76750;;Yainville;YAINVILLE;76480;76;SEINE MARITIME;1
76751;;Yébleron;YEBLERON;76640;76;SEINE MARITIME;1
76752;;Yerville;YERVILLE;76760;76;SEINE MARITIME;1
76753;;Ymare;YMARE;76520;76;SEINE MARITIME;1
76754;;Yport;YPORT;76111;76;SEINE MARITIME;1
76755;;Ypreville-Biville;YPREVILLE-BIVILLE;76540;76;SEINE MARITIME;1
76756;;Yquebeuf;YQUEBEUF;76690;76;SEINE MARITIME;1
76757;;Yvecrique;YVECRIQUE;76560;76;SEINE MARITIME;1
76758;;Yvetot;YVETOT;76190;76;SEINE MARITIME;1
76759;;Yville-sur-Seine;YVILLE-SUR-SEINE;76530;76;SEINE MARITIME;1
77001;;Achères-la-Forêt;ACHERES-LA-FORET;77760;77;SEINE ET MARNE;1
77002;;Amillis;AMILLIS;77120;77;SEINE ET MARNE;1
77003;;Amponville;AMPONVILLE;77760;77;SEINE ET MARNE;1
77004;;Andrezel;ANDREZEL;77390;77;SEINE ET MARNE;1
77005;;Annet-sur-Marne;ANNET-SUR-MARNE;77410;77;SEINE ET MARNE;1
77006;;Arbonne-la-Forêt;ARBONNE-LA-FORET;77630;77;SEINE ET MARNE;1
77007;;Argentières;ARGENTIERES;77390;77;SEINE ET MARNE;1
77008;;Armentières-en-Brie;ARMENTIERES-EN-BRIE;77440;77;SEINE ET MARNE;1
77009;;Arville;ARVILLE;77890;77;SEINE ET MARNE;1
77010;;Aubepierre-Ozouer-le-Repos;AUBEPIERRE-OZOUER-LE-REPOS;77720;77;SEINE ET MARNE;1
77011;;Aufferville;AUFFERVILLE;77570;77;SEINE ET MARNE;1
77012;;Augers-en-Brie;AUGERS-EN-BRIE;77560;77;SEINE ET MARNE;1
77013;;Aulnoy;AULNOY;77120;77;SEINE ET MARNE;1
77014;;Avon;AVON;77210;77;SEINE ET MARNE;1
77015;;Baby;BABY;77480;77;SEINE ET MARNE;1
77016;;Bagneaux-sur-Loing;BAGNEAUX-SUR-LOING;77167;77;SEINE ET MARNE;1
77018;;Bailly-Romainvilliers;BAILLY-ROMAINVILLIERS;77700;77;SEINE ET MARNE;1
77019;;Balloy;BALLOY;77118;77;SEINE ET MARNE;1
77020;;Bannost-Villegagnon;BANNOST-VILLEGAGNON;77970;77;SEINE ET MARNE;1
77021;;Barbey;BARBEY;77130;77;SEINE ET MARNE;1
77022;;Barbizon;BARBIZON;77630;77;SEINE ET MARNE;1
77023;;Barcy;BARCY;77910;77;SEINE ET MARNE;1
77024;;Bassevelle;BASSEVELLE;77750;77;SEINE ET MARNE;1
77025;;Bazoches-lès-Bray;BAZOCHES-LES-BRAY;77118;77;SEINE ET MARNE;1
77026;;Beauchery-Saint-Martin;BEAUCHERY-SAINT-MARTIN;77560;77;SEINE ET MARNE;1
77027;;Beaumont-du-Gâtinais;BEAUMONT-DU-GATINAIS;77890;77;SEINE ET MARNE;1
77028;;Beautheil;BEAUTHEIL;77120;77;SEINE ET MARNE;1
77029;;Beauvoir;BEAUVOIR;77390;77;SEINE ET MARNE;1
77030;;Bellot;BELLOT;77510;77;SEINE ET MARNE;1
77031;;Bernay-Vilbert;BERNAY-VILBERT;77540;77;SEINE ET MARNE;1
77032;;Beton-Bazoches;BETON-BAZOCHES;77320;77;SEINE ET MARNE;1
77033;;Bezalles;BEZALLES;77970;77;SEINE ET MARNE;1
77034;;Blandy;BLANDY;77115;77;SEINE ET MARNE;1
77035;;Blennes;BLENNES;77940;77;SEINE ET MARNE;1
77036;;Boisdon;BOISDON;77970;77;SEINE ET MARNE;1
77037;;Bois-le-Roi;BOIS-LE-ROI;77590;77;SEINE ET MARNE;1
77038;;Boissettes;BOISSETTES;77350;77;SEINE ET MARNE;1
77039;;Boissise-la-Bertrand;BOISSISE-LA-BERTRAND;77350;77;SEINE ET MARNE;1
77040;;Boissise-le-Roi;BOISSISE-LE-ROI;77310;77;SEINE ET MARNE;1
77041;;Boissy-aux-Cailles;BOISSY-AUX-CAILLES;77760;77;SEINE ET MARNE;1
77042;;Boissy-le-Châtel;BOISSY-LE-CHATEL;77169;77;SEINE ET MARNE;1
77043;;Boitron;BOITRON;77750;77;SEINE ET MARNE;1
77044;;Bombon;BOMBON;77720;77;SEINE ET MARNE;1
77045;;Bougligny;BOUGLIGNY;77570;77;SEINE ET MARNE;1
77046;;Boulancourt;BOULANCOURT;77760;77;SEINE ET MARNE;1
77047;;Bouleurs;BOULEURS;77580;77;SEINE ET MARNE;1
77048;;Bourron-Marlotte;BOURRON-MARLOTTE;77780;77;SEINE ET MARNE;1
77049;;Boutigny;BOUTIGNY;77470;77;SEINE ET MARNE;1
77050;;Bransles;BRANSLES;77620;77;SEINE ET MARNE;1
77051;;Bray-sur-Seine;BRAY-SUR-SEINE;77480;77;SEINE ET MARNE;1
77052;;Bréau;BREAU;77720;77;SEINE ET MARNE;1
77053;;Brie-Comte-Robert;BRIE-COMTE-ROBERT;77170;77;SEINE ET MARNE;1
77054;La;Brosse-Montceaux;BROSSE-MONTCEAUX;77940;77;SEINE ET MARNE;1
77055;;Brou-sur-Chantereine;BROU-SUR-CHANTEREINE;77177;77;SEINE ET MARNE;1
77056;;Burcy;BURCY;77890;77;SEINE ET MARNE;1
77057;;Bussières;BUSSIERES;77750;77;SEINE ET MARNE;1
77058;;Bussy-Saint-Georges;BUSSY-SAINT-GEORGES;77600;77;SEINE ET MARNE;1
77059;;Bussy-Saint-Martin;BUSSY-SAINT-MARTIN;77600;77;SEINE ET MARNE;1
77060;;Buthiers;BUTHIERS;77760;77;SEINE ET MARNE;1
77061;;Cannes-Écluse;CANNES-ECLUSE;77130;77;SEINE ET MARNE;1
77062;;Carnetin;CARNETIN;77400;77;SEINE ET MARNE;1
77063;La;Celle-sur-Morin;CELLE-SUR-MORIN;77515;77;SEINE ET MARNE;1
77065;;Cély;CELY;77930;77;SEINE ET MARNE;1
77066;;Cerneux;CERNEUX;77320;77;SEINE ET MARNE;1
77067;;Cesson;CESSON;77240;77;SEINE ET MARNE;1
77068;;Cessoy-en-Montois;CESSOY-EN-MONTOIS;77520;77;SEINE ET MARNE;1
77069;;Chailly-en-Bière;CHAILLY-EN-BIERE;77930;77;SEINE ET MARNE;1
77070;;Chailly-en-Brie;CHAILLY-EN-BRIE;77120;77;SEINE ET MARNE;1
77071;;Chaintreaux;CHAINTREAUX;77460;77;SEINE ET MARNE;1
77072;;Chalautre-la-Grande;CHALAUTRE-LA-GRANDE;77171;77;SEINE ET MARNE;1
77073;;Chalautre-la-Petite;CHALAUTRE-LA-PETITE;77160;77;SEINE ET MARNE;1
77075;;Chalifert;CHALIFERT;77144;77;SEINE ET MARNE;1
77076;;Chalmaison;CHALMAISON;77650;77;SEINE ET MARNE;1
77077;;Chambry;CHAMBRY;77910;77;SEINE ET MARNE;1
77078;;Chamigny;CHAMIGNY;77260;77;SEINE ET MARNE;1
77079;;Champagne-sur-Seine;CHAMPAGNE-SUR-SEINE;77430;77;SEINE ET MARNE;1
77080;;Champcenest;CHAMPCENEST;77560;77;SEINE ET MARNE;1
77081;;Champdeuil;CHAMPDEUIL;77390;77;SEINE ET MARNE;1
77082;;Champeaux;CHAMPEAUX;77720;77;SEINE ET MARNE;1
77083;;Champs-sur-Marne;CHAMPS-SUR-MARNE;77420;77;SEINE ET MARNE;1
77084;;Changis-sur-Marne;CHANGIS-SUR-MARNE;77660;77;SEINE ET MARNE;1
77085;;Chanteloup-en-Brie;CHANTELOUP-EN-BRIE;77600;77;SEINE ET MARNE;1
77086;La;Chapelle-Gauthier;CHAPELLE-GAUTHIER;77720;77;SEINE ET MARNE;1
77087;La;Chapelle-Iger;CHAPELLE-IGER;77540;77;SEINE ET MARNE;1
77088;La;Chapelle-la-Reine;CHAPELLE-LA-REINE;77760;77;SEINE ET MARNE;1
77089;La;Chapelle-Rablais;CHAPELLE-RABLAIS;77370;77;SEINE ET MARNE;1
77090;La;Chapelle-Saint-Sulpice;CHAPELLE-SAINT-SULPICE;77160;77;SEINE ET MARNE;1
77091;Les;Chapelles-Bourbon;CHAPELLES-BOURBON;77610;77;SEINE ET MARNE;1
77093;La;Chapelle-Moutils;CHAPELLE-MOUTILS;77320;77;SEINE ET MARNE;1
77094;;Charmentray;CHARMENTRAY;77410;77;SEINE ET MARNE;1
77095;;Charny;CHARNY;77410;77;SEINE ET MARNE;1
77096;;Chartrettes;CHARTRETTES;77590;77;SEINE ET MARNE;1
77097;;Chartronges;CHARTRONGES;77320;77;SEINE ET MARNE;1
77098;;Châteaubleau;CHATEAUBLEAU;77370;77;SEINE ET MARNE;1
77099;;Château-Landon;CHATEAU-LANDON;77570;77;SEINE ET MARNE;1
77100;Le;Châtelet-en-Brie;CHATELET-EN-BRIE;77820;77;SEINE ET MARNE;1
77101;;Châtenay-sur-Seine;CHATENAY-SUR-SEINE;77126;77;SEINE ET MARNE;1
77102;;Châtenoy;CHATENOY;77167;77;SEINE ET MARNE;1
77103;;Châtillon-la-Borde;CHATILLON-LA-BORDE;77820;77;SEINE ET MARNE;1
77104;;Châtres;CHATRES;77610;77;SEINE ET MARNE;1
77106;;Chauffry;CHAUFFRY;77169;77;SEINE ET MARNE;1
77107;;Chaumes-en-Brie;CHAUMES-EN-BRIE;77390;77;SEINE ET MARNE;1
77108;;Chelles;CHELLES;77500;77;SEINE ET MARNE;1
77109;;Chenoise;CHENOISE;77160;77;SEINE ET MARNE;1
77110;;Chenou;CHENOU;77570;77;SEINE ET MARNE;1
77111;;Chessy;CHESSY;77700;77;SEINE ET MARNE;1
77112;;Chevrainvilliers;CHEVRAINVILLIERS;77760;77;SEINE ET MARNE;1
77113;;Chevru;CHEVRU;77320;77;SEINE ET MARNE;1
77114;;Chevry-Cossigny;CHEVRY-COSSIGNY;77173;77;SEINE ET MARNE;1
77115;;Chevry-en-Sereine;CHEVRY-EN-SEREINE;77710;77;SEINE ET MARNE;1
77116;;Choisy-en-Brie;CHOISY-EN-BRIE;77320;77;SEINE ET MARNE;1
77117;;Citry;CITRY;77730;77;SEINE ET MARNE;1
77118;;Claye-Souilly;CLAYE-SOUILLY;77410;77;SEINE ET MARNE;1
77119;;Clos-Fontaine;CLOS-FONTAINE;77370;77;SEINE ET MARNE;1
77120;;Cocherel;COCHEREL;77440;77;SEINE ET MARNE;1
77121;;Collégien;COLLEGIEN;77090;77;SEINE ET MARNE;1
77122;;Combs-la-Ville;COMBS-LA-VILLE;77380;77;SEINE ET MARNE;1
77123;;Compans;COMPANS;77290;77;SEINE ET MARNE;1
77124;;Conches-sur-Gondoire;CONCHES-SUR-GONDOIRE;77600;77;SEINE ET MARNE;1
77125;;Condé-Sainte-Libiaire;CONDE-SAINTE-LIBIAIRE;77450;77;SEINE ET MARNE;1
77126;;Congis-sur-Thérouanne;CONGIS-SUR-THEROUANNE;77440;77;SEINE ET MARNE;1
77127;;Coubert;COUBERT;77170;77;SEINE ET MARNE;1
77128;;Couilly-Pont-aux-Dames;COUILLY-PONT-AUX-DAMES;77860;77;SEINE ET MARNE;1
77129;;Coulombs-en-Valois;COULOMBS-EN-VALOIS;77840;77;SEINE ET MARNE;1
77130;;Coulommes;COULOMMES;77580;77;SEINE ET MARNE;1
77131;;Coulommiers;COULOMMIERS;77120;77;SEINE ET MARNE;1
77132;;Coupvray;COUPVRAY;77700;77;SEINE ET MARNE;1
77133;;Courcelles-en-Bassée;COURCELLES-EN-BASSEE;77126;77;SEINE ET MARNE;1
77134;;Courchamp;COURCHAMP;77560;77;SEINE ET MARNE;1
77135;;Courpalay;COURPALAY;77540;77;SEINE ET MARNE;1
77136;;Courquetaine;COURQUETAINE;77390;77;SEINE ET MARNE;1
77137;;Courtacon;COURTACON;77560;77;SEINE ET MARNE;1
77138;;Courtomer;COURTOMER;77390;77;SEINE ET MARNE;1
77139;;Courtry;COURTRY;77181;77;SEINE ET MARNE;1
77140;;Coutençon;COUTENCON;77154;77;SEINE ET MARNE;1
77141;;Coutevroult;COUTEVROULT;77580;77;SEINE ET MARNE;1
77142;;Crécy-la-Chapelle;CRECY-LA-CHAPELLE;77580;77;SEINE ET MARNE;1
77143;;Crégy-lès-Meaux;CREGY-LES-MEAUX;77124;77;SEINE ET MARNE;1
77144;;Crèvecœur-en-Brie;CREVECOEUR-EN-BRIE;77610;77;SEINE ET MARNE;1
77145;;Crisenoy;CRISENOY;77390;77;SEINE ET MARNE;1
77146;;Croissy-Beaubourg;CROISSY-BEAUBOURG;77183;77;SEINE ET MARNE;1
77147;La;Croix-en-Brie;CROIX-EN-BRIE;77370;77;SEINE ET MARNE;1
77148;;Crouy-sur-Ourcq;CROUY-SUR-OURCQ;77840;77;SEINE ET MARNE;1
77149;;Cucharmoy;CUCHARMOY;77160;77;SEINE ET MARNE;1
77150;;Cuisy;CUISY;77165;77;SEINE ET MARNE;1
77151;;Dagny;DAGNY;77320;77;SEINE ET MARNE;1
77152;;Dammarie-les-Lys;DAMMARIE-LES-LYS;77190;77;SEINE ET MARNE;1
77153;;Dammartin-en-Goële;DAMMARTIN-EN-GOELE;77230;77;SEINE ET MARNE;1
77154;;Dammartin-sur-Tigeaux;DAMMARTIN-SUR-TIGEAUX;77163;77;SEINE ET MARNE;1
77155;;Dampmart;DAMPMART;77400;77;SEINE ET MARNE;1
77156;;Darvault;DARVAULT;77140;77;SEINE ET MARNE;1
77157;;Dhuisy;DHUISY;77440;77;SEINE ET MARNE;1
77158;;Diant;DIANT;77940;77;SEINE ET MARNE;1
77159;;Donnemarie-Dontilly;DONNEMARIE-DONTILLY;77520;77;SEINE ET MARNE;1
77161;;Dormelles;DORMELLES;77130;77;SEINE ET MARNE;1
77162;;Doue;DOUE;77510;77;SEINE ET MARNE;1
77163;;Douy-la-Ramée;DOUY-LA-RAMEE;77139;77;SEINE ET MARNE;1
77164;;Échouboulains;ECHOUBOULAINS;77830;77;SEINE ET MARNE;1
77165;Les;Écrennes;ECRENNES;77820;77;SEINE ET MARNE;1
77166;;Écuelles;ECUELLES;77250;77;SEINE ET MARNE;1
77167;;Égligny;EGLIGNY;77126;77;SEINE ET MARNE;1
77168;;Égreville;EGREVILLE;77620;77;SEINE ET MARNE;1
77169;;Émerainville;EMERAINVILLE;77184;77;SEINE ET MARNE;1
77170;;Épisy;EPISY;77250;77;SEINE ET MARNE;1
77171;;Esbly;ESBLY;77450;77;SEINE ET MARNE;1
77172;;Esmans;ESMANS;77940;77;SEINE ET MARNE;1
77173;;Étrépilly;ETREPILLY;77139;77;SEINE ET MARNE;1
77174;;Everly;EVERLY;77157;77;SEINE ET MARNE;1
77175;;Évry-Grégy-sur-Yerre;EVRY-GREGY-SUR-YERRE;77166;77;SEINE ET MARNE;1
77176;;Faremoutiers;FAREMOUTIERS;77515;77;SEINE ET MARNE;1
77177;;Favières;FAVIERES;77220;77;SEINE ET MARNE;1
77178;;Faÿ-lès-Nemours;FAY-LES-NEMOURS;77167;77;SEINE ET MARNE;1
77179;;Féricy;FERICY;77133;77;SEINE ET MARNE;1
77180;;Férolles-Attilly;FEROLLES-ATTILLY;77150;77;SEINE ET MARNE;1
77181;;Ferrières-en-Brie;FERRIERES-EN-BRIE;77164;77;SEINE ET MARNE;1
77182;La;Ferté-Gaucher;FERTE-GAUCHER;77320;77;SEINE ET MARNE;1
77183;La;Ferté-sous-Jouarre;FERTE-SOUS-JOUARRE;77260;77;SEINE ET MARNE;1
77184;;Flagy;FLAGY;77940;77;SEINE ET MARNE;1
77185;;Fleury-en-Bière;FLEURY-EN-BIERE;77930;77;SEINE ET MARNE;1
77186;;Fontainebleau;FONTAINEBLEAU;77300;77;SEINE ET MARNE;1
77187;;Fontaine-Fourches;FONTAINE-FOURCHES;77480;77;SEINE ET MARNE;1
77188;;Fontaine-le-Port;FONTAINE-LE-PORT;77590;77;SEINE ET MARNE;1
77190;;Fontains;FONTAINS;77370;77;SEINE ET MARNE;1
77191;;Fontenailles;FONTENAILLES;77370;77;SEINE ET MARNE;1
77192;;Fontenay-Trésigny;FONTENAY-TRESIGNY;77610;77;SEINE ET MARNE;1
77193;;Forfry;FORFRY;77165;77;SEINE ET MARNE;1
77194;;Forges;FORGES;77130;77;SEINE ET MARNE;1
77195;;Fouju;FOUJU;77390;77;SEINE ET MARNE;1
77196;;Fresnes-sur-Marne;FRESNES-SUR-MARNE;77410;77;SEINE ET MARNE;1
77197;;Frétoy;FRETOY;77320;77;SEINE ET MARNE;1
77198;;Fromont;FROMONT;77760;77;SEINE ET MARNE;1
77199;;Fublaines;FUBLAINES;77470;77;SEINE ET MARNE;1
77200;;Garentreville;GARENTREVILLE;77890;77;SEINE ET MARNE;1
77201;;Gastins;GASTINS;77370;77;SEINE ET MARNE;1
77202;La;Genevraye;GENEVRAYE;77690;77;SEINE ET MARNE;1
77203;;Germigny-l'Évêque;GERMIGNY-L'EVEQUE;77910;77;SEINE ET MARNE;1
77204;;Germigny-sous-Coulombs;GERMIGNY-SOUS-COULOMBS;77840;77;SEINE ET MARNE;1
77205;;Gesvres-le-Chapitre;GESVRES-LE-CHAPITRE;77165;77;SEINE ET MARNE;1
77206;;Giremoutiers;GIREMOUTIERS;77120;77;SEINE ET MARNE;1
77207;;Gironville;GIRONVILLE;77890;77;SEINE ET MARNE;1
77208;;Gouaix;GOUAIX;77114;77;SEINE ET MARNE;1
77209;;Gouvernes;GOUVERNES;77400;77;SEINE ET MARNE;1
77210;La;Grande-Paroisse;GRANDE-PAROISSE;77130;77;SEINE ET MARNE;1
77211;;Grandpuits-Bailly-Carrois;GRANDPUITS-BAILLY-CARROIS;77720;77;SEINE ET MARNE;1
77212;;Gravon;GRAVON;77118;77;SEINE ET MARNE;1
77214;;Gressy;GRESSY;77410;77;SEINE ET MARNE;1
77215;;Gretz-Armainvilliers;GRETZ-ARMAINVILLIERS;77220;77;SEINE ET MARNE;1
77216;;Grez-sur-Loing;GREZ-SUR-LOING;77880;77;SEINE ET MARNE;1
77217;;Grisy-Suisnes;GRISY-SUISNES;77166;77;SEINE ET MARNE;1
77218;;Grisy-sur-Seine;GRISY-SUR-SEINE;77480;77;SEINE ET MARNE;1
77219;;Guérard;GUERARD;77580;77;SEINE ET MARNE;1
77220;;Guercheville;GUERCHEVILLE;77760;77;SEINE ET MARNE;1
77221;;Guermantes;GUERMANTES;77600;77;SEINE ET MARNE;1
77222;;Guignes;GUIGNES;77390;77;SEINE ET MARNE;1
77223;;Gurcy-le-Châtel;GURCY-LE-CHATEL;77520;77;SEINE ET MARNE;1
77224;;Hautefeuille;HAUTEFEUILLE;77515;77;SEINE ET MARNE;1
77225;La;Haute-Maison;HAUTE-MAISON;77580;77;SEINE ET MARNE;1
77226;;Héricy;HERICY;77850;77;SEINE ET MARNE;1
77227;;Hermé;HERME;77114;77;SEINE ET MARNE;1
77228;;Hondevilliers;HONDEVILLIERS;77510;77;SEINE ET MARNE;1
77229;La;Houssaye-en-Brie;HOUSSAYE-EN-BRIE;77610;77;SEINE ET MARNE;1
77230;;Ichy;ICHY;77890;77;SEINE ET MARNE;1
77231;;Isles-les-Meldeuses;ISLES-LES-MELDEUSES;77440;77;SEINE ET MARNE;1
77232;;Isles-lès-Villenoy;ISLES-LES-VILLENOY;77450;77;SEINE ET MARNE;1
77233;;Iverny;IVERNY;77165;77;SEINE ET MARNE;1
77234;;Jablines;JABLINES;77450;77;SEINE ET MARNE;1
77235;;Jaignes;JAIGNES;77440;77;SEINE ET MARNE;1
77236;;Jaulnes;JAULNES;77480;77;SEINE ET MARNE;1
77237;;Jossigny;JOSSIGNY;77600;77;SEINE ET MARNE;1
77238;;Jouarre;JOUARRE;77640;77;SEINE ET MARNE;1
77239;;Jouy-le-Châtel;JOUY-LE-CHATEL;77970;77;SEINE ET MARNE;1
77240;;Jouy-sur-Morin;JOUY-SUR-MORIN;77320;77;SEINE ET MARNE;1
77241;;Juilly;JUILLY;77230;77;SEINE ET MARNE;1
77242;;Jutigny;JUTIGNY;77650;77;SEINE ET MARNE;1
77243;;Lagny-sur-Marne;LAGNY-SUR-MARNE;77400;77;SEINE ET MARNE;1
77244;;Larchant;LARCHANT;77760;77;SEINE ET MARNE;1
77245;;Laval-en-Brie;LAVAL-EN-BRIE;77148;77;SEINE ET MARNE;1
77246;;Léchelle;LECHELLE;77171;77;SEINE ET MARNE;1
77247;;Lescherolles;LESCHEROLLES;77320;77;SEINE ET MARNE;1
77248;;Lesches;LESCHES;77450;77;SEINE ET MARNE;1
77249;;Lésigny;LESIGNY;77150;77;SEINE ET MARNE;1
77250;;Leudon-en-Brie;LEUDON-EN-BRIE;77320;77;SEINE ET MARNE;1
77251;;Lieusaint;LIEUSAINT;77127;77;SEINE ET MARNE;1
77252;;Limoges-Fourches;LIMOGES-FOURCHES;77550;77;SEINE ET MARNE;1
77253;;Lissy;LISSY;77550;77;SEINE ET MARNE;1
77254;;Liverdy-en-Brie;LIVERDY-EN-BRIE;77220;77;SEINE ET MARNE;1
77255;;Livry-sur-Seine;LIVRY-SUR-SEINE;77000;77;SEINE ET MARNE;1
77256;;Lizines;LIZINES;77650;77;SEINE ET MARNE;1
77257;;Lizy-sur-Ourcq;LIZY-SUR-OURCQ;77440;77;SEINE ET MARNE;1
77258;;Lognes;LOGNES;77185;77;SEINE ET MARNE;1
77259;;Longperrier;LONGPERRIER;77230;77;SEINE ET MARNE;1
77260;;Longueville;LONGUEVILLE;77650;77;SEINE ET MARNE;1
77261;;Lorrez-le-Bocage-Préaux;LORREZ-LE-BOCAGE-PREAUX;77710;77;SEINE ET MARNE;1
77262;;Louan-Villegruis-Fontaine;LOUAN-VILLEGRUIS-FONTAINE;77560;77;SEINE ET MARNE;1
77263;;Luisetaines;LUISETAINES;77520;77;SEINE ET MARNE;1
77264;;Lumigny-Nesles-Ormeaux;LUMIGNY-NESLES-ORMEAUX;77540;77;SEINE ET MARNE;1
77265;;Luzancy;LUZANCY;77138;77;SEINE ET MARNE;1
77266;;Machault;MACHAULT;77133;77;SEINE ET MARNE;1
77267;La;Madeleine-sur-Loing;MADELEINE-SUR-LOING;77570;77;SEINE ET MARNE;1
77268;;Magny-le-Hongre;MAGNY-LE-HONGRE;77700;77;SEINE ET MARNE;1
77269;;Maincy;MAINCY;77950;77;SEINE ET MARNE;1
77270;;Maisoncelles-en-Brie;MAISONCELLES-EN-BRIE;77580;77;SEINE ET MARNE;1
77271;;Maisoncelles-en-Gâtinais;MAISONCELLES-EN-GATINAIS;77570;77;SEINE ET MARNE;1
77272;;Maison-Rouge;MAISON-ROUGE;77370;77;SEINE ET MARNE;1
77273;;Marchémoret;MARCHEMORET;77230;77;SEINE ET MARNE;1
77274;;Marcilly;MARCILLY;77139;77;SEINE ET MARNE;1
77275;Les;Marêts;MARETS;77560;77;SEINE ET MARNE;1
77276;;Mareuil-lès-Meaux;MAREUIL-LES-MEAUX;77100;77;SEINE ET MARNE;1
77277;;Marles-en-Brie;MARLES-EN-BRIE;77610;77;SEINE ET MARNE;1
77278;;Marolles-en-Brie;MAROLLES-EN-BRIE;77120;77;SEINE ET MARNE;1
77279;;Marolles-sur-Seine;MAROLLES-SUR-SEINE;77130;77;SEINE ET MARNE;1
77280;;Mary-sur-Marne;MARY-SUR-MARNE;77440;77;SEINE ET MARNE;1
77281;;Mauperthuis;MAUPERTHUIS;77120;77;SEINE ET MARNE;1
77282;;Mauregard;MAUREGARD;77990;77;SEINE ET MARNE;1
77283;;May-en-Multien;MAY-EN-MULTIEN;77145;77;SEINE ET MARNE;1
77284;;Meaux;MEAUX;77100;77;SEINE ET MARNE;1
77285;Le;Mée-sur-Seine;MEE-SUR-SEINE;77350;77;SEINE ET MARNE;1
77286;;Meigneux;MEIGNEUX;77520;77;SEINE ET MARNE;1
77287;;Meilleray;MEILLERAY;77320;77;SEINE ET MARNE;1
77288;;Melun;MELUN;77000;77;SEINE ET MARNE;1
77289;;Melz-sur-Seine;MELZ-SUR-SEINE;77171;77;SEINE ET MARNE;1
77290;;Méry-sur-Marne;MERY-SUR-MARNE;77730;77;SEINE ET MARNE;1
77291;Le;Mesnil-Amelot;MESNIL-AMELOT;77990;77;SEINE ET MARNE;1
77292;;Messy;MESSY;77410;77;SEINE ET MARNE;1
77293;;Misy-sur-Yonne;MISY-SUR-YONNE;77130;77;SEINE ET MARNE;1
77294;;Mitry-Mory;MITRY-MORY;77290;77;SEINE ET MARNE;1
77295;;Moisenay;MOISENAY;77950;77;SEINE ET MARNE;1
77296;;Moissy-Cramayel;MOISSY-CRAMAYEL;77550;77;SEINE ET MARNE;1
77297;;Mondreville;MONDREVILLE;77570;77;SEINE ET MARNE;1
77298;;Mons-en-Montois;MONS-EN-MONTOIS;77520;77;SEINE ET MARNE;1
77299;;Montarlot;MONTARLOT;77250;77;SEINE ET MARNE;1
77300;;Montceaux-lès-Meaux;MONTCEAUX-LES-MEAUX;77470;77;SEINE ET MARNE;1
77301;;Montceaux-lès-Provins;MONTCEAUX-LES-PROVINS;77151;77;SEINE ET MARNE;1
77302;;Montcourt-Fromonville;MONTCOURT-FROMONVILLE;77140;77;SEINE ET MARNE;1
77303;;Montdauphin;MONTDAUPHIN;77320;77;SEINE ET MARNE;1
77304;;Montenils;MONTENILS;77320;77;SEINE ET MARNE;1
77305;;Montereau-Fault-Yonne;MONTEREAU-FAULT-YONNE;77130;77;SEINE ET MARNE;1
77306;;Montereau-sur-le-Jard;MONTEREAU-SUR-LE-JARD;77950;77;SEINE ET MARNE;1
77307;;Montévrain;MONTEVRAIN;77144;77;SEINE ET MARNE;1
77308;;Montgé-en-Goële;MONTGE-EN-GOELE;77230;77;SEINE ET MARNE;1
77309;;Monthyon;MONTHYON;77122;77;SEINE ET MARNE;1
77310;;Montigny-le-Guesdier;MONTIGNY-LE-GUESDIER;77480;77;SEINE ET MARNE;1
77311;;Montigny-Lencoup;MONTIGNY-LENCOUP;77520;77;SEINE ET MARNE;1
77312;;Montigny-sur-Loing;MONTIGNY-SUR-LOING;77690;77;SEINE ET MARNE;1
77313;;Montmachoux;MONTMACHOUX;77940;77;SEINE ET MARNE;1
77314;;Montolivet;MONTOLIVET;77320;77;SEINE ET MARNE;1
77315;;Montry;MONTRY;77450;77;SEINE ET MARNE;1
77316;;Moret-sur-Loing;MORET-SUR-LOING;77250;77;SEINE ET MARNE;1
77317;;Mormant;MORMANT;77720;77;SEINE ET MARNE;1
77318;;Mortcerf;MORTCERF;77163;77;SEINE ET MARNE;1
77319;;Mortery;MORTERY;77160;77;SEINE ET MARNE;1
77320;;Mouroux;MOUROUX;77120;77;SEINE ET MARNE;1
77321;;Mousseaux-lès-Bray;MOUSSEAUX-LES-BRAY;77480;77;SEINE ET MARNE;1
77322;;Moussy-le-Neuf;MOUSSY-LE-NEUF;77230;77;SEINE ET MARNE;1
77323;;Moussy-le-Vieux;MOUSSY-LE-VIEUX;77230;77;SEINE ET MARNE;1
77325;;Mouy-sur-Seine;MOUY-SUR-SEINE;77480;77;SEINE ET MARNE;1
77326;;Nandy;NANDY;77176;77;SEINE ET MARNE;1
77327;;Nangis;NANGIS;77370;77;SEINE ET MARNE;1
77328;;Nanteau-sur-Essonne;NANTEAU-SUR-ESSONNE;77760;77;SEINE ET MARNE;1
77329;;Nanteau-sur-Lunain;NANTEAU-SUR-LUNAIN;77710;77;SEINE ET MARNE;1
77330;;Nanteuil-lès-Meaux;NANTEUIL-LES-MEAUX;77100;77;SEINE ET MARNE;1
77331;;Nanteuil-sur-Marne;NANTEUIL-SUR-MARNE;77730;77;SEINE ET MARNE;1
77332;;Nantouillet;NANTOUILLET;77230;77;SEINE ET MARNE;1
77333;;Nemours;NEMOURS;77140;77;SEINE ET MARNE;1
77335;;Chauconin-Neufmontiers;CHAUCONIN-NEUFMONTIERS;77124;77;SEINE ET MARNE;1
77336;;Neufmoutiers-en-Brie;NEUFMOUTIERS-EN-BRIE;77610;77;SEINE ET MARNE;1
77337;;Noisiel;NOISIEL;77186;77;SEINE ET MARNE;1
77338;;Noisy-Rudignon;NOISY-RUDIGNON;77940;77;SEINE ET MARNE;1
77339;;Noisy-sur-École;NOISY-SUR-ECOLE;77123;77;SEINE ET MARNE;1
77340;;Nonville;NONVILLE;77140;77;SEINE ET MARNE;1
77341;;Noyen-sur-Seine;NOYEN-SUR-SEINE;77114;77;SEINE ET MARNE;1
77342;;Obsonville;OBSONVILLE;77890;77;SEINE ET MARNE;1
77343;;Ocquerre;OCQUERRE;77440;77;SEINE ET MARNE;1
77344;;Oissery;OISSERY;77178;77;SEINE ET MARNE;1
77345;;Orly-sur-Morin;ORLY-SUR-MORIN;77750;77;SEINE ET MARNE;1
77347;Les;Ormes-sur-Voulzie;ORMES-SUR-VOULZIE;77134;77;SEINE ET MARNE;1
77348;;Ormesson;ORMESSON;77167;77;SEINE ET MARNE;1
77349;;Othis;OTHIS;77280;77;SEINE ET MARNE;1
77350;;Ozoir-la-Ferrière;OZOIR-LA-FERRIERE;77330;77;SEINE ET MARNE;1
77352;;Ozouer-le-Voulgis;OZOUER-LE-VOULGIS;77390;77;SEINE ET MARNE;1
77353;;Paley;PALEY;77710;77;SEINE ET MARNE;1
77354;;Pamfou;PAMFOU;77830;77;SEINE ET MARNE;1
77355;;Paroy;PAROY;77520;77;SEINE ET MARNE;1
77356;;Passy-sur-Seine;PASSY-SUR-SEINE;77480;77;SEINE ET MARNE;1
77357;;Pécy;PECY;77970;77;SEINE ET MARNE;1
77358;;Penchard;PENCHARD;77124;77;SEINE ET MARNE;1
77359;;Perthes;PERTHES;77930;77;SEINE ET MARNE;1
77360;;Pézarches;PEZARCHES;77131;77;SEINE ET MARNE;1
77361;;Pierre-Levée;PIERRE-LEVEE;77580;77;SEINE ET MARNE;1
77363;Le;Pin;PIN;77181;77;SEINE ET MARNE;1
77364;Le;Plessis-aux-Bois;PLESSIS-AUX-BOIS;77165;77;SEINE ET MARNE;1
77365;Le;Plessis-Feu-Aussoux;PLESSIS-FEU-AUSSOUX;77540;77;SEINE ET MARNE;1
77366;Le;Plessis-l'Évêque;PLESSIS-L'EVEQUE;77165;77;SEINE ET MARNE;1
77367;Le;Plessis-Placy;PLESSIS-PLACY;77440;77;SEINE ET MARNE;1
77368;;Poigny;POIGNY;77160;77;SEINE ET MARNE;1
77369;;Poincy;POINCY;77470;77;SEINE ET MARNE;1
77370;;Poligny;POLIGNY;77167;77;SEINE ET MARNE;1
77371;;Pommeuse;POMMEUSE;77515;77;SEINE ET MARNE;1
77372;;Pomponne;POMPONNE;77400;77;SEINE ET MARNE;1
77373;;Pontault-Combault;PONTAULT-COMBAULT;77340;77;SEINE ET MARNE;1
77374;;Pontcarré;PONTCARRE;77135;77;SEINE ET MARNE;1
77376;;Précy-sur-Marne;PRECY-SUR-MARNE;77410;77;SEINE ET MARNE;1
77377;;Presles-en-Brie;PRESLES-EN-BRIE;77220;77;SEINE ET MARNE;1
77378;;Pringy;PRINGY;77310;77;SEINE ET MARNE;1
77379;;Provins;PROVINS;77160;77;SEINE ET MARNE;1
77380;;Puisieux;PUISIEUX;77139;77;SEINE ET MARNE;1
77381;;Quiers;QUIERS;77720;77;SEINE ET MARNE;1
77382;;Quincy-Voisins;QUINCY-VOISINS;77860;77;SEINE ET MARNE;1
77383;;Rampillon;RAMPILLON;77370;77;SEINE ET MARNE;1
77384;;Réau;REAU;77550;77;SEINE ET MARNE;1
77385;;Rebais;REBAIS;77510;77;SEINE ET MARNE;1
77386;;Recloses;RECLOSES;77760;77;SEINE ET MARNE;1
77387;;Remauville;REMAUVILLE;77710;77;SEINE ET MARNE;1
77388;;Reuil-en-Brie;REUIL-EN-BRIE;77260;77;SEINE ET MARNE;1
77389;La;Rochette;ROCHETTE;77000;77;SEINE ET MARNE;1
77390;;Roissy-en-Brie;ROISSY-EN-BRIE;77680;77;SEINE ET MARNE;1
77391;;Rouilly;ROUILLY;77160;77;SEINE ET MARNE;1
77392;;Rouvres;ROUVRES;77230;77;SEINE ET MARNE;1
77393;;Rozay-en-Brie;ROZAY-EN-BRIE;77540;77;SEINE ET MARNE;1
77394;;Rubelles;RUBELLES;77950;77;SEINE ET MARNE;1
77395;;Rumont;RUMONT;77760;77;SEINE ET MARNE;1
77396;;Rupéreux;RUPEREUX;77560;77;SEINE ET MARNE;1
77397;;Saâcy-sur-Marne;SAACY-SUR-MARNE;77730;77;SEINE ET MARNE;1
77398;;Sablonnières;SABLONNIERES;77510;77;SEINE ET MARNE;1
77399;;Saint-Ange-le-Viel;SAINT-ANGE-LE-VIEL;77710;77;SEINE ET MARNE;1
77400;;Saint-Augustin;SAINT-AUGUSTIN;77515;77;SEINE ET MARNE;1
77401;;Sainte-Aulde;SAINTE-AULDE;77260;77;SEINE ET MARNE;1
77402;;Saint-Barthélemy;SAINT-BARTHELEMY;77320;77;SEINE ET MARNE;1
77403;;Saint-Brice;SAINT-BRICE;77160;77;SEINE ET MARNE;1
77404;;Sainte-Colombe;SAINTE-COLOMBE;77650;77;SEINE ET MARNE;1
77405;;Saint-Cyr-sur-Morin;SAINT-CYR-SUR-MORIN;77750;77;SEINE ET MARNE;1
77406;;Saint-Denis-lès-Rebais;SAINT-DENIS-LES-REBAIS;77510;77;SEINE ET MARNE;1
77407;;Saint-Fargeau-Ponthierry;SAINT-FARGEAU-PONTHIERRY;77310;77;SEINE ET MARNE;1
77408;;Saint-Fiacre;SAINT-FIACRE;77470;77;SEINE ET MARNE;1
77409;;Saint-Germain-Laval;SAINT-GERMAIN-LAVAL;77130;77;SEINE ET MARNE;1
77410;;Saint-Germain-Laxis;SAINT-GERMAIN-LAXIS;77950;77;SEINE ET MARNE;1
77411;;Saint-Germain-sous-Doue;SAINT-GERMAIN-SOUS-DOUE;77169;77;SEINE ET MARNE;1
77412;;Saint-Germain-sur-École;SAINT-GERMAIN-SUR-ECOLE;77930;77;SEINE ET MARNE;1
77413;;Saint-Germain-sur-Morin;SAINT-GERMAIN-SUR-MORIN;77860;77;SEINE ET MARNE;1
77414;;Saint-Hilliers;SAINT-HILLIERS;77160;77;SEINE ET MARNE;1
77415;;Saint-Jean-les-Deux-Jumeaux;SAINT-JEAN-LES-DEUX-JUMEAUX;77660;77;SEINE ET MARNE;1
77416;;Saint-Just-en-Brie;SAINT-JUST-EN-BRIE;77370;77;SEINE ET MARNE;1
77417;;Saint-Léger;SAINT-LEGER;77510;77;SEINE ET MARNE;1
77418;;Saint-Loup-de-Naud;SAINT-LOUP-DE-NAUD;77650;77;SEINE ET MARNE;1
77419;;Saint-Mammès;SAINT-MAMMES;77670;77;SEINE ET MARNE;1
77420;;Saint-Mard;SAINT-MARD;77230;77;SEINE ET MARNE;1
77421;;Saint-Mars-Vieux-Maisons;SAINT-MARS-VIEUX-MAISONS;77320;77;SEINE ET MARNE;1
77423;;Saint-Martin-des-Champs;SAINT-MARTIN-DES-CHAMPS;77320;77;SEINE ET MARNE;1
77424;;Saint-Martin-du-Boschet;SAINT-MARTIN-DU-BOSCHET;77320;77;SEINE ET MARNE;1
77425;;Saint-Martin-en-Bière;SAINT-MARTIN-EN-BIERE;77630;77;SEINE ET MARNE;1
77426;;Saint-Méry;SAINT-MERY;77720;77;SEINE ET MARNE;1
77427;;Saint-Mesmes;SAINT-MESMES;77410;77;SEINE ET MARNE;1
77428;;Saint-Ouen-en-Brie;SAINT-OUEN-EN-BRIE;77720;77;SEINE ET MARNE;1
77429;;Saint-Ouen-sur-Morin;SAINT-OUEN-SUR-MORIN;77750;77;SEINE ET MARNE;1
77430;;Saint-Pathus;SAINT-PATHUS;77178;77;SEINE ET MARNE;1
77431;;Saint-Pierre-lès-Nemours;SAINT-PIERRE-LES-NEMOURS;77140;77;SEINE ET MARNE;1
77432;;Saint-Rémy-la-Vanne;SAINT-REMY-LA-VANNE;77320;77;SEINE ET MARNE;1
77433;;Saints;SAINTS;77120;77;SEINE ET MARNE;1
77434;;Saint-Sauveur-lès-Bray;SAINT-SAUVEUR-LES-BRAY;77480;77;SEINE ET MARNE;1
77435;;Saint-Sauveur-sur-École;SAINT-SAUVEUR-SUR-ECOLE;77930;77;SEINE ET MARNE;1
77436;;Saint-Siméon;SAINT-SIMEON;77169;77;SEINE ET MARNE;1
77437;;Saint-Soupplets;SAINT-SOUPPLETS;77165;77;SEINE ET MARNE;1
77438;;Saint-Thibault-des-Vignes;SAINT-THIBAULT-DES-VIGNES;77400;77;SEINE ET MARNE;1
77439;;Salins;SALINS;77148;77;SEINE ET MARNE;1
77440;;Sammeron;SAMMERON;77260;77;SEINE ET MARNE;1
77441;;Samois-sur-Seine;SAMOIS-SUR-SEINE;77920;77;SEINE ET MARNE;1
77442;;Samoreau;SAMOREAU;77210;77;SEINE ET MARNE;1
77443;;Sancy;SANCY;77580;77;SEINE ET MARNE;1
77444;;Sancy-lès-Provins;SANCY-LES-PROVINS;77320;77;SEINE ET MARNE;1
77445;;Savigny-le-Temple;SAVIGNY-LE-TEMPLE;77176;77;SEINE ET MARNE;1
77446;;Savins;SAVINS;77650;77;SEINE ET MARNE;1
77447;;Seine-Port;SEINE-PORT;77240;77;SEINE ET MARNE;1
77448;;Sept-Sorts;SEPT-SORTS;77260;77;SEINE ET MARNE;1
77449;;Serris;SERRIS;77700;77;SEINE ET MARNE;1
77450;;Servon;SERVON;77170;77;SEINE ET MARNE;1
77451;;Signy-Signets;SIGNY-SIGNETS;77640;77;SEINE ET MARNE;1
77452;;Sigy;SIGY;77520;77;SEINE ET MARNE;1
77453;;Sivry-Courtry;SIVRY-COURTRY;77115;77;SEINE ET MARNE;1
77454;;Sognolles-en-Montois;SOGNOLLES-EN-MONTOIS;77520;77;SEINE ET MARNE;1
77455;;Soignolles-en-Brie;SOIGNOLLES-EN-BRIE;77111;77;SEINE ET MARNE;1
77456;;Soisy-Bouy;SOISY-BOUY;77650;77;SEINE ET MARNE;1
77457;;Solers;SOLERS;77111;77;SEINE ET MARNE;1
77458;;Souppes-sur-Loing;SOUPPES-SUR-LOING;77460;77;SEINE ET MARNE;1
77459;;Sourdun;SOURDUN;77171;77;SEINE ET MARNE;1
77460;;Tancrou;TANCROU;77440;77;SEINE ET MARNE;1
77461;;Thénisy;THENISY;77520;77;SEINE ET MARNE;1
77462;;Thieux;THIEUX;77230;77;SEINE ET MARNE;1
77463;;Thomery;THOMERY;77810;77;SEINE ET MARNE;1
77464;;Thorigny-sur-Marne;THORIGNY-SUR-MARNE;77400;77;SEINE ET MARNE;1
77465;;Thoury-Férottes;THOURY-FEROTTES;77156;77;SEINE ET MARNE;1
77466;;Tigeaux;TIGEAUX;77163;77;SEINE ET MARNE;1
77467;La;Tombe;TOMBE;77130;77;SEINE ET MARNE;1
77468;;Torcy;TORCY;77200;77;SEINE ET MARNE;1
77469;;Touquin;TOUQUIN;77131;77;SEINE ET MARNE;1
77470;;Tournan-en-Brie;TOURNAN-EN-BRIE;77220;77;SEINE ET MARNE;1
77471;;Tousson;TOUSSON;77123;77;SEINE ET MARNE;1
77472;La;Trétoire;TRETOIRE;77510;77;SEINE ET MARNE;1
77473;;Treuzy-Levelay;TREUZY-LEVELAY;77710;77;SEINE ET MARNE;1
77474;;Trilbardou;TRILBARDOU;77450;77;SEINE ET MARNE;1
77475;;Trilport;TRILPORT;77470;77;SEINE ET MARNE;1
77476;;Trocy-en-Multien;TROCY-EN-MULTIEN;77440;77;SEINE ET MARNE;1
77477;;Ury;URY;77760;77;SEINE ET MARNE;1
77478;;Ussy-sur-Marne;USSY-SUR-MARNE;77260;77;SEINE ET MARNE;1
77479;;Vaires-sur-Marne;VAIRES-SUR-MARNE;77360;77;SEINE ET MARNE;1
77480;;Valence-en-Brie;VALENCE-EN-BRIE;77830;77;SEINE ET MARNE;1
77481;;Vanvillé;VANVILLE;77370;77;SEINE ET MARNE;1
77482;;Varennes-sur-Seine;VARENNES-SUR-SEINE;77130;77;SEINE ET MARNE;1
77483;;Varreddes;VARREDDES;77910;77;SEINE ET MARNE;1
77484;;Vaucourtois;VAUCOURTOIS;77580;77;SEINE ET MARNE;1
77485;Le;Vaudoué;VAUDOUE;77123;77;SEINE ET MARNE;1
77486;;Vaudoy-en-Brie;VAUDOY-EN-BRIE;77141;77;SEINE ET MARNE;1
77487;;Vaux-le-Pénil;VAUX-LE-PENIL;77000;77;SEINE ET MARNE;1
77489;;Vaux-sur-Lunain;VAUX-SUR-LUNAIN;77710;77;SEINE ET MARNE;1
77490;;Vendrest;VENDREST;77440;77;SEINE ET MARNE;1
77491;;Veneux-les-Sablons;VENEUX-LES-SABLONS;77250;77;SEINE ET MARNE;1
77492;;Verdelot;VERDELOT;77510;77;SEINE ET MARNE;1
77493;;Verneuil-l'Étang;VERNEUIL-L'ETANG;77390;77;SEINE ET MARNE;1
77494;;Vernou-la-Celle-sur-Seine;VERNOU-LA-CELLE-SUR-SEINE;77670;77;SEINE ET MARNE;1
77495;;Vert-Saint-Denis;VERT-SAINT-DENIS;77240;77;SEINE ET MARNE;1
77496;;Vieux-Champagne;VIEUX-CHAMPAGNE;77370;77;SEINE ET MARNE;1
77498;;Vignely;VIGNELY;77450;77;SEINE ET MARNE;1
77500;;Villebéon;VILLEBEON;77710;77;SEINE ET MARNE;1
77501;;Villecerf;VILLECERF;77250;77;SEINE ET MARNE;1
77504;;Villemaréchal;VILLEMARECHAL;77710;77;SEINE ET MARNE;1
77505;;Villemareuil;VILLEMAREUIL;77470;77;SEINE ET MARNE;1
77506;;Villemer;VILLEMER;77250;77;SEINE ET MARNE;1
77507;;Villenauxe-la-Petite;VILLENAUXE-LA-PETITE;77480;77;SEINE ET MARNE;1
77508;;Villeneuve-le-Comte;VILLENEUVE-LE-COMTE;77174;77;SEINE ET MARNE;1
77509;;Villeneuve-les-Bordes;VILLENEUVE-LES-BORDES;77154;77;SEINE ET MARNE;1
77510;;Villeneuve-Saint-Denis;VILLENEUVE-SAINT-DENIS;77174;77;SEINE ET MARNE;1
77511;;Villeneuve-sous-Dammartin;VILLENEUVE-SOUS-DAMMARTIN;77230;77;SEINE ET MARNE;1
77512;;Villeneuve-sur-Bellot;VILLENEUVE-SUR-BELLOT;77510;77;SEINE ET MARNE;1
77513;;Villenoy;VILLENOY;77124;77;SEINE ET MARNE;1
77514;;Villeparisis;VILLEPARISIS;77270;77;SEINE ET MARNE;1
77515;;Villeroy;VILLEROY;77410;77;SEINE ET MARNE;1
77516;;Ville-Saint-Jacques;VILLE-SAINT-JACQUES;77130;77;SEINE ET MARNE;1
77517;;Villevaudé;VILLEVAUDE;77410;77;SEINE ET MARNE;1
77518;;Villiers-en-Bière;VILLIERS-EN-BIERE;77190;77;SEINE ET MARNE;1
77519;;Villiers-Saint-Georges;VILLIERS-SAINT-GEORGES;77560;77;SEINE ET MARNE;1
77520;;Villiers-sous-Grez;VILLIERS-SOUS-GREZ;77760;77;SEINE ET MARNE;1
77521;;Villiers-sur-Morin;VILLIERS-SUR-MORIN;77580;77;SEINE ET MARNE;1
77522;;Villiers-sur-Seine;VILLIERS-SUR-SEINE;77114;77;SEINE ET MARNE;1
77523;;Villuis;VILLUIS;77480;77;SEINE ET MARNE;1
77524;;Vimpelles;VIMPELLES;77520;77;SEINE ET MARNE;1
77525;;Vinantes;VINANTES;77230;77;SEINE ET MARNE;1
77526;;Vincy-Manœuvre;VINCY-MANOEUVRE;77139;77;SEINE ET MARNE;1
77527;;Voinsles;VOINSLES;77540;77;SEINE ET MARNE;1
77528;;Voisenon;VOISENON;77950;77;SEINE ET MARNE;1
77529;;Voulangis;VOULANGIS;77580;77;SEINE ET MARNE;1
77530;;Voulton;VOULTON;77560;77;SEINE ET MARNE;1
77531;;Voulx;VOULX;77940;77;SEINE ET MARNE;1
77532;;Vulaines-lès-Provins;VULAINES-LES-PROVINS;77160;77;SEINE ET MARNE;1
77533;;Vulaines-sur-Seine;VULAINES-SUR-SEINE;77870;77;SEINE ET MARNE;1
77534;;Yèbles;YEBLES;77390;77;SEINE ET MARNE;1
78003;;Ablis;ABLIS;78660;78;YVELINES;1
78005;;Achères;ACHERES;78260;78;YVELINES;1
78006;;Adainville;ADAINVILLE;78113;78;YVELINES;1
78007;;Aigremont;AIGREMONT;78240;78;YVELINES;1
78009;;Allainville;ALLAINVILLE;78660;78;YVELINES;1
78010;Les;Alluets-le-Roi;ALLUETS-LE-ROI;78580;78;YVELINES;1
78013;;Andelu;ANDELU;78770;78;YVELINES;1
78015;;Andrésy;ANDRESY;78570;78;YVELINES;1
78020;;Arnouville-lès-Mantes;ARNOUVILLE-LES-MANTES;78790;78;YVELINES;1
78029;;Aubergenville;AUBERGENVILLE;78410;78;YVELINES;1
78030;;Auffargis;AUFFARGIS;78610;78;YVELINES;1
78031;;Auffreville-Brasseuil;AUFFREVILLE-BRASSEUIL;78930;78;YVELINES;1
78033;;Aulnay-sur-Mauldre;AULNAY-SUR-MAULDRE;78126;78;YVELINES;1
78034;;Auteuil;AUTEUIL;78770;78;YVELINES;1
78036;;Autouillet;AUTOUILLET;78770;78;YVELINES;1
78043;;Bailly;BAILLY;78870;78;YVELINES;1
78048;;Bazainville;BAZAINVILLE;78550;78;YVELINES;1
78049;;Bazemont;BAZEMONT;78580;78;YVELINES;1
78050;;Bazoches-sur-Guyonne;BAZOCHES-SUR-GUYONNE;78490;78;YVELINES;1
78053;;Béhoust;BEHOUST;78910;78;YVELINES;1
78057;;Bennecourt;BENNECOURT;78270;78;YVELINES;1
78062;;Beynes;BEYNES;78650;78;YVELINES;1
78068;;Blaru;BLARU;78270;78;YVELINES;1
78070;;Boinville-en-Mantois;BOINVILLE-EN-MANTOIS;78930;78;YVELINES;1
78071;;Boinville-le-Gaillard;BOINVILLE-LE-GAILLARD;78660;78;YVELINES;1
78072;;Boinvilliers;BOINVILLIERS;78200;78;YVELINES;1
78073;;Bois-d'Arcy;BOIS-D'ARCY;78390;78;YVELINES;1
78076;;Boissets;BOISSETS;78910;78;YVELINES;1
78077;La;Boissière-École;BOISSIERE-ECOLE;78125;78;YVELINES;1
78082;;Boissy-Mauvoisin;BOISSY-MAUVOISIN;78200;78;YVELINES;1
78084;;Boissy-sans-Avoir;BOISSY-SANS-AVOIR;78490;78;YVELINES;1
78087;;Bonnelles;BONNELLES;78830;78;YVELINES;1
78089;;Bonnières-sur-Seine;BONNIERES-SUR-SEINE;78270;78;YVELINES;1
78090;;Bouafle;BOUAFLE;78410;78;YVELINES;1
78092;;Bougival;BOUGIVAL;78380;78;YVELINES;1
78096;;Bourdonné;BOURDONNE;78113;78;YVELINES;1
78104;;Breuil-Bois-Robert;BREUIL-BOIS-ROBERT;78930;78;YVELINES;1
78107;;Bréval;BREVAL;78980;78;YVELINES;1
78108;Les;Bréviaires;BREVIAIRES;78610;78;YVELINES;1
78113;;Brueil-en-Vexin;BRUEIL-EN-VEXIN;78440;78;YVELINES;1
78117;;Buc;BUC;78530;78;YVELINES;1
78118;;Buchelay;BUCHELAY;78200;78;YVELINES;1
78120;;Bullion;BULLION;78830;78;YVELINES;1
78123;;Carrières-sous-Poissy;CARRIERES-SOUS-POISSY;78955;78;YVELINES;1
78124;;Carrières-sur-Seine;CARRIERES-SUR-SEINE;78420;78;YVELINES;1
78125;La;Celle-les-Bordes;CELLE-LES-BORDES;78720;78;YVELINES;1
78126;La;Celle-Saint-Cloud;CELLE-SAINT-CLOUD;78170;78;YVELINES;1
78128;;Cernay-la-Ville;CERNAY-LA-VILLE;78720;78;YVELINES;1
78133;;Chambourcy;CHAMBOURCY;78240;78;YVELINES;1
78138;;Chanteloup-les-Vignes;CHANTELOUP-LES-VIGNES;78570;78;YVELINES;1
78140;;Chapet;CHAPET;78130;78;YVELINES;1
78143;;Châteaufort;CHATEAUFORT;78117;78;YVELINES;1
78146;;Chatou;CHATOU;78400;78;YVELINES;1
78147;;Chaufour-lès-Bonnières;CHAUFOUR-LES-BONNIERES;78270;78;YVELINES;1
78152;;Chavenay;CHAVENAY;78450;78;YVELINES;1
78158;Le;Chesnay;CHESNAY;78150;78;YVELINES;1
78160;;Chevreuse;CHEVREUSE;78460;78;YVELINES;1
78162;;Choisel;CHOISEL;78460;78;YVELINES;1
78163;;Civry-la-Forêt;CIVRY-LA-FORET;78910;78;YVELINES;1
78164;;Clairefontaine-en-Yvelines;CLAIREFONTAINE-EN-YVELINES;78120;78;YVELINES;1
78165;Les;Clayes-sous-Bois;CLAYES-SOUS-BOIS;78340;78;YVELINES;1
78168;;Coignières;COIGNIERES;78310;78;YVELINES;1
78171;;Condé-sur-Vesgre;CONDE-SUR-VESGRE;78113;78;YVELINES;1
78172;;Conflans-Sainte-Honorine;CONFLANS-SAINTE-HONORINE;78700;78;YVELINES;1
78185;;Courgent;COURGENT;78790;78;YVELINES;1
78188;;Cravent;CRAVENT;78270;78;YVELINES;1
78189;;Crespières;CRESPIERES;78121;78;YVELINES;1
78190;;Croissy-sur-Seine;CROISSY-SUR-SEINE;78290;78;YVELINES;1
78192;;Dammartin-en-Serve;DAMMARTIN-EN-SERVE;78111;78;YVELINES;1
78193;;Dampierre-en-Yvelines;DAMPIERRE-EN-YVELINES;78720;78;YVELINES;1
78194;;Dannemarie;DANNEMARIE;78550;78;YVELINES;1
78196;;Davron;DAVRON;78810;78;YVELINES;1
78202;;Drocourt;DROCOURT;78440;78;YVELINES;1
78206;;Ecquevilly;ECQUEVILLY;78920;78;YVELINES;1
78208;;Élancourt;ELANCOURT;78990;78;YVELINES;1
78209;;Émancé;EMANCE;78125;78;YVELINES;1
78217;;Épône;EPONE;78680;78;YVELINES;1
78220;Les;Essarts-le-Roi;ESSARTS-LE-ROI;78690;78;YVELINES;1
78224;L';Étang-la-Ville;ETANG-LA-VILLE;78620;78;YVELINES;1
78227;;Évecquemont;EVECQUEMONT;78740;78;YVELINES;1
78230;La;Falaise;FALAISE;78410;78;YVELINES;1
78231;;Favrieux;FAVRIEUX;78200;78;YVELINES;1
78233;;Feucherolles;FEUCHEROLLES;78810;78;YVELINES;1
78234;;Flacourt;FLACOURT;78200;78;YVELINES;1
78236;;Flexanville;FLEXANVILLE;78910;78;YVELINES;1
78237;;Flins-Neuve-Église;FLINS-NEUVE-EGLISE;78790;78;YVELINES;1
78238;;Flins-sur-Seine;FLINS-SUR-SEINE;78410;78;YVELINES;1
78239;;Follainville-Dennemont;FOLLAINVILLE-DENNEMONT;78520;78;YVELINES;1
78242;;Fontenay-le-Fleury;FONTENAY-LE-FLEURY;78330;78;YVELINES;1
78245;;Fontenay-Mauvoisin;FONTENAY-MAUVOISIN;78200;78;YVELINES;1
78246;;Fontenay-Saint-Père;FONTENAY-SAINT-PERE;78440;78;YVELINES;1
78251;;Fourqueux;FOURQUEUX;78112;78;YVELINES;1
78255;;Freneuse;FRENEUSE;78840;78;YVELINES;1
78261;;Gaillon-sur-Montcient;GAILLON-SUR-MONTCIENT;78250;78;YVELINES;1
78262;;Galluis;GALLUIS;78490;78;YVELINES;1
78263;;Gambais;GAMBAIS;78950;78;YVELINES;1
78264;;Gambaiseuil;GAMBAISEUIL;78490;78;YVELINES;1
78265;;Garancières;GARANCIERES;78890;78;YVELINES;1
78267;;Gargenville;GARGENVILLE;78440;78;YVELINES;1
78269;;Gazeran;GAZERAN;78125;78;YVELINES;1
78276;;Gommecourt;GOMMECOURT;78270;78;YVELINES;1
78278;;Goupillières;GOUPILLIERES;78770;78;YVELINES;1
78281;;Goussonville;GOUSSONVILLE;78930;78;YVELINES;1
78283;;Grandchamp;GRANDCHAMP;78113;78;YVELINES;1
78285;;Gressey;GRESSEY;78550;78;YVELINES;1
78289;;Grosrouvre;GROSROUVRE;78490;78;YVELINES;1
78290;;Guernes;GUERNES;78520;78;YVELINES;1
78291;;Guerville;GUERVILLE;78930;78;YVELINES;1
78296;;Guitrancourt;GUITRANCOURT;78440;78;YVELINES;1
78297;;Guyancourt;GUYANCOURT;78280;78;YVELINES;1
78299;;Hardricourt;HARDRICOURT;78250;78;YVELINES;1
78300;;Hargeville;HARGEVILLE;78790;78;YVELINES;1
78302;La;Hauteville;HAUTEVILLE;78113;78;YVELINES;1
78305;;Herbeville;HERBEVILLE;78580;78;YVELINES;1
78307;;Hermeray;HERMERAY;78125;78;YVELINES;1
78310;;Houdan;HOUDAN;78550;78;YVELINES;1
78311;;Houilles;HOUILLES;78800;78;YVELINES;1
78314;;Issou;ISSOU;78440;78;YVELINES;1
78317;;Jambville;JAMBVILLE;78440;78;YVELINES;1
78320;;Jeufosse;JEUFOSSE;78270;78;YVELINES;1
78321;;Jouars-Pontchartrain;JOUARS-PONTCHARTRAIN;78760;78;YVELINES;1
78322;;Jouy-en-Josas;JOUY-EN-JOSAS;78350;78;YVELINES;1
78324;;Jouy-Mauvoisin;JOUY-MAUVOISIN;78200;78;YVELINES;1
78325;;Jumeauville;JUMEAUVILLE;78580;78;YVELINES;1
78327;;Juziers;JUZIERS;78820;78;YVELINES;1
78329;;Lainville-en-Vexin;LAINVILLE-EN-VEXIN;78440;78;YVELINES;1
78334;;Lévis-Saint-Nom;LEVIS-SAINT-NOM;78320;78;YVELINES;1
78335;;Limay;LIMAY;78520;78;YVELINES;1
78337;;Limetz-Villez;LIMETZ-VILLEZ;78270;78;YVELINES;1
78343;Les;Loges-en-Josas;LOGES-EN-JOSAS;78350;78;YVELINES;1
78344;;Lommoye;LOMMOYE;78270;78;YVELINES;1
78346;;Longnes;LONGNES;78980;78;YVELINES;1
78349;;Longvilliers;LONGVILLIERS;78730;78;YVELINES;1
78350;;Louveciennes;LOUVECIENNES;78430;78;YVELINES;1
78354;;Magnanville;MAGNANVILLE;78200;78;YVELINES;1
78356;;Magny-les-Hameaux;MAGNY-LES-HAMEAUX;78114;78;YVELINES;1
78358;;Maisons-Laffitte;MAISONS-LAFFITTE;78600;78;YVELINES;1
78361;;Mantes-la-Jolie;MANTES-LA-JOLIE;78200;78;YVELINES;1
78362;;Mantes-la-Ville;MANTES-LA-VILLE;78200;78;YVELINES;1
78364;;Marcq;MARCQ;78770;78;YVELINES;1
78366;;Mareil-le-Guyon;MAREIL-LE-GUYON;78490;78;YVELINES;1
78367;;Mareil-Marly;MAREIL-MARLY;78750;78;YVELINES;1
78368;;Mareil-sur-Mauldre;MAREIL-SUR-MAULDRE;78124;78;YVELINES;1
78372;;Marly-le-Roi;MARLY-LE-ROI;78160;78;YVELINES;1
78380;;Maule;MAULE;78580;78;YVELINES;1
78381;;Maulette;MAULETTE;78550;78;YVELINES;1
78382;;Maurecourt;MAURECOURT;78780;78;YVELINES;1
78383;;Maurepas;MAUREPAS;78310;78;YVELINES;1
78384;;Médan;MEDAN;78670;78;YVELINES;1
78385;;Ménerville;MENERVILLE;78200;78;YVELINES;1
78389;;Méré;MERE;78490;78;YVELINES;1
78391;;Méricourt;MERICOURT;78270;78;YVELINES;1
78396;Le;Mesnil-le-Roi;MESNIL-LE-ROI;78600;78;YVELINES;1
78397;Le;Mesnil-Saint-Denis;MESNIL-SAINT-DENIS;78320;78;YVELINES;1
78398;Les;Mesnuls;MESNULS;78490;78;YVELINES;1
78401;;Meulan-en-Yvelines;MEULAN-EN-YVELINES;78250;78;YVELINES;1
78402;;Mézières-sur-Seine;MEZIERES-SUR-SEINE;78970;78;YVELINES;1
78403;;Mézy-sur-Seine;MEZY-SUR-SEINE;78250;78;YVELINES;1
78404;;Millemont;MILLEMONT;78940;78;YVELINES;1
78406;;Milon-la-Chapelle;MILON-LA-CHAPELLE;78470;78;YVELINES;1
78407;;Mittainville;MITTAINVILLE;78125;78;YVELINES;1
78410;;Moisson;MOISSON;78840;78;YVELINES;1
78413;;Mondreville;MONDREVILLE;78980;78;YVELINES;1
78415;;Montainville;MONTAINVILLE;78124;78;YVELINES;1
78416;;Montalet-le-Bois;MONTALET-LE-BOIS;78440;78;YVELINES;1
78417;;Montchauvet;MONTCHAUVET;78790;78;YVELINES;1
78418;;Montesson;MONTESSON;78360;78;YVELINES;1
78420;;Montfort-l'Amaury;MONTFORT-L'AMAURY;78490;78;YVELINES;1
78423;;Montigny-le-Bretonneux;MONTIGNY-LE-BRETONNEUX;78180;78;YVELINES;1
78431;;Morainvilliers;MORAINVILLIERS;78630;78;YVELINES;1
78437;;Mousseaux-sur-Seine;MOUSSEAUX-SUR-SEINE;78270;78;YVELINES;1
78439;;Mulcent;MULCENT;78790;78;YVELINES;1
78440;Les;Mureaux;MUREAUX;78130;78;YVELINES;1
78442;;Neauphle-le-Château;NEAUPHLE-LE-CHATEAU;78640;78;YVELINES;1
78443;;Neauphle-le-Vieux;NEAUPHLE-LE-VIEUX;78640;78;YVELINES;1
78444;;Neauphlette;NEAUPHLETTE;78980;78;YVELINES;1
78451;;Nézel;NEZEL;78410;78;YVELINES;1
78455;;Noisy-le-Roi;NOISY-LE-ROI;78590;78;YVELINES;1
78460;;Oinville-sur-Montcient;OINVILLE-SUR-MONTCIENT;78250;78;YVELINES;1
78464;;Orcemont;ORCEMONT;78125;78;YVELINES;1
78465;;Orgerus;ORGERUS;78910;78;YVELINES;1
78466;;Orgeval;ORGEVAL;78630;78;YVELINES;1
78470;;Orphin;ORPHIN;78125;78;YVELINES;1
78472;;Orsonville;ORSONVILLE;78660;78;YVELINES;1
78474;;Orvilliers;ORVILLIERS;78910;78;YVELINES;1
78475;;Osmoy;OSMOY;78910;78;YVELINES;1
78478;;Paray-Douaville;PARAY-DOUAVILLE;78660;78;YVELINES;1
78481;Le;Pecq;PECQ;78230;78;YVELINES;1
78484;;Perdreauville;PERDREAUVILLE;78200;78;YVELINES;1
78486;Le;Perray-en-Yvelines;PERRAY-EN-YVELINES;78610;78;YVELINES;1
78490;;Plaisir;PLAISIR;78370;78;YVELINES;1
78497;;Poigny-la-Forêt;POIGNY-LA-FORET;78125;78;YVELINES;1
78498;;Poissy;POISSY;78300;78;YVELINES;1
78499;;Ponthévrard;PONTHEVRARD;78730;78;YVELINES;1
78501;;Porcheville;PORCHEVILLE;78440;78;YVELINES;1
78502;Le;Port-Marly;PORT-MARLY;78560;78;YVELINES;1
78503;;Port-Villez;PORT-VILLEZ;78270;78;YVELINES;1
78505;;Prunay-le-Temple;PRUNAY-LE-TEMPLE;78910;78;YVELINES;1
78506;;Prunay-en-Yvelines;PRUNAY-EN-YVELINES;78660;78;YVELINES;1
78513;La;Queue-les-Yvelines;QUEUE-LES-YVELINES;78940;78;YVELINES;1
78516;;Raizeux;RAIZEUX;78125;78;YVELINES;1
78517;;Rambouillet;RAMBOUILLET;78120;78;YVELINES;1
78518;;Rennemoulin;RENNEMOULIN;78590;78;YVELINES;1
78520;;Richebourg;RICHEBOURG;78550;78;YVELINES;1
78522;;Rochefort-en-Yvelines;ROCHEFORT-EN-YVELINES;78730;78;YVELINES;1
78524;;Rocquencourt;ROCQUENCOURT;78150;78;YVELINES;1
78528;;Rolleboise;ROLLEBOISE;78270;78;YVELINES;1
78530;;Rosay;ROSAY;78790;78;YVELINES;1
78531;;Rosny-sur-Seine;ROSNY-SUR-SEINE;78710;78;YVELINES;1
78536;;Sailly;SAILLY;78440;78;YVELINES;1
78537;;Saint-Arnoult-en-Yvelines;SAINT-ARNOULT-EN-YVELINES;78730;78;YVELINES;1
78545;;Saint-Cyr-l'École;SAINT-CYR-L'ECOLE;78210;78;YVELINES;1
78548;;Saint-Forget;SAINT-FORGET;78720;78;YVELINES;1
78550;;Saint-Germain-de-la-Grange;SAINT-GERMAIN-DE-LA-GRANGE;78640;78;YVELINES;1
78551;;Saint-Germain-en-Laye;SAINT-GERMAIN-EN-LAYE;78100;78;YVELINES;1
78557;;Saint-Hilarion;SAINT-HILARION;78125;78;YVELINES;1
78558;;Saint-Illiers-la-Ville;SAINT-ILLIERS-LA-VILLE;78980;78;YVELINES;1
78559;;Saint-Illiers-le-Bois;SAINT-ILLIERS-LE-BOIS;78980;78;YVELINES;1
78561;;Saint-Lambert;SAINT-LAMBERT;78470;78;YVELINES;1
78562;;Saint-Léger-en-Yvelines;SAINT-LEGER-EN-YVELINES;78610;78;YVELINES;1
78564;;Saint-Martin-de-Bréthencourt;SAINT-MARTIN-DE-BRETHENCOURT;78660;78;YVELINES;1
78565;;Saint-Martin-des-Champs;SAINT-MARTIN-DES-CHAMPS;78790;78;YVELINES;1
78567;;Saint-Martin-la-Garenne;SAINT-MARTIN-LA-GARENNE;78520;78;YVELINES;1
78569;;Sainte-Mesme;SAINTE-MESME;78730;78;YVELINES;1
78571;;Saint-Nom-la-Bretèche;SAINT-NOM-LA-BRETECHE;78860;78;YVELINES;1
78575;;Saint-Rémy-lès-Chevreuse;SAINT-REMY-LES-CHEVREUSE;78470;78;YVELINES;1
78576;;Saint-Rémy-l'Honoré;SAINT-REMY-L'HONORE;78690;78;YVELINES;1
78586;;Sartrouville;SARTROUVILLE;78500;78;YVELINES;1
78588;;Saulx-Marchais;SAULX-MARCHAIS;78650;78;YVELINES;1
78590;;Senlisse;SENLISSE;78720;78;YVELINES;1
78591;;Septeuil;SEPTEUIL;78790;78;YVELINES;1
78597;;Soindres;SOINDRES;78200;78;YVELINES;1
78601;;Sonchamp;SONCHAMP;78120;78;YVELINES;1
78605;;Tacoignières;TACOIGNIERES;78910;78;YVELINES;1
78606;Le;Tartre-Gaudran;TARTRE-GAUDRAN;78113;78;YVELINES;1
78608;Le;Tertre-Saint-Denis;TERTRE-SAINT-DENIS;78980;78;YVELINES;1
78609;;Tessancourt-sur-Aubette;TESSANCOURT-SUR-AUBETTE;78250;78;YVELINES;1
78615;;Thiverval-Grignon;THIVERVAL-GRIGNON;78850;78;YVELINES;1
78616;;Thoiry;THOIRY;78770;78;YVELINES;1
78618;;Tilly;TILLY;78790;78;YVELINES;1
78620;;Toussus-le-Noble;TOUSSUS-LE-NOBLE;78117;78;YVELINES;1
78621;;Trappes;TRAPPES;78190;78;YVELINES;1
78623;Le;Tremblay-sur-Mauldre;TREMBLAY-SUR-MAULDRE;78490;78;YVELINES;1
78624;;Triel-sur-Seine;TRIEL-SUR-SEINE;78510;78;YVELINES;1
78638;;Vaux-sur-Seine;VAUX-SUR-SEINE;78740;78;YVELINES;1
78640;;Vélizy-Villacoublay;VELIZY-VILLACOUBLAY;78140;78;YVELINES;1
78642;;Verneuil-sur-Seine;VERNEUIL-SUR-SEINE;78480;78;YVELINES;1
78643;;Vernouillet;VERNOUILLET;78540;78;YVELINES;1
78644;La;Verrière;VERRIERE;78320;78;YVELINES;1
78646;;Versailles;VERSAILLES;78000;78;YVELINES;1
78647;;Vert;VERT;78930;78;YVELINES;1
78650;Le;Vésinet;VESINET;78110;78;YVELINES;1
78653;;Vicq;VICQ;78490;78;YVELINES;1
78655;;Vieille-Église-en-Yvelines;VIEILLE-EGLISE-EN-YVELINES;78125;78;YVELINES;1
78668;La;Villeneuve-en-Chevrie;VILLENEUVE-EN-CHEVRIE;78270;78;YVELINES;1
78672;;Villennes-sur-Seine;VILLENNES-SUR-SEINE;78670;78;YVELINES;1
78674;;Villepreux;VILLEPREUX;78450;78;YVELINES;1
78677;;Villette;VILLETTE;78930;78;YVELINES;1
78681;;Villiers-le-Mahieu;VILLIERS-LE-MAHIEU;78770;78;YVELINES;1
78683;;Villiers-Saint-Frédéric;VILLIERS-SAINT-FREDERIC;78640;78;YVELINES;1
78686;;Viroflay;VIROFLAY;78220;78;YVELINES;1
78688;;Voisins-le-Bretonneux;VOISINS-LE-BRETONNEUX;78960;78;YVELINES;1
79001;L';Absie;ABSIE;79240;79;DEUX SEVRES;1
79002;;Adilly;ADILLY;79200;79;DEUX SEVRES;1
79003;;Aiffres;AIFFRES;79230;79;DEUX SEVRES;1
79004;;Aigonnay;AIGONNAY;79370;79;DEUX SEVRES;1
79005;;Airvault;AIRVAULT;79600;79;DEUX SEVRES;1
79006;Les;Alleuds;ALLEUDS;79190;79;DEUX SEVRES;1
79007;;Allonne;ALLONNE;79130;79;DEUX SEVRES;1
79008;;Amailloux;AMAILLOUX;79350;79;DEUX SEVRES;1
79009;;Amuré;AMURE;79210;79;DEUX SEVRES;1
79010;;Arçais;ARCAIS;79210;79;DEUX SEVRES;1
79011;;Ardilleux;ARDILLEUX;79110;79;DEUX SEVRES;1
79012;;Ardin;ARDIN;79160;79;DEUX SEVRES;1
79013;;Argenton-les-Vallées;ARGENTON-LES-VALLEES;79150;79;DEUX SEVRES;1
79014;;Argenton-l'Église;ARGENTON-L'EGLISE;79290;79;DEUX SEVRES;1
79015;;Asnières-en-Poitou;ASNIERES-EN-POITOU;79170;79;DEUX SEVRES;1
79016;;Assais-les-Jumeaux;ASSAIS-LES-JUMEAUX;79600;79;DEUX SEVRES;1
79018;;Aubigné;AUBIGNE;79110;79;DEUX SEVRES;1
79019;;Aubigny;AUBIGNY;79390;79;DEUX SEVRES;1
79020;;Augé;AUGE;79400;79;DEUX SEVRES;1
79022;;Availles-Thouarsais;AVAILLES-THOUARSAIS;79600;79;DEUX SEVRES;1
79023;;Avon;AVON;79800;79;DEUX SEVRES;1
79024;;Azay-le-Brûlé;AZAY-LE-BRULE;79400;79;DEUX SEVRES;1
79025;;Azay-sur-Thouet;AZAY-SUR-THOUET;79130;79;DEUX SEVRES;1
79027;La;Bataille;BATAILLE;79110;79;DEUX SEVRES;1
79029;;Beaulieu-sous-Parthenay;BEAULIEU-SOUS-PARTHENAY;79420;79;DEUX SEVRES;1
79030;;Beaussais;BEAUSSAIS;79370;79;DEUX SEVRES;1
79031;;Beauvoir-sur-Niort;BEAUVOIR-SUR-NIORT;79360;79;DEUX SEVRES;1
79032;;Béceleuf;BECELEUF;79160;79;DEUX SEVRES;1
79033;;Belleville;BELLEVILLE;79360;79;DEUX SEVRES;1
79034;;Bessines;BESSINES;79000;79;DEUX SEVRES;1
79035;Le;Beugnon;BEUGNON;79130;79;DEUX SEVRES;1
79038;;Boismé;BOISME;79300;79;DEUX SEVRES;1
79039;;Boisserolles;BOISSEROLLES;79360;79;DEUX SEVRES;1
79040;La;Boissière-en-Gâtine;BOISSIERE-EN-GATINE;79310;79;DEUX SEVRES;1
79042;;Bougon;BOUGON;79800;79;DEUX SEVRES;1
79043;;Bouillé-Loretz;BOUILLE-LORETZ;79290;79;DEUX SEVRES;1
79044;;Bouillé-Saint-Paul;BOUILLE-SAINT-PAUL;79290;79;DEUX SEVRES;1
79045;;Bouin;BOUIN;79110;79;DEUX SEVRES;1
79046;Le;Bourdet;BOURDET;79210;79;DEUX SEVRES;1
79047;;Boussais;BOUSSAIS;79600;79;DEUX SEVRES;1
79048;La;Crèche;CRECHE;79260;79;DEUX SEVRES;1
79049;;Bressuire;BRESSUIRE;79300;79;DEUX SEVRES;1
79050;;Bretignolles;BRETIGNOLLES;79140;79;DEUX SEVRES;1
79051;Le;Breuil-Bernard;BREUIL-BERNARD;79320;79;DEUX SEVRES;1
79053;Le;Breuil-sous-Argenton;BREUIL-SOUS-ARGENTON;79150;79;DEUX SEVRES;1
79054;;Brie;BRIE;79100;79;DEUX SEVRES;1
79055;;Brieuil-sur-Chizé;BRIEUIL-SUR-CHIZE;79170;79;DEUX SEVRES;1
79056;;Brion-près-Thouet;BRION-PRES-THOUET;79290;79;DEUX SEVRES;1
79057;;Brioux-sur-Boutonne;BRIOUX-SUR-BOUTONNE;79170;79;DEUX SEVRES;1
79058;;Brûlain;BRULAIN;79230;79;DEUX SEVRES;1
79059;Le;Busseau;BUSSEAU;79240;79;DEUX SEVRES;1
79060;;Caunay;CAUNAY;79190;79;DEUX SEVRES;1
79061;;Celles-sur-Belle;CELLES-SUR-BELLE;79370;79;DEUX SEVRES;1
79062;;Cerizay;CERIZAY;79140;79;DEUX SEVRES;1
79063;;Cersay;CERSAY;79290;79;DEUX SEVRES;1
79064;;Chail;CHAIL;79500;79;DEUX SEVRES;1
79066;;Champdeniers-Saint-Denis;CHAMPDENIERS-SAINT-DENIS;79220;79;DEUX SEVRES;1
79068;;Chantecorps;CHANTECORPS;79340;79;DEUX SEVRES;1
79069;;Chanteloup;CHANTELOUP;79320;79;DEUX SEVRES;1
79070;La;Chapelle-Bâton;CHAPELLE-BATON;79220;79;DEUX SEVRES;1
79071;La;Chapelle-Bertrand;CHAPELLE-BERTRAND;79200;79;DEUX SEVRES;1
79072;La;Chapelle-Gaudin;CHAPELLE-GAUDIN;79300;79;DEUX SEVRES;1
79074;La;Chapelle-Pouilloux;CHAPELLE-POUILLOUX;79190;79;DEUX SEVRES;1
79075;La;Chapelle-Saint-Étienne;CHAPELLE-SAINT-ETIENNE;79240;79;DEUX SEVRES;1
79076;La;Chapelle-Saint-Laurent;CHAPELLE-SAINT-LAURENT;79430;79;DEUX SEVRES;1
79077;La;Chapelle-Thireuil;CHAPELLE-THIREUIL;79160;79;DEUX SEVRES;1
79078;;Prissé-la-Charrière;PRISSE-LA-CHARRIERE;79360;79;DEUX SEVRES;1
79079;;Mauléon;MAULEON;79700;79;DEUX SEVRES;1
79080;;Châtillon-sur-Thouet;CHATILLON-SUR-THOUET;79200;79;DEUX SEVRES;1
79081;;Chauray;CHAURAY;79180;79;DEUX SEVRES;1
79083;;Chef-Boutonne;CHEF-BOUTONNE;79110;79;DEUX SEVRES;1
79084;;Chenay;CHENAY;79120;79;DEUX SEVRES;1
79085;;Chérigné;CHERIGNE;79170;79;DEUX SEVRES;1
79086;;Cherveux;CHERVEUX;79410;79;DEUX SEVRES;1
79087;;Chey;CHEY;79120;79;DEUX SEVRES;1
79088;;Chiché;CHICHE;79350;79;DEUX SEVRES;1
79089;Le;Chillou;CHILLOU;79600;79;DEUX SEVRES;1
79090;;Chizé;CHIZE;79170;79;DEUX SEVRES;1
79091;;Cirières;CIRIERES;79140;79;DEUX SEVRES;1
79092;;Clavé;CLAVE;79420;79;DEUX SEVRES;1
79094;;Clessé;CLESSE;79350;79;DEUX SEVRES;1
79095;;Clussais-la-Pommeraie;CLUSSAIS-LA-POMMERAIE;79190;79;DEUX SEVRES;1
79096;;Combrand;COMBRAND;79140;79;DEUX SEVRES;1
79098;La;Couarde;COUARDE;79800;79;DEUX SEVRES;1
79099;La;Coudre;COUDRE;79150;79;DEUX SEVRES;1
79100;;Coulon;COULON;79510;79;DEUX SEVRES;1
79101;;Coulonges-sur-l'Autize;COULONGES-SUR-L'AUTIZE;79160;79;DEUX SEVRES;1
79102;;Coulonges-Thouarsais;COULONGES-THOUARSAIS;79330;79;DEUX SEVRES;1
79103;;Courlay;COURLAY;79440;79;DEUX SEVRES;1
79104;;Cours;COURS;79220;79;DEUX SEVRES;1
79105;;Coutières;COUTIERES;79340;79;DEUX SEVRES;1
79106;;Couture-d'Argenson;COUTURE-D'ARGENSON;79110;79;DEUX SEVRES;1
79107;;Crézières;CREZIERES;79110;79;DEUX SEVRES;1
79108;;Doux;DOUX;79390;79;DEUX SEVRES;1
79109;;Échiré;ECHIRE;79410;79;DEUX SEVRES;1
79111;;Ensigné;ENSIGNE;79170;79;DEUX SEVRES;1
79112;;Épannes;EPANNES;79270;79;DEUX SEVRES;1
79113;;Étusson;ETUSSON;79150;79;DEUX SEVRES;1
79114;;Exireuil;EXIREUIL;79400;79;DEUX SEVRES;1
79115;;Exoudun;EXOUDUN;79800;79;DEUX SEVRES;1
79116;;Faye-l'Abbesse;FAYE-L'ABBESSE;79350;79;DEUX SEVRES;1
79117;;Faye-sur-Ardin;FAYE-SUR-ARDIN;79160;79;DEUX SEVRES;1
79118;;Fénery;FENERY;79450;79;DEUX SEVRES;1
79119;;Fenioux;FENIOUX;79160;79;DEUX SEVRES;1
79120;La;Ferrière-en-Parthenay;FERRIERE-EN-PARTHENAY;79390;79;DEUX SEVRES;1
79121;;Fomperron;FOMPERRON;79340;79;DEUX SEVRES;1
79122;;Fontenille-Saint-Martin-d'Entraigues;FONTENILLE-SAINT-MARTIN-D'ENTRAIGUES;79110;79;DEUX SEVRES;1
79123;La;Forêt-sur-Sèvre;FORET-SUR-SEVRE;79380;79;DEUX SEVRES;1
79124;Les;Forges;FORGES;79340;79;DEUX SEVRES;1
79125;;Fors;FORS;79230;79;DEUX SEVRES;1
79126;Les;Fosses;FOSSES;79360;79;DEUX SEVRES;1
79127;La;Foye-Monjault;FOYE-MONJAULT;79360;79;DEUX SEVRES;1
79128;;François;FRANCOIS;79260;79;DEUX SEVRES;1
79129;;Fressines;FRESSINES;79370;79;DEUX SEVRES;1
79130;;Frontenay-Rohan-Rohan;FRONTENAY-ROHAN-ROHAN;79270;79;DEUX SEVRES;1
79131;;Geay;GEAY;79330;79;DEUX SEVRES;1
79132;;Genneton;GENNETON;79150;79;DEUX SEVRES;1
79133;;Germond-Rouvre;GERMOND-ROUVRE;79220;79;DEUX SEVRES;1
79134;;Glénay;GLENAY;79330;79;DEUX SEVRES;1
79135;;Gourgé;GOURGE;79200;79;DEUX SEVRES;1
79136;;Gournay-Loizé;GOURNAY-LOIZE;79110;79;DEUX SEVRES;1
79137;;Granzay-Gript;GRANZAY-GRIPT;79360;79;DEUX SEVRES;1
79139;Les;Groseillers;GROSEILLERS;79220;79;DEUX SEVRES;1
79140;;Hanc;HANC;79110;79;DEUX SEVRES;1
79141;;Irais;IRAIS;79600;79;DEUX SEVRES;1
79142;;Juillé;JUILLE;79170;79;DEUX SEVRES;1
79144;;Juscorps;JUSCORPS;79230;79;DEUX SEVRES;1
79145;;Lageon;LAGEON;79200;79;DEUX SEVRES;1
79147;;Largeasse;LARGEASSE;79240;79;DEUX SEVRES;1
79148;;Lezay;LEZAY;79120;79;DEUX SEVRES;1
79149;;Lhoumois;LHOUMOIS;79390;79;DEUX SEVRES;1
79150;;Limalonges;LIMALONGES;79190;79;DEUX SEVRES;1
79152;;Lorigné;LORIGNE;79190;79;DEUX SEVRES;1
79153;;Loubigné;LOUBIGNE;79110;79;DEUX SEVRES;1
79154;;Loubillé;LOUBILLE;79110;79;DEUX SEVRES;1
79156;;Louin;LOUIN;79600;79;DEUX SEVRES;1
79157;;Louzy;LOUZY;79100;79;DEUX SEVRES;1
79158;;Luché-sur-Brioux;LUCHE-SUR-BRIOUX;79170;79;DEUX SEVRES;1
79159;;Luché-Thouarsais;LUCHE-THOUARSAIS;79330;79;DEUX SEVRES;1
79160;;Lusseray;LUSSERAY;79170;79;DEUX SEVRES;1
79161;;Luzay;LUZAY;79100;79;DEUX SEVRES;1
79162;;Magné;MAGNE;79460;79;DEUX SEVRES;1
79163;;Mairé-Levescault;MAIRE-LEVESCAULT;79190;79;DEUX SEVRES;1
79164;;Maisonnay;MAISONNAY;79500;79;DEUX SEVRES;1
79165;;Maisontiers;MAISONTIERS;79600;79;DEUX SEVRES;1
79166;;Marigny;MARIGNY;79360;79;DEUX SEVRES;1
79167;;Marnes;MARNES;79600;79;DEUX SEVRES;1
79168;;Massais;MASSAIS;79150;79;DEUX SEVRES;1
79170;;Mauzé-sur-le-Mignon;MAUZE-SUR-LE-MIGNON;79210;79;DEUX SEVRES;1
79171;;Mauzé-Thouarsais;MAUZE-THOUARSAIS;79100;79;DEUX SEVRES;1
79172;;Mazières-en-Gâtine;MAZIERES-EN-GATINE;79310;79;DEUX SEVRES;1
79173;;Mazières-sur-Béronne;MAZIERES-SUR-BERONNE;79500;79;DEUX SEVRES;1
79174;;Melle;MELLE;79500;79;DEUX SEVRES;1
79175;;Melleran;MELLERAN;79190;79;DEUX SEVRES;1
79176;;Ménigoute;MENIGOUTE;79340;79;DEUX SEVRES;1
79177;;Messé;MESSE;79120;79;DEUX SEVRES;1
79178;;Missé;MISSE;79100;79;DEUX SEVRES;1
79179;;Moncoutant;MONCOUTANT;79320;79;DEUX SEVRES;1
79180;;Montalembert;MONTALEMBERT;79190;79;DEUX SEVRES;1
79183;;Montravers;MONTRAVERS;79140;79;DEUX SEVRES;1
79184;La;Mothe-Saint-Héray;MOTHE-SAINT-HERAY;79800;79;DEUX SEVRES;1
79185;;Mougon;MOUGON;79370;79;DEUX SEVRES;1
79187;;Moutiers-sous-Argenton;MOUTIERS-SOUS-ARGENTON;79150;79;DEUX SEVRES;1
79188;;Moutiers-sous-Chantemerle;MOUTIERS-SOUS-CHANTEMERLE;79320;79;DEUX SEVRES;1
79189;;Nanteuil;NANTEUIL;79400;79;DEUX SEVRES;1
79190;;Neuvy-Bouin;NEUVY-BOUIN;79130;79;DEUX SEVRES;1
79191;;Niort;NIORT;79000;79;DEUX SEVRES;1
79195;;Nueil-les-Aubiers;NUEIL-LES-AUBIERS;79250;79;DEUX SEVRES;1
79196;;Oiron;OIRON;79100;79;DEUX SEVRES;1
79197;;Oroux;OROUX;79390;79;DEUX SEVRES;1
79198;;Paizay-le-Chapt;PAIZAY-LE-CHAPT;79170;79;DEUX SEVRES;1
79199;;Paizay-le-Tort;PAIZAY-LE-TORT;79500;79;DEUX SEVRES;1
79200;;Pamplie;PAMPLIE;79220;79;DEUX SEVRES;1
79201;;Pamproux;PAMPROUX;79800;79;DEUX SEVRES;1
79202;;Parthenay;PARTHENAY;79200;79;DEUX SEVRES;1
79203;;Pas-de-Jeu;PAS-DE-JEU;79100;79;DEUX SEVRES;1
79204;;Périgné;PERIGNE;79170;79;DEUX SEVRES;1
79205;;Pers;PERS;79190;79;DEUX SEVRES;1
79207;La;Petite-Boissière;PETITE-BOISSIERE;79700;79;DEUX SEVRES;1
79208;La;Peyratte;PEYRATTE;79200;79;DEUX SEVRES;1
79209;;Pierrefitte;PIERREFITTE;79330;79;DEUX SEVRES;1
79210;Le;Pin;PIN;79140;79;DEUX SEVRES;1
79211;;Pioussay;PIOUSSAY;79110;79;DEUX SEVRES;1
79212;;Pliboux;PLIBOUX;79190;79;DEUX SEVRES;1
79213;;Pompaire;POMPAIRE;79200;79;DEUX SEVRES;1
79214;;Pouffonds;POUFFONDS;79500;79;DEUX SEVRES;1
79215;;Pougne-Hérisson;POUGNE-HERISSON;79130;79;DEUX SEVRES;1
79216;;Prahecq;PRAHECQ;79230;79;DEUX SEVRES;1
79217;;Prailles;PRAILLES;79370;79;DEUX SEVRES;1
79218;;Pressigny;PRESSIGNY;79390;79;DEUX SEVRES;1
79219;;Priaires;PRIAIRES;79210;79;DEUX SEVRES;1
79220;;Prin-Deyrançon;PRIN-DEYRANCON;79210;79;DEUX SEVRES;1
79222;;Pugny;PUGNY;79320;79;DEUX SEVRES;1
79223;;Puihardy;PUIHARDY;79160;79;DEUX SEVRES;1
79225;;Reffannes;REFFANNES;79420;79;DEUX SEVRES;1
79226;Le;Retail;RETAIL;79130;79;DEUX SEVRES;1
79229;La;Rochénard;ROCHENARD;79270;79;DEUX SEVRES;1
79230;;Rom;ROM;79120;79;DEUX SEVRES;1
79231;;Romans;ROMANS;79260;79;DEUX SEVRES;1
79235;;Saint-Amand-sur-Sèvre;SAINT-AMAND-SUR-SEVRE;79700;79;DEUX SEVRES;1
79236;;Saint-André-sur-Sèvre;SAINT-ANDRE-SUR-SEVRE;79380;79;DEUX SEVRES;1
79238;;Saint-Aubin-du-Plain;SAINT-AUBIN-DU-PLAIN;79300;79;DEUX SEVRES;1
79239;;Saint-Aubin-le-Cloud;SAINT-AUBIN-LE-CLOUD;79450;79;DEUX SEVRES;1
79240;;Sainte-Blandine;SAINTE-BLANDINE;79370;79;DEUX SEVRES;1
79241;;Saint-Christophe-sur-Roc;SAINT-CHRISTOPHE-SUR-ROC;79220;79;DEUX SEVRES;1
79242;;Saint-Clémentin;SAINT-CLEMENTIN;79150;79;DEUX SEVRES;1
79243;;Saint-Coutant;SAINT-COUTANT;79120;79;DEUX SEVRES;1
79244;;Saint-Cyr-la-Lande;SAINT-CYR-LA-LANDE;79100;79;DEUX SEVRES;1
79246;;Sainte-Eanne;SAINTE-EANNE;79800;79;DEUX SEVRES;1
79247;;Saint-Étienne-la-Cigogne;SAINT-ETIENNE-LA-CIGOGNE;79360;79;DEUX SEVRES;1
79249;;Saint-Gelais;SAINT-GELAIS;79410;79;DEUX SEVRES;1
79250;;Sainte-Gemme;SAINTE-GEMME;79330;79;DEUX SEVRES;1
79251;;Saint-Génard;SAINT-GENARD;79500;79;DEUX SEVRES;1
79252;;Saint-Généroux;SAINT-GENEROUX;79600;79;DEUX SEVRES;1
79253;;Saint-Georges-de-Noisné;SAINT-GEORGES-DE-NOISNE;79400;79;DEUX SEVRES;1
79254;;Saint-Georges-de-Rex;SAINT-GEORGES-DE-REX;79210;79;DEUX SEVRES;1
79255;;Saint-Germain-de-Longue-Chaume;SAINT-GERMAIN-DE-LONGUE-CHAUME;79200;79;DEUX SEVRES;1
79256;;Saint-Germier;SAINT-GERMIER;79340;79;DEUX SEVRES;1
79257;;Saint-Hilaire-la-Palud;SAINT-HILAIRE-LA-PALUD;79210;79;DEUX SEVRES;1
79258;;Saint-Jacques-de-Thouars;SAINT-JACQUES-DE-THOUARS;79100;79;DEUX SEVRES;1
79259;;Saint-Jean-de-Thouars;SAINT-JEAN-DE-THOUARS;79100;79;DEUX SEVRES;1
79260;;Saint-Jouin-de-Marnes;SAINT-JOUIN-DE-MARNES;79600;79;DEUX SEVRES;1
79261;;Saint-Jouin-de-Milly;SAINT-JOUIN-DE-MILLY;79380;79;DEUX SEVRES;1
79263;;Saint-Laurs;SAINT-LAURS;79160;79;DEUX SEVRES;1
79264;;Saint-Léger-de-la-Martinière;SAINT-LEGER-DE-LA-MARTINIERE;79500;79;DEUX SEVRES;1
79265;;Saint-Léger-de-Montbrun;SAINT-LEGER-DE-MONTBRUN;79100;79;DEUX SEVRES;1
79267;;Saint-Lin;SAINT-LIN;79420;79;DEUX SEVRES;1
79268;;Saint-Loup-Lamairé;SAINT-LOUP-LAMAIRE;79600;79;DEUX SEVRES;1
79269;;Saint-Maixent-de-Beugné;SAINT-MAIXENT-DE-BEUGNE;79160;79;DEUX SEVRES;1
79270;;Saint-Maixent-l'École;SAINT-MAIXENT-L'ECOLE;79400;79;DEUX SEVRES;1
79271;;Saint-Marc-la-Lande;SAINT-MARC-LA-LANDE;79310;79;DEUX SEVRES;1
79273;;Saint-Martin-de-Bernegoue;SAINT-MARTIN-DE-BERNEGOUE;79230;79;DEUX SEVRES;1
79274;;Saint-Martin-de-Mâcon;SAINT-MARTIN-DE-MACON;79100;79;DEUX SEVRES;1
79276;;Saint-Martin-de-Saint-Maixent;SAINT-MARTIN-DE-SAINT-MAIXENT;79400;79;DEUX SEVRES;1
79277;;Saint-Martin-de-Sanzay;SAINT-MARTIN-DE-SANZAY;79290;79;DEUX SEVRES;1
79278;;Saint-Martin-du-Fouilloux;SAINT-MARTIN-DU-FOUILLOUX;79420;79;DEUX SEVRES;1
79279;;Saint-Martin-lès-Melle;SAINT-MARTIN-LES-MELLE;79500;79;DEUX SEVRES;1
79280;;Saint-Maurice-la-Fougereuse;SAINT-MAURICE-LA-FOUGEREUSE;79150;79;DEUX SEVRES;1
79281;;Saint-Maxire;SAINT-MAXIRE;79410;79;DEUX SEVRES;1
79282;;Saint-Médard;SAINT-MEDARD;79370;79;DEUX SEVRES;1
79283;;Sainte-Néomaye;SAINTE-NEOMAYE;79260;79;DEUX SEVRES;1
79284;;Sainte-Ouenne;SAINTE-OUENNE;79220;79;DEUX SEVRES;1
79285;;Saint-Pardoux;SAINT-PARDOUX;79310;79;DEUX SEVRES;1
79286;;Saint-Paul-en-Gâtine;SAINT-PAUL-EN-GATINE;79240;79;DEUX SEVRES;1
79289;;Saint-Pierre-des-Échaubrognes;SAINT-PIERRE-DES-ECHAUBROGNES;79700;79;DEUX SEVRES;1
79290;;Saint-Pompain;SAINT-POMPAIN;79160;79;DEUX SEVRES;1
79292;;Sainte-Radegonde;SAINTE-RADEGONDE;79100;79;DEUX SEVRES;1
79293;;Saint-Rémy;SAINT-REMY;79410;79;DEUX SEVRES;1
79294;;Saint-Romans-des-Champs;SAINT-ROMANS-DES-CHAMPS;79230;79;DEUX SEVRES;1
79295;;Saint-Romans-lès-Melle;SAINT-ROMANS-LES-MELLE;79500;79;DEUX SEVRES;1
79297;;Sainte-Soline;SAINTE-SOLINE;79120;79;DEUX SEVRES;1
79298;;Saint-Symphorien;SAINT-SYMPHORIEN;79270;79;DEUX SEVRES;1
79299;;Saint-Varent;SAINT-VARENT;79330;79;DEUX SEVRES;1
79300;;Sainte-Verge;SAINTE-VERGE;79100;79;DEUX SEVRES;1
79301;;Saint-Vincent-la-Châtre;SAINT-VINCENT-LA-CHATRE;79500;79;DEUX SEVRES;1
79302;;Saivres;SAIVRES;79400;79;DEUX SEVRES;1
79303;;Salles;SALLES;79800;79;DEUX SEVRES;1
79304;;Sansais;SANSAIS;79270;79;DEUX SEVRES;1
79306;;Saurais;SAURAIS;79200;79;DEUX SEVRES;1
79307;;Sauzé-Vaussais;SAUZE-VAUSSAIS;79190;79;DEUX SEVRES;1
79308;;Sciecq;SCIECQ;79000;79;DEUX SEVRES;1
79309;;Scillé;SCILLE;79240;79;DEUX SEVRES;1
79310;;Secondigné-sur-Belle;SECONDIGNE-SUR-BELLE;79170;79;DEUX SEVRES;1
79311;;Secondigny;SECONDIGNY;79130;79;DEUX SEVRES;1
79312;;Séligné;SELIGNE;79170;79;DEUX SEVRES;1
79313;;Sepvret;SEPVRET;79120;79;DEUX SEVRES;1
79314;;Sompt;SOMPT;79110;79;DEUX SEVRES;1
79316;;Soudan;SOUDAN;79800;79;DEUX SEVRES;1
79318;;Soutiers;SOUTIERS;79310;79;DEUX SEVRES;1
79319;;Souvigné;SOUVIGNE;79800;79;DEUX SEVRES;1
79320;;Surin;SURIN;79220;79;DEUX SEVRES;1
79321;;Taizé;TAIZE;79100;79;DEUX SEVRES;1
79322;Le;Tallud;TALLUD;79200;79;DEUX SEVRES;1
79325;;Tessonnière;TESSONNIERE;79600;79;DEUX SEVRES;1
79326;;Thénezay;THENEZAY;79390;79;DEUX SEVRES;1
79327;;Thorigné;THORIGNE;79370;79;DEUX SEVRES;1
79328;;Thorigny-sur-le-Mignon;THORIGNY-SUR-LE-MIGNON;79360;79;DEUX SEVRES;1
79329;;Thouars;THOUARS;79100;79;DEUX SEVRES;1
79330;;Tillou;TILLOU;79110;79;DEUX SEVRES;1
79331;;Tourtenay;TOURTENAY;79100;79;DEUX SEVRES;1
79332;;Trayes;TRAYES;79240;79;DEUX SEVRES;1
79333;;Ulcot;ULCOT;79150;79;DEUX SEVRES;1
79334;;Usseau;USSEAU;79210;79;DEUX SEVRES;1
79335;;Vallans;VALLANS;79270;79;DEUX SEVRES;1
79336;;Vançais;VANCAIS;79120;79;DEUX SEVRES;1
79337;Le;Vanneau-Irleau;VANNEAU-IRLEAU;79270;79;DEUX SEVRES;1
79338;;Vanzay;VANZAY;79120;79;DEUX SEVRES;1
79339;;Vasles;VASLES;79340;79;DEUX SEVRES;1
79340;;Vausseroux;VAUSSEROUX;79420;79;DEUX SEVRES;1
79341;;Vautebis;VAUTEBIS;79420;79;DEUX SEVRES;1
79342;;Vernoux-en-Gâtine;VERNOUX-EN-GATINE;79240;79;DEUX SEVRES;1
79343;;Vernoux-sur-Boutonne;VERNOUX-SUR-BOUTONNE;79170;79;DEUX SEVRES;1
79345;;Verruyes;VERRUYES;79310;79;DEUX SEVRES;1
79346;Le;Vert;VERT;79170;79;DEUX SEVRES;1
79347;;Viennay;VIENNAY;79200;79;DEUX SEVRES;1
79348;;Villefollet;VILLEFOLLET;79170;79;DEUX SEVRES;1
79349;;Villemain;VILLEMAIN;79110;79;DEUX SEVRES;1
79350;;Villiers-en-Bois;VILLIERS-EN-BOIS;79360;79;DEUX SEVRES;1
79351;;Villiers-en-Plaine;VILLIERS-EN-PLAINE;79160;79;DEUX SEVRES;1
79352;;Villiers-sur-Chizé;VILLIERS-SUR-CHIZE;79170;79;DEUX SEVRES;1
79353;;Vitré;VITRE;79370;79;DEUX SEVRES;1
79354;;Vouhé;VOUHE;79310;79;DEUX SEVRES;1
79355;;Vouillé;VOUILLE;79230;79;DEUX SEVRES;1
79356;;Voultegon;VOULTEGON;79150;79;DEUX SEVRES;1
79357;;Xaintray;XAINTRAY;79220;79;DEUX SEVRES;1
80001;;Abbeville;ABBEVILLE;80100;80;SOMME;1
80002;;Ablaincourt-Pressoir;ABLAINCOURT-PRESSOIR;80320;80;SOMME;1
80003;;Acheux-en-Amiénois;ACHEUX-EN-AMIENOIS;80560;80;SOMME;1
80004;;Acheux-en-Vimeu;ACHEUX-EN-VIMEU;80210;80;SOMME;1
80005;;Agenville;AGENVILLE;80370;80;SOMME;1
80006;;Agenvillers;AGENVILLERS;80150;80;SOMME;1
80008;;Aigneville;AIGNEVILLE;80210;80;SOMME;1
80009;;Ailly-le-Haut-Clocher;AILLY-LE-HAUT-CLOCHER;80690;80;SOMME;1
80010;;Ailly-sur-Noye;AILLY-SUR-NOYE;80250;80;SOMME;1
80011;;Ailly-sur-Somme;AILLY-SUR-SOMME;80470;80;SOMME;1
80013;;Airaines;AIRAINES;80270;80;SOMME;1
80014;;Aizecourt-le-Bas;AIZECOURT-LE-BAS;80240;80;SOMME;1
80015;;Aizecourt-le-Haut;AIZECOURT-LE-HAUT;80200;80;SOMME;1
80016;;Albert;ALBERT;80300;80;SOMME;1
80017;;Allaines;ALLAINES;80200;80;SOMME;1
80018;;Allenay;ALLENAY;80530;80;SOMME;1
80019;;Allery;ALLERY;80270;80;SOMME;1
80020;;Allonville;ALLONVILLE;80260;80;SOMME;1
80021;;Amiens;AMIENS;80000;80;SOMME;1
80022;;Andainville;ANDAINVILLE;80140;80;SOMME;1
80023;;Andechy;ANDECHY;80700;80;SOMME;1
80024;;Argœuves;ARGOEUVES;80730;80;SOMME;1
80025;;Argoules;ARGOULES;80120;80;SOMME;1
80026;;Arguel;ARGUEL;80140;80;SOMME;1
80027;;Armancourt;ARMANCOURT;80700;80;SOMME;1
80028;;Arquèves;ARQUEVES;80560;80;SOMME;1
80029;;Arrest;ARREST;80820;80;SOMME;1
80030;;Arry;ARRY;80120;80;SOMME;1
80031;;Arvillers;ARVILLERS;80910;80;SOMME;1
80032;;Assainvillers;ASSAINVILLERS;80500;80;SOMME;1
80033;;Assevillers;ASSEVILLERS;80200;80;SOMME;1
80034;;Athies;ATHIES;80200;80;SOMME;1
80035;;Aubercourt;AUBERCOURT;80110;80;SOMME;1
80036;;Aubigny;AUBIGNY;80800;80;SOMME;1
80037;;Aubvillers;AUBVILLERS;80110;80;SOMME;1
80038;;Auchonvillers;AUCHONVILLERS;80560;80;SOMME;1
80039;;Ault;AULT;80460;80;SOMME;1
80040;;Aumâtre;AUMATRE;80140;80;SOMME;1
80041;;Aumont;AUMONT;80640;80;SOMME;1
80042;;Autheux;AUTHEUX;80600;80;SOMME;1
80043;;Authie;AUTHIE;80560;80;SOMME;1
80044;;Authieule;AUTHIEULE;80600;80;SOMME;1
80045;;Authuille;AUTHUILLE;80300;80;SOMME;1
80046;;Avelesges;AVELESGES;80270;80;SOMME;1
80047;;Aveluy;AVELUY;80300;80;SOMME;1
80048;;Avesnes-Chaussoy;AVESNES-CHAUSSOY;80140;80;SOMME;1
80049;;Ayencourt;AYENCOURT;80500;80;SOMME;1
80050;;Bacouel-sur-Selle;BACOUEL-SUR-SELLE;80480;80;SOMME;1
80051;;Bailleul;BAILLEUL;80490;80;SOMME;1
80052;;Baizieux;BAIZIEUX;80300;80;SOMME;1
80053;;Balâtre;BALATRE;80700;80;SOMME;1
80054;;Barleux;BARLEUX;80200;80;SOMME;1
80055;;Barly;BARLY;80600;80;SOMME;1
80056;;Bavelincourt;BAVELINCOURT;80260;80;SOMME;1
80057;;Bayencourt;BAYENCOURT;80560;80;SOMME;1
80058;;Bayonvillers;BAYONVILLERS;80170;80;SOMME;1
80059;;Bazentin;BAZENTIN;80300;80;SOMME;1
80060;;Béalcourt;BEALCOURT;80370;80;SOMME;1
80061;;Beaucamps-le-Jeune;BEAUCAMPS-LE-JEUNE;80430;80;SOMME;1
80062;;Beaucamps-le-Vieux;BEAUCAMPS-LE-VIEUX;80430;80;SOMME;1
80063;;Beauchamps;BEAUCHAMPS;80770;80;SOMME;1
80064;;Beaucourt-en-Santerre;BEAUCOURT-EN-SANTERRE;80110;80;SOMME;1
80065;;Beaucourt-sur-l'Ancre;BEAUCOURT-SUR-L'ANCRE;80300;80;SOMME;1
80066;;Beaucourt-sur-l'Hallue;BEAUCOURT-SUR-L'HALLUE;80260;80;SOMME;1
80067;;Beaufort-en-Santerre;BEAUFORT-EN-SANTERRE;80170;80;SOMME;1
80068;;Beaumetz;BEAUMETZ;80370;80;SOMME;1
80069;;Beaumont-Hamel;BEAUMONT-HAMEL;80300;80;SOMME;1
80070;;Beauquesne;BEAUQUESNE;80600;80;SOMME;1
80071;;Beauval;BEAUVAL;80630;80;SOMME;1
80073;;Bécordel-Bécourt;BECORDEL-BECOURT;80300;80;SOMME;1
80074;;Becquigny;BECQUIGNY;80500;80;SOMME;1
80076;;Béhen;BEHEN;80870;80;SOMME;1
80077;;Béhencourt;BEHENCOURT;80260;80;SOMME;1
80078;;Bellancourt;BELLANCOURT;80132;80;SOMME;1
80079;;Belleuse;BELLEUSE;80160;80;SOMME;1
80080;;Belloy-en-Santerre;BELLOY-EN-SANTERRE;80200;80;SOMME;1
80081;;Belloy-Saint-Léonard;BELLOY-SAINT-LEONARD;80270;80;SOMME;1
80082;;Belloy-sur-Somme;BELLOY-SUR-SOMME;80310;80;SOMME;1
80083;;Bergicourt;BERGICOURT;80290;80;SOMME;1
80084;;Bermesnil;BERMESNIL;80140;80;SOMME;1
80085;;Bernâtre;BERNATRE;80370;80;SOMME;1
80086;;Bernaville;BERNAVILLE;80370;80;SOMME;1
80087;;Bernay-en-Ponthieu;BERNAY-EN-PONTHIEU;80120;80;SOMME;1
80088;;Bernes;BERNES;80240;80;SOMME;1
80089;;Berneuil;BERNEUIL;80620;80;SOMME;1
80090;;Berny-en-Santerre;BERNY-EN-SANTERRE;80200;80;SOMME;1
80092;;Bertangles;BERTANGLES;80260;80;SOMME;1
80093;;Berteaucourt-les-Dames;BERTEAUCOURT-LES-DAMES;80850;80;SOMME;1
80094;;Berteaucourt-lès-Thennes;BERTEAUCOURT-LES-THENNES;80110;80;SOMME;1
80095;;Bertrancourt;BERTRANCOURT;80560;80;SOMME;1
80096;;Béthencourt-sur-Mer;BETHENCOURT-SUR-MER;80530;80;SOMME;1
80097;;Béthencourt-sur-Somme;BETHENCOURT-SUR-SOMME;80190;80;SOMME;1
80098;;Bettembos;BETTEMBOS;80590;80;SOMME;1
80099;;Bettencourt-Rivière;BETTENCOURT-RIVIERE;80270;80;SOMME;1
80100;;Bettencourt-Saint-Ouen;BETTENCOURT-SAINT-OUEN;80610;80;SOMME;1
80101;;Beuvraignes;BEUVRAIGNES;80700;80;SOMME;1
80102;;Biaches;BIACHES;80200;80;SOMME;1
80103;;Biarre;BIARRE;80190;80;SOMME;1
80104;;Biencourt;BIENCOURT;80140;80;SOMME;1
80105;;Billancourt;BILLANCOURT;80190;80;SOMME;1
80106;;Blangy-sous-Poix;BLANGY-SOUS-POIX;80290;80;SOMME;1
80107;;Blangy-Tronville;BLANGY-TRONVILLE;80440;80;SOMME;1
80108;;Boisbergues;BOISBERGUES;80600;80;SOMME;1
80109;Le;Boisle;BOISLE;80150;80;SOMME;1
80110;;Boismont;BOISMONT;80230;80;SOMME;1
80112;;Bonnay;BONNAY;80800;80;SOMME;1
80113;;Bonneville;BONNEVILLE;80670;80;SOMME;1
80114;;Bosquel;BOSQUEL;80160;80;SOMME;1
80115;;Bouchavesnes-Bergen;BOUCHAVESNES-BERGEN;80200;80;SOMME;1
80116;;Bouchoir;BOUCHOIR;80910;80;SOMME;1
80117;;Bouchon;BOUCHON;80830;80;SOMME;1
80118;;Boufflers;BOUFFLERS;80150;80;SOMME;1
80119;;Bougainville;BOUGAINVILLE;80540;80;SOMME;1
80120;;Bouillancourt-en-Séry;BOUILLANCOURT-EN-SERY;80220;80;SOMME;1
80121;;Bouillancourt-la-Bataille;BOUILLANCOURT-LA-BATAILLE;80500;80;SOMME;1
80122;;Bouquemaison;BOUQUEMAISON;80600;80;SOMME;1
80123;;Bourdon;BOURDON;80310;80;SOMME;1
80124;;Bourseville;BOURSEVILLE;80130;80;SOMME;1
80125;;Boussicourt;BOUSSICOURT;80500;80;SOMME;1
80126;;Bouttencourt;BOUTTENCOURT;80220;80;SOMME;1
80127;;Bouvaincourt-sur-Bresle;BOUVAINCOURT-SUR-BRESLE;80220;80;SOMME;1
80128;;Bouvincourt-en-Vermandois;BOUVINCOURT-EN-VERMANDOIS;80200;80;SOMME;1
80129;;Bouzincourt;BOUZINCOURT;80300;80;SOMME;1
80130;;Bovelles;BOVELLES;80540;80;SOMME;1
80131;;Boves;BOVES;80440;80;SOMME;1
80132;;Braches;BRACHES;80110;80;SOMME;1
80133;;Brailly-Cornehotte;BRAILLY-CORNEHOTTE;80150;80;SOMME;1
80134;;Brassy;BRASSY;80160;80;SOMME;1
80135;;Bray-lès-Mareuil;BRAY-LES-MAREUIL;80580;80;SOMME;1
80136;;Bray-sur-Somme;BRAY-SUR-SOMME;80340;80;SOMME;1
80137;;Breilly;BREILLY;80470;80;SOMME;1
80138;;Bresle;BRESLE;80300;80;SOMME;1
80139;;Breuil;BREUIL;80400;80;SOMME;1
80140;;Brévillers;BREVILLERS;80600;80;SOMME;1
80141;;Brie;BRIE;80200;80;SOMME;1
80142;;Briquemesnil-Floxicourt;BRIQUEMESNIL-FLOXICOURT;80540;80;SOMME;1
80143;;Brocourt;BROCOURT;80430;80;SOMME;1
80144;;Brouchy;BROUCHY;80400;80;SOMME;1
80145;;Brucamps;BRUCAMPS;80690;80;SOMME;1
80146;;Brutelles;BRUTELLES;80230;80;SOMME;1
80147;;Buigny-l'Abbé;BUIGNY-L'ABBE;80132;80;SOMME;1
80148;;Buigny-lès-Gamaches;BUIGNY-LES-GAMACHES;80220;80;SOMME;1
80149;;Buigny-Saint-Maclou;BUIGNY-SAINT-MACLOU;80132;80;SOMME;1
80150;;Buire-Courcelles;BUIRE-COURCELLES;80200;80;SOMME;1
80151;;Buire-sur-l'Ancre;BUIRE-SUR-L'ANCRE;80300;80;SOMME;1
80152;;Bus-la-Mésière;BUS-LA-MESIERE;80700;80;SOMME;1
80153;;Bus-lès-Artois;BUS-LES-ARTOIS;80560;80;SOMME;1
80154;;Bussu;BUSSU;80200;80;SOMME;1
80155;;Bussus-Bussuel;BUSSUS-BUSSUEL;80135;80;SOMME;1
80156;;Bussy-lès-Daours;BUSSY-LES-DAOURS;80800;80;SOMME;1
80157;;Bussy-lès-Poix;BUSSY-LES-POIX;80290;80;SOMME;1
80158;;Buverchy;BUVERCHY;80400;80;SOMME;1
80159;;Cachy;CACHY;80380;80;SOMME;1
80160;;Cagny;CAGNY;80330;80;SOMME;1
80161;;Cahon;CAHON;80132;80;SOMME;1
80162;;Caix;CAIX;80170;80;SOMME;1
80163;;Cambron;CAMBRON;80132;80;SOMME;1
80164;;Camon;CAMON;80450;80;SOMME;1
80165;;Camps-en-Amiénois;CAMPS-EN-AMIENOIS;80540;80;SOMME;1
80166;;Canaples;CANAPLES;80670;80;SOMME;1
80167;;Canchy;CANCHY;80150;80;SOMME;1
80168;;Candas;CANDAS;80750;80;SOMME;1
80169;;Cannessières;CANNESSIERES;80140;80;SOMME;1
80170;;Cantigny;CANTIGNY;80500;80;SOMME;1
80171;;Caours;CAOURS;80132;80;SOMME;1
80172;;Cappy;CAPPY;80340;80;SOMME;1
80173;;Cardonnette;CARDONNETTE;80260;80;SOMME;1
80174;Le;Cardonnois;CARDONNOIS;80500;80;SOMME;1
80175;;Carnoy;CARNOY;80300;80;SOMME;1
80176;;Carrépuis;CARREPUIS;80700;80;SOMME;1
80177;;Cartigny;CARTIGNY;80200;80;SOMME;1
80179;;Caulières;CAULIERES;80590;80;SOMME;1
80180;;Cavillon;CAVILLON;80310;80;SOMME;1
80181;;Cayeux-en-Santerre;CAYEUX-EN-SANTERRE;80720;80;SOMME;1
80182;;Cayeux-sur-Mer;CAYEUX-SUR-MER;80410;80;SOMME;1
80183;;Cerisy-Buleux;CERISY-BULEUX;80140;80;SOMME;1
80184;;Cerisy;CERISY;80800;80;SOMME;1
80185;;Champien;CHAMPIEN;80700;80;SOMME;1
80186;;Chaulnes;CHAULNES;80320;80;SOMME;1
80187;La;Chaussée-Tirancourt;CHAUSSEE-TIRANCOURT;80310;80;SOMME;1
80188;;Chaussoy-Epagny;CHAUSSOY-EPAGNY;80250;80;SOMME;1
80189;La;Chavatte;CHAVATTE;80700;80;SOMME;1
80190;;Chépy;CHEPY;80210;80;SOMME;1
80191;;Chilly;CHILLY;80170;80;SOMME;1
80192;;Chipilly;CHIPILLY;80800;80;SOMME;1
80193;;Chirmont;CHIRMONT;80250;80;SOMME;1
80194;;Chuignes;CHUIGNES;80340;80;SOMME;1
80195;;Chuignolles;CHUIGNOLLES;80340;80;SOMME;1
80196;;Citerne;CITERNE;80490;80;SOMME;1
80197;;Cizancourt;CIZANCOURT;80200;80;SOMME;1
80198;;Clairy-Saulchoix;CLAIRY-SAULCHOIX;80540;80;SOMME;1
80199;;Cléry-sur-Somme;CLERY-SUR-SOMME;80200;80;SOMME;1
80200;;Cocquerel;COCQUEREL;80510;80;SOMME;1
80201;;Coigneux;COIGNEUX;80560;80;SOMME;1
80202;;Coisy;COISY;80260;80;SOMME;1
80203;;Colincamps;COLINCAMPS;80560;80;SOMME;1
80204;;Combles;COMBLES;80360;80;SOMME;1
80205;;Condé-Folie;CONDE-FOLIE;80890;80;SOMME;1
80206;;Contalmaison;CONTALMAISON;80300;80;SOMME;1
80207;;Contay;CONTAY;80560;80;SOMME;1
80208;;Conteville;CONTEVILLE;80370;80;SOMME;1
80209;;Contoire;CONTOIRE;80500;80;SOMME;1
80210;;Contre;CONTRE;80160;80;SOMME;1
80211;;Conty;CONTY;80160;80;SOMME;1
80212;;Corbie;CORBIE;80800;80;SOMME;1
80213;;Cottenchy;COTTENCHY;80440;80;SOMME;1
80214;;Coullemelle;COULLEMELLE;80250;80;SOMME;1
80215;;Coulonvillers;COULONVILLERS;80135;80;SOMME;1
80216;;Courcelette;COURCELETTE;80300;80;SOMME;1
80217;;Courcelles-au-Bois;COURCELLES-AU-BOIS;80560;80;SOMME;1
80218;;Courcelles-sous-Moyencourt;COURCELLES-SOUS-MOYENCOURT;80290;80;SOMME;1
80219;;Courcelles-sous-Thoix;COURCELLES-SOUS-THOIX;80160;80;SOMME;1
80220;;Courtemanche;COURTEMANCHE;80500;80;SOMME;1
80221;;Cramont;CRAMONT;80370;80;SOMME;1
80222;;Crécy-en-Ponthieu;CRECY-EN-PONTHIEU;80150;80;SOMME;1
80223;;Crémery;CREMERY;80700;80;SOMME;1
80224;;Cressy-Omencourt;CRESSY-OMENCOURT;80190;80;SOMME;1
80225;;Creuse;CREUSE;80480;80;SOMME;1
80226;;Croix-Moligneaux;CROIX-MOLIGNEAUX;80400;80;SOMME;1
80227;;Croixrault;CROIXRAULT;80290;80;SOMME;1
80228;Le;Crotoy;CROTOY;80550;80;SOMME;1
80229;;Crouy-Saint-Pierre;CROUY-SAINT-PIERRE;80310;80;SOMME;1
80230;;Curchy;CURCHY;80190;80;SOMME;1
80231;;Curlu;CURLU;80360;80;SOMME;1
80232;;Damery;DAMERY;80700;80;SOMME;1
80233;;Dancourt-Popincourt;DANCOURT-POPINCOURT;80700;80;SOMME;1
80234;;Daours;DAOURS;80800;80;SOMME;1
80235;;Dargnies;DARGNIES;80570;80;SOMME;1
80236;;Davenescourt;DAVENESCOURT;80500;80;SOMME;1
80237;;Démuin;DEMUIN;80110;80;SOMME;1
80238;;Dernancourt;DERNANCOURT;80300;80;SOMME;1
80239;;Devise;DEVISE;80200;80;SOMME;1
80240;;Doingt;DOINGT;80200;80;SOMME;1
80241;;Domart-en-Ponthieu;DOMART-EN-PONTHIEU;80620;80;SOMME;1
80242;;Domart-sur-la-Luce;DOMART-SUR-LA-LUCE;80110;80;SOMME;1
80243;;Domesmont;DOMESMONT;80370;80;SOMME;1
80244;;Dominois;DOMINOIS;80120;80;SOMME;1
80245;;Domléger-Longvillers;DOMLEGER-LONGVILLERS;80370;80;SOMME;1
80246;;Dommartin;DOMMARTIN;80440;80;SOMME;1
80247;;Dompierre-Becquincourt;DOMPIERRE-BECQUINCOURT;80980;80;SOMME;1
80248;;Dompierre-sur-Authie;DOMPIERRE-SUR-AUTHIE;80150;80;SOMME;1
80249;;Domqueur;DOMQUEUR;80620;80;SOMME;1
80250;;Domvast;DOMVAST;80150;80;SOMME;1
80251;;Doudelainville;DOUDELAINVILLE;80140;80;SOMME;1
80252;;Douilly;DOUILLY;80400;80;SOMME;1
80253;;Doullens;DOULLENS;80600;80;SOMME;1
80256;;Dreuil-lès-Amiens;DREUIL-LES-AMIENS;80730;80;SOMME;1
80258;;Driencourt;DRIENCOURT;80240;80;SOMME;1
80259;;Dromesnil;DROMESNIL;80640;80;SOMME;1
80260;;Drucat;DRUCAT;80132;80;SOMME;1
80261;;Dury;DURY;80480;80;SOMME;1
80262;;Eaucourt-sur-Somme;EAUCOURT-SUR-SOMME;80580;80;SOMME;1
80263;L';Échelle-Saint-Aurin;ECHELLE-SAINT-AURIN;80700;80;SOMME;1
80264;;Éclusier-Vaux;ECLUSIER-VAUX;80340;80;SOMME;1
80265;;Embreville;EMBREVILLE;80570;80;SOMME;1
80266;;Englebelmer;ENGLEBELMER;80300;80;SOMME;1
80267;;Ennemain;ENNEMAIN;80200;80;SOMME;1
80268;;Épagne-Épagnette;EPAGNE-EPAGNETTE;80580;80;SOMME;1
80269;;Épaumesnil;EPAUMESNIL;80140;80;SOMME;1
80270;;Épécamps;EPECAMPS;80370;80;SOMME;1
80271;;Épehy;EPEHY;80740;80;SOMME;1
80272;;Épénancourt;EPENANCOURT;80190;80;SOMME;1
80273;;Éplessier;EPLESSIER;80290;80;SOMME;1
80274;;Eppeville;EPPEVILLE;80400;80;SOMME;1
80275;;Équancourt;EQUANCOURT;80360;80;SOMME;1
80276;;Équennes-Éramecourt;EQUENNES-ERAMECOURT;80290;80;SOMME;1
80278;;Erches;ERCHES;80500;80;SOMME;1
80279;;Ercheu;ERCHEU;80930;80;SOMME;1
80280;;Ercourt;ERCOURT;80210;80;SOMME;1
80281;;Ergnies;ERGNIES;80690;80;SOMME;1
80282;;Érondelle;ERONDELLE;80580;80;SOMME;1
80283;;Esclainvillers;ESCLAINVILLERS;80250;80;SOMME;1
80284;;Esmery-Hallon;ESMERY-HALLON;80400;80;SOMME;1
80285;;Essertaux;ESSERTAUX;80160;80;SOMME;1
80287;;Estrébœuf;ESTREBOEUF;80230;80;SOMME;1
80288;;Estrées-Deniécourt;ESTREES-DENIECOURT;80200;80;SOMME;1
80290;;Estrées-lès-Crécy;ESTREES-LES-CRECY;80150;80;SOMME;1
80291;;Estrées-sur-Noye;ESTREES-SUR-NOYE;80250;80;SOMME;1
80292;;Étalon;ETALON;80190;80;SOMME;1
80293;;Ételfay;ETELFAY;80500;80;SOMME;1
80294;;Éterpigny;ETERPIGNY;80200;80;SOMME;1
80295;;Étinehem;ETINEHEM;80340;80;SOMME;1
80296;L';Étoile;ETOILE;80830;80;SOMME;1
80297;;Étréjust;ETREJUST;80140;80;SOMME;1
80298;;Étricourt-Manancourt;ETRICOURT-MANANCOURT;80360;80;SOMME;1
80299;La;Faloise;FALOISE;80250;80;SOMME;1
80300;;Falvy;FALVY;80190;80;SOMME;1
80301;;Famechon;FAMECHON;80290;80;SOMME;1
80302;;Faverolles;FAVEROLLES;80500;80;SOMME;1
80303;;Favières;FAVIERES;80120;80;SOMME;1
80304;;Fay;FAY;80200;80;SOMME;1
80305;;Ferrières;FERRIERES;80470;80;SOMME;1
80306;;Fescamps;FESCAMPS;80500;80;SOMME;1
80307;;Feuillères;FEUILLERES;80200;80;SOMME;1
80308;;Feuquières-en-Vimeu;FEUQUIERES-EN-VIMEU;80210;80;SOMME;1
80310;;Fienvillers;FIENVILLERS;80750;80;SOMME;1
80311;;Fignières;FIGNIERES;80500;80;SOMME;1
80312;;Fins;FINS;80360;80;SOMME;1
80313;;Flaucourt;FLAUCOURT;80200;80;SOMME;1
80314;;Flers;FLERS;80360;80;SOMME;1
80315;;Flers-sur-Noye;FLERS-SUR-NOYE;80160;80;SOMME;1
80316;;Flesselles;FLESSELLES;80260;80;SOMME;1
80317;;Fleury;FLEURY;80160;80;SOMME;1
80318;;Flixecourt;FLIXECOURT;80420;80;SOMME;1
80319;;Fluy;FLUY;80540;80;SOMME;1
80320;;Folies;FOLIES;80170;80;SOMME;1
80321;;Folleville;FOLLEVILLE;80250;80;SOMME;1
80322;;Fonches-Fonchette;FONCHES-FONCHETTE;80700;80;SOMME;1
80324;;Fontaine-le-Sec;FONTAINE-LE-SEC;80140;80;SOMME;1
80325;;Fontaine-lès-Cappy;FONTAINE-LES-CAPPY;80340;80;SOMME;1
80326;;Fontaine-sous-Montdidier;FONTAINE-SOUS-MONTDIDIER;80500;80;SOMME;1
80327;;Fontaine-sur-Maye;FONTAINE-SUR-MAYE;80150;80;SOMME;1
80328;;Fontaine-sur-Somme;FONTAINE-SUR-SOMME;80510;80;SOMME;1
80329;;Forceville;FORCEVILLE;80560;80;SOMME;1
80330;;Forceville-en-Vimeu;FORCEVILLE-EN-VIMEU;80140;80;SOMME;1
80331;;Forest-l'Abbaye;FOREST-L'ABBAYE;80150;80;SOMME;1
80332;;Forest-Montiers;FOREST-MONTIERS;80120;80;SOMME;1
80333;;Fort-Mahon-Plage;FORT-MAHON-PLAGE;80790;80;SOMME;1
80334;;Fossemanant;FOSSEMANANT;80160;80;SOMME;1
80335;;Foucaucourt-en-Santerre;FOUCAUCOURT-EN-SANTERRE;80340;80;SOMME;1
80336;;Foucaucourt-Hors-Nesle;FOUCAUCOURT-HORS-NESLE;80140;80;SOMME;1
80337;;Fouencamps;FOUENCAMPS;80440;80;SOMME;1
80338;;Fouilloy;FOUILLOY;80800;80;SOMME;1
80339;;Fouquescourt;FOUQUESCOURT;80170;80;SOMME;1
80340;;Fourcigny;FOURCIGNY;80590;80;SOMME;1
80341;;Fourdrinoy;FOURDRINOY;80310;80;SOMME;1
80342;;Framerville-Rainecourt;FRAMERVILLE-RAINECOURT;80131;80;SOMME;1
80343;;Framicourt;FRAMICOURT;80140;80;SOMME;1
80344;;Francières;FRANCIERES;80690;80;SOMME;1
80345;;Franleu;FRANLEU;80210;80;SOMME;1
80346;;Franqueville;FRANQUEVILLE;80620;80;SOMME;1
80347;;Fransart;FRANSART;80700;80;SOMME;1
80348;;Fransu;FRANSU;80620;80;SOMME;1
80349;;Fransures;FRANSURES;80160;80;SOMME;1
80350;;Franvillers;FRANVILLERS;80800;80;SOMME;1
80351;;Fréchencourt;FRECHENCOURT;80260;80;SOMME;1
80352;;Frémontiers;FREMONTIERS;80160;80;SOMME;1
80353;;Fresnes-Mazancourt;FRESNES-MAZANCOURT;80320;80;SOMME;1
80354;;Fresnes-Tilloloy;FRESNES-TILLOLOY;80140;80;SOMME;1
80355;;Fresneville;FRESNEVILLE;80140;80;SOMME;1
80356;;Fresnoy-Andainville;FRESNOY-ANDAINVILLE;80140;80;SOMME;1
80357;;Fresnoy-au-Val;FRESNOY-AU-VAL;80710;80;SOMME;1
80358;;Fresnoy-en-Chaussée;FRESNOY-EN-CHAUSSEE;80110;80;SOMME;1
80359;;Fresnoy-lès-Roye;FRESNOY-LES-ROYE;80700;80;SOMME;1
80360;;Fressenneville;FRESSENNEVILLE;80390;80;SOMME;1
80361;;Frettecuisse;FRETTECUISSE;80140;80;SOMME;1
80362;;Frettemeule;FRETTEMEULE;80220;80;SOMME;1
80364;;Friaucourt;FRIAUCOURT;80940;80;SOMME;1
80365;;Fricamps;FRICAMPS;80290;80;SOMME;1
80366;;Fricourt;FRICOURT;80300;80;SOMME;1
80367;;Frise;FRISE;80340;80;SOMME;1
80368;;Friville-Escarbotin;FRIVILLE-ESCARBOTIN;80130;80;SOMME;1
80369;;Frohen-sur-Authie;FROHEN-SUR-AUTHIE;80370;80;SOMME;1
80371;;Froyelles;FROYELLES;80150;80;SOMME;1
80372;;Frucourt;FRUCOURT;80490;80;SOMME;1
80373;;Gamaches;GAMACHES;80220;80;SOMME;1
80374;;Gapennes;GAPENNES;80150;80;SOMME;1
80375;;Gauville;GAUVILLE;80590;80;SOMME;1
80376;;Gentelles;GENTELLES;80380;80;SOMME;1
80377;;Gézaincourt;GEZAINCOURT;80600;80;SOMME;1
80378;;Ginchy;GINCHY;80360;80;SOMME;1
80379;;Glisy;GLISY;80440;80;SOMME;1
80380;;Gorenflos;GORENFLOS;80690;80;SOMME;1
80381;;Gorges;GORGES;80370;80;SOMME;1
80383;;Goyencourt;GOYENCOURT;80700;80;SOMME;1
80384;;Grandcourt;GRANDCOURT;80300;80;SOMME;1
80385;;Grand-Laviers;GRAND-LAVIERS;80132;80;SOMME;1
80386;;Gratibus;GRATIBUS;80500;80;SOMME;1
80387;;Grattepanche;GRATTEPANCHE;80680;80;SOMME;1
80388;;Grébault-Mesnil;GREBAULT-MESNIL;80140;80;SOMME;1
80389;;Grécourt;GRECOURT;80400;80;SOMME;1
80390;;Grivesnes;GRIVESNES;80250;80;SOMME;1
80391;;Grivillers;GRIVILLERS;80700;80;SOMME;1
80392;;Grouches-Luchuel;GROUCHES-LUCHUEL;80600;80;SOMME;1
80393;;Gruny;GRUNY;80700;80;SOMME;1
80395;;Guerbigny;GUERBIGNY;80500;80;SOMME;1
80396;;Gueschart;GUESCHART;80150;80;SOMME;1
80397;;Gueudecourt;GUEUDECOURT;80360;80;SOMME;1
80399;;Guignemicourt;GUIGNEMICOURT;80540;80;SOMME;1
80400;;Guillaucourt;GUILLAUCOURT;80170;80;SOMME;1
80401;;Guillemont;GUILLEMONT;80360;80;SOMME;1
80402;;Guizancourt;GUIZANCOURT;80290;80;SOMME;1
80403;;Guyencourt-sur-Noye;GUYENCOURT-SUR-NOYE;80250;80;SOMME;1
80404;;Guyencourt-Saulcourt;GUYENCOURT-SAULCOURT;80240;80;SOMME;1
80405;;Hailles;HAILLES;80110;80;SOMME;1
80406;;Hallencourt;HALLENCOURT;80490;80;SOMME;1
80407;;Hallivillers;HALLIVILLERS;80250;80;SOMME;1
80408;;Halloy-lès-Pernois;HALLOY-LES-PERNOIS;80670;80;SOMME;1
80409;;Hallu;HALLU;80320;80;SOMME;1
80410;;Ham;HAM;80400;80;SOMME;1
80411;Le;Hamel;HAMEL;80800;80;SOMME;1
80412;;Hamelet;HAMELET;80800;80;SOMME;1
80413;;Hancourt;HANCOURT;80240;80;SOMME;1
80414;;Hangard;HANGARD;80110;80;SOMME;1
80415;;Hangest-en-Santerre;HANGEST-EN-SANTERRE;80134;80;SOMME;1
80416;;Hangest-sur-Somme;HANGEST-SUR-SOMME;80310;80;SOMME;1
80417;;Harbonnières;HARBONNIERES;80131;80;SOMME;1
80418;;Hardecourt-aux-Bois;HARDECOURT-AUX-BOIS;80360;80;SOMME;1
80419;;Hargicourt;HARGICOURT;80500;80;SOMME;1
80420;;Harponville;HARPONVILLE;80560;80;SOMME;1
80421;;Hattencourt;HATTENCOURT;80700;80;SOMME;1
80422;;Hautvillers-Ouville;HAUTVILLERS-OUVILLE;80132;80;SOMME;1
80423;;Havernas;HAVERNAS;80670;80;SOMME;1
80424;;Hébécourt;HEBECOURT;80680;80;SOMME;1
80425;;Hédauville;HEDAUVILLE;80560;80;SOMME;1
80426;;Heilly;HEILLY;80113;80;SOMME;1
80427;;Hem-Hardinval;HEM-HARDINVAL;80600;80;SOMME;1
80428;;Hem-Monacu;HEM-MONACU;80360;80;SOMME;1
80429;;Hénencourt;HENENCOURT;80300;80;SOMME;1
80430;;Herbécourt;HERBECOURT;80200;80;SOMME;1
80431;;Hérissart;HERISSART;80260;80;SOMME;1
80432;;Herleville;HERLEVILLE;80340;80;SOMME;1
80433;;Herly;HERLY;80190;80;SOMME;1
80434;;Hervilly;HERVILLY;80240;80;SOMME;1
80435;;Hesbécourt;HESBECOURT;80240;80;SOMME;1
80436;;Hescamps;HESCAMPS;80290;80;SOMME;1
80437;;Heucourt-Croquoison;HEUCOURT-CROQUOISON;80270;80;SOMME;1
80438;;Heudicourt;HEUDICOURT;80122;80;SOMME;1
80439;;Heuzecourt;HEUZECOURT;80370;80;SOMME;1
80440;;Hiermont;HIERMONT;80370;80;SOMME;1
80442;;Hombleux;HOMBLEUX;80400;80;SOMME;1
80443;;Hornoy-le-Bourg;HORNOY-LE-BOURG;80640;80;SOMME;1
80444;;Huchenneville;HUCHENNEVILLE;80132;80;SOMME;1
80445;;Humbercourt;HUMBERCOURT;80600;80;SOMME;1
80446;;Huppy;HUPPY;80140;80;SOMME;1
80447;;Hyencourt-le-Grand;HYENCOURT-LE-GRAND;80320;80;SOMME;1
80449;;Ignaucourt;IGNAUCOURT;80720;80;SOMME;1
80450;;Inval-Boiron;INVAL-BOIRON;80430;80;SOMME;1
80451;;Irles;IRLES;80300;80;SOMME;1
80452;;Jumel;JUMEL;80250;80;SOMME;1
80453;;Laboissière-en-Santerre;LABOISSIERE-EN-SANTERRE;80500;80;SOMME;1
80455;;Lachapelle;LACHAPELLE;80290;80;SOMME;1
80456;;Lafresguimont-Saint-Martin;LAFRESGUIMONT-SAINT-MARTIN;80430;80;SOMME;1
80458;;Lahoussoye;LAHOUSSOYE;80800;80;SOMME;1
80459;;Laleu;LALEU;80270;80;SOMME;1
80460;;Lamaronde;LAMARONDE;80590;80;SOMME;1
80461;;Lamotte-Brebière;LAMOTTE-BREBIERE;80450;80;SOMME;1
80462;;Lamotte-Buleux;LAMOTTE-BULEUX;80150;80;SOMME;1
80463;;Lamotte-Warfusée;LAMOTTE-WARFUSEE;80720;80;SOMME;1
80464;;Lanchères;LANCHERES;80230;80;SOMME;1
80465;;Languevoisin-Quiquery;LANGUEVOISIN-QUIQUERY;80190;80;SOMME;1
80466;;Lanches-Saint-Hilaire;LANCHES-SAINT-HILAIRE;80620;80;SOMME;1
80467;;Laucourt;LAUCOURT;80700;80;SOMME;1
80468;;Laviéville;LAVIEVILLE;80300;80;SOMME;1
80469;;Lawarde-Mauger-l'Hortoy;LAWARDE-MAUGER-L'HORTOY;80250;80;SOMME;1
80470;;Léalvillers;LEALVILLERS;80560;80;SOMME;1
80472;;Lesbœufs;LESBOEUFS;80360;80;SOMME;1
80473;;Liancourt-Fosse;LIANCOURT-FOSSE;80700;80;SOMME;1
80474;;Licourt;LICOURT;80320;80;SOMME;1
80475;;Liéramont;LIERAMONT;80240;80;SOMME;1
80476;;Liercourt;LIERCOURT;80580;80;SOMME;1
80477;;Ligescourt;LIGESCOURT;80150;80;SOMME;1
80478;;Lignières;LIGNIERES;80500;80;SOMME;1
80479;;Lignières-Châtelain;LIGNIERES-CHATELAIN;80590;80;SOMME;1
80480;;Lignières-en-Vimeu;LIGNIERES-EN-VIMEU;80140;80;SOMME;1
80481;;Lihons;LIHONS;80320;80;SOMME;1
80482;;Limeux;LIMEUX;80490;80;SOMME;1
80484;;Liomer;LIOMER;80430;80;SOMME;1
80485;;Lœuilly;LOEUILLY;80160;80;SOMME;1
80486;;Long;LONG;80510;80;SOMME;1
80487;;Longavesnes;LONGAVESNES;80240;80;SOMME;1
80488;;Longpré-les-Corps-Saints;LONGPRE-LES-CORPS-SAINTS;80510;80;SOMME;1
80489;;Longueau;LONGUEAU;80330;80;SOMME;1
80490;;Longueval;LONGUEVAL;80360;80;SOMME;1
80491;;Longuevillette;LONGUEVILLETTE;80600;80;SOMME;1
80493;;Louvencourt;LOUVENCOURT;80560;80;SOMME;1
80494;;Louvrechy;LOUVRECHY;80250;80;SOMME;1
80495;;Lucheux;LUCHEUX;80600;80;SOMME;1
80496;;Machiel;MACHIEL;80150;80;SOMME;1
80497;;Machy;MACHY;80150;80;SOMME;1
80498;;Mailly-Maillet;MAILLY-MAILLET;80560;80;SOMME;1
80499;;Mailly-Raineval;MAILLY-RAINEVAL;80110;80;SOMME;1
80500;;Maisnières;MAISNIERES;80220;80;SOMME;1
80501;;Maison-Ponthieu;MAISON-PONTHIEU;80150;80;SOMME;1
80502;;Maison-Roland;MAISON-ROLAND;80135;80;SOMME;1
80503;;Maizicourt;MAIZICOURT;80370;80;SOMME;1
80504;;Malpart;MALPART;80250;80;SOMME;1
80505;;Mametz;MAMETZ;80300;80;SOMME;1
80507;;Marcelcave;MARCELCAVE;80720;80;SOMME;1
80508;;Marché-Allouarde;MARCHE-ALLOUARDE;80700;80;SOMME;1
80509;;Marchélepot;MARCHELEPOT;80200;80;SOMME;1
80511;;Marestmontiers;MARESTMONTIERS;80500;80;SOMME;1
80512;;Mareuil-Caubert;MAREUIL-CAUBERT;80132;80;SOMME;1
80513;;Maricourt;MARICOURT;80360;80;SOMME;1
80514;;Marieux;MARIEUX;80560;80;SOMME;1
80515;;Marlers;MARLERS;80590;80;SOMME;1
80516;;Marquaix;MARQUAIX;80240;80;SOMME;1
80517;;Marquivillers;MARQUIVILLERS;80700;80;SOMME;1
80518;;Martainneville;MARTAINNEVILLE;80140;80;SOMME;1
80519;;Matigny;MATIGNY;80400;80;SOMME;1
80520;;Maucourt;MAUCOURT;80170;80;SOMME;1
80521;;Maurepas;MAUREPAS;80360;80;SOMME;1
80522;Le;Mazis;MAZIS;80430;80;SOMME;1
80523;;Méaulte;MEAULTE;80810;80;SOMME;1
80524;;Méharicourt;MEHARICOURT;80170;80;SOMME;1
80525;;Meigneux;MEIGNEUX;80590;80;SOMME;1
80526;Le;Meillard;MEILLARD;80370;80;SOMME;1
80527;;Méneslies;MENESLIES;80520;80;SOMME;1
80528;;Méréaucourt;MEREAUCOURT;80290;80;SOMME;1
80529;;Mérélessart;MERELESSART;80490;80;SOMME;1
80530;;Méricourt-l'Abbé;MERICOURT-L'ABBE;80113;80;SOMME;1
80531;;Méricourt-en-Vimeu;MERICOURT-EN-VIMEU;80640;80;SOMME;1
80532;;Méricourt-sur-Somme;MERICOURT-SUR-SOMME;80340;80;SOMME;1
80533;;Mers-les-Bains;MERS-LES-BAINS;80350;80;SOMME;1
80535;Le;Mesge;MESGE;80310;80;SOMME;1
80536;;Mesnil-Bruntel;MESNIL-BRUNTEL;80200;80;SOMME;1
80537;;Mesnil-Domqueur;MESNIL-DOMQUEUR;80620;80;SOMME;1
80538;;Mesnil-en-Arrouaise;MESNIL-EN-ARROUAISE;80360;80;SOMME;1
80540;;Mesnil-Martinsart;MESNIL-MARTINSART;80300;80;SOMME;1
80541;;Mesnil-Saint-Georges;MESNIL-SAINT-GEORGES;80500;80;SOMME;1
80542;;Mesnil-Saint-Nicaise;MESNIL-SAINT-NICAISE;80190;80;SOMME;1
80543;;Métigny;METIGNY;80270;80;SOMME;1
80544;;Mézerolles;MEZEROLLES;80600;80;SOMME;1
80545;;Mézières-en-Santerre;MEZIERES-EN-SANTERRE;80110;80;SOMME;1
80546;;Miannay;MIANNAY;80132;80;SOMME;1
80547;;Millencourt;MILLENCOURT;80300;80;SOMME;1
80548;;Millencourt-en-Ponthieu;MILLENCOURT-EN-PONTHIEU;80135;80;SOMME;1
80549;;Miraumont;MIRAUMONT;80300;80;SOMME;1
80550;;Mirvaux;MIRVAUX;80260;80;SOMME;1
80551;;Misery;MISERY;80320;80;SOMME;1
80552;;Moislains;MOISLAINS;80760;80;SOMME;1
80553;;Molliens-au-Bois;MOLLIENS-AU-BOIS;80260;80;SOMME;1
80554;;Molliens-Dreuil;MOLLIENS-DREUIL;80540;80;SOMME;1
80555;;Monchy-Lagache;MONCHY-LAGACHE;80200;80;SOMME;1
80556;;Mons-Boubert;MONS-BOUBERT;80210;80;SOMME;1
80557;;Estrées-Mons;ESTREES-MONS;80200;80;SOMME;1
80558;;Monsures;MONSURES;80160;80;SOMME;1
80559;;Montagne-Fayel;MONTAGNE-FAYEL;80540;80;SOMME;1
80560;;Montauban-de-Picardie;MONTAUBAN-DE-PICARDIE;80300;80;SOMME;1
80561;;Montdidier;MONTDIDIER;80500;80;SOMME;1
80562;;Montigny-sur-l'Hallue;MONTIGNY-SUR-L'HALLUE;80260;80;SOMME;1
80563;;Montigny-les-Jongleurs;MONTIGNY-LES-JONGLEURS;80370;80;SOMME;1
80565;;Montonvillers;MONTONVILLERS;80260;80;SOMME;1
80566;;Fieffes-Montrelet;FIEFFES-MONTRELET;80670;80;SOMME;1
80568;;Morchain;MORCHAIN;80190;80;SOMME;1
80569;;Morcourt;MORCOURT;80340;80;SOMME;1
80570;;Moreuil;MOREUIL;80110;80;SOMME;1
80571;;Morisel;MORISEL;80110;80;SOMME;1
80572;;Morlancourt;MORLANCOURT;80300;80;SOMME;1
80573;;Morvillers-Saint-Saturnin;MORVILLERS-SAINT-SATURNIN;80590;80;SOMME;1
80574;;Mouflers;MOUFLERS;80690;80;SOMME;1
80575;;Mouflières;MOUFLIERES;80140;80;SOMME;1
80576;;Moyencourt;MOYENCOURT;80400;80;SOMME;1
80577;;Moyencourt-lès-Poix;MOYENCOURT-LES-POIX;80290;80;SOMME;1
80578;;Moyenneville;MOYENNEVILLE;80870;80;SOMME;1
80579;;Muille-Villette;MUILLE-VILLETTE;80400;80;SOMME;1
80580;;Nampont;NAMPONT;80120;80;SOMME;1
80582;;Namps-Maisnil;NAMPS-MAISNIL;80710;80;SOMME;1
80583;;Nampty;NAMPTY;80160;80;SOMME;1
80584;;Naours;NAOURS;80260;80;SOMME;1
80585;;Nesle;NESLE;80190;80;SOMME;1
80586;;Nesle-l'Hôpital;NESLE-L'HOPITAL;80140;80;SOMME;1
80587;;Neslette;NESLETTE;80140;80;SOMME;1
80588;;Neufmoulin;NEUFMOULIN;80132;80;SOMME;1
80589;;Neuilly-le-Dien;NEUILLY-LE-DIEN;80150;80;SOMME;1
80590;;Neuilly-l'Hôpital;NEUILLY-L'HOPITAL;80132;80;SOMME;1
80591;;Neuville-au-Bois;NEUVILLE-AU-BOIS;80140;80;SOMME;1
80592;;Neuville-Coppegueule;NEUVILLE-COPPEGUEULE;80430;80;SOMME;1
80593;La;Neuville-lès-Bray;NEUVILLE-LES-BRAY;80340;80;SOMME;1
80594;;Neuville-lès-Lœuilly;NEUVILLE-LES-LOEUILLY;80160;80;SOMME;1
80595;La;Neuville-Sire-Bernard;NEUVILLE-SIRE-BERNARD;80110;80;SOMME;1
80596;;Neuvillette;NEUVILLETTE;80600;80;SOMME;1
80597;;Nibas;NIBAS;80390;80;SOMME;1
80598;;Nouvion;NOUVION;80860;80;SOMME;1
80599;;Noyelles-en-Chaussée;NOYELLES-EN-CHAUSSEE;80150;80;SOMME;1
80600;;Noyelles-sur-Mer;NOYELLES-SUR-MER;80860;80;SOMME;1
80601;;Nurlu;NURLU;80240;80;SOMME;1
80602;;Occoches;OCCOCHES;80600;80;SOMME;1
80603;;Ochancourt;OCHANCOURT;80210;80;SOMME;1
80604;;Offignies;OFFIGNIES;80590;80;SOMME;1
80605;;Offoy;OFFOY;80400;80;SOMME;1
80606;;Oisemont;OISEMONT;80140;80;SOMME;1
80607;;Oissy;OISSY;80540;80;SOMME;1
80608;;Omiécourt;OMIECOURT;80320;80;SOMME;1
80609;;Oneux;ONEUX;80135;80;SOMME;1
80611;;Oresmaux;ORESMAUX;80160;80;SOMME;1
80613;;Oust-Marest;OUST-MAREST;80460;80;SOMME;1
80614;;Outrebois;OUTREBOIS;80600;80;SOMME;1
80615;;Ovillers-la-Boisselle;OVILLERS-LA-BOISSELLE;80300;80;SOMME;1
80616;;Pargny;PARGNY;80190;80;SOMME;1
80617;;Parvillers-le-Quesnoy;PARVILLERS-LE-QUESNOY;80700;80;SOMME;1
80618;;Pendé;PENDE;80230;80;SOMME;1
80619;;Pernois;PERNOIS;80670;80;SOMME;1
80620;;Péronne;PERONNE;80200;80;SOMME;1
80621;;Pertain;PERTAIN;80320;80;SOMME;1
80622;;Picquigny;PICQUIGNY;80310;80;SOMME;1
80623;;Piennes-Onvillers;PIENNES-ONVILLERS;80500;80;SOMME;1
80624;;Pierregot;PIERREGOT;80260;80;SOMME;1
80625;;Pierrepont-sur-Avre;PIERREPONT-SUR-AVRE;80500;80;SOMME;1
80626;;Pissy;PISSY;80540;80;SOMME;1
80627;;Plachy-Buyon;PLACHY-BUYON;80160;80;SOMME;1
80628;Le;Plessier-Rozainvillers;PLESSIER-ROZAINVILLERS;80110;80;SOMME;1
80629;;Pœuilly;POEUILLY;80240;80;SOMME;1
80630;;Poix-de-Picardie;POIX-DE-PICARDIE;80290;80;SOMME;1
80631;;Ponches-Estruval;PONCHES-ESTRUVAL;80150;80;SOMME;1
80632;;Pont-de-Metz;PONT-DE-METZ;80480;80;SOMME;1
80633;;Ponthoile;PONTHOILE;80860;80;SOMME;1
80634;;Pont-Noyelles;PONT-NOYELLES;80115;80;SOMME;1
80635;;Pont-Remy;PONT-REMY;80580;80;SOMME;1
80637;;Port-le-Grand;PORT-LE-GRAND;80132;80;SOMME;1
80638;;Potte;POTTE;80190;80;SOMME;1
80639;;Poulainville;POULAINVILLE;80260;80;SOMME;1
80640;;Pozières;POZIERES;80300;80;SOMME;1
80642;;Prouville;PROUVILLE;80370;80;SOMME;1
80643;;Prouzel;PROUZEL;80160;80;SOMME;1
80644;;Proyart;PROYART;80121;80;SOMME;1
80645;;Puchevillers;PUCHEVILLERS;80560;80;SOMME;1
80646;;Punchy;PUNCHY;80320;80;SOMME;1
80647;;Puzeaux;PUZEAUX;80320;80;SOMME;1
80648;;Pys;PYS;80300;80;SOMME;1
80649;;Quend;QUEND;80120;80;SOMME;1
80650;;Querrieu;QUERRIEU;80115;80;SOMME;1
80651;Le;Quesne;QUESNE;80430;80;SOMME;1
80652;Le;Quesnel;QUESNEL;80118;80;SOMME;1
80654;;Quesnoy-le-Montant;QUESNOY-LE-MONTANT;80132;80;SOMME;1
80655;;Quesnoy-sur-Airaines;QUESNOY-SUR-AIRAINES;80270;80;SOMME;1
80656;;Quevauvillers;QUEVAUVILLERS;80710;80;SOMME;1
80657;;Quiry-le-Sec;QUIRY-LE-SEC;80250;80;SOMME;1
80658;;Quivières;QUIVIERES;80400;80;SOMME;1
80659;;Raincheval;RAINCHEVAL;80600;80;SOMME;1
80661;;Rainneville;RAINNEVILLE;80260;80;SOMME;1
80662;;Ramburelles;RAMBURELLES;80140;80;SOMME;1
80663;;Rambures;RAMBURES;80140;80;SOMME;1
80664;;Rancourt;RANCOURT;80360;80;SOMME;1
80665;;Regnière-Écluse;REGNIERE-ECLUSE;80120;80;SOMME;1
80666;;Remaisnil;REMAISNIL;80600;80;SOMME;1
80667;;Remaugies;REMAUGIES;80500;80;SOMME;1
80668;;Remiencourt;REMIENCOURT;80250;80;SOMME;1
80669;;Rethonvillers;RETHONVILLERS;80700;80;SOMME;1
80670;;Revelles;REVELLES;80540;80;SOMME;1
80671;;Ribeaucourt;RIBEAUCOURT;80620;80;SOMME;1
80672;;Ribemont-sur-Ancre;RIBEMONT-SUR-ANCRE;80113;80;SOMME;1
80673;;Riencourt;RIENCOURT;80310;80;SOMME;1
80674;;Rivery;RIVERY;80136;80;SOMME;1
80675;;Rogy;ROGY;80160;80;SOMME;1
80676;;Roiglise;ROIGLISE;80700;80;SOMME;1
80677;;Roisel;ROISEL;80240;80;SOMME;1
80678;;Rollot;ROLLOT;80500;80;SOMME;1
80679;;Ronssoy;RONSSOY;80740;80;SOMME;1
80680;;Rosières-en-Santerre;ROSIERES-EN-SANTERRE;80170;80;SOMME;1
80681;;Rouvrel;ROUVREL;80250;80;SOMME;1
80682;;Rouvroy-en-Santerre;ROUVROY-EN-SANTERRE;80170;80;SOMME;1
80683;;Rouy-le-Grand;ROUY-LE-GRAND;80190;80;SOMME;1
80684;;Rouy-le-Petit;ROUY-LE-PETIT;80190;80;SOMME;1
80685;;Roye;ROYE;80700;80;SOMME;1
80686;;Rubempré;RUBEMPRE;80260;80;SOMME;1
80687;;Rubescourt;RUBESCOURT;80500;80;SOMME;1
80688;;Rue;RUE;80120;80;SOMME;1
80690;;Rumigny;RUMIGNY;80680;80;SOMME;1
80691;;Saigneville;SAIGNEVILLE;80230;80;SOMME;1
80692;;Sailly-Flibeaucourt;SAILLY-FLIBEAUCOURT;80970;80;SOMME;1
80693;;Sailly-Laurette;SAILLY-LAURETTE;80800;80;SOMME;1
80694;;Sailly-le-Sec;SAILLY-LE-SEC;80800;80;SOMME;1
80695;;Sailly-Saillisel;SAILLY-SAILLISEL;80360;80;SOMME;1
80696;;Sains-en-Amiénois;SAINS-EN-AMIENOIS;80680;80;SOMME;1
80697;;Saint-Acheul;SAINT-ACHEUL;80370;80;SOMME;1
80698;;Saint-Aubin-Montenoy;SAINT-AUBIN-MONTENOY;80540;80;SOMME;1
80699;;Saint-Aubin-Rivière;SAINT-AUBIN-RIVIERE;80430;80;SOMME;1
80700;;Saint-Blimont;SAINT-BLIMONT;80960;80;SOMME;1
80701;;Saint-Christ-Briost;SAINT-CHRIST-BRIOST;80200;80;SOMME;1
80702;;Saint-Fuscien;SAINT-FUSCIEN;80680;80;SOMME;1
80703;;Saint-Germain-sur-Bresle;SAINT-GERMAIN-SUR-BRESLE;80430;80;SOMME;1
80704;;Saint-Gratien;SAINT-GRATIEN;80260;80;SOMME;1
80705;;Saint-Léger-lès-Authie;SAINT-LEGER-LES-AUTHIE;80560;80;SOMME;1
80706;;Saint-Léger-lès-Domart;SAINT-LEGER-LES-DOMART;80780;80;SOMME;1
80707;;Saint-Léger-sur-Bresle;SAINT-LEGER-SUR-BRESLE;80140;80;SOMME;1
80708;;Saint-Mard;SAINT-MARD;80700;80;SOMME;1
80709;;Saint-Maulvis;SAINT-MAULVIS;80140;80;SOMME;1
80710;;Saint-Maxent;SAINT-MAXENT;80140;80;SOMME;1
80711;;Saint-Ouen;SAINT-OUEN;80610;80;SOMME;1
80713;;Saint-Quentin-en-Tourmont;SAINT-QUENTIN-EN-TOURMONT;80120;80;SOMME;1
80714;;Saint-Quentin-la-Motte-Croix-au-Bailly;SAINT-QUENTIN-LA-MOTTE-CROIX-AU-BAILLY;80880;80;SOMME;1
80716;;Saint-Riquier;SAINT-RIQUIER;80135;80;SOMME;1
80717;;Saint-Sauflieu;SAINT-SAUFLIEU;80160;80;SOMME;1
80718;;Saint-Sauveur;SAINT-SAUVEUR;80470;80;SOMME;1
80719;;Sainte-Segrée;SAINTE-SEGREE;80290;80;SOMME;1
80721;;Saint-Valery-sur-Somme;SAINT-VALERY-SUR-SOMME;80230;80;SOMME;1
80722;;Saint-Vaast-en-Chaussée;SAINT-VAAST-EN-CHAUSSEE;80310;80;SOMME;1
80723;;Saisseval;SAISSEVAL;80540;80;SOMME;1
80724;;Saleux;SALEUX;80480;80;SOMME;1
80725;;Salouël;SALOUEL;80480;80;SOMME;1
80726;;Sancourt;SANCOURT;80400;80;SOMME;1
80728;;Saulchoy-sous-Poix;SAULCHOY-SOUS-POIX;80290;80;SOMME;1
80729;;Sauvillers-Mongival;SAUVILLERS-MONGIVAL;80110;80;SOMME;1
80730;;Saveuse;SAVEUSE;80730;80;SOMME;1
80732;;Senarpont;SENARPONT;80140;80;SOMME;1
80733;;Senlis-le-Sec;SENLIS-LE-SEC;80300;80;SOMME;1
80734;;Sentelie;SENTELIE;80160;80;SOMME;1
80735;;Seux;SEUX;80540;80;SOMME;1
80736;;Sorel-en-Vimeu;SOREL-EN-VIMEU;80490;80;SOMME;1
80737;;Sorel;SOREL;80240;80;SOMME;1
80738;;Soues;SOUES;80310;80;SOMME;1
80740;;Sourdon;SOURDON;80250;80;SOMME;1
80741;;Soyécourt;SOYECOURT;80200;80;SOMME;1
80742;;Surcamps;SURCAMPS;80620;80;SOMME;1
80743;;Suzanne;SUZANNE;80340;80;SOMME;1
80744;;Tailly;TAILLY;80270;80;SOMME;1
80746;;Talmas;TALMAS;80260;80;SOMME;1
80747;;Templeux-la-Fosse;TEMPLEUX-LA-FOSSE;80240;80;SOMME;1
80748;;Templeux-le-Guérard;TEMPLEUX-LE-GUERARD;80240;80;SOMME;1
80749;;Terramesnil;TERRAMESNIL;80600;80;SOMME;1
80750;;Tertry;TERTRY;80200;80;SOMME;1
80751;;Thennes;THENNES;80110;80;SOMME;1
80752;;Thézy-Glimont;THEZY-GLIMONT;80110;80;SOMME;1
80753;;Thiepval;THIEPVAL;80300;80;SOMME;1
80754;;Thieulloy-l'Abbaye;THIEULLOY-L'ABBAYE;80126;80;SOMME;1
80755;;Thieulloy-la-Ville;THIEULLOY-LA-VILLE;80290;80;SOMME;1
80756;;Thièvres;THIEVRES;62760;80;PAS DE CALAIS;1
80757;;Thoix;THOIX;80160;80;SOMME;1
80758;;Thory;THORY;80250;80;SOMME;1
80759;;Tilloloy;TILLOLOY;80700;80;SOMME;1
80760;;Tilloy-Floriville;TILLOY-FLORIVILLE;80220;80;SOMME;1
80761;;Tilloy-lès-Conty;TILLOY-LES-CONTY;80160;80;SOMME;1
80762;;Tincourt-Boucly;TINCOURT-BOUCLY;80240;80;SOMME;1
80763;Le;Titre;TITRE;80132;80;SOMME;1
80764;;Tœufles;TOEUFLES;80870;80;SOMME;1
80765;;Tours-en-Vimeu;TOURS-EN-VIMEU;80210;80;SOMME;1
80766;;Toutencourt;TOUTENCOURT;80560;80;SOMME;1
80767;Le;Translay;TRANSLAY;80140;80;SOMME;1
80769;;Treux;TREUX;80300;80;SOMME;1
80770;;Tully;TULLY;80530;80;SOMME;1
80771;;Ugny-l'Équipée;UGNY-L'EQUIPEE;80400;80;SOMME;1
80773;;Vadencourt;VADENCOURT;80560;80;SOMME;1
80774;;Vaire-sous-Corbie;VAIRE-SOUS-CORBIE;80800;80;SOMME;1
80775;;Valines;VALINES;80210;80;SOMME;1
80776;;Varennes;VARENNES;80560;80;SOMME;1
80777;;Vauchelles-lès-Authie;VAUCHELLES-LES-AUTHIE;80560;80;SOMME;1
80778;;Vauchelles-lès-Domart;VAUCHELLES-LES-DOMART;80620;80;SOMME;1
80779;;Vauchelles-les-Quesnoy;VAUCHELLES-LES-QUESNOY;80132;80;SOMME;1
80780;;Vaudricourt;VAUDRICOURT;80230;80;SOMME;1
80781;;Vauvillers;VAUVILLERS;80131;80;SOMME;1
80782;;Vaux-en-Amiénois;VAUX-EN-AMIENOIS;80260;80;SOMME;1
80783;;Vaux-Marquenneville;VAUX-MARQUENNEVILLE;80140;80;SOMME;1
80784;;Vaux-sur-Somme;VAUX-SUR-SOMME;80800;80;SOMME;1
80785;;Vecquemont;VECQUEMONT;80800;80;SOMME;1
80786;;Velennes;VELENNES;80160;80;SOMME;1
80787;;Vercourt;VERCOURT;80120;80;SOMME;1
80788;;Vergies;VERGIES;80270;80;SOMME;1
80789;;Vermandovillers;VERMANDOVILLERS;80320;80;SOMME;1
80790;;Verpillières;VERPILLIERES;80700;80;SOMME;1
80791;;Vers-sur-Selles;VERS-SUR-SELLES;80480;80;SOMME;1
80792;La;Vicogne;VICOGNE;80260;80;SOMME;1
80793;;Vignacourt;VIGNACOURT;80650;80;SOMME;1
80794;;Villecourt;VILLECOURT;80190;80;SOMME;1
80795;;Ville-le-Marclet;VILLE-LE-MARCLET;80420;80;SOMME;1
80796;;Villeroy;VILLEROY;80140;80;SOMME;1
80797;;Villers-aux-Érables;VILLERS-AUX-ERABLES;80110;80;SOMME;1
80798;;Villers-Bocage;VILLERS-BOCAGE;80260;80;SOMME;1
80799;;Villers-Bretonneux;VILLERS-BRETONNEUX;80380;80;SOMME;1
80800;;Villers-Campsart;VILLERS-CAMPSART;80140;80;SOMME;1
80801;;Villers-Carbonnel;VILLERS-CARBONNEL;80200;80;SOMME;1
80802;;Villers-Faucon;VILLERS-FAUCON;80112;80;SOMME;1
80803;;Villers-lès-Roye;VILLERS-LES-ROYE;80700;80;SOMME;1
80804;;Villers-sous-Ailly;VILLERS-SOUS-AILLY;80690;80;SOMME;1
80805;;Villers-Tournelle;VILLERS-TOURNELLE;80500;80;SOMME;1
80806;;Villers-sur-Authie;VILLERS-SUR-AUTHIE;80120;80;SOMME;1
80807;;Ville-sur-Ancre;VILLE-SUR-ANCRE;80300;80;SOMME;1
80808;;Vironchaux;VIRONCHAUX;80150;80;SOMME;1
80809;;Vismes;VISMES;80140;80;SOMME;1
80810;;Vitz-sur-Authie;VITZ-SUR-AUTHIE;80150;80;SOMME;1
80811;;Voyennes;VOYENNES;80400;80;SOMME;1
80812;;Vraignes-en-Vermandois;VRAIGNES-EN-VERMANDOIS;80240;80;SOMME;1
80813;;Vraignes-lès-Hornoy;VRAIGNES-LES-HORNOY;80640;80;SOMME;1
80814;;Vrély;VRELY;80170;80;SOMME;1
80815;;Vron;VRON;80120;80;SOMME;1
80819;;Wargnies;WARGNIES;80670;80;SOMME;1
80820;;Warloy-Baillon;WARLOY-BAILLON;80300;80;SOMME;1
80821;;Warlus;WARLUS;80270;80;SOMME;1
80822;;Warsy;WARSY;80500;80;SOMME;1
80823;;Warvillers;WARVILLERS;80170;80;SOMME;1
80824;;Wiencourt-l'Équipée;WIENCOURT-L'EQUIPEE;80170;80;SOMME;1
80825;;Wiry-au-Mont;WIRY-AU-MONT;80270;80;SOMME;1
80826;;Woignarue;WOIGNARUE;80460;80;SOMME;1
80827;;Woincourt;WOINCOURT;80520;80;SOMME;1
80828;;Woirel;WOIREL;80140;80;SOMME;1
80829;;Y;Y;80190;80;SOMME;1
80830;;Yaucourt-Bussus;YAUCOURT-BUSSUS;80135;80;SOMME;1
80832;;Yvrench;YVRENCH;80150;80;SOMME;1
80833;;Yvrencheux;YVRENCHEUX;80150;80;SOMME;1
80834;;Yzengremer;YZENGREMER;80520;80;SOMME;1
80835;;Yzeux;YZEUX;80310;80;SOMME;1
80836;;Yonval;YONVAL;80132;80;SOMME;1
81001;;Aguts;AGUTS;81470;81;TARN;1
81002;;Aiguefonde;AIGUEFONDE;81200;81;TARN;1
81003;;Alban;ALBAN;81250;81;TARN;1
81004;;Albi;ALBI;81000;81;TARN;1
81005;;Albine;ALBINE;81240;81;TARN;1
81006;;Algans;ALGANS;81470;81;TARN;1
81007;;Alos;ALOS;81140;81;TARN;1
81008;;Almayrac;ALMAYRAC;81190;81;TARN;1
81009;;Amarens;AMARENS;81170;81;TARN;1
81010;;Ambialet;AMBIALET;81430;81;TARN;1
81011;;Ambres;AMBRES;81500;81;TARN;1
81012;;Andillac;ANDILLAC;81140;81;TARN;1
81013;;Andouque;ANDOUQUE;81350;81;TARN;1
81014;;Anglès;ANGLES;81260;81;TARN;1
81015;;Appelle;APPELLE;81700;81;TARN;1
81016;;Arfons;ARFONS;81110;81;TARN;1
81017;;Arifat;ARIFAT;81360;81;TARN;1
81018;;Arthès;ARTHES;81160;81;TARN;1
81019;;Assac;ASSAC;81340;81;TARN;1
81020;;Aussac;AUSSAC;81600;81;TARN;1
81021;;Aussillon;AUSSILLON;81200;81;TARN;1
81022;;Bannières;BANNIERES;81500;81;TARN;1
81023;;Barre;BARRE;81320;81;TARN;1
81024;;Beauvais-sur-Tescou;BEAUVAIS-SUR-TESCOU;81630;81;TARN;1
81025;;Belcastel;BELCASTEL;81500;81;TARN;1
81026;;Bellegarde;BELLEGARDE;81430;81;TARN;1
81027;;Belleserre;BELLESERRE;81540;81;TARN;1
81028;;Berlats;BERLATS;81260;81;TARN;1
81029;;Bernac;BERNAC;81150;81;TARN;1
81030;;Bertre;BERTRE;81700;81;TARN;1
81031;Le;Bez;BEZ;81260;81;TARN;1
81032;;Blan;BLAN;81700;81;TARN;1
81033;;Blaye-les-Mines;BLAYE-LES-MINES;81400;81;TARN;1
81034;;Boissezon;BOISSEZON;81490;81;TARN;1
81035;;Bournazel;BOURNAZEL;81170;81;TARN;1
81036;;Bout-du-Pont-de-Larn;BOUT-DU-PONT-DE-LARN;81660;81;TARN;1
81037;;Brassac;BRASSAC;81260;81;TARN;1
81038;;Brens;BRENS;81600;81;TARN;1
81039;;Briatexte;BRIATEXTE;81390;81;TARN;1
81040;;Brousse;BROUSSE;81440;81;TARN;1
81041;;Broze;BROZE;81600;81;TARN;1
81042;;Burlats;BURLATS;81100;81;TARN;1
81043;;Busque;BUSQUE;81300;81;TARN;1
81044;;Cabanès;CABANES;81500;81;TARN;1
81045;Les;Cabannes;CABANNES;81170;81;TARN;1
81046;;Cadalen;CADALEN;81600;81;TARN;1
81047;;Cadix;CADIX;81340;81;TARN;1
81048;;Cagnac-les-Mines;CAGNAC-LES-MINES;81130;81;TARN;1
81049;;Cahuzac;CAHUZAC;81540;81;TARN;1
81050;;Cambon-lès-Lavaur;CAMBON-LES-LAVAUR;81470;81;TARN;1
81051;;Cahuzac-sur-Vère;CAHUZAC-SUR-VERE;81140;81;TARN;1
81052;;Cambon;CAMBON;81990;81;TARN;1
81053;;Cambounès;CAMBOUNES;81260;81;TARN;1
81054;;Cambounet-sur-le-Sor;CAMBOUNET-SUR-LE-SOR;81580;81;TARN;1
81055;Les;Cammazes;CAMMAZES;81540;81;TARN;1
81056;;Campagnac;CAMPAGNAC;81140;81;TARN;1
81058;;Carbes;CARBES;81570;81;TARN;1
81059;;Carlus;CARLUS;81990;81;TARN;1
81060;;Carmaux;CARMAUX;81400;81;TARN;1
81061;;Castanet;CASTANET;81150;81;TARN;1
81062;;Castelnau-de-Brassac;CASTELNAU-DE-BRASSAC;81260;81;TARN;1
81063;;Castelnau-de-Lévis;CASTELNAU-DE-LEVIS;81150;81;TARN;1
81064;;Castelnau-de-Montmiral;CASTELNAU-DE-MONTMIRAL;81140;81;TARN;1
81065;;Castres;CASTRES;81100;81;TARN;1
81066;;Caucalières;CAUCALIERES;81200;81;TARN;1
81067;;Cestayrols;CESTAYROLS;81150;81;TARN;1
81068;;Combefa;COMBEFA;81640;81;TARN;1
81069;;Cordes-sur-Ciel;CORDES-SUR-CIEL;81170;81;TARN;1
81070;;Coufouleux;COUFOULEUX;81800;81;TARN;1
81071;;Courris;COURRIS;81340;81;TARN;1
81072;;Crespin;CRESPIN;81350;81;TARN;1
81073;;Crespinet;CRESPINET;81350;81;TARN;1
81074;;Cunac;CUNAC;81990;81;TARN;1
81075;;Cuq;CUQ;81570;81;TARN;1
81076;;Cuq-Toulza;CUQ-TOULZA;81470;81;TARN;1
81077;;Curvalle;CURVALLE;81250;81;TARN;1
81078;;Damiatte;DAMIATTE;81220;81;TARN;1
81079;;Dénat;DENAT;81120;81;TARN;1
81080;;Donnazac;DONNAZAC;81170;81;TARN;1
81081;;Dourgne;DOURGNE;81110;81;TARN;1
81082;Le;Dourn;DOURN;81340;81;TARN;1
81083;;Durfort;DURFORT;81540;81;TARN;1
81084;;Escoussens;ESCOUSSENS;81290;81;TARN;1
81085;;Escroux;ESCROUX;81530;81;TARN;1
81086;;Espérausses;ESPERAUSSES;81260;81;TARN;1
81087;;Fayssac;FAYSSAC;81150;81;TARN;1
81088;;Fauch;FAUCH;81120;81;TARN;1
81089;;Faussergues;FAUSSERGUES;81340;81;TARN;1
81090;;Fénols;FENOLS;81600;81;TARN;1
81091;;Ferrières;FERRIERES;81260;81;TARN;1
81092;;Fiac;FIAC;81500;81;TARN;1
81093;;Florentin;FLORENTIN;81150;81;TARN;1
81094;;Fraissines;FRAISSINES;81340;81;TARN;1
81095;;Frausseilles;FRAUSSEILLES;81170;81;TARN;1
81096;Le;Fraysse;FRAYSSE;81430;81;TARN;1
81097;;Fréjairolles;FREJAIROLLES;81990;81;TARN;1
81098;;Fréjeville;FREJEVILLE;81570;81;TARN;1
81099;;Gaillac;GAILLAC;81600;81;TARN;1
81100;;Garrevaques;GARREVAQUES;81700;81;TARN;1
81101;Le;Garric;GARRIC;81450;81;TARN;1
81102;;Garrigues;GARRIGUES;81500;81;TARN;1
81103;;Gijounet;GIJOUNET;81530;81;TARN;1
81104;;Giroussens;GIROUSSENS;81500;81;TARN;1
81105;;Graulhet;GRAULHET;81300;81;TARN;1
81106;;Grazac;GRAZAC;81800;81;TARN;1
81108;;Itzac;ITZAC;81170;81;TARN;1
81109;;Jonquières;JONQUIERES;81440;81;TARN;1
81110;;Jouqueviel;JOUQUEVIEL;81190;81;TARN;1
81111;;Labarthe-Bleys;LABARTHE-BLEYS;81170;81;TARN;1
81112;;Labastide-de-Lévis;LABASTIDE-DE-LEVIS;81150;81;TARN;1
81113;;Labastide-Dénat;LABASTIDE-DENAT;81120;81;TARN;1
81114;;Labastide-Gabausse;LABASTIDE-GABAUSSE;81400;81;TARN;1
81115;;Labastide-Rouairoux;LABASTIDE-ROUAIROUX;81270;81;TARN;1
81116;;Labastide-Saint-Georges;LABASTIDE-SAINT-GEORGES;81500;81;TARN;1
81117;;Labessière-Candeil;LABESSIERE-CANDEIL;81300;81;TARN;1
81118;;Laboulbène;LABOULBENE;81100;81;TARN;1
81119;;Laboutarie;LABOUTARIE;81120;81;TARN;1
81120;;Labruguière;LABRUGUIERE;81290;81;TARN;1
81121;;Lacabarède;LACABAREDE;81240;81;TARN;1
81122;;Lacapelle-Pinet;LACAPELLE-PINET;81340;81;TARN;1
81123;;Lacapelle-Ségalar;LACAPELLE-SEGALAR;81170;81;TARN;1
81124;;Lacaune;LACAUNE;81230;81;TARN;1
81125;;Lacaze;LACAZE;81330;81;TARN;1
81126;;Lacougotte-Cadoul;LACOUGOTTE-CADOUL;81500;81;TARN;1
81127;;Lacroisille;LACROISILLE;81470;81;TARN;1
81128;;Lacrouzette;LACROUZETTE;81210;81;TARN;1
81129;;Lagardiolle;LAGARDIOLLE;81110;81;TARN;1
81130;;Lagarrigue;LAGARRIGUE;81090;81;TARN;1
81131;;Lagrave;LAGRAVE;81150;81;TARN;1
81132;;Guitalens-L'Albarède;GUITALENS-L'ALBAREDE;81220;81;TARN;1
81133;;Lamillarié;LAMILLARIE;81120;81;TARN;1
81134;;Lamontélarié;LAMONTELARIE;81260;81;TARN;1
81135;;Laparrouquial;LAPARROUQUIAL;81640;81;TARN;1
81136;;Larroque;LARROQUE;81140;81;TARN;1
81137;;Lasfaillades;LASFAILLADES;81260;81;TARN;1
81138;;Lasgraisses;LASGRAISSES;81300;81;TARN;1
81139;;Lautrec;LAUTREC;81440;81;TARN;1
81140;;Lavaur;LAVAUR;81500;81;TARN;1
81141;;Lédas-et-Penthiès;LEDAS-ET-PENTHIES;81340;81;TARN;1
81142;;Lempaut;LEMPAUT;81700;81;TARN;1
81143;;Lescout;LESCOUT;81110;81;TARN;1
81144;;Lescure-d'Albigeois;LESCURE-D'ALBIGEOIS;81380;81;TARN;1
81145;;Lisle-sur-Tarn;LISLE-SUR-TARN;81310;81;TARN;1
81146;;Livers-Cazelles;LIVERS-CAZELLES;81170;81;TARN;1
81147;;Lombers;LOMBERS;81120;81;TARN;1
81148;;Loubers;LOUBERS;81170;81;TARN;1
81149;;Loupiac;LOUPIAC;81800;81;TARN;1
81150;;Lugan;LUGAN;81500;81;TARN;1
81151;;Magrin;MAGRIN;81220;81;TARN;1
81152;;Mailhoc;MAILHOC;81130;81;TARN;1
81153;Le;Margnès;MARGNES;81260;81;TARN;1
81154;;Marnaves;MARNAVES;81170;81;TARN;1
81155;;Marsal;MARSAL;81430;81;TARN;1
81156;;Marssac-sur-Tarn;MARSSAC-SUR-TARN;81150;81;TARN;1
81157;;Marzens;MARZENS;81500;81;TARN;1
81158;Le;Masnau-Massuguiès;MASNAU-MASSUGUIES;81530;81;TARN;1
81159;;Massac-Séran;MASSAC-SERAN;81500;81;TARN;1
81160;;Massaguel;MASSAGUEL;81110;81;TARN;1
81161;;Massals;MASSALS;81250;81;TARN;1
81162;;Maurens-Scopont;MAURENS-SCOPONT;81470;81;TARN;1
81163;;Mazamet;MAZAMET;81200;81;TARN;1
81164;;Mézens;MEZENS;81800;81;TARN;1
81165;;Milhars;MILHARS;81170;81;TARN;1
81166;;Milhavet;MILHAVET;81130;81;TARN;1
81167;;Miolles;MIOLLES;81250;81;TARN;1
81168;;Mirandol-Bourgnounac;MIRANDOL-BOURGNOUNAC;81190;81;TARN;1
81169;;Missècle;MISSECLE;81300;81;TARN;1
81170;;Monestiés;MONESTIES;81640;81;TARN;1
81171;;Montans;MONTANS;81600;81;TARN;1
81172;;Montauriol;MONTAURIOL;81190;81;TARN;1
81173;;Montcabrier;MONTCABRIER;81500;81;TARN;1
81174;;Montdragon;MONTDRAGON;81440;81;TARN;1
81175;;Montdurausse;MONTDURAUSSE;81630;81;TARN;1
81176;;Montels;MONTELS;81140;81;TARN;1
81177;;Montfa;MONTFA;81210;81;TARN;1
81178;;Montgaillard;MONTGAILLARD;81800;81;TARN;1
81179;;Montgey;MONTGEY;81470;81;TARN;1
81180;;Montirat;MONTIRAT;81190;81;TARN;1
81181;;Montpinier;MONTPINIER;81440;81;TARN;1
81182;;Montredon-Labessonnié;MONTREDON-LABESSONNIE;81360;81;TARN;1
81183;;Mont-Roc;MONT-ROC;81120;81;TARN;1
81184;;Montrosier;MONTROSIER;81170;81;TARN;1
81185;;Montvalen;MONTVALEN;81630;81;TARN;1
81186;;Moularès;MOULARES;81190;81;TARN;1
81187;;Moulayrès;MOULAYRES;81300;81;TARN;1
81188;;Moulin-Mage;MOULIN-MAGE;81320;81;TARN;1
81189;;Mouzens;MOUZENS;81470;81;TARN;1
81190;;Mouzieys-Teulet;MOUZIEYS-TEULET;81430;81;TARN;1
81191;;Mouzieys-Panens;MOUZIEYS-PANENS;81170;81;TARN;1
81192;;Murat-sur-Vèbre;MURAT-SUR-VEBRE;81320;81;TARN;1
81193;;Nages;NAGES;81320;81;TARN;1
81195;;Navès;NAVES;81710;81;TARN;1
81196;;Noailhac;NOAILHAC;81490;81;TARN;1
81197;;Noailles;NOAILLES;81170;81;TARN;1
81198;;Orban;ORBAN;81120;81;TARN;1
81199;;Padiès;PADIES;81340;81;TARN;1
81200;;Palleville;PALLEVILLE;81700;81;TARN;1
81201;;Pampelonne;PAMPELONNE;81190;81;TARN;1
81202;;Parisot;PARISOT;81310;81;TARN;1
81203;;Paulinet;PAULINET;81250;81;TARN;1
81204;;Payrin-Augmontel;PAYRIN-AUGMONTEL;81660;81;TARN;1
81205;;Péchaudier;PECHAUDIER;81470;81;TARN;1
81206;;Penne;PENNE;81140;81;TARN;1
81207;;Peyregoux;PEYREGOUX;81440;81;TARN;1
81208;;Peyrole;PEYROLE;81310;81;TARN;1
81209;;Pont-de-Larn;PONT-DE-LARN;81660;81;TARN;1
81210;;Poudis;POUDIS;81700;81;TARN;1
81211;;Poulan-Pouzols;POULAN-POUZOLS;81120;81;TARN;1
81212;;Prades;PRADES;81220;81;TARN;1
81213;;Pratviel;PRATVIEL;81500;81;TARN;1
81214;;Puéchoursi;PUECHOURSI;81470;81;TARN;1
81215;;Puybegon;PUYBEGON;81390;81;TARN;1
81216;;Puycalvel;PUYCALVEL;81440;81;TARN;1
81217;;Puycelsi;PUYCELSI;81140;81;TARN;1
81218;;Puygouzon;PUYGOUZON;81990;81;TARN;1
81219;;Puylaurens;PUYLAURENS;81700;81;TARN;1
81220;;Rabastens;RABASTENS;81800;81;TARN;1
81221;;Rayssac;RAYSSAC;81330;81;TARN;1
81222;;Réalmont;REALMONT;81120;81;TARN;1
81223;Le;Rialet;RIALET;81240;81;TARN;1
81224;Le;Riols;RIOLS;81170;81;TARN;1
81225;;Rivières;RIVIERES;81600;81;TARN;1
81226;;Ronel;RONEL;81120;81;TARN;1
81227;;Roquecourbe;ROQUECOURBE;81210;81;TARN;1
81228;;Roquemaure;ROQUEMAURE;81800;81;TARN;1
81229;;Roquevidal;ROQUEVIDAL;81470;81;TARN;1
81230;;Rosières;ROSIERES;81400;81;TARN;1
81231;;Rouairoux;ROUAIROUX;81240;81;TARN;1
81232;;Rouffiac;ROUFFIAC;81150;81;TARN;1
81233;;Roumégoux;ROUMEGOUX;81120;81;TARN;1
81234;;Roussayrolles;ROUSSAYROLLES;81140;81;TARN;1
81235;;Saint-Affrique-les-Montagnes;SAINT-AFFRIQUE-LES-MONTAGNES;81290;81;TARN;1
81236;;Saint-Agnan;SAINT-AGNAN;81500;81;TARN;1
81237;;Saint-Amancet;SAINT-AMANCET;81110;81;TARN;1
81238;;Saint-Amans-Soult;SAINT-AMANS-SOULT;81240;81;TARN;1
81239;;Saint-Amans-Valtoret;SAINT-AMANS-VALTORET;81240;81;TARN;1
81240;;Saint-André;SAINT-ANDRE;81250;81;TARN;1
81241;;Saint-Antonin-de-Lacalm;SAINT-ANTONIN-DE-LACALM;81120;81;TARN;1
81242;;Saint-Avit;SAINT-AVIT;81110;81;TARN;1
81243;;Saint-Beauzile;SAINT-BEAUZILE;81140;81;TARN;1
81244;;Saint-Benoît-de-Carmaux;SAINT-BENOIT-DE-CARMAUX;81400;81;TARN;1
81245;;Saint-Christophe;SAINT-CHRISTOPHE;81190;81;TARN;1
81246;;Sainte-Cécile-du-Cayrou;SAINTE-CECILE-DU-CAYROU;81140;81;TARN;1
81247;;Saint-Cirgue;SAINT-CIRGUE;81340;81;TARN;1
81248;;Saint-Gauzens;SAINT-GAUZENS;81390;81;TARN;1
81249;;Sainte-Gemme;SAINTE-GEMME;81190;81;TARN;1
81250;;Saint-Genest-de-Contest;SAINT-GENEST-DE-CONTEST;81440;81;TARN;1
81251;;Saint-Germain-des-Prés;SAINT-GERMAIN-DES-PRES;81700;81;TARN;1
81252;;Saint-Germier;SAINT-GERMIER;81210;81;TARN;1
81253;;Saint-Grégoire;SAINT-GREGOIRE;81350;81;TARN;1
81254;;Saint-Jean-de-Marcel;SAINT-JEAN-DE-MARCEL;81350;81;TARN;1
81255;;Saint-Jean-de-Rives;SAINT-JEAN-DE-RIVES;81500;81;TARN;1
81256;;Saint-Jean-de-Vals;SAINT-JEAN-DE-VALS;81210;81;TARN;1
81257;;Saint-Juéry;SAINT-JUERY;81160;81;TARN;1
81258;;Saint-Julien-du-Puy;SAINT-JULIEN-DU-PUY;81440;81;TARN;1
81259;;Saint-Julien-Gaulène;SAINT-JULIEN-GAULENE;81340;81;TARN;1
81260;;Saint-Lieux-Lafenasse;SAINT-LIEUX-LAFENASSE;81120;81;TARN;1
81261;;Saint-Lieux-lès-Lavaur;SAINT-LIEUX-LES-LAVAUR;81500;81;TARN;1
81262;;Saint-Marcel-Campes;SAINT-MARCEL-CAMPES;81170;81;TARN;1
81263;;Saint-Martin-Laguépie;SAINT-MARTIN-LAGUEPIE;81170;81;TARN;1
81264;;Saint-Michel-Labadié;SAINT-MICHEL-LABADIE;81340;81;TARN;1
81265;;Saint-Michel-de-Vax;SAINT-MICHEL-DE-VAX;81140;81;TARN;1
81266;;Saint-Paul-Cap-de-Joux;SAINT-PAUL-CAP-DE-JOUX;81220;81;TARN;1
81267;;Saint-Pierre-de-Trivisy;SAINT-PIERRE-DE-TRIVISY;81330;81;TARN;1
81268;;Saint-Salvi-de-Carcavès;SAINT-SALVI-DE-CARCAVES;81530;81;TARN;1
81269;;Saint-Salvy-de-la-Balme;SAINT-SALVY-DE-LA-BALME;81490;81;TARN;1
81270;;Saint-Sernin-lès-Lavaur;SAINT-SERNIN-LES-LAVAUR;81700;81;TARN;1
81271;;Saint-Sulpice;SAINT-SULPICE;81370;81;TARN;1
81272;;Saint-Urcisse;SAINT-URCISSE;81630;81;TARN;1
81273;;Saïx;SAIX;81710;81;TARN;1
81274;;Saliès;SALIES;81990;81;TARN;1
81275;;Salles;SALLES;81640;81;TARN;1
81276;;Salvagnac;SALVAGNAC;81630;81;TARN;1
81277;;Saussenac;SAUSSENAC;81350;81;TARN;1
81278;;Sauveterre;SAUVETERRE;81240;81;TARN;1
81279;La;Sauzière-Saint-Jean;SAUZIERE-SAINT-JEAN;81630;81;TARN;1
81280;Le;Ségur;SEGUR;81640;81;TARN;1
81281;;Sémalens;SEMALENS;81570;81;TARN;1
81282;;Senaux;SENAUX;81530;81;TARN;1
81283;;Senouillac;SENOUILLAC;81600;81;TARN;1
81284;Le;Sequestre;SEQUESTRE;81990;81;TARN;1
81285;;Sérénac;SERENAC;81350;81;TARN;1
81286;;Serviès;SERVIES;81220;81;TARN;1
81287;;Sieurac;SIEURAC;81120;81;TARN;1
81288;;Sorèze;SOREZE;81540;81;TARN;1
81289;;Soual;SOUAL;81580;81;TARN;1
81290;;Souel;SOUEL;81170;81;TARN;1
81291;;Taïx;TAIX;81130;81;TARN;1
81292;;Tanus;TANUS;81190;81;TARN;1
81293;;Tauriac;TAURIAC;81630;81;TARN;1
81294;;Técou;TECOU;81600;81;TARN;1
81295;;Teillet;TEILLET;81120;81;TARN;1
81296;;Terre-Clapier;TERRE-CLAPIER;81120;81;TARN;1
81297;;Terssac;TERSSAC;81150;81;TARN;1
81298;;Teulat;TEULAT;81500;81;TARN;1
81299;;Teyssode;TEYSSODE;81220;81;TARN;1
81300;;Tonnac;TONNAC;81170;81;TARN;1
81301;Le;Travet;TRAVET;81120;81;TARN;1
81302;;Tréban;TREBAN;81190;81;TARN;1
81303;;Trébas;TREBAS;81340;81;TARN;1
81304;;Trévien;TREVIEN;81190;81;TARN;1
81305;;Vabre;VABRE;81330;81;TARN;1
81306;;Valderiès;VALDERIES;81350;81;TARN;1
81307;;Valdurenque;VALDURENQUE;81090;81;TARN;1
81308;;Valence-d'Albigeois;VALENCE-D'ALBIGEOIS;81340;81;TARN;1
81309;;Vaour;VAOUR;81140;81;TARN;1
81310;;Veilhes;VEILHES;81500;81;TARN;1
81311;;Vénès;VENES;81440;81;TARN;1
81312;;Verdalle;VERDALLE;81110;81;TARN;1
81313;Le;Verdier;VERDIER;81140;81;TARN;1
81314;;Viane;VIANE;81530;81;TARN;1
81315;;Vielmur-sur-Agout;VIELMUR-SUR-AGOUT;81570;81;TARN;1
81316;;Vieux;VIEUX;81140;81;TARN;1
81317;;Villefranche-d'Albigeois;VILLEFRANCHE-D'ALBIGEOIS;81430;81;TARN;1
81318;;Villeneuve-lès-Lavaur;VILLENEUVE-LES-LAVAUR;81500;81;TARN;1
81319;;Villeneuve-sur-Vère;VILLENEUVE-SUR-VERE;81130;81;TARN;1
81320;;Vindrac-Alayrac;VINDRAC-ALAYRAC;81170;81;TARN;1
81321;Le;Vintrou;VINTROU;81240;81;TARN;1
81322;;Virac;VIRAC;81640;81;TARN;1
81323;;Viterbe;VITERBE;81220;81;TARN;1
81324;;Viviers-lès-Lavaur;VIVIERS-LES-LAVAUR;81500;81;TARN;1
81325;;Viviers-lès-Montagnes;VIVIERS-LES-MONTAGNES;81290;81;TARN;1
81326;;Sainte-Croix;SAINTE-CROIX;81150;81;TARN;1
82001;;Albefeuille-Lagarde;ALBEFEUILLE-LAGARDE;82290;82;TARN ET GARONNE;1
82002;;Albias;ALBIAS;82350;82;TARN ET GARONNE;1
82003;;Angeville;ANGEVILLE;82210;82;TARN ET GARONNE;1
82004;;Asques;ASQUES;82120;82;TARN ET GARONNE;1
82005;;Aucamville;AUCAMVILLE;82600;82;TARN ET GARONNE;1
82006;;Auterive;AUTERIVE;82500;82;TARN ET GARONNE;1
82007;;Auty;AUTY;82220;82;TARN ET GARONNE;1
82008;;Auvillar;AUVILLAR;82340;82;TARN ET GARONNE;1
82009;;Balignac;BALIGNAC;82120;82;TARN ET GARONNE;1
82010;;Bardigues;BARDIGUES;82340;82;TARN ET GARONNE;1
82011;;Barry-d'Islemade;BARRY-D'ISLEMADE;82290;82;TARN ET GARONNE;1
82012;Les;Barthes;BARTHES;82100;82;TARN ET GARONNE;1
82013;;Beaumont-de-Lomagne;BEAUMONT-DE-LOMAGNE;82500;82;TARN ET GARONNE;1
82014;;Beaupuy;BEAUPUY;82600;82;TARN ET GARONNE;1
82015;;Belbèse;BELBESE;82500;82;TARN ET GARONNE;1
82016;;Belvèze;BELVEZE;82150;82;TARN ET GARONNE;1
82017;;Bessens;BESSENS;82170;82;TARN ET GARONNE;1
82018;;Bioule;BIOULE;82800;82;TARN ET GARONNE;1
82019;;Boudou;BOUDOU;82200;82;TARN ET GARONNE;1
82020;;Bouillac;BOUILLAC;82600;82;TARN ET GARONNE;1
82021;;Bouloc;BOULOC;82110;82;TARN ET GARONNE;1
82022;;Bourg-de-Visa;BOURG-DE-VISA;82190;82;TARN ET GARONNE;1
82023;;Bourret;BOURRET;82700;82;TARN ET GARONNE;1
82024;;Brassac;BRASSAC;82190;82;TARN ET GARONNE;1
82025;;Bressols;BRESSOLS;82710;82;TARN ET GARONNE;1
82026;;Bruniquel;BRUNIQUEL;82800;82;TARN ET GARONNE;1
82027;;Campsas;CAMPSAS;82370;82;TARN ET GARONNE;1
82028;;Canals;CANALS;82170;82;TARN ET GARONNE;1
82029;;Castanet;CASTANET;82160;82;TARN ET GARONNE;1
82030;;Castelferrus;CASTELFERRUS;82100;82;TARN ET GARONNE;1
82031;;Castelmayran;CASTELMAYRAN;82210;82;TARN ET GARONNE;1
82032;;Castelsagrat;CASTELSAGRAT;82400;82;TARN ET GARONNE;1
82033;;Castelsarrasin;CASTELSARRASIN;82100;82;TARN ET GARONNE;1
82034;;Castéra-Bouzet;CASTERA-BOUZET;82120;82;TARN ET GARONNE;1
82035;;Caumont;CAUMONT;82210;82;TARN ET GARONNE;1
82036;Le;Causé;CAUSE;82500;82;TARN ET GARONNE;1
82037;;Caussade;CAUSSADE;82300;82;TARN ET GARONNE;1
82038;;Caylus;CAYLUS;82160;82;TARN ET GARONNE;1
82039;;Cayrac;CAYRAC;82440;82;TARN ET GARONNE;1
82040;;Cayriech;CAYRIECH;82240;82;TARN ET GARONNE;1
82041;;Cazals;CAZALS;82140;82;TARN ET GARONNE;1
82042;;Cazes-Mondenard;CAZES-MONDENARD;82110;82;TARN ET GARONNE;1
82043;;Comberouger;COMBEROUGER;82600;82;TARN ET GARONNE;1
82044;;Corbarieu;CORBARIEU;82370;82;TARN ET GARONNE;1
82045;;Cordes-Tolosannes;CORDES-TOLOSANNES;82700;82;TARN ET GARONNE;1
82046;;Coutures;COUTURES;82210;82;TARN ET GARONNE;1
82047;;Cumont;CUMONT;82500;82;TARN ET GARONNE;1
82048;;Dieupentale;DIEUPENTALE;82170;82;TARN ET GARONNE;1
82049;;Donzac;DONZAC;82340;82;TARN ET GARONNE;1
82050;;Dunes;DUNES;82340;82;TARN ET GARONNE;1
82051;;Durfort-Lacapelette;DURFORT-LACAPELETTE;82390;82;TARN ET GARONNE;1
82052;;Escatalens;ESCATALENS;82700;82;TARN ET GARONNE;1
82053;;Escazeaux;ESCAZEAUX;82500;82;TARN ET GARONNE;1
82054;;Espalais;ESPALAIS;82400;82;TARN ET GARONNE;1
82055;;Esparsac;ESPARSAC;82500;82;TARN ET GARONNE;1
82056;;Espinas;ESPINAS;82160;82;TARN ET GARONNE;1
82057;;Fabas;FABAS;82170;82;TARN ET GARONNE;1
82058;;Fajolles;FAJOLLES;82210;82;TARN ET GARONNE;1
82059;;Faudoas;FAUDOAS;82500;82;TARN ET GARONNE;1
82060;;Fauroux;FAUROUX;82190;82;TARN ET GARONNE;1
82061;;Féneyrols;FENEYROLS;82140;82;TARN ET GARONNE;1
82062;;Finhan;FINHAN;82700;82;TARN ET GARONNE;1
82063;;Garganvillar;GARGANVILLAR;82100;82;TARN ET GARONNE;1
82064;;Gariès;GARIES;82500;82;TARN ET GARONNE;1
82065;;Gasques;GASQUES;82400;82;TARN ET GARONNE;1
82066;;Génébrières;GENEBRIERES;82230;82;TARN ET GARONNE;1
82067;;Gensac;GENSAC;82120;82;TARN ET GARONNE;1
82068;;Gimat;GIMAT;82500;82;TARN ET GARONNE;1
82069;;Ginals;GINALS;82330;82;TARN ET GARONNE;1
82070;;Glatens;GLATENS;82500;82;TARN ET GARONNE;1
82071;;Goas;GOAS;82500;82;TARN ET GARONNE;1
82072;;Golfech;GOLFECH;82400;82;TARN ET GARONNE;1
82073;;Goudourville;GOUDOURVILLE;82400;82;TARN ET GARONNE;1
82074;;Gramont;GRAMONT;82120;82;TARN ET GARONNE;1
82075;;Grisolles;GRISOLLES;82170;82;TARN ET GARONNE;1
82076;L';Honor-de-Cos;HONOR-DE-COS;82130;82;TARN ET GARONNE;1
82077;;Labarthe;LABARTHE;82220;82;TARN ET GARONNE;1
82078;;Labastide-de-Penne;LABASTIDE-DE-PENNE;82240;82;TARN ET GARONNE;1
82079;;Labastide-Saint-Pierre;LABASTIDE-SAINT-PIERRE;82370;82;TARN ET GARONNE;1
82080;;Labastide-du-Temple;LABASTIDE-DU-TEMPLE;82100;82;TARN ET GARONNE;1
82081;;Labourgade;LABOURGADE;82100;82;TARN ET GARONNE;1
82082;;Lacapelle-Livron;LACAPELLE-LIVRON;82160;82;TARN ET GARONNE;1
82083;;Lachapelle;LACHAPELLE;82120;82;TARN ET GARONNE;1
82084;;Lacour;LACOUR;82190;82;TARN ET GARONNE;1
82085;;Lacourt-Saint-Pierre;LACOURT-SAINT-PIERRE;82290;82;TARN ET GARONNE;1
82086;;Lafitte;LAFITTE;82100;82;TARN ET GARONNE;1
82087;;Lafrançaise;LAFRANCAISE;82130;82;TARN ET GARONNE;1
82088;;Laguépie;LAGUEPIE;82250;82;TARN ET GARONNE;1
82089;;Lamagistère;LAMAGISTERE;82360;82;TARN ET GARONNE;1
82090;;Lamothe-Capdeville;LAMOTHE-CAPDEVILLE;82130;82;TARN ET GARONNE;1
82091;;Lamothe-Cumont;LAMOTHE-CUMONT;82500;82;TARN ET GARONNE;1
82092;;Lapenche;LAPENCHE;82240;82;TARN ET GARONNE;1
82093;;Larrazet;LARRAZET;82500;82;TARN ET GARONNE;1
82094;;Lauzerte;LAUZERTE;82110;82;TARN ET GARONNE;1
82095;;Lavaurette;LAVAURETTE;82240;82;TARN ET GARONNE;1
82096;La;Ville-Dieu-du-Temple;VILLE-DIEU-DU-TEMPLE;82290;82;TARN ET GARONNE;1
82097;;Lavit;LAVIT;82120;82;TARN ET GARONNE;1
82098;;Léojac;LEOJAC;82230;82;TARN ET GARONNE;1
82099;;Lizac;LIZAC;82200;82;TARN ET GARONNE;1
82100;;Loze;LOZE;82160;82;TARN ET GARONNE;1
82101;;Malause;MALAUSE;82200;82;TARN ET GARONNE;1
82102;;Mansonville;MANSONVILLE;82120;82;TARN ET GARONNE;1
82103;;Marignac;MARIGNAC;82500;82;TARN ET GARONNE;1
82104;;Marsac;MARSAC;82120;82;TARN ET GARONNE;1
82105;;Mas-Grenier;MAS-GRENIER;82600;82;TARN ET GARONNE;1
82106;;Maubec;MAUBEC;82500;82;TARN ET GARONNE;1
82107;;Maumusson;MAUMUSSON;82120;82;TARN ET GARONNE;1
82108;;Meauzac;MEAUZAC;82290;82;TARN ET GARONNE;1
82109;;Merles;MERLES;82210;82;TARN ET GARONNE;1
82110;;Mirabel;MIRABEL;82440;82;TARN ET GARONNE;1
82111;;Miramont-de-Quercy;MIRAMONT-DE-QUERCY;82190;82;TARN ET GARONNE;1
82112;;Moissac;MOISSAC;82200;82;TARN ET GARONNE;1
82113;;Molières;MOLIERES;82220;82;TARN ET GARONNE;1
82114;;Monbéqui;MONBEQUI;82170;82;TARN ET GARONNE;1
82115;;Monclar-de-Quercy;MONCLAR-DE-QUERCY;82230;82;TARN ET GARONNE;1
82116;;Montagudet;MONTAGUDET;82110;82;TARN ET GARONNE;1
82117;;Montaigu-de-Quercy;MONTAIGU-DE-QUERCY;82150;82;TARN ET GARONNE;1
82118;;Montaïn;MONTAIN;82100;82;TARN ET GARONNE;1
82119;;Montalzat;MONTALZAT;82270;82;TARN ET GARONNE;1
82120;;Montastruc;MONTASTRUC;82130;82;TARN ET GARONNE;1
82121;;Montauban;MONTAUBAN;82000;82;TARN ET GARONNE;1
82122;;Montbarla;MONTBARLA;82110;82;TARN ET GARONNE;1
82123;;Montbartier;MONTBARTIER;82700;82;TARN ET GARONNE;1
82124;;Montbeton;MONTBETON;82290;82;TARN ET GARONNE;1
82125;;Montech;MONTECH;82700;82;TARN ET GARONNE;1
82126;;Monteils;MONTEILS;82300;82;TARN ET GARONNE;1
82127;;Montesquieu;MONTESQUIEU;82200;82;TARN ET GARONNE;1
82128;;Montfermier;MONTFERMIER;82270;82;TARN ET GARONNE;1
82129;;Montgaillard;MONTGAILLARD;82120;82;TARN ET GARONNE;1
82130;;Montjoi;MONTJOI;82400;82;TARN ET GARONNE;1
82131;;Montpezat-de-Quercy;MONTPEZAT-DE-QUERCY;82270;82;TARN ET GARONNE;1
82132;;Montricoux;MONTRICOUX;82800;82;TARN ET GARONNE;1
82133;;Mouillac;MOUILLAC;82160;82;TARN ET GARONNE;1
82134;;Nègrepelisse;NEGREPELISSE;82800;82;TARN ET GARONNE;1
82135;;Nohic;NOHIC;82370;82;TARN ET GARONNE;1
82136;;Orgueil;ORGUEIL;82370;82;TARN ET GARONNE;1
82137;;Parisot;PARISOT;82160;82;TARN ET GARONNE;1
82138;;Perville;PERVILLE;82400;82;TARN ET GARONNE;1
82139;Le;Pin;PIN;82340;82;TARN ET GARONNE;1
82140;;Piquecos;PIQUECOS;82130;82;TARN ET GARONNE;1
82141;;Pommevic;POMMEVIC;82400;82;TARN ET GARONNE;1
82142;;Pompignan;POMPIGNAN;82170;82;TARN ET GARONNE;1
82143;;Poupas;POUPAS;82120;82;TARN ET GARONNE;1
82144;;Puycornet;PUYCORNET;82220;82;TARN ET GARONNE;1
82145;;Puygaillard-de-Quercy;PUYGAILLARD-DE-QUERCY;82800;82;TARN ET GARONNE;1
82146;;Puygaillard-de-Lomagne;PUYGAILLARD-DE-LOMAGNE;82120;82;TARN ET GARONNE;1
82147;;Puylagarde;PUYLAGARDE;82160;82;TARN ET GARONNE;1
82148;;Puylaroque;PUYLAROQUE;82240;82;TARN ET GARONNE;1
82149;;Réalville;REALVILLE;82440;82;TARN ET GARONNE;1
82150;;Reyniès;REYNIES;82370;82;TARN ET GARONNE;1
82151;;Roquecor;ROQUECOR;82150;82;TARN ET GARONNE;1
82152;;Saint-Aignan;SAINT-AIGNAN;82100;82;TARN ET GARONNE;1
82153;;Saint-Amans-du-Pech;SAINT-AMANS-DU-PECH;82150;82;TARN ET GARONNE;1
82154;;Saint-Amans-de-Pellagal;SAINT-AMANS-DE-PELLAGAL;82110;82;TARN ET GARONNE;1
82155;;Saint-Antonin-Noble-Val;SAINT-ANTONIN-NOBLE-VAL;82140;82;TARN ET GARONNE;1
82156;;Saint-Arroumex;SAINT-ARROUMEX;82210;82;TARN ET GARONNE;1
82157;;Saint-Beauzeil;SAINT-BEAUZEIL;82150;82;TARN ET GARONNE;1
82158;;Saint-Cirice;SAINT-CIRICE;82340;82;TARN ET GARONNE;1
82159;;Saint-Cirq;SAINT-CIRQ;82300;82;TARN ET GARONNE;1
82160;;Saint-Clair;SAINT-CLAIR;82400;82;TARN ET GARONNE;1
82161;;Saint-Étienne-de-Tulmont;SAINT-ETIENNE-DE-TULMONT;82410;82;TARN ET GARONNE;1
82162;;Saint-Georges;SAINT-GEORGES;82240;82;TARN ET GARONNE;1
82163;;Saint-Jean-du-Bouzet;SAINT-JEAN-DU-BOUZET;82120;82;TARN ET GARONNE;1
82164;;Sainte-Juliette;SAINTE-JULIETTE;82110;82;TARN ET GARONNE;1
82165;;Saint-Loup;SAINT-LOUP;82340;82;TARN ET GARONNE;1
82166;;Saint-Michel;SAINT-MICHEL;82340;82;TARN ET GARONNE;1
82167;;Saint-Nauphary;SAINT-NAUPHARY;82370;82;TARN ET GARONNE;1
82168;;Saint-Nazaire-de-Valentane;SAINT-NAZAIRE-DE-VALENTANE;82190;82;TARN ET GARONNE;1
82169;;Saint-Nicolas-de-la-Grave;SAINT-NICOLAS-DE-LA-GRAVE;82210;82;TARN ET GARONNE;1
82170;;Saint-Paul-d'Espis;SAINT-PAUL-D'ESPIS;82400;82;TARN ET GARONNE;1
82171;;Saint-Porquier;SAINT-PORQUIER;82700;82;TARN ET GARONNE;1
82172;;Saint-Projet;SAINT-PROJET;82160;82;TARN ET GARONNE;1
82173;;Saint-Sardos;SAINT-SARDOS;82600;82;TARN ET GARONNE;1
82174;;Saint-Vincent;SAINT-VINCENT;82300;82;TARN ET GARONNE;1
82175;;Saint-Vincent-Lespinasse;SAINT-VINCENT-LESPINASSE;82400;82;TARN ET GARONNE;1
82176;La;Salvetat-Belmontet;SALVETAT-BELMONTET;82230;82;TARN ET GARONNE;1
82177;;Sauveterre;SAUVETERRE;82110;82;TARN ET GARONNE;1
82178;;Savenès;SAVENES;82600;82;TARN ET GARONNE;1
82179;;Septfonds;SEPTFONDS;82240;82;TARN ET GARONNE;1
82180;;Sérignac;SERIGNAC;82500;82;TARN ET GARONNE;1
82181;;Sistels;SISTELS;82340;82;TARN ET GARONNE;1
82182;;Touffailles;TOUFFAILLES;82190;82;TARN ET GARONNE;1
82183;;Tréjouls;TREJOULS;82110;82;TARN ET GARONNE;1
82184;;Vaïssac;VAISSAC;82800;82;TARN ET GARONNE;1
82185;;Valeilles;VALEILLES;82150;82;TARN ET GARONNE;1
82186;;Valence;VALENCE;82400;82;TARN ET GARONNE;1
82187;;Varen;VAREN;82330;82;TARN ET GARONNE;1
82188;;Varennes;VARENNES;82370;82;TARN ET GARONNE;1
82189;;Vazerac;VAZERAC;82220;82;TARN ET GARONNE;1
82190;;Verdun-sur-Garonne;VERDUN-SUR-GARONNE;82600;82;TARN ET GARONNE;1
82191;;Verfeil;VERFEIL;82330;82;TARN ET GARONNE;1
82192;;Verlhac-Tescou;VERLHAC-TESCOU;82230;82;TARN ET GARONNE;1
82193;;Vigueron;VIGUERON;82500;82;TARN ET GARONNE;1
82194;;Villebrumier;VILLEBRUMIER;82370;82;TARN ET GARONNE;1
82195;;Villemade;VILLEMADE;82130;82;TARN ET GARONNE;1
83001;Les;Adrets-de-l'Estérel;ADRETS-DE-L'ESTEREL;83600;83;VAR;1
83002;;Aiguines;AIGUINES;83630;83;VAR;1
83003;;Ampus;AMPUS;83111;83;VAR;1
83004;Les;Arcs;ARCS;83460;83;VAR;1
83005;;Artignosc-sur-Verdon;ARTIGNOSC-SUR-VERDON;83630;83;VAR;1
83006;;Artigues;ARTIGUES;83560;83;VAR;1
83007;;Aups;AUPS;83630;83;VAR;1
83008;;Bagnols-en-Forêt;BAGNOLS-EN-FORET;83600;83;VAR;1
83009;;Bandol;BANDOL;83150;83;VAR;1
83010;;Bargème;BARGEME;83840;83;VAR;1
83011;;Bargemon;BARGEMON;83830;83;VAR;1
83012;;Barjols;BARJOLS;83670;83;VAR;1
83013;La;Bastide;BASTIDE;83840;83;VAR;1
83014;;Baudinard-sur-Verdon;BAUDINARD-SUR-VERDON;83630;83;VAR;1
83015;;Bauduen;BAUDUEN;83630;83;VAR;1
83016;Le;Beausset;BEAUSSET;83330;83;VAR;1
83017;;Belgentier;BELGENTIER;83210;83;VAR;1
83018;;Besse-sur-Issole;BESSE-SUR-ISSOLE;83890;83;VAR;1
83019;;Bormes-les-Mimosas;BORMES-LES-MIMOSAS;83230;83;VAR;1
83020;Le;Bourguet;BOURGUET;83840;83;VAR;1
83021;;Bras;BRAS;83149;83;VAR;1
83022;;Brenon;BRENON;83840;83;VAR;1
83023;;Brignoles;BRIGNOLES;83170;83;VAR;1
83025;;Brue-Auriac;BRUE-AURIAC;83119;83;VAR;1
83026;;Cabasse;CABASSE;83340;83;VAR;1
83027;La;Cadière-d'Azur;CADIERE-D'AZUR;83740;83;VAR;1
83028;;Callas;CALLAS;83830;83;VAR;1
83029;;Callian;CALLIAN;83440;83;VAR;1
83030;;Camps-la-Source;CAMPS-LA-SOURCE;83170;83;VAR;1
83031;Le;Cannet-des-Maures;CANNET-DES-MAURES;83340;83;VAR;1
83032;;Carcès;CARCES;83570;83;VAR;1
83033;;Carnoules;CARNOULES;83660;83;VAR;1
83034;;Carqueiranne;CARQUEIRANNE;83320;83;VAR;1
83035;Le;Castellet;CASTELLET;83330;83;VAR;1
83036;;Cavalaire-sur-Mer;CAVALAIRE-SUR-MER;83240;83;VAR;1
83037;La;Celle;CELLE;83170;83;VAR;1
83038;;Châteaudouble;CHATEAUDOUBLE;83300;83;VAR;1
83039;;Châteauvert;CHATEAUVERT;83670;83;VAR;1
83040;;Châteauvieux;CHATEAUVIEUX;83840;83;VAR;1
83041;;Claviers;CLAVIERS;83830;83;VAR;1
83042;;Cogolin;COGOLIN;83310;83;VAR;1
83043;;Collobrières;COLLOBRIERES;83610;83;VAR;1
83044;;Comps-sur-Artuby;COMPS-SUR-ARTUBY;83840;83;VAR;1
83045;;Correns;CORRENS;83570;83;VAR;1
83046;;Cotignac;COTIGNAC;83570;83;VAR;1
83047;La;Crau;CRAU;83260;83;VAR;1
83048;La;Croix-Valmer;CROIX-VALMER;83420;83;VAR;1
83049;;Cuers;CUERS;83390;83;VAR;1
83050;;Draguignan;DRAGUIGNAN;83300;83;VAR;1
83051;;Entrecasteaux;ENTRECASTEAUX;83570;83;VAR;1
83052;;Esparron;ESPARRON;83560;83;VAR;1
83053;;Évenos;EVENOS;83330;83;VAR;1
83054;La;Farlède;FARLEDE;83210;83;VAR;1
83055;;Fayence;FAYENCE;83440;83;VAR;1
83056;;Figanières;FIGANIERES;83830;83;VAR;1
83057;;Flassans-sur-Issole;FLASSANS-SUR-ISSOLE;83340;83;VAR;1
83058;;Flayosc;FLAYOSC;83780;83;VAR;1
83059;;Forcalqueiret;FORCALQUEIRET;83136;83;VAR;1
83060;;Fox-Amphoux;FOX-AMPHOUX;83670;83;VAR;1
83061;;Fréjus;FREJUS;83600;83;VAR;1
83062;La;Garde;GARDE;83130;83;VAR;1
83063;La;Garde-Freinet;GARDE-FREINET;83680;83;VAR;1
83064;;Garéoult;GAREOULT;83136;83;VAR;1
83065;;Gassin;GASSIN;83580;83;VAR;1
83066;;Ginasservis;GINASSERVIS;83560;83;VAR;1
83067;;Gonfaron;GONFARON;83590;83;VAR;1
83068;;Grimaud;GRIMAUD;83310;83;VAR;1
83069;;Hyères;HYERES;83400;83;VAR;1
83070;Le;Lavandou;LAVANDOU;83980;83;VAR;1
83071;La;Londe-les-Maures;LONDE-LES-MAURES;83250;83;VAR;1
83072;;Lorgues;LORGUES;83510;83;VAR;1
83073;Le;Luc;LUC;83340;83;VAR;1
83074;La;Martre;MARTRE;83840;83;VAR;1
83075;Les;Mayons;MAYONS;83340;83;VAR;1
83076;;Mazaugues;MAZAUGUES;83136;83;VAR;1
83077;;Méounes-lès-Montrieux;MEOUNES-LES-MONTRIEUX;83136;83;VAR;1
83078;;Moissac-Bellevue;MOISSAC-BELLEVUE;83630;83;VAR;1
83079;La;Môle;MOLE;83310;83;VAR;1
83080;;Mons;MONS;83440;83;VAR;1
83081;;Montauroux;MONTAUROUX;83440;83;VAR;1
83082;;Montferrat;MONTFERRAT;83131;83;VAR;1
83083;;Montfort-sur-Argens;MONTFORT-SUR-ARGENS;83570;83;VAR;1
83084;;Montmeyan;MONTMEYAN;83670;83;VAR;1
83085;La;Motte;MOTTE;83920;83;VAR;1
83086;Le;Muy;MUY;83490;83;VAR;1
83087;;Nans-les-Pins;NANS-LES-PINS;83860;83;VAR;1
83088;;Néoules;NEOULES;83136;83;VAR;1
83089;;Ollières;OLLIERES;83470;83;VAR;1
83090;;Ollioules;OLLIOULES;83190;83;VAR;1
83091;;Pierrefeu-du-Var;PIERREFEU-DU-VAR;83390;83;VAR;1
83092;;Pignans;PIGNANS;83790;83;VAR;1
83093;;Plan-d'Aups-Sainte-Baume;PLAN-D'AUPS-SAINTE-BAUME;83640;83;VAR;1
83094;Le;Plan-de-la-Tour;PLAN-DE-LA-TOUR;83120;83;VAR;1
83095;;Pontevès;PONTEVES;83670;83;VAR;1
83096;;Pourcieux;POURCIEUX;83470;83;VAR;1
83097;;Pourrières;POURRIERES;83910;83;VAR;1
83098;Le;Pradet;PRADET;83220;83;VAR;1
83099;;Puget-sur-Argens;PUGET-SUR-ARGENS;83480;83;VAR;1
83100;;Puget-Ville;PUGET-VILLE;83390;83;VAR;1
83101;;Ramatuelle;RAMATUELLE;83350;83;VAR;1
83102;;Régusse;REGUSSE;83630;83;VAR;1
83103;Le;Revest-les-Eaux;REVEST-LES-EAUX;83200;83;VAR;1
83104;;Rians;RIANS;83560;83;VAR;1
83105;;Riboux;RIBOUX;13780;83;BOUCHES DU RHONE;1
83106;;Rocbaron;ROCBARON;83136;83;VAR;1
83107;;Roquebrune-sur-Argens;ROQUEBRUNE-SUR-ARGENS;83520;83;VAR;1
83108;La;Roquebrussanne;ROQUEBRUSSANNE;83136;83;VAR;1
83109;La;Roque-Esclapon;ROQUE-ESCLAPON;83840;83;VAR;1
83110;;Rougiers;ROUGIERS;83170;83;VAR;1
83111;;Sainte-Anastasie-sur-Issole;SAINTE-ANASTASIE-SUR-ISSOLE;83136;83;VAR;1
83112;;Saint-Cyr-sur-Mer;SAINT-CYR-SUR-MER;83270;83;VAR;1
83113;;Saint-Julien;SAINT-JULIEN;83560;83;VAR;1
83114;;Saint-Martin;SAINT-MARTIN;83560;83;VAR;1
83115;;Sainte-Maxime;SAINTE-MAXIME;83120;83;VAR;1
83116;;Saint-Maximin-la-Sainte-Baume;SAINT-MAXIMIN-LA-SAINTE-BAUME;83470;83;VAR;1
83117;;Saint-Paul-en-Forêt;SAINT-PAUL-EN-FORET;83440;83;VAR;1
83118;;Saint-Raphaël;SAINT-RAPHAEL;83700;83;VAR;1
83119;;Saint-Tropez;SAINT-TROPEZ;83990;83;VAR;1
83120;;Saint-Zacharie;SAINT-ZACHARIE;83640;83;VAR;1
83121;;Salernes;SALERNES;83690;83;VAR;1
83122;Les;Salles-sur-Verdon;SALLES-SUR-VERDON;83630;83;VAR;1
83123;;Sanary-sur-Mer;SANARY-SUR-MER;83110;83;VAR;1
83124;;Seillans;SEILLANS;83440;83;VAR;1
83125;;Seillons-Source-d'Argens;SEILLONS-SOURCE-D'ARGENS;83470;83;VAR;1
83126;La;Seyne-sur-Mer;SEYNE-SUR-MER;83500;83;VAR;1
83127;;Signes;SIGNES;83870;83;VAR;1
83128;;Sillans-la-Cascade;SILLANS-LA-CASCADE;83690;83;VAR;1
83129;;Six-Fours-les-Plages;SIX-FOURS-LES-PLAGES;83140;83;VAR;1
83130;;Solliès-Pont;SOLLIES-PONT;83210;83;VAR;1
83131;;Solliès-Toucas;SOLLIES-TOUCAS;83210;83;VAR;1
83132;;Solliès-Ville;SOLLIES-VILLE;83210;83;VAR;1
83133;;Tanneron;TANNERON;83440;83;VAR;1
83134;;Taradeau;TARADEAU;83460;83;VAR;1
83135;;Tavernes;TAVERNES;83670;83;VAR;1
83136;Le;Thoronet;THORONET;83340;83;VAR;1
83137;;Toulon;TOULON;83000;83;VAR;1
83138;;Tourrettes;TOURRETTES;83440;83;VAR;1
83139;;Tourtour;TOURTOUR;83690;83;VAR;1
83140;;Tourves;TOURVES;83170;83;VAR;1
83141;;Trans-en-Provence;TRANS-EN-PROVENCE;83720;83;VAR;1
83142;;Trigance;TRIGANCE;83840;83;VAR;1
83143;Le;Val;VAL;83143;83;VAR;1
83144;La;Valette-du-Var;VALETTE-DU-VAR;83160;83;VAR;1
83145;;Varages;VARAGES;83670;83;VAR;1
83146;La;Verdière;VERDIERE;83560;83;VAR;1
83147;;Vérignon;VERIGNON;83630;83;VAR;1
83148;;Vidauban;VIDAUBAN;83550;83;VAR;1
83149;;Villecroze;VILLECROZE;83690;83;VAR;1
83150;;Vinon-sur-Verdon;VINON-SUR-VERDON;83560;83;VAR;1
83151;;Vins-sur-Caramy;VINS-SUR-CARAMY;83170;83;VAR;1
83152;;Rayol-Canadel-sur-Mer;RAYOL-CANADEL-SUR-MER;83820;83;VAR;1
83153;;Saint-Mandrier-sur-Mer;SAINT-MANDRIER-SUR-MER;83430;83;VAR;1
83154;;Saint-Antonin-du-Var;SAINT-ANTONIN-DU-VAR;83510;83;VAR;1
84001;;Althen-des-Paluds;ALTHEN-DES-PALUDS;84210;84;VAUCLUSE;1
84002;;Ansouis;ANSOUIS;84240;84;VAUCLUSE;1
84003;;Apt;APT;84400;84;VAUCLUSE;1
84004;;Aubignan;AUBIGNAN;84810;84;VAUCLUSE;1
84005;;Aurel;AUREL;84390;84;VAUCLUSE;1
84006;;Auribeau;AURIBEAU;84400;84;VAUCLUSE;1
84007;;Avignon;AVIGNON;84000;84;VAUCLUSE;1
84008;Le;Barroux;BARROUX;84330;84;VAUCLUSE;1
84009;La;Bastide-des-Jourdans;BASTIDE-DES-JOURDANS;84240;84;VAUCLUSE;1
84010;La;Bastidonne;BASTIDONNE;84120;84;VAUCLUSE;1
84011;Le;Beaucet;BEAUCET;84210;84;VAUCLUSE;1
84012;;Beaumes-de-Venise;BEAUMES-DE-VENISE;84190;84;VAUCLUSE;1
84013;;Beaumettes;BEAUMETTES;84220;84;VAUCLUSE;1
84014;;Beaumont-de-Pertuis;BEAUMONT-DE-PERTUIS;84120;84;VAUCLUSE;1
84015;;Beaumont-du-Ventoux;BEAUMONT-DU-VENTOUX;84340;84;VAUCLUSE;1
84016;;Bédarrides;BEDARRIDES;84370;84;VAUCLUSE;1
84017;;Bédoin;BEDOIN;84410;84;VAUCLUSE;1
84018;;Blauvac;BLAUVAC;84570;84;VAUCLUSE;1
84019;;Bollène;BOLLENE;84500;84;VAUCLUSE;1
84020;;Bonnieux;BONNIEUX;84480;84;VAUCLUSE;1
84021;;Brantes;BRANTES;84390;84;VAUCLUSE;1
84022;;Buisson;BUISSON;84110;84;VAUCLUSE;1
84023;;Buoux;BUOUX;84480;84;VAUCLUSE;1
84024;;Cabrières-d'Aigues;CABRIERES-D'AIGUES;84240;84;VAUCLUSE;1
84025;;Cabrières-d'Avignon;CABRIERES-D'AVIGNON;84220;84;VAUCLUSE;1
84026;;Cadenet;CADENET;84160;84;VAUCLUSE;1
84027;;Caderousse;CADEROUSSE;84860;84;VAUCLUSE;1
84028;;Cairanne;CAIRANNE;84290;84;VAUCLUSE;1
84029;;Camaret-sur-Aigues;CAMARET-SUR-AIGUES;84850;84;VAUCLUSE;1
84030;;Caromb;CAROMB;84330;84;VAUCLUSE;1
84031;;Carpentras;CARPENTRAS;84200;84;VAUCLUSE;1
84032;;Caseneuve;CASENEUVE;84750;84;VAUCLUSE;1
84033;;Castellet;CASTELLET;84400;84;VAUCLUSE;1
84034;;Caumont-sur-Durance;CAUMONT-SUR-DURANCE;84510;84;VAUCLUSE;1
84035;;Cavaillon;CAVAILLON;84300;84;VAUCLUSE;1
84036;;Châteauneuf-de-Gadagne;CHATEAUNEUF-DE-GADAGNE;84470;84;VAUCLUSE;1
84037;;Châteauneuf-du-Pape;CHATEAUNEUF-DU-PAPE;84230;84;VAUCLUSE;1
84038;;Cheval-Blanc;CHEVAL-BLANC;84460;84;VAUCLUSE;1
84039;;Courthézon;COURTHEZON;84350;84;VAUCLUSE;1
84040;;Crestet;CRESTET;84110;84;VAUCLUSE;1
84041;;Crillon-le-Brave;CRILLON-LE-BRAVE;84410;84;VAUCLUSE;1
84042;;Cucuron;CUCURON;84160;84;VAUCLUSE;1
84043;;Entraigues-sur-la-Sorgue;ENTRAIGUES-SUR-LA-SORGUE;84320;84;VAUCLUSE;1
84044;;Entrechaux;ENTRECHAUX;84340;84;VAUCLUSE;1
84045;;Faucon;FAUCON;84110;84;VAUCLUSE;1
84046;;Flassan;FLASSAN;84410;84;VAUCLUSE;1
84047;;Gargas;GARGAS;84400;84;VAUCLUSE;1
84048;;Gignac;GIGNAC;84400;84;VAUCLUSE;1
84049;;Gigondas;GIGONDAS;84190;84;VAUCLUSE;1
84050;;Gordes;GORDES;84220;84;VAUCLUSE;1
84051;;Goult;GOULT;84220;84;VAUCLUSE;1
84052;;Grambois;GRAMBOIS;84240;84;VAUCLUSE;1
84053;;Grillon;GRILLON;84600;84;VAUCLUSE;1
84054;L';Isle-sur-la-Sorgue;ISLE-SUR-LA-SORGUE;84800;84;VAUCLUSE;1
84055;;Jonquerettes;JONQUERETTES;84450;84;VAUCLUSE;1
84056;;Jonquières;JONQUIERES;84150;84;VAUCLUSE;1
84057;;Joucas;JOUCAS;84220;84;VAUCLUSE;1
84058;;Lacoste;LACOSTE;84480;84;VAUCLUSE;1
84059;;Lafare;LAFARE;84190;84;VAUCLUSE;1
84060;;Lagarde-d'Apt;LAGARDE-D'APT;84400;84;VAUCLUSE;1
84061;;Lagarde-Paréol;LAGARDE-PAREOL;84290;84;VAUCLUSE;1
84062;;Lagnes;LAGNES;84800;84;VAUCLUSE;1
84063;;Lamotte-du-Rhône;LAMOTTE-DU-RHONE;84840;84;VAUCLUSE;1
84064;;Lapalud;LAPALUD;84840;84;VAUCLUSE;1
84065;;Lauris;LAURIS;84360;84;VAUCLUSE;1
84066;;Lioux;LIOUX;84220;84;VAUCLUSE;1
84067;;Loriol-du-Comtat;LORIOL-DU-COMTAT;84870;84;VAUCLUSE;1
84068;;Lourmarin;LOURMARIN;84160;84;VAUCLUSE;1
84069;;Malaucène;MALAUCENE;84340;84;VAUCLUSE;1
84070;;Malemort-du-Comtat;MALEMORT-DU-COMTAT;84570;84;VAUCLUSE;1
84071;;Maubec;MAUBEC;84660;84;VAUCLUSE;1
84072;;Mazan;MAZAN;84380;84;VAUCLUSE;1
84073;;Ménerbes;MENERBES;84560;84;VAUCLUSE;1
84074;;Mérindol;MERINDOL;84360;84;VAUCLUSE;1
84075;;Méthamis;METHAMIS;84570;84;VAUCLUSE;1
84076;;Mirabeau;MIRABEAU;84120;84;VAUCLUSE;1
84077;;Modène;MODENE;84330;84;VAUCLUSE;1
84078;;Mondragon;MONDRAGON;84430;84;VAUCLUSE;1
84079;;Monieux;MONIEUX;84390;84;VAUCLUSE;1
84080;;Monteux;MONTEUX;84170;84;VAUCLUSE;1
84081;;Morières-lès-Avignon;MORIERES-LES-AVIGNON;84310;84;VAUCLUSE;1
84082;;Mormoiron;MORMOIRON;84570;84;VAUCLUSE;1
84083;;Mornas;MORNAS;84550;84;VAUCLUSE;1
84084;La;Motte-d'Aigues;MOTTE-D'AIGUES;84240;84;VAUCLUSE;1
84085;;Murs;MURS;84220;84;VAUCLUSE;1
84086;;Oppède;OPPEDE;84580;84;VAUCLUSE;1
84087;;Orange;ORANGE;84100;84;VAUCLUSE;1
84088;;Pernes-les-Fontaines;PERNES-LES-FONTAINES;84210;84;VAUCLUSE;1
84089;;Pertuis;PERTUIS;84120;84;VAUCLUSE;1
84090;;Peypin-d'Aigues;PEYPIN-D'AIGUES;84240;84;VAUCLUSE;1
84091;;Piolenc;PIOLENC;84420;84;VAUCLUSE;1
84092;Le;Pontet;PONTET;84130;84;VAUCLUSE;1
84093;;Puget;PUGET;84360;84;VAUCLUSE;1
84094;;Puyméras;PUYMERAS;84110;84;VAUCLUSE;1
84095;;Puyvert;PUYVERT;84160;84;VAUCLUSE;1
84096;;Rasteau;RASTEAU;84110;84;VAUCLUSE;1
84097;;Richerenches;RICHERENCHES;84600;84;VAUCLUSE;1
84098;;Roaix;ROAIX;84110;84;VAUCLUSE;1
84099;;Robion;ROBION;84440;84;VAUCLUSE;1
84100;La;Roque-Alric;ROQUE-ALRIC;84190;84;VAUCLUSE;1
84101;La;Roque-sur-Pernes;ROQUE-SUR-PERNES;84210;84;VAUCLUSE;1
84102;;Roussillon;ROUSSILLON;84220;84;VAUCLUSE;1
84103;;Rustrel;RUSTREL;84400;84;VAUCLUSE;1
84104;;Sablet;SABLET;84110;84;VAUCLUSE;1
84105;;Saignon;SAIGNON;84400;84;VAUCLUSE;1
84106;;Sainte-Cécile-les-Vignes;SAINTE-CECILE-LES-VIGNES;84290;84;VAUCLUSE;1
84107;;Saint-Christol;SAINT-CHRISTOL;84390;84;VAUCLUSE;1
84108;;Saint-Didier;SAINT-DIDIER;84210;84;VAUCLUSE;1
84109;;Saint-Hippolyte-le-Graveyron;SAINT-HIPPOLYTE-LE-GRAVEYRON;84330;84;VAUCLUSE;1
84110;;Saint-Léger-du-Ventoux;SAINT-LEGER-DU-VENTOUX;84390;84;VAUCLUSE;1
84111;;Saint-Marcellin-lès-Vaison;SAINT-MARCELLIN-LES-VAISON;84110;84;VAUCLUSE;1
84112;;Saint-Martin-de-Castillon;SAINT-MARTIN-DE-CASTILLON;84750;84;VAUCLUSE;1
84113;;Saint-Martin-de-la-Brasque;SAINT-MARTIN-DE-LA-BRASQUE;84760;84;VAUCLUSE;1
84114;;Saint-Pantaléon;SAINT-PANTALEON;84220;84;VAUCLUSE;1
84115;;Saint-Pierre-de-Vassols;SAINT-PIERRE-DE-VASSOLS;84330;84;VAUCLUSE;1
84116;;Saint-Romain-en-Viennois;SAINT-ROMAIN-EN-VIENNOIS;84110;84;VAUCLUSE;1
84117;;Saint-Roman-de-Malegarde;SAINT-ROMAN-DE-MALEGARDE;84290;84;VAUCLUSE;1
84118;;Saint-Saturnin-lès-Apt;SAINT-SATURNIN-LES-APT;84490;84;VAUCLUSE;1
84119;;Saint-Saturnin-lès-Avignon;SAINT-SATURNIN-LES-AVIGNON;84450;84;VAUCLUSE;1
84120;;Saint-Trinit;SAINT-TRINIT;84390;84;VAUCLUSE;1
84121;;Sannes;SANNES;84240;84;VAUCLUSE;1
84122;;Sarrians;SARRIANS;84260;84;VAUCLUSE;1
84123;;Sault;SAULT;84390;84;VAUCLUSE;1
84124;;Saumane-de-Vaucluse;SAUMANE-DE-VAUCLUSE;84800;84;VAUCLUSE;1
84125;;Savoillan;SAVOILLAN;84390;84;VAUCLUSE;1
84126;;Séguret;SEGURET;84110;84;VAUCLUSE;1
84127;;Sérignan-du-Comtat;SERIGNAN-DU-COMTAT;84830;84;VAUCLUSE;1
84128;;Sivergues;SIVERGUES;84400;84;VAUCLUSE;1
84129;;Sorgues;SORGUES;84700;84;VAUCLUSE;1
84130;;Suzette;SUZETTE;84190;84;VAUCLUSE;1
84131;;Taillades;TAILLADES;84300;84;VAUCLUSE;1
84132;Le;Thor;THOR;84250;84;VAUCLUSE;1
84133;La;Tour-d'Aigues;TOUR-D'AIGUES;84240;84;VAUCLUSE;1
84134;;Travaillan;TRAVAILLAN;84850;84;VAUCLUSE;1
84135;;Uchaux;UCHAUX;84100;84;VAUCLUSE;1
84136;;Vacqueyras;VACQUEYRAS;84190;84;VAUCLUSE;1
84137;;Vaison-la-Romaine;VAISON-LA-ROMAINE;84110;84;VAUCLUSE;1
84138;;Valréas;VALREAS;84600;84;VAUCLUSE;1
84139;;Fontaine-de-Vaucluse;FONTAINE-DE-VAUCLUSE;84800;84;VAUCLUSE;1
84140;;Vaugines;VAUGINES;84160;84;VAUCLUSE;1
84141;;Vedène;VEDENE;84270;84;VAUCLUSE;1
84142;;Velleron;VELLERON;84740;84;VAUCLUSE;1
84143;;Venasque;VENASQUE;84210;84;VAUCLUSE;1
84144;;Viens;VIENS;84750;84;VAUCLUSE;1
84145;;Villars;VILLARS;84400;84;VAUCLUSE;1
84146;;Villedieu;VILLEDIEU;84110;84;VAUCLUSE;1
84147;;Villelaure;VILLELAURE;84530;84;VAUCLUSE;1
84148;;Villes-sur-Auzon;VILLES-SUR-AUZON;84570;84;VAUCLUSE;1
84149;;Violès;VIOLES;84150;84;VAUCLUSE;1
84150;;Visan;VISAN;84820;84;VAUCLUSE;1
84151;;Vitrolles-en-Lubéron;VITROLLES-EN-LUBERON;84240;84;VAUCLUSE;1
85001;L';Aiguillon-sur-Mer;AIGUILLON-SUR-MER;85460;85;VENDEE;1
85002;L';Aiguillon-sur-Vie;AIGUILLON-SUR-VIE;85220;85;VENDEE;1
85003;;Aizenay;AIZENAY;85190;85;VENDEE;1
85004;;Angles;ANGLES;85750;85;VENDEE;1
85005;;Antigny;ANTIGNY;85120;85;VENDEE;1
85006;;Apremont;APREMONT;85220;85;VENDEE;1
85008;;Aubigny;AUBIGNY;85430;85;VENDEE;1
85009;;Auzay;AUZAY;85200;85;VENDEE;1
85010;;Avrillé;AVRILLE;85440;85;VENDEE;1
85011;;Barbâtre;BARBATRE;85630;85;VENDEE;1
85012;La;Barre-de-Monts;BARRE-DE-MONTS;85550;85;VENDEE;1
85013;;Bazoges-en-Paillers;BAZOGES-EN-PAILLERS;85130;85;VENDEE;1
85014;;Bazoges-en-Pareds;BAZOGES-EN-PAREDS;85390;85;VENDEE;1
85015;;Beaufou;BEAUFOU;85170;85;VENDEE;1
85016;;Beaulieu-sous-la-Roche;BEAULIEU-SOUS-LA-ROCHE;85190;85;VENDEE;1
85017;;Beaurepaire;BEAUREPAIRE;85500;85;VENDEE;1
85018;;Beauvoir-sur-Mer;BEAUVOIR-SUR-MER;85230;85;VENDEE;1
85019;;Belleville-sur-Vie;BELLEVILLE-SUR-VIE;85170;85;VENDEE;1
85020;;Benet;BENET;85490;85;VENDEE;1
85021;La;Bernardière;BERNARDIERE;85610;85;VENDEE;1
85022;Le;Bernard;BERNARD;85560;85;VENDEE;1
85023;;Bessay;BESSAY;85320;85;VENDEE;1
85024;;Bois-de-Céné;BOIS-DE-CENE;85710;85;VENDEE;1
85025;La;Boissière-de-Montaigu;BOISSIERE-DE-MONTAIGU;85600;85;VENDEE;1
85026;La;Boissière-des-Landes;BOISSIERE-DES-LANDES;85430;85;VENDEE;1
85027;;Boufféré;BOUFFERE;85600;85;VENDEE;1
85028;;Bouillé-Courdault;BOUILLE-COURDAULT;85420;85;VENDEE;1
85029;;Bouin;BOUIN;85230;85;VENDEE;1
85030;;Boulogne;BOULOGNE;85140;85;VENDEE;1
85031;Le;Boupère;BOUPERE;85510;85;VENDEE;1
85033;;Bourneau;BOURNEAU;85200;85;VENDEE;1
85034;;Bournezeau;BOURNEZEAU;85480;85;VENDEE;1
85035;;Bretignolles-sur-Mer;BRETIGNOLLES-SUR-MER;85470;85;VENDEE;1
85036;La;Bretonnière-la-Claye;BRETONNIERE-LA-CLAYE;85320;85;VENDEE;1
85037;;Breuil-Barret;BREUIL-BARRET;85120;85;VENDEE;1
85038;Les;Brouzils;BROUZILS;85260;85;VENDEE;1
85039;La;Bruffière;BRUFFIERE;85530;85;VENDEE;1
85040;La;Caillère-Saint-Hilaire;CAILLERE-SAINT-HILAIRE;85410;85;VENDEE;1
85041;;Cezais;CEZAIS;85410;85;VENDEE;1
85042;;Chaillé-les-Marais;CHAILLE-LES-MARAIS;85450;85;VENDEE;1
85043;;Chaillé-sous-les-Ormeaux;CHAILLE-SOUS-LES-ORMEAUX;85310;85;VENDEE;1
85044;;Chaix;CHAIX;85200;85;VENDEE;1
85045;La;Chaize-Giraud;CHAIZE-GIRAUD;85220;85;VENDEE;1
85046;La;Chaize-le-Vicomte;CHAIZE-LE-VICOMTE;85310;85;VENDEE;1
85047;;Challans;CHALLANS;85300;85;VENDEE;1
85048;;Chambretaud;CHAMBRETAUD;85500;85;VENDEE;1
85049;;Champagné-les-Marais;CHAMPAGNE-LES-MARAIS;85450;85;VENDEE;1
85050;Le;Champ-Saint-Père;CHAMP-SAINT-PERE;85540;85;VENDEE;1
85051;;Chantonnay;CHANTONNAY;85110;85;VENDEE;1
85052;La;Chapelle-Achard;CHAPELLE-ACHARD;85150;85;VENDEE;1
85053;La;Chapelle-aux-Lys;CHAPELLE-AUX-LYS;85120;85;VENDEE;1
85054;La;Chapelle-Hermier;CHAPELLE-HERMIER;85220;85;VENDEE;1
85055;La;Chapelle-Palluau;CHAPELLE-PALLUAU;85670;85;VENDEE;1
85056;La;Chapelle-Thémer;CHAPELLE-THEMER;85210;85;VENDEE;1
85058;;Chasnais;CHASNAIS;85400;85;VENDEE;1
85059;La;Châtaigneraie;CHATAIGNERAIE;85120;85;VENDEE;1
85060;;Château-d'Olonne;CHATEAU-D'OLONNE;85180;85;VENDEE;1
85061;;Château-Guibert;CHATEAU-GUIBERT;85320;85;VENDEE;1
85062;;Châteauneuf;CHATEAUNEUF;85710;85;VENDEE;1
85063;Les;Châtelliers-Châteaumur;CHATELLIERS-CHATEAUMUR;85700;85;VENDEE;1
85064;;Chauché;CHAUCHE;85140;85;VENDEE;1
85065;;Chavagnes-en-Paillers;CHAVAGNES-EN-PAILLERS;85250;85;VENDEE;1
85066;;Chavagnes-les-Redoux;CHAVAGNES-LES-REDOUX;85390;85;VENDEE;1
85067;;Cheffois;CHEFFOIS;85390;85;VENDEE;1
85069;Les;Clouzeaux;CLOUZEAUX;85430;85;VENDEE;1
85070;;Coëx;COEX;85220;85;VENDEE;1
85071;;Commequiers;COMMEQUIERS;85220;85;VENDEE;1
85072;La;Copechagnière;COPECHAGNIERE;85260;85;VENDEE;1
85073;;Corpe;CORPE;85320;85;VENDEE;1
85074;La;Couture;COUTURE;85320;85;VENDEE;1
85076;;Cugand;CUGAND;85610;85;VENDEE;1
85077;;Curzon;CURZON;85540;85;VENDEE;1
85078;;Damvix;DAMVIX;85420;85;VENDEE;1
85080;;Doix;DOIX;85200;85;VENDEE;1
85081;;Dompierre-sur-Yon;DOMPIERRE-SUR-YON;85170;85;VENDEE;1
85082;Les;Epesses;EPESSES;85590;85;VENDEE;1
85083;L';Épine;EPINE;85740;85;VENDEE;1
85084;Les;Essarts;ESSARTS;85140;85;VENDEE;1
85086;;Falleron;FALLERON;85670;85;VENDEE;1
85087;;Faymoreau;FAYMOREAU;85240;85;VENDEE;1
85088;Le;Fenouiller;FENOUILLER;85800;85;VENDEE;1
85089;La;Ferrière;FERRIERE;85280;85;VENDEE;1
85090;La;Flocellière;FLOCELLIERE;85700;85;VENDEE;1
85091;;Fontaines;FONTAINES;85200;85;VENDEE;1
85092;;Fontenay-le-Comte;FONTENAY-LE-COMTE;85200;85;VENDEE;1
85093;;Fougeré;FOUGERE;85480;85;VENDEE;1
85094;;Foussais-Payré;FOUSSAIS-PAYRE;85240;85;VENDEE;1
85095;;Froidfond;FROIDFOND;85300;85;VENDEE;1
85096;La;Garnache;GARNACHE;85710;85;VENDEE;1
85097;La;Gaubretière;GAUBRETIERE;85130;85;VENDEE;1
85098;La;Génétouze;GENETOUZE;85190;85;VENDEE;1
85099;Le;Girouard;GIROUARD;85150;85;VENDEE;1
85100;;Givrand;GIVRAND;85800;85;VENDEE;1
85101;Le;Givre;GIVRE;85540;85;VENDEE;1
85102;;Grand'Landes;GRAND'LANDES;85670;85;VENDEE;1
85103;;Grosbreuil;GROSBREUIL;85440;85;VENDEE;1
85104;;Grues;GRUES;85580;85;VENDEE;1
85105;Le;Gué-de-Velluire;GUE-DE-VELLUIRE;85770;85;VENDEE;1
85106;La;Guérinière;GUERINIERE;85680;85;VENDEE;1
85107;La;Guyonnière;GUYONNIERE;85600;85;VENDEE;1
85108;L';Herbergement;HERBERGEMENT;85260;85;VENDEE;1
85109;Les;Herbiers;HERBIERS;85500;85;VENDEE;1
85110;L';Hermenault;HERMENAULT;85570;85;VENDEE;1
85111;L';Île-d'Elle;ILE-D'ELLE;85770;85;VENDEE;1
85112;L';Île-d'Olonne;ILE-D'OLONNE;85340;85;VENDEE;1
85113;L';Île-d'Yeu;ILE-D'YEU;85350;85;VENDEE;1
85114;;Jard-sur-Mer;JARD-SUR-MER;85520;85;VENDEE;1
85115;La;Jaudonnière;JAUDONNIERE;85110;85;VENDEE;1
85116;La;Jonchère;JONCHERE;85540;85;VENDEE;1
85117;;Lairoux;LAIROUX;85400;85;VENDEE;1
85118;;Landeronde;LANDERONDE;85150;85;VENDEE;1
85119;Les;Landes-Genusson;LANDES-GENUSSON;85130;85;VENDEE;1
85120;;Landevieille;LANDEVIEILLE;85220;85;VENDEE;1
85121;Le;Langon;LANGON;85370;85;VENDEE;1
85123;;Liez;LIEZ;85420;85;VENDEE;1
85125;;Loge-Fougereuse;LOGE-FOUGEREUSE;85120;85;VENDEE;1
85126;;Longèves;LONGEVES;85200;85;VENDEE;1
85127;;Longeville-sur-Mer;LONGEVILLE-SUR-MER;85560;85;VENDEE;1
85128;;Luçon;LUCON;85400;85;VENDEE;1
85129;Les;Lucs-sur-Boulogne;LUCS-SUR-BOULOGNE;85170;85;VENDEE;1
85130;;Maché;MACHE;85190;85;VENDEE;1
85131;Les;Magnils-Reigniers;MAGNILS-REIGNIERS;85400;85;VENDEE;1
85132;;Maillé;MAILLE;85420;85;VENDEE;1
85133;;Maillezais;MAILLEZAIS;85420;85;VENDEE;1
85134;;Mallièvre;MALLIEVRE;85590;85;VENDEE;1
85135;;Mareuil-sur-Lay-Dissais;MAREUIL-SUR-LAY-DISSAIS;85320;85;VENDEE;1
85136;;Marillet;MARILLET;85240;85;VENDEE;1
85137;;Marsais-Sainte-Radégonde;MARSAIS-SAINTE-RADEGONDE;85570;85;VENDEE;1
85138;;Martinet;MARTINET;85150;85;VENDEE;1
85139;Le;Mazeau;MAZEAU;85420;85;VENDEE;1
85140;La;Meilleraie-Tillay;MEILLERAIE-TILLAY;85700;85;VENDEE;1
85141;;Menomblet;MENOMBLET;85700;85;VENDEE;1
85142;La;Merlatière;MERLATIERE;85140;85;VENDEE;1
85143;;Mervent;MERVENT;85200;85;VENDEE;1
85144;;Mesnard-la-Barotière;MESNARD-LA-BAROTIERE;85500;85;VENDEE;1
85145;;Monsireigne;MONSIREIGNE;85110;85;VENDEE;1
85146;;Montaigu;MONTAIGU;85600;85;VENDEE;1
85147;;Montournais;MONTOURNAIS;85700;85;VENDEE;1
85148;;Montreuil;MONTREUIL;85200;85;VENDEE;1
85149;;Moreilles;MOREILLES;85450;85;VENDEE;1
85150;;Mormaison;MORMAISON;85260;85;VENDEE;1
85151;;Mortagne-sur-Sèvre;MORTAGNE-SUR-SEVRE;85290;85;VENDEE;1
85152;La;Mothe-Achard;MOTHE-ACHARD;85150;85;VENDEE;1
85153;;Mouchamps;MOUCHAMPS;85640;85;VENDEE;1
85154;;Mouilleron-en-Pareds;MOUILLERON-EN-PAREDS;85390;85;VENDEE;1
85155;;Mouilleron-le-Captif;MOUILLERON-LE-CAPTIF;85000;85;VENDEE;1
85156;;Moutiers-les-Mauxfaits;MOUTIERS-LES-MAUXFAITS;85540;85;VENDEE;1
85157;;Moutiers-sur-le-Lay;MOUTIERS-SUR-LE-LAY;85320;85;VENDEE;1
85158;;Mouzeuil-Saint-Martin;MOUZEUIL-SAINT-MARTIN;85370;85;VENDEE;1
85159;;Nalliers;NALLIERS;85370;85;VENDEE;1
85160;;Nesmy;NESMY;85310;85;VENDEE;1
85161;;Nieul-le-Dolent;NIEUL-LE-DOLENT;85430;85;VENDEE;1
85162;;Nieul-sur-l'Autise;NIEUL-SUR-L'AUTISE;85240;85;VENDEE;1
85163;;Noirmoutier-en-l'Île;NOIRMOUTIER-EN-L'ILE;85330;85;VENDEE;1
85164;;Notre-Dame-de-Monts;NOTRE-DAME-DE-MONTS;85690;85;VENDEE;1
85165;L';Oie;OIE;85140;85;VENDEE;1
85166;;Olonne-sur-Mer;OLONNE-SUR-MER;85340;85;VENDEE;1
85167;L';Orbrie;ORBRIE;85200;85;VENDEE;1
85168;;Oulmes;OULMES;85420;85;VENDEE;1
85169;;Palluau;PALLUAU;85670;85;VENDEE;1
85171;;Péault;PEAULT;85320;85;VENDEE;1
85172;Le;Perrier;PERRIER;85300;85;VENDEE;1
85174;;Petosse;PETOSSE;85570;85;VENDEE;1
85175;Les;Pineaux;PINEAUX;85320;85;VENDEE;1
85176;;Pissotte;PISSOTTE;85200;85;VENDEE;1
85177;Le;Poiré-sur-Velluire;POIRE-SUR-VELLUIRE;85770;85;VENDEE;1
85178;Le;Poiré-sur-Vie;POIRE-SUR-VIE;85170;85;VENDEE;1
85179;;Poiroux;POIROUX;85440;85;VENDEE;1
85180;La;Pommeraie-sur-Sèvre;POMMERAIE-SUR-SEVRE;85700;85;VENDEE;1
85181;;Pouillé;POUILLE;85570;85;VENDEE;1
85182;;Pouzauges;POUZAUGES;85700;85;VENDEE;1
85184;;Puy-de-Serre;PUY-DE-SERRE;85240;85;VENDEE;1
85185;;Puyravault;PUYRAVAULT;85450;85;VENDEE;1
85186;La;Rabatelière;RABATELIERE;85250;85;VENDEE;1
85187;;Réaumur;REAUMUR;85700;85;VENDEE;1
85188;La;Réorthe;REORTHE;85210;85;VENDEE;1
85189;;Notre-Dame-de-Riez;NOTRE-DAME-DE-RIEZ;85270;85;VENDEE;1
85190;;Rocheservière;ROCHESERVIERE;85620;85;VENDEE;1
85191;La;Roche-sur-Yon;ROCHE-SUR-YON;85000;85;VENDEE;1
85192;;Rochetrejoux;ROCHETREJOUX;85510;85;VENDEE;1
85193;;Rosnay;ROSNAY;85320;85;VENDEE;1
85194;Les;Sables-d'Olonne;SABLES-D'OLONNE;85100;85;VENDEE;1
85196;;Saint-André-Goule-d'Oie;SAINT-ANDRE-GOULE-D'OIE;85250;85;VENDEE;1
85197;;Saint-André-Treize-Voies;SAINT-ANDRE-TREIZE-VOIES;85260;85;VENDEE;1
85198;;Saint-Aubin-des-Ormeaux;SAINT-AUBIN-DES-ORMEAUX;85130;85;VENDEE;1
85199;;Saint-Aubin-la-Plaine;SAINT-AUBIN-LA-PLAINE;85210;85;VENDEE;1
85200;;Saint-Avaugourd-des-Landes;SAINT-AVAUGOURD-DES-LANDES;85540;85;VENDEE;1
85201;;Saint-Benoist-sur-Mer;SAINT-BENOIST-SUR-MER;85540;85;VENDEE;1
85202;;Sainte-Cécile;SAINTE-CECILE;85110;85;VENDEE;1
85204;;Saint-Christophe-du-Ligneron;SAINT-CHRISTOPHE-DU-LIGNERON;85670;85;VENDEE;1
85205;;Saint-Cyr-des-Gâts;SAINT-CYR-DES-GATS;85410;85;VENDEE;1
85206;;Saint-Cyr-en-Talmondais;SAINT-CYR-EN-TALMONDAIS;85540;85;VENDEE;1
85207;;Saint-Denis-du-Payré;SAINT-DENIS-DU-PAYRE;85580;85;VENDEE;1
85208;;Saint-Denis-la-Chevasse;SAINT-DENIS-LA-CHEVASSE;85170;85;VENDEE;1
85209;;Saint-Étienne-de-Brillouet;SAINT-ETIENNE-DE-BRILLOUET;85210;85;VENDEE;1
85210;;Saint-Étienne-du-Bois;SAINT-ETIENNE-DU-BOIS;85670;85;VENDEE;1
85211;;Sainte-Flaive-des-Loups;SAINTE-FLAIVE-DES-LOUPS;85150;85;VENDEE;1
85212;;Sainte-Florence;SAINTE-FLORENCE;85140;85;VENDEE;1
85213;;Saint-Florent-des-Bois;SAINT-FLORENT-DES-BOIS;85310;85;VENDEE;1
85214;;Sainte-Foy;SAINTE-FOY;85150;85;VENDEE;1
85215;;Saint-Fulgent;SAINT-FULGENT;85250;85;VENDEE;1
85216;;Sainte-Gemme-la-Plaine;SAINTE-GEMME-LA-PLAINE;85400;85;VENDEE;1
85217;;Saint-Georges-de-Montaigu;SAINT-GEORGES-DE-MONTAIGU;85600;85;VENDEE;1
85218;;Saint-Georges-de-Pointindoux;SAINT-GEORGES-DE-POINTINDOUX;85150;85;VENDEE;1
85219;;Saint-Germain-l'Aiguiller;SAINT-GERMAIN-L'AIGUILLER;85390;85;VENDEE;1
85220;;Saint-Germain-de-Prinçay;SAINT-GERMAIN-DE-PRINCAY;85110;85;VENDEE;1
85221;;Saint-Gervais;SAINT-GERVAIS;85230;85;VENDEE;1
85222;;Saint-Gilles-Croix-de-Vie;SAINT-GILLES-CROIX-DE-VIE;85800;85;VENDEE;1
85223;;Sainte-Hermine;SAINTE-HERMINE;85210;85;VENDEE;1
85224;;Saint-Hilaire-de-Loulay;SAINT-HILAIRE-DE-LOULAY;85600;85;VENDEE;1
85226;;Saint-Hilaire-de-Riez;SAINT-HILAIRE-DE-RIEZ;85270;85;VENDEE;1
85227;;Saint-Hilaire-des-Loges;SAINT-HILAIRE-DES-LOGES;85240;85;VENDEE;1
85229;;Saint-Hilaire-de-Voust;SAINT-HILAIRE-DE-VOUST;85120;85;VENDEE;1
85231;;Saint-Hilaire-la-Forêt;SAINT-HILAIRE-LA-FORET;85440;85;VENDEE;1
85232;;Saint-Hilaire-le-Vouhis;SAINT-HILAIRE-LE-VOUHIS;85480;85;VENDEE;1
85233;;Saint-Jean-de-Beugné;SAINT-JEAN-DE-BEUGNE;85210;85;VENDEE;1
85234;;Saint-Jean-de-Monts;SAINT-JEAN-DE-MONTS;85160;85;VENDEE;1
85235;;Saint-Juire-Champgillon;SAINT-JUIRE-CHAMPGILLON;85210;85;VENDEE;1
85236;;Saint-Julien-des-Landes;SAINT-JULIEN-DES-LANDES;85150;85;VENDEE;1
85237;;Saint-Laurent-de-la-Salle;SAINT-LAURENT-DE-LA-SALLE;85410;85;VENDEE;1
85238;;Saint-Laurent-sur-Sèvre;SAINT-LAURENT-SUR-SEVRE;85290;85;VENDEE;1
85239;;Saint-Maixent-sur-Vie;SAINT-MAIXENT-SUR-VIE;85220;85;VENDEE;1
85240;;Saint-Malô-du-Bois;SAINT-MALO-DU-BOIS;85590;85;VENDEE;1
85242;;Saint-Mars-la-Réorthe;SAINT-MARS-LA-REORTHE;85590;85;VENDEE;1
85243;;Brem-sur-Mer;BREM-SUR-MER;85470;85;VENDEE;1
85244;;Saint-Martin-de-Fraigneau;SAINT-MARTIN-DE-FRAIGNEAU;85200;85;VENDEE;1
85245;;Saint-Martin-des-Fontaines;SAINT-MARTIN-DES-FONTAINES;85570;85;VENDEE;1
85246;;Saint-Martin-des-Noyers;SAINT-MARTIN-DES-NOYERS;85140;85;VENDEE;1
85247;;Saint-Martin-des-Tilleuls;SAINT-MARTIN-DES-TILLEULS;85130;85;VENDEE;1
85248;;Saint-Martin-Lars-en-Sainte-Hermine;SAINT-MARTIN-LARS-EN-SAINTE-HERMINE;85210;85;VENDEE;1
85250;;Saint-Mathurin;SAINT-MATHURIN;85150;85;VENDEE;1
85251;;Saint-Maurice-des-Noues;SAINT-MAURICE-DES-NOUES;85120;85;VENDEE;1
85252;;Saint-Maurice-le-Girard;SAINT-MAURICE-LE-GIRARD;85390;85;VENDEE;1
85254;;Saint-Mesmin;SAINT-MESMIN;85700;85;VENDEE;1
85255;;Saint-Michel-en-l'Herm;SAINT-MICHEL-EN-L'HERM;85580;85;VENDEE;1
85256;;Saint-Michel-le-Cloucq;SAINT-MICHEL-LE-CLOUCQ;85200;85;VENDEE;1
85257;;Saint-Michel-Mont-Mercure;SAINT-MICHEL-MONT-MERCURE;85700;85;VENDEE;1
85259;;Saint-Paul-en-Pareds;SAINT-PAUL-EN-PAREDS;85500;85;VENDEE;1
85260;;Saint-Paul-Mont-Penit;SAINT-PAUL-MONT-PENIT;85670;85;VENDEE;1
85261;;Sainte-Pexine;SAINTE-PEXINE;85320;85;VENDEE;1
85262;;Saint-Philbert-de-Bouaine;SAINT-PHILBERT-DE-BOUAINE;85660;85;VENDEE;1
85264;;Saint-Pierre-du-Chemin;SAINT-PIERRE-DU-CHEMIN;85120;85;VENDEE;1
85265;;Saint-Pierre-le-Vieux;SAINT-PIERRE-LE-VIEUX;85420;85;VENDEE;1
85266;;Saint-Prouant;SAINT-PROUANT;85110;85;VENDEE;1
85267;;Sainte-Radégonde-des-Noyers;SAINTE-RADEGONDE-DES-NOYERS;85450;85;VENDEE;1
85268;;Saint-Révérend;SAINT-REVEREND;85220;85;VENDEE;1
85269;;Saint-Sigismond;SAINT-SIGISMOND;85420;85;VENDEE;1
85271;;Saint-Sulpice-en-Pareds;SAINT-SULPICE-EN-PAREDS;85410;85;VENDEE;1
85272;;Saint-Sulpice-le-Verdon;SAINT-SULPICE-LE-VERDON;85260;85;VENDEE;1
85273;;Saint-Urbain;SAINT-URBAIN;85230;85;VENDEE;1
85274;;Saint-Valérien;SAINT-VALERIEN;85570;85;VENDEE;1
85276;;Saint-Vincent-Sterlanges;SAINT-VINCENT-STERLANGES;85110;85;VENDEE;1
85277;;Saint-Vincent-sur-Graon;SAINT-VINCENT-SUR-GRAON;85540;85;VENDEE;1
85278;;Saint-Vincent-sur-Jard;SAINT-VINCENT-SUR-JARD;85520;85;VENDEE;1
85279;;Saligny;SALIGNY;85170;85;VENDEE;1
85280;;Sallertaine;SALLERTAINE;85300;85;VENDEE;1
85281;;Sérigné;SERIGNE;85200;85;VENDEE;1
85282;;Sigournais;SIGOURNAIS;85110;85;VENDEE;1
85284;;Soullans;SOULLANS;85300;85;VENDEE;1
85285;Le;Tablier;TABLIER;85310;85;VENDEE;1
85286;La;Taillée;TAILLEE;85450;85;VENDEE;1
85287;;Tallud-Sainte-Gemme;TALLUD-SAINTE-GEMME;85390;85;VENDEE;1
85288;;Talmont-Saint-Hilaire;TALMONT-SAINT-HILAIRE;85440;85;VENDEE;1
85289;La;Tardière;TARDIERE;85120;85;VENDEE;1
85290;;Thiré;THIRE;85210;85;VENDEE;1
85291;;Thorigny;THORIGNY;85480;85;VENDEE;1
85292;;Thouarsais-Bouildroux;THOUARSAIS-BOUILDROUX;85410;85;VENDEE;1
85293;;Tiffauges;TIFFAUGES;85130;85;VENDEE;1
85294;La;Tranche-sur-Mer;TRANCHE-SUR-MER;85360;85;VENDEE;1
85295;;Treize-Septiers;TREIZE-SEPTIERS;85600;85;VENDEE;1
85296;;Treize-Vents;TREIZE-VENTS;85590;85;VENDEE;1
85297;;Triaize;TRIAIZE;85580;85;VENDEE;1
85298;;Vairé;VAIRE;85150;85;VENDEE;1
85299;;Velluire;VELLUIRE;85770;85;VENDEE;1
85300;;Venansault;VENANSAULT;85190;85;VENDEE;1
85301;;Vendrennes;VENDRENNES;85250;85;VENDEE;1
85302;La;Verrie;VERRIE;85130;85;VENDEE;1
85303;;Vix;VIX;85770;85;VENDEE;1
85304;;Vouillé-les-Marais;VOUILLE-LES-MARAIS;85450;85;VENDEE;1
85305;;Vouvant;VOUVANT;85120;85;VENDEE;1
85306;;Xanton-Chassenon;XANTON-CHASSENON;85240;85;VENDEE;1
85307;La;Faute-sur-Mer;FAUTE-SUR-MER;85460;85;VENDEE;1
86001;;Adriers;ADRIERS;86430;86;VIENNE;1
86002;;Amberre;AMBERRE;86110;86;VIENNE;1
86003;;Anché;ANCHE;86700;86;VIENNE;1
86004;;Angles-sur-l'Anglin;ANGLES-SUR-L'ANGLIN;86260;86;VIENNE;1
86005;;Angliers;ANGLIERS;86330;86;VIENNE;1
86006;;Antigny;ANTIGNY;86310;86;VIENNE;1
86007;;Antran;ANTRAN;86100;86;VIENNE;1
86008;;Arçay;ARCAY;86200;86;VIENNE;1
86009;;Archigny;ARCHIGNY;86210;86;VIENNE;1
86010;;Aslonnes;ASLONNES;86340;86;VIENNE;1
86011;;Asnières-sur-Blour;ASNIERES-SUR-BLOUR;86430;86;VIENNE;1
86012;;Asnois;ASNOIS;86250;86;VIENNE;1
86013;;Aulnay;AULNAY;86330;86;VIENNE;1
86014;;Availles-en-Châtellerault;AVAILLES-EN-CHATELLERAULT;86530;86;VIENNE;1
86015;;Availles-Limouzine;AVAILLES-LIMOUZINE;86460;86;VIENNE;1
86016;;Avanton;AVANTON;86170;86;VIENNE;1
86017;;Ayron;AYRON;86190;86;VIENNE;1
86018;;Basses;BASSES;86200;86;VIENNE;1
86019;;Beaumont;BEAUMONT;86490;86;VIENNE;1
86020;;Bellefonds;BELLEFONDS;86210;86;VIENNE;1
86021;;Benassay;BENASSAY;86470;86;VIENNE;1
86022;;Berrie;BERRIE;86120;86;VIENNE;1
86023;;Berthegon;BERTHEGON;86420;86;VIENNE;1
86024;;Béruges;BERUGES;86190;86;VIENNE;1
86025;;Béthines;BETHINES;86310;86;VIENNE;1
86026;;Beuxes;BEUXES;86120;86;VIENNE;1
86027;;Biard;BIARD;86000;86;VIENNE;1
86028;;Bignoux;BIGNOUX;86800;86;VIENNE;1
86029;;Blanzay;BLANZAY;86400;86;VIENNE;1
86030;;Blaslay;BLASLAY;86170;86;VIENNE;1
86031;;Bonnes;BONNES;86300;86;VIENNE;1
86032;;Bonneuil-Matours;BONNEUIL-MATOURS;86210;86;VIENNE;1
86034;;Bouresse;BOURESSE;86410;86;VIENNE;1
86035;;Bourg-Archambault;BOURG-ARCHAMBAULT;86390;86;VIENNE;1
86036;;Bournand;BOURNAND;86120;86;VIENNE;1
86037;;Brigueil-le-Chantre;BRIGUEIL-LE-CHANTRE;86290;86;VIENNE;1
86038;;Brion;BRION;86160;86;VIENNE;1
86039;;Brux;BRUX;86510;86;VIENNE;1
86040;La;Bussière;BUSSIERE;86310;86;VIENNE;1
86041;;Buxerolles;BUXEROLLES;86180;86;VIENNE;1
86042;;Buxeuil;BUXEUIL;37160;86;INDRE ET LOIRE;1
86043;;Ceaux-en-Couhé;CEAUX-EN-COUHE;86700;86;VIENNE;1
86044;;Ceaux-en-Loudun;CEAUX-EN-LOUDUN;86200;86;VIENNE;1
86045;;Celle-Lévescault;CELLE-LEVESCAULT;86600;86;VIENNE;1
86046;;Cenon-sur-Vienne;CENON-SUR-VIENNE;86530;86;VIENNE;1
86047;;Cernay;CERNAY;86140;86;VIENNE;1
86048;;Chabournay;CHABOURNAY;86380;86;VIENNE;1
86049;;Chalais;CHALAIS;86200;86;VIENNE;1
86050;;Chalandray;CHALANDRAY;86190;86;VIENNE;1
86051;;Champagné-le-Sec;CHAMPAGNE-LE-SEC;86510;86;VIENNE;1
86052;;Champagné-Saint-Hilaire;CHAMPAGNE-SAINT-HILAIRE;86160;86;VIENNE;1
86053;;Champigny-le-Sec;CHAMPIGNY-LE-SEC;86170;86;VIENNE;1
86054;;Champniers;CHAMPNIERS;86400;86;VIENNE;1
86055;La;Chapelle-Bâton;CHAPELLE-BATON;86250;86;VIENNE;1
86056;La;Chapelle-Montreuil;CHAPELLE-MONTREUIL;86470;86;VIENNE;1
86058;La;Chapelle-Moulière;CHAPELLE-MOULIERE;86210;86;VIENNE;1
86059;;Chapelle-Viviers;CHAPELLE-VIVIERS;86300;86;VIENNE;1
86060;;Charrais;CHARRAIS;86170;86;VIENNE;1
86061;;Charroux;CHARROUX;86250;86;VIENNE;1
86062;;Chasseneuil-du-Poitou;CHASSENEUIL-DU-POITOU;86360;86;VIENNE;1
86063;;Chatain;CHATAIN;86250;86;VIENNE;1
86064;;Château-Garnier;CHATEAU-GARNIER;86350;86;VIENNE;1
86065;;Château-Larcher;CHATEAU-LARCHER;86370;86;VIENNE;1
86066;;Châtellerault;CHATELLERAULT;86100;86;VIENNE;1
86067;;Châtillon;CHATILLON;86700;86;VIENNE;1
86068;;Chaunay;CHAUNAY;86510;86;VIENNE;1
86069;La;Chaussée;CHAUSSEE;86330;86;VIENNE;1
86070;;Chauvigny;CHAUVIGNY;86300;86;VIENNE;1
86071;;Cheneché;CHENECHE;86380;86;VIENNE;1
86072;;Chenevelles;CHENEVELLES;86450;86;VIENNE;1
86073;;Cherves;CHERVES;86170;86;VIENNE;1
86074;;Chiré-en-Montreuil;CHIRE-EN-MONTREUIL;86190;86;VIENNE;1
86075;;Chouppes;CHOUPPES;86110;86;VIENNE;1
86076;;Cissé;CISSE;86170;86;VIENNE;1
86077;;Civaux;CIVAUX;86320;86;VIENNE;1
86078;;Civray;CIVRAY;86400;86;VIENNE;1
86079;La;Roche-Rigault;ROCHE-RIGAULT;86200;86;VIENNE;1
86080;;Cloué;CLOUE;86600;86;VIENNE;1
86081;;Colombiers;COLOMBIERS;86490;86;VIENNE;1
86082;;Couhé;COUHE;86700;86;VIENNE;1
86083;;Coulombiers;COULOMBIERS;86600;86;VIENNE;1
86084;;Coulonges;COULONGES;86290;86;VIENNE;1
86085;;Coussay;COUSSAY;86110;86;VIENNE;1
86086;;Coussay-les-Bois;COUSSAY-LES-BOIS;86270;86;VIENNE;1
86087;;Craon;CRAON;86110;86;VIENNE;1
86088;;Croutelle;CROUTELLE;86240;86;VIENNE;1
86089;;Cuhon;CUHON;86110;86;VIENNE;1
86090;;Curçay-sur-Dive;CURCAY-SUR-DIVE;86120;86;VIENNE;1
86091;;Curzay-sur-Vonne;CURZAY-SUR-VONNE;86600;86;VIENNE;1
86092;;Dangé-Saint-Romain;DANGE-SAINT-ROMAIN;86220;86;VIENNE;1
86093;;Dercé;DERCE;86420;86;VIENNE;1
86094;;Dienné;DIENNE;86410;86;VIENNE;1
86095;;Dissay;DISSAY;86130;86;VIENNE;1
86096;;Doussay;DOUSSAY;86140;86;VIENNE;1
86097;La;Ferrière-Airoux;FERRIERE-AIROUX;86160;86;VIENNE;1
86098;;Fleix;FLEIX;86300;86;VIENNE;1
86099;;Fleuré;FLEURE;86340;86;VIENNE;1
86100;;Fontaine-le-Comte;FONTAINE-LE-COMTE;86240;86;VIENNE;1
86102;;Frozes;FROZES;86190;86;VIENNE;1
86103;;Gençay;GENCAY;86160;86;VIENNE;1
86104;;Genouillé;GENOUILLE;86250;86;VIENNE;1
86105;;Gizay;GIZAY;86340;86;VIENNE;1
86106;;Glénouze;GLENOUZE;86200;86;VIENNE;1
86107;;Gouex;GOUEX;86320;86;VIENNE;1
86108;La;Grimaudière;GRIMAUDIERE;86330;86;VIENNE;1
86109;;Guesnes;GUESNES;86420;86;VIENNE;1
86110;;Haims;HAIMS;86310;86;VIENNE;1
86111;;Ingrandes;INGRANDES;86220;86;VIENNE;1
86112;L';Isle-Jourdain;ISLE-JOURDAIN;86150;86;VIENNE;1
86113;;Iteuil;ITEUIL;86240;86;VIENNE;1
86114;;Jardres;JARDRES;86800;86;VIENNE;1
86115;;Jaunay-Clan;JAUNAY-CLAN;86130;86;VIENNE;1
86116;;Jazeneuil;JAZENEUIL;86600;86;VIENNE;1
86117;;Jouhet;JOUHET;86500;86;VIENNE;1
86118;;Journet;JOURNET;86290;86;VIENNE;1
86119;;Joussé;JOUSSE;86350;86;VIENNE;1
86120;;Lathus-Saint-Rémy;LATHUS-SAINT-REMY;86390;86;VIENNE;1
86121;;Latillé;LATILLE;86190;86;VIENNE;1
86122;;Lauthiers;LAUTHIERS;86300;86;VIENNE;1
86123;;Lavausseau;LAVAUSSEAU;86470;86;VIENNE;1
86124;;Lavoux;LAVOUX;86800;86;VIENNE;1
86125;;Leigné-les-Bois;LEIGNE-LES-BOIS;86450;86;VIENNE;1
86126;;Leignes-sur-Fontaine;LEIGNES-SUR-FONTAINE;86300;86;VIENNE;1
86127;;Leigné-sur-Usseau;LEIGNE-SUR-USSEAU;86230;86;VIENNE;1
86128;;Lencloître;LENCLOITRE;86140;86;VIENNE;1
86129;;Lésigny;LESIGNY;86270;86;VIENNE;1
86130;;Leugny;LEUGNY;86220;86;VIENNE;1
86131;;Lhommaizé;LHOMMAIZE;86410;86;VIENNE;1
86132;;Liglet;LIGLET;86290;86;VIENNE;1
86133;;Ligugé;LIGUGE;86240;86;VIENNE;1
86134;;Linazay;LINAZAY;86400;86;VIENNE;1
86135;;Liniers;LINIERS;86800;86;VIENNE;1
86136;;Lizant;LIZANT;86400;86;VIENNE;1
86137;;Loudun;LOUDUN;86200;86;VIENNE;1
86138;;Luchapt;LUCHAPT;86430;86;VIENNE;1
86139;;Lusignan;LUSIGNAN;86600;86;VIENNE;1
86140;;Lussac-les-Châteaux;LUSSAC-LES-CHATEAUX;86320;86;VIENNE;1
86141;;Magné;MAGNE;86160;86;VIENNE;1
86142;;Maillé;MAILLE;86190;86;VIENNE;1
86143;;Mairé;MAIRE;86270;86;VIENNE;1
86144;;Maisonneuve;MAISONNEUVE;86170;86;VIENNE;1
86145;;Marçay;MARCAY;86370;86;VIENNE;1
86146;;Marigny-Brizay;MARIGNY-BRIZAY;86380;86;VIENNE;1
86147;;Marigny-Chemereau;MARIGNY-CHEMEREAU;86370;86;VIENNE;1
86148;;Marnay;MARNAY;86160;86;VIENNE;1
86149;;Martaizé;MARTAIZE;86330;86;VIENNE;1
86150;;Massognes;MASSOGNES;86170;86;VIENNE;1
86151;;Maulay;MAULAY;86200;86;VIENNE;1
86152;;Mauprévoir;MAUPREVOIR;86460;86;VIENNE;1
86153;;Mazerolles;MAZEROLLES;86320;86;VIENNE;1
86154;;Mazeuil;MAZEUIL;86110;86;VIENNE;1
86156;;Messemé;MESSEME;86200;86;VIENNE;1
86157;;Mignaloux-Beauvoir;MIGNALOUX-BEAUVOIR;86550;86;VIENNE;1
86158;;Migné-Auxances;MIGNE-AUXANCES;86440;86;VIENNE;1
86159;;Millac;MILLAC;86150;86;VIENNE;1
86160;;Mirebeau;MIREBEAU;86110;86;VIENNE;1
86161;;Moncontour;MONCONTOUR;86330;86;VIENNE;1
86162;;Mondion;MONDION;86230;86;VIENNE;1
86163;;Montamisé;MONTAMISE;86360;86;VIENNE;1
86164;;Monthoiron;MONTHOIRON;86210;86;VIENNE;1
86165;;Montmorillon;MONTMORILLON;86500;86;VIENNE;1
86166;;Montreuil-Bonnin;MONTREUIL-BONNIN;86470;86;VIENNE;1
86167;;Monts-sur-Guesnes;MONTS-SUR-GUESNES;86420;86;VIENNE;1
86169;;Morton;MORTON;86120;86;VIENNE;1
86170;;Moulismes;MOULISMES;86500;86;VIENNE;1
86171;;Moussac;MOUSSAC;86150;86;VIENNE;1
86172;;Mouterre-sur-Blourde;MOUTERRE-SUR-BLOURDE;86430;86;VIENNE;1
86173;;Mouterre-Silly;MOUTERRE-SILLY;86200;86;VIENNE;1
86174;;Naintré;NAINTRE;86530;86;VIENNE;1
86175;;Nalliers;NALLIERS;86310;86;VIENNE;1
86176;;Nérignac;NERIGNAC;86150;86;VIENNE;1
86177;;Neuville-de-Poitou;NEUVILLE-DE-POITOU;86170;86;VIENNE;1
86178;;Nieuil-l'Espoir;NIEUIL-L'ESPOIR;86340;86;VIENNE;1
86180;;Nouaillé-Maupertuis;NOUAILLE-MAUPERTUIS;86340;86;VIENNE;1
86181;;Nueil-sous-Faye;NUEIL-SOUS-FAYE;86200;86;VIENNE;1
86182;;Orches;ORCHES;86230;86;VIENNE;1
86183;Les;Ormes;ORMES;86220;86;VIENNE;1
86184;;Ouzilly;OUZILLY;86380;86;VIENNE;1
86186;;Oyré;OYRE;86220;86;VIENNE;1
86187;;Paizay-le-Sec;PAIZAY-LE-SEC;86300;86;VIENNE;1
86188;;Payré;PAYRE;86700;86;VIENNE;1
86189;;Payroux;PAYROUX;86350;86;VIENNE;1
86190;;Persac;PERSAC;86320;86;VIENNE;1
86191;;Pindray;PINDRAY;86500;86;VIENNE;1
86192;;Plaisance;PLAISANCE;86500;86;VIENNE;1
86193;;Pleumartin;PLEUMARTIN;86450;86;VIENNE;1
86194;;Poitiers;POITIERS;86000;86;VIENNE;1
86195;;Port-de-Piles;PORT-DE-PILES;86220;86;VIENNE;1
86196;;Pouançay;POUANCAY;86120;86;VIENNE;1
86197;;Pouant;POUANT;86200;86;VIENNE;1
86198;;Pouillé;POUILLE;86800;86;VIENNE;1
86200;;Pressac;PRESSAC;86460;86;VIENNE;1
86201;;Prinçay;PRINCAY;86420;86;VIENNE;1
86202;La;Puye;PUYE;86260;86;VIENNE;1
86203;;Queaux;QUEAUX;86150;86;VIENNE;1
86204;;Quinçay;QUINCAY;86190;86;VIENNE;1
86205;;Ranton;RANTON;86200;86;VIENNE;1
86206;;Raslay;RASLAY;86120;86;VIENNE;1
86207;La;Roche-Posay;ROCHE-POSAY;86270;86;VIENNE;1
86208;Le;Rochereau;ROCHEREAU;86170;86;VIENNE;1
86209;;Roches-Prémarie-Andillé;ROCHES-PREMARIE-ANDILLE;86340;86;VIENNE;1
86210;;Roiffé;ROIFFE;86120;86;VIENNE;1
86211;;Romagne;ROMAGNE;86700;86;VIENNE;1
86213;;Rouillé;ROUILLE;86480;86;VIENNE;1
86214;;Saint-Benoît;SAINT-BENOIT;86280;86;VIENNE;1
86217;;Saint-Christophe;SAINT-CHRISTOPHE;86230;86;VIENNE;1
86218;;Saint-Clair;SAINT-CLAIR;86330;86;VIENNE;1
86219;;Saint-Cyr;SAINT-CYR;86130;86;VIENNE;1
86220;;Saint-Gaudent;SAINT-GAUDENT;86400;86;VIENNE;1
86221;;Saint-Genest-d'Ambière;SAINT-GENEST-D'AMBIERE;86140;86;VIENNE;1
86222;;Saint-Georges-lès-Baillargeaux;SAINT-GEORGES-LES-BAILLARGEAUX;86130;86;VIENNE;1
86223;;Saint-Germain;SAINT-GERMAIN;86310;86;VIENNE;1
86224;;Saint-Gervais-les-Trois-Clochers;SAINT-GERVAIS-LES-TROIS-CLOCHERS;86230;86;VIENNE;1
86225;;Saint-Jean-de-Sauves;SAINT-JEAN-DE-SAUVES;86330;86;VIENNE;1
86226;;Saint-Julien-l'Ars;SAINT-JULIEN-L'ARS;86800;86;VIENNE;1
86227;;Saint-Laon;SAINT-LAON;86200;86;VIENNE;1
86228;;Saint-Laurent-de-Jourdes;SAINT-LAURENT-DE-JOURDES;86410;86;VIENNE;1
86229;;Saint-Léger-de-Montbrillais;SAINT-LEGER-DE-MONTBRILLAIS;86120;86;VIENNE;1
86230;;Saint-Léomer;SAINT-LEOMER;86290;86;VIENNE;1
86231;;Saint-Macoux;SAINT-MACOUX;86400;86;VIENNE;1
86233;;Valdivienne;VALDIVIENNE;86300;86;VIENNE;1
86234;;Saint-Martin-l'Ars;SAINT-MARTIN-L'ARS;86350;86;VIENNE;1
86235;;Saint-Maurice-la-Clouère;SAINT-MAURICE-LA-CLOUERE;86160;86;VIENNE;1
86236;;Saint-Pierre-de-Maillé;SAINT-PIERRE-DE-MAILLE;86260;86;VIENNE;1
86237;;Saint-Pierre-d'Exideuil;SAINT-PIERRE-D'EXIDEUIL;86400;86;VIENNE;1
86239;;Sainte-Radégonde;SAINTE-RADEGONDE;86300;86;VIENNE;1
86241;;Saint-Rémy-sur-Creuse;SAINT-REMY-SUR-CREUSE;86220;86;VIENNE;1
86242;;Saint-Romain;SAINT-ROMAIN;86250;86;VIENNE;1
86244;;Saint-Sauvant;SAINT-SAUVANT;86600;86;VIENNE;1
86245;;Saint-Sauveur;SAINT-SAUVEUR;86100;86;VIENNE;1
86246;;Saint-Savin;SAINT-SAVIN;86310;86;VIENNE;1
86247;;Saint-Saviol;SAINT-SAVIOL;86400;86;VIENNE;1
86248;;Saint-Secondin;SAINT-SECONDIN;86350;86;VIENNE;1
86249;;Saires;SAIRES;86420;86;VIENNE;1
86250;;Saix;SAIX;86120;86;VIENNE;1
86252;;Sammarçolles;SAMMARCOLLES;86200;86;VIENNE;1
86253;;Sanxay;SANXAY;86600;86;VIENNE;1
86254;;Saulgé;SAULGE;86500;86;VIENNE;1
86255;;Savigné;SAVIGNE;86400;86;VIENNE;1
86256;;Savigny-Lévescault;SAVIGNY-LEVESCAULT;86800;86;VIENNE;1
86257;;Savigny-sous-Faye;SAVIGNY-SOUS-FAYE;86140;86;VIENNE;1
86258;;Scorbé-Clairvaux;SCORBE-CLAIRVAUX;86140;86;VIENNE;1
86259;;Senillé;SENILLE;86100;86;VIENNE;1
86260;;Sérigny;SERIGNY;86230;86;VIENNE;1
86261;;Sèvres-Anxaumont;SEVRES-ANXAUMONT;86800;86;VIENNE;1
86262;;Sillars;SILLARS;86320;86;VIENNE;1
86263;;Smarves;SMARVES;86240;86;VIENNE;1
86264;;Sommières-du-Clain;SOMMIERES-DU-CLAIN;86160;86;VIENNE;1
86265;;Sossais;SOSSAIS;86230;86;VIENNE;1
86266;;Surin;SURIN;86250;86;VIENNE;1
86268;;Tercé;TERCE;86800;86;VIENNE;1
86269;;Ternay;TERNAY;86120;86;VIENNE;1
86270;;Thollet;THOLLET;86290;86;VIENNE;1
86271;;Thurageau;THURAGEAU;86110;86;VIENNE;1
86272;;Thuré;THURE;86540;86;VIENNE;1
86273;La;Trimouille;TRIMOUILLE;86290;86;VIENNE;1
86274;Les;Trois-Moutiers;TROIS-MOUTIERS;86120;86;VIENNE;1
86275;;Usseau;USSEAU;86230;86;VIENNE;1
86276;;Usson-du-Poitou;USSON-DU-POITOU;86350;86;VIENNE;1
86277;;Varennes;VARENNES;86110;86;VIENNE;1
86278;;Vaux;VAUX;86700;86;VIENNE;1
86279;;Vaux-sur-Vienne;VAUX-SUR-VIENNE;86220;86;VIENNE;1
86280;;Vellèches;VELLECHES;86230;86;VIENNE;1
86281;;Vendeuvre-du-Poitou;VENDEUVRE-DU-POITOU;86380;86;VIENNE;1
86284;;Vernon;VERNON;86340;86;VIENNE;1
86285;;Verrières;VERRIERES;86410;86;VIENNE;1
86286;;Verrue;VERRUE;86420;86;VIENNE;1
86287;;Vézières;VEZIERES;86120;86;VIENNE;1
86288;;Vicq-sur-Gartempe;VICQ-SUR-GARTEMPE;86260;86;VIENNE;1
86289;Le;Vigeant;VIGEANT;86150;86;VIENNE;1
86290;La;Villedieu-du-Clain;VILLEDIEU-DU-CLAIN;86340;86;VIENNE;1
86291;;Villemort;VILLEMORT;86310;86;VIENNE;1
86292;;Villiers;VILLIERS;86190;86;VIENNE;1
86293;;Vivonne;VIVONNE;86370;86;VIENNE;1
86294;;Vouillé;VOUILLE;86190;86;VIENNE;1
86295;;Voulême;VOULEME;86400;86;VIENNE;1
86296;;Voulon;VOULON;86700;86;VIENNE;1
86297;;Vouneuil-sous-Biard;VOUNEUIL-SOUS-BIARD;86580;86;VIENNE;1
86298;;Vouneuil-sur-Vienne;VOUNEUIL-SUR-VIENNE;86210;86;VIENNE;1
86299;;Vouzailles;VOUZAILLES;86170;86;VIENNE;1
86300;;Yversay;YVERSAY;86170;86;VIENNE;1
87001;;Aixe-sur-Vienne;AIXE-SUR-VIENNE;87700;87;HAUTE VIENNE;1
87002;;Ambazac;AMBAZAC;87240;87;HAUTE VIENNE;1
87003;;Arnac-la-Poste;ARNAC-LA-POSTE;87160;87;HAUTE VIENNE;1
87004;;Augne;AUGNE;87120;87;HAUTE VIENNE;1
87005;;Aureil;AUREIL;87220;87;HAUTE VIENNE;1
87006;;Azat-le-Ris;AZAT-LE-RIS;87360;87;HAUTE VIENNE;1
87007;;Balledent;BALLEDENT;87290;87;HAUTE VIENNE;1
87008;La;Bazeuge;BAZEUGE;87210;87;HAUTE VIENNE;1
87009;;Beaumont-du-Lac;BEAUMONT-DU-LAC;87120;87;HAUTE VIENNE;1
87011;;Bellac;BELLAC;87300;87;HAUTE VIENNE;1
87012;;Berneuil;BERNEUIL;87300;87;HAUTE VIENNE;1
87013;;Bersac-sur-Rivalier;BERSAC-SUR-RIVALIER;87370;87;HAUTE VIENNE;1
87014;;Bessines-sur-Gartempe;BESSINES-SUR-GARTEMPE;87250;87;HAUTE VIENNE;1
87015;;Beynac;BEYNAC;87700;87;HAUTE VIENNE;1
87016;Les;Billanges;BILLANGES;87340;87;HAUTE VIENNE;1
87017;;Blanzac;BLANZAC;87300;87;HAUTE VIENNE;1
87018;;Blond;BLOND;87300;87;HAUTE VIENNE;1
87019;;Boisseuil;BOISSEUIL;87220;87;HAUTE VIENNE;1
87020;;Bonnac-la-Côte;BONNAC-LA-COTE;87270;87;HAUTE VIENNE;1
87021;;Bosmie-l'Aiguille;BOSMIE-L'AIGUILLE;87110;87;HAUTE VIENNE;1
87022;;Breuilaufa;BREUILAUFA;87300;87;HAUTE VIENNE;1
87023;Le;Buis;BUIS;87140;87;HAUTE VIENNE;1
87024;;Bujaleuf;BUJALEUF;87460;87;HAUTE VIENNE;1
87025;;Burgnac;BURGNAC;87800;87;HAUTE VIENNE;1
87026;;Bussière-Boffy;BUSSIERE-BOFFY;87330;87;HAUTE VIENNE;1
87027;;Bussière-Galant;BUSSIERE-GALANT;87230;87;HAUTE VIENNE;1
87028;;Bussière-Poitevine;BUSSIERE-POITEVINE;87320;87;HAUTE VIENNE;1
87029;Les;Cars;CARS;87230;87;HAUTE VIENNE;1
87030;;Chaillac-sur-Vienne;CHAILLAC-SUR-VIENNE;87200;87;HAUTE VIENNE;1
87031;Le;Chalard;CHALARD;87500;87;HAUTE VIENNE;1
87032;;Châlus;CHALUS;87230;87;HAUTE VIENNE;1
87033;;Chamboret;CHAMBORET;87140;87;HAUTE VIENNE;1
87034;;Champagnac-la-Rivière;CHAMPAGNAC-LA-RIVIERE;87150;87;HAUTE VIENNE;1
87035;;Champnétery;CHAMPNETERY;87400;87;HAUTE VIENNE;1
87036;;Champsac;CHAMPSAC;87230;87;HAUTE VIENNE;1
87037;La;Chapelle-Montbrandeix;CHAPELLE-MONTBRANDEIX;87440;87;HAUTE VIENNE;1
87038;;Chaptelat;CHAPTELAT;87270;87;HAUTE VIENNE;1
87039;;Château-Chervix;CHATEAU-CHERVIX;87380;87;HAUTE VIENNE;1
87040;;Châteauneuf-la-Forêt;CHATEAUNEUF-LA-FORET;87130;87;HAUTE VIENNE;1
87041;;Châteauponsac;CHATEAUPONSAC;87290;87;HAUTE VIENNE;1
87042;Le;Châtenet-en-Dognon;CHATENET-EN-DOGNON;87400;87;HAUTE VIENNE;1
87043;;Cheissoux;CHEISSOUX;87460;87;HAUTE VIENNE;1
87044;;Chéronnac;CHERONNAC;87600;87;HAUTE VIENNE;1
87045;;Cieux;CIEUX;87520;87;HAUTE VIENNE;1
87046;;Cognac-la-Forêt;COGNAC-LA-FORET;87310;87;HAUTE VIENNE;1
87047;;Compreignac;COMPREIGNAC;87140;87;HAUTE VIENNE;1
87048;;Condat-sur-Vienne;CONDAT-SUR-VIENNE;87920;87;HAUTE VIENNE;1
87049;;Coussac-Bonneval;COUSSAC-BONNEVAL;87500;87;HAUTE VIENNE;1
87050;;Couzeix;COUZEIX;87270;87;HAUTE VIENNE;1
87051;La;Croisille-sur-Briance;CROISILLE-SUR-BRIANCE;87130;87;HAUTE VIENNE;1
87052;La;Croix-sur-Gartempe;CROIX-SUR-GARTEMPE;87210;87;HAUTE VIENNE;1
87053;;Cromac;CROMAC;87160;87;HAUTE VIENNE;1
87054;;Cussac;CUSSAC;87150;87;HAUTE VIENNE;1
87055;;Darnac;DARNAC;87320;87;HAUTE VIENNE;1
87056;;Dinsac;DINSAC;87210;87;HAUTE VIENNE;1
87057;;Dompierre-les-Églises;DOMPIERRE-LES-EGLISES;87190;87;HAUTE VIENNE;1
87058;;Domps;DOMPS;87120;87;HAUTE VIENNE;1
87059;Le;Dorat;DORAT;87210;87;HAUTE VIENNE;1
87060;;Dournazac;DOURNAZAC;87230;87;HAUTE VIENNE;1
87061;;Droux;DROUX;87190;87;HAUTE VIENNE;1
87062;;Eybouleuf;EYBOULEUF;87400;87;HAUTE VIENNE;1
87063;;Eyjeaux;EYJEAUX;87220;87;HAUTE VIENNE;1
87064;;Eymoutiers;EYMOUTIERS;87120;87;HAUTE VIENNE;1
87065;;Feytiat;FEYTIAT;87220;87;HAUTE VIENNE;1
87066;;Flavignac;FLAVIGNAC;87230;87;HAUTE VIENNE;1
87067;;Folles;FOLLES;87250;87;HAUTE VIENNE;1
87068;;Fromental;FROMENTAL;87250;87;HAUTE VIENNE;1
87069;;Gajoubert;GAJOUBERT;87330;87;HAUTE VIENNE;1
87070;La;Geneytouse;GENEYTOUSE;87400;87;HAUTE VIENNE;1
87071;;Glandon;GLANDON;87500;87;HAUTE VIENNE;1
87072;;Glanges;GLANGES;87380;87;HAUTE VIENNE;1
87073;;Gorre;GORRE;87310;87;HAUTE VIENNE;1
87074;Les;Grands-Chézeaux;GRANDS-CHEZEAUX;87160;87;HAUTE VIENNE;1
87075;;Isle;ISLE;87170;87;HAUTE VIENNE;1
87076;;Jabreilles-les-Bordes;JABREILLES-LES-BORDES;87370;87;HAUTE VIENNE;1
87077;;Janailhac;JANAILHAC;87800;87;HAUTE VIENNE;1
87078;;Javerdat;JAVERDAT;87520;87;HAUTE VIENNE;1
87079;La;Jonchère-Saint-Maurice;JONCHERE-SAINT-MAURICE;87340;87;HAUTE VIENNE;1
87080;;Jouac;JOUAC;87890;87;HAUTE VIENNE;1
87081;;Jourgnac;JOURGNAC;87800;87;HAUTE VIENNE;1
87082;;Ladignac-le-Long;LADIGNAC-LE-LONG;87500;87;HAUTE VIENNE;1
87083;;Laurière;LAURIERE;87370;87;HAUTE VIENNE;1
87084;;Lavignac;LAVIGNAC;87230;87;HAUTE VIENNE;1
87085;;Limoges;LIMOGES;87000;87;HAUTE VIENNE;1
87086;;Linards;LINARDS;87130;87;HAUTE VIENNE;1
87087;;Lussac-les-Églises;LUSSAC-LES-EGLISES;87360;87;HAUTE VIENNE;1
87088;;Magnac-Bourg;MAGNAC-BOURG;87380;87;HAUTE VIENNE;1
87089;;Magnac-Laval;MAGNAC-LAVAL;87190;87;HAUTE VIENNE;1
87090;;Mailhac-sur-Benaize;MAILHAC-SUR-BENAIZE;87160;87;HAUTE VIENNE;1
87091;;Maisonnais-sur-Tardoire;MAISONNAIS-SUR-TARDOIRE;87440;87;HAUTE VIENNE;1
87092;;Marval;MARVAL;87440;87;HAUTE VIENNE;1
87093;;Masléon;MASLEON;87130;87;HAUTE VIENNE;1
87094;;Meilhac;MEILHAC;87800;87;HAUTE VIENNE;1
87095;;Meuzac;MEUZAC;87380;87;HAUTE VIENNE;1
87096;La;Meyze;MEYZE;87800;87;HAUTE VIENNE;1
87097;;Mézières-sur-Issoire;MEZIERES-SUR-ISSOIRE;87330;87;HAUTE VIENNE;1
87099;;Moissannes;MOISSANNES;87400;87;HAUTE VIENNE;1
87100;;Montrol-Sénard;MONTROL-SENARD;87330;87;HAUTE VIENNE;1
87101;;Mortemart;MORTEMART;87330;87;HAUTE VIENNE;1
87103;;Nantiat;NANTIAT;87140;87;HAUTE VIENNE;1
87104;;Nedde;NEDDE;87120;87;HAUTE VIENNE;1
87105;;Neuvic-Entier;NEUVIC-ENTIER;87130;87;HAUTE VIENNE;1
87106;;Nexon;NEXON;87800;87;HAUTE VIENNE;1
87107;;Nieul;NIEUL;87510;87;HAUTE VIENNE;1
87108;;Nouic;NOUIC;87330;87;HAUTE VIENNE;1
87109;;Oradour-Saint-Genest;ORADOUR-SAINT-GENEST;87210;87;HAUTE VIENNE;1
87110;;Oradour-sur-Glane;ORADOUR-SUR-GLANE;87520;87;HAUTE VIENNE;1
87111;;Oradour-sur-Vayres;ORADOUR-SUR-VAYRES;87150;87;HAUTE VIENNE;1
87112;;Pageas;PAGEAS;87230;87;HAUTE VIENNE;1
87113;Le;Palais-sur-Vienne;PALAIS-SUR-VIENNE;87410;87;HAUTE VIENNE;1
87114;;Panazol;PANAZOL;87350;87;HAUTE VIENNE;1
87115;;Pensol;PENSOL;87440;87;HAUTE VIENNE;1
87116;;Peyrat-de-Bellac;PEYRAT-DE-BELLAC;87300;87;HAUTE VIENNE;1
87117;;Peyrat-le-Château;PEYRAT-LE-CHATEAU;87470;87;HAUTE VIENNE;1
87118;;Peyrilhac;PEYRILHAC;87510;87;HAUTE VIENNE;1
87119;;Pierre-Buffière;PIERRE-BUFFIERE;87260;87;HAUTE VIENNE;1
87120;La;Porcherie;PORCHERIE;87380;87;HAUTE VIENNE;1
87121;;Rancon;RANCON;87290;87;HAUTE VIENNE;1
87122;;Razès;RAZES;87640;87;HAUTE VIENNE;1
87123;;Rempnat;REMPNAT;87120;87;HAUTE VIENNE;1
87124;;Rilhac-Lastours;RILHAC-LASTOURS;87800;87;HAUTE VIENNE;1
87125;;Rilhac-Rancon;RILHAC-RANCON;87570;87;HAUTE VIENNE;1
87126;;Rochechouart;ROCHECHOUART;87600;87;HAUTE VIENNE;1
87127;La;Roche-l'Abeille;ROCHE-L'ABEILLE;87800;87;HAUTE VIENNE;1
87128;;Roussac;ROUSSAC;87140;87;HAUTE VIENNE;1
87129;;Royères;ROYERES;87400;87;HAUTE VIENNE;1
87130;;Roziers-Saint-Georges;ROZIERS-SAINT-GEORGES;87130;87;HAUTE VIENNE;1
87131;;Saillat-sur-Vienne;SAILLAT-SUR-VIENNE;87720;87;HAUTE VIENNE;1
87132;;Saint-Amand-le-Petit;SAINT-AMAND-LE-PETIT;87120;87;HAUTE VIENNE;1
87133;;Saint-Amand-Magnazeix;SAINT-AMAND-MAGNAZEIX;87290;87;HAUTE VIENNE;1
87134;;Sainte-Anne-Saint-Priest;SAINTE-ANNE-SAINT-PRIEST;87120;87;HAUTE VIENNE;1
87135;;Saint-Auvent;SAINT-AUVENT;87310;87;HAUTE VIENNE;1
87136;;Saint-Barbant;SAINT-BARBANT;87330;87;HAUTE VIENNE;1
87137;;Saint-Bazile;SAINT-BAZILE;87150;87;HAUTE VIENNE;1
87138;;Saint-Bonnet-Briance;SAINT-BONNET-BRIANCE;87260;87;HAUTE VIENNE;1
87139;;Saint-Bonnet-de-Bellac;SAINT-BONNET-DE-BELLAC;87300;87;HAUTE VIENNE;1
87140;;Saint-Brice-sur-Vienne;SAINT-BRICE-SUR-VIENNE;87200;87;HAUTE VIENNE;1
87141;;Saint-Cyr;SAINT-CYR;87310;87;HAUTE VIENNE;1
87142;;Saint-Denis-des-Murs;SAINT-DENIS-DES-MURS;87400;87;HAUTE VIENNE;1
87143;;Saint-Gence;SAINT-GENCE;87510;87;HAUTE VIENNE;1
87144;;Saint-Genest-sur-Roselle;SAINT-GENEST-SUR-ROSELLE;87260;87;HAUTE VIENNE;1
87145;;Saint-Georges-les-Landes;SAINT-GEORGES-LES-LANDES;87160;87;HAUTE VIENNE;1
87146;;Saint-Germain-les-Belles;SAINT-GERMAIN-LES-BELLES;87380;87;HAUTE VIENNE;1
87147;;Saint-Gilles-les-Forêts;SAINT-GILLES-LES-FORETS;87130;87;HAUTE VIENNE;1
87148;;Saint-Hilaire-Bonneval;SAINT-HILAIRE-BONNEVAL;87260;87;HAUTE VIENNE;1
87149;;Saint-Hilaire-la-Treille;SAINT-HILAIRE-LA-TREILLE;87190;87;HAUTE VIENNE;1
87150;;Saint-Hilaire-les-Places;SAINT-HILAIRE-LES-PLACES;87800;87;HAUTE VIENNE;1
87151;;Saint-Jean-Ligoure;SAINT-JEAN-LIGOURE;87260;87;HAUTE VIENNE;1
87152;;Saint-Jouvent;SAINT-JOUVENT;87510;87;HAUTE VIENNE;1
87153;;Saint-Julien-le-Petit;SAINT-JULIEN-LE-PETIT;87460;87;HAUTE VIENNE;1
87154;;Saint-Junien;SAINT-JUNIEN;87200;87;HAUTE VIENNE;1
87155;;Saint-Junien-les-Combes;SAINT-JUNIEN-LES-COMBES;87300;87;HAUTE VIENNE;1
87156;;Saint-Just-le-Martel;SAINT-JUST-LE-MARTEL;87590;87;HAUTE VIENNE;1
87157;;Saint-Laurent-les-Églises;SAINT-LAURENT-LES-EGLISES;87340;87;HAUTE VIENNE;1
87158;;Saint-Laurent-sur-Gorre;SAINT-LAURENT-SUR-GORRE;87310;87;HAUTE VIENNE;1
87159;;Saint-Léger-la-Montagne;SAINT-LEGER-LA-MONTAGNE;87340;87;HAUTE VIENNE;1
87160;;Saint-Léger-Magnazeix;SAINT-LEGER-MAGNAZEIX;87190;87;HAUTE VIENNE;1
87161;;Saint-Léonard-de-Noblat;SAINT-LEONARD-DE-NOBLAT;87400;87;HAUTE VIENNE;1
87162;;Sainte-Marie-de-Vaux;SAINTE-MARIE-DE-VAUX;87420;87;HAUTE VIENNE;1
87163;;Saint-Martial-sur-Isop;SAINT-MARTIAL-SUR-ISOP;87330;87;HAUTE VIENNE;1
87164;;Saint-Martin-de-Jussac;SAINT-MARTIN-DE-JUSSAC;87200;87;HAUTE VIENNE;1
87165;;Saint-Martin-le-Mault;SAINT-MARTIN-LE-MAULT;87360;87;HAUTE VIENNE;1
87166;;Saint-Martin-le-Vieux;SAINT-MARTIN-LE-VIEUX;87700;87;HAUTE VIENNE;1
87167;;Saint-Martin-Terressus;SAINT-MARTIN-TERRESSUS;87400;87;HAUTE VIENNE;1
87168;;Saint-Mathieu;SAINT-MATHIEU;87440;87;HAUTE VIENNE;1
87169;;Saint-Maurice-les-Brousses;SAINT-MAURICE-LES-BROUSSES;87800;87;HAUTE VIENNE;1
87170;;Saint-Méard;SAINT-MEARD;87130;87;HAUTE VIENNE;1
87172;;Saint-Ouen-sur-Gartempe;SAINT-OUEN-SUR-GARTEMPE;87300;87;HAUTE VIENNE;1
87173;;Saint-Pardoux;SAINT-PARDOUX;87250;87;HAUTE VIENNE;1
87174;;Saint-Paul;SAINT-PAUL;87260;87;HAUTE VIENNE;1
87176;;Saint-Priest-Ligoure;SAINT-PRIEST-LIGOURE;87800;87;HAUTE VIENNE;1
87177;;Saint-Priest-sous-Aixe;SAINT-PRIEST-SOUS-AIXE;87700;87;HAUTE VIENNE;1
87178;;Saint-Priest-Taurion;SAINT-PRIEST-TAURION;87480;87;HAUTE VIENNE;1
87179;;Saint-Sornin-la-Marche;SAINT-SORNIN-LA-MARCHE;87210;87;HAUTE VIENNE;1
87180;;Saint-Sornin-Leulac;SAINT-SORNIN-LEULAC;87290;87;HAUTE VIENNE;1
87181;;Saint-Sulpice-Laurière;SAINT-SULPICE-LAURIERE;87370;87;HAUTE VIENNE;1
87182;;Saint-Sulpice-les-Feuilles;SAINT-SULPICE-LES-FEUILLES;87160;87;HAUTE VIENNE;1
87183;;Saint-Sylvestre;SAINT-SYLVESTRE;87240;87;HAUTE VIENNE;1
87184;;Saint-Symphorien-sur-Couze;SAINT-SYMPHORIEN-SUR-COUZE;87140;87;HAUTE VIENNE;1
87185;;Saint-Victurnien;SAINT-VICTURNIEN;87420;87;HAUTE VIENNE;1
87186;;Saint-Vitte-sur-Briance;SAINT-VITTE-SUR-BRIANCE;87380;87;HAUTE VIENNE;1
87187;;Saint-Yrieix-la-Perche;SAINT-YRIEIX-LA-PERCHE;87500;87;HAUTE VIENNE;1
87188;;Saint-Yrieix-sous-Aixe;SAINT-YRIEIX-SOUS-AIXE;87700;87;HAUTE VIENNE;1
87189;Les;Salles-Lavauguyon;SALLES-LAVAUGUYON;87440;87;HAUTE VIENNE;1
87190;;Sauviat-sur-Vige;SAUVIAT-SUR-VIGE;87400;87;HAUTE VIENNE;1
87191;;Séreilhac;SEREILHAC;87620;87;HAUTE VIENNE;1
87192;;Solignac;SOLIGNAC;87110;87;HAUTE VIENNE;1
87193;;Surdoux;SURDOUX;87130;87;HAUTE VIENNE;1
87194;;Sussac;SUSSAC;87130;87;HAUTE VIENNE;1
87195;;Tersannes;TERSANNES;87360;87;HAUTE VIENNE;1
87196;;Thiat;THIAT;87320;87;HAUTE VIENNE;1
87197;;Thouron;THOURON;87140;87;HAUTE VIENNE;1
87198;;Vaulry;VAULRY;87140;87;HAUTE VIENNE;1
87199;;Vayres;VAYRES;87600;87;HAUTE VIENNE;1
87200;;Verneuil-Moustiers;VERNEUIL-MOUSTIERS;87360;87;HAUTE VIENNE;1
87201;;Verneuil-sur-Vienne;VERNEUIL-SUR-VIENNE;87430;87;HAUTE VIENNE;1
87202;;Veyrac;VEYRAC;87520;87;HAUTE VIENNE;1
87203;;Vicq-sur-Breuilh;VICQ-SUR-BREUILH;87260;87;HAUTE VIENNE;1
87204;;Videix;VIDEIX;87600;87;HAUTE VIENNE;1
87205;Le;Vigen;VIGEN;87110;87;HAUTE VIENNE;1
87206;;Villefavard;VILLEFAVARD;87190;87;HAUTE VIENNE;1
88001;Les;Ableuvenettes;ABLEUVENETTES;88270;88;VOSGES;1
88002;;Ahéville;AHEVILLE;88500;88;VOSGES;1
88003;;Aingeville;AINGEVILLE;88140;88;VOSGES;1
88004;;Ainvelle;AINVELLE;88320;88;VOSGES;1
88005;;Allarmont;ALLARMONT;88110;88;VOSGES;1
88006;;Ambacourt;AMBACOURT;88500;88;VOSGES;1
88007;;Ameuvelle;AMEUVELLE;88410;88;VOSGES;1
88008;;Anglemont;ANGLEMONT;88700;88;VOSGES;1
88009;;Anould;ANOULD;88650;88;VOSGES;1
88010;;Aouze;AOUZE;88170;88;VOSGES;1
88011;;Arches;ARCHES;88380;88;VOSGES;1
88012;;Archettes;ARCHETTES;88380;88;VOSGES;1
88013;;Aroffe;AROFFE;88170;88;VOSGES;1
88014;;Arrentès-de-Corcieux;ARRENTES-DE-CORCIEUX;88430;88;VOSGES;1
88015;;Attignéville;ATTIGNEVILLE;88300;88;VOSGES;1
88016;;Attigny;ATTIGNY;88260;88;VOSGES;1
88017;;Aulnois;AULNOIS;88300;88;VOSGES;1
88018;;Aumontzey;AUMONTZEY;88640;88;VOSGES;1
88019;;Autigny-la-Tour;AUTIGNY-LA-TOUR;88300;88;VOSGES;1
88020;;Autreville;AUTREVILLE;88300;88;VOSGES;1
88021;;Autrey;AUTREY;88700;88;VOSGES;1
88022;;Auzainvilliers;AUZAINVILLIERS;88140;88;VOSGES;1
88023;;Avillers;AVILLERS;88500;88;VOSGES;1
88024;;Avrainville;AVRAINVILLE;88130;88;VOSGES;1
88025;;Avranville;AVRANVILLE;88630;88;VOSGES;1
88026;;Aydoilles;AYDOILLES;88600;88;VOSGES;1
88027;;Badménil-aux-Bois;BADMENIL-AUX-BOIS;88330;88;VOSGES;1
88028;La;Baffe;BAFFE;88460;88;VOSGES;1
88029;;Bains-les-Bains;BAINS-LES-BAINS;88240;88;VOSGES;1
88030;;Bainville-aux-Saules;BAINVILLE-AUX-SAULES;88270;88;VOSGES;1
88031;;Balléville;BALLEVILLE;88170;88;VOSGES;1
88032;;Ban-de-Laveline;BAN-DE-LAVELINE;88520;88;VOSGES;1
88033;;Ban-de-Sapt;BAN-DE-SAPT;88210;88;VOSGES;1
88035;;Barbey-Seroux;BARBEY-SEROUX;88640;88;VOSGES;1
88036;;Barville;BARVILLE;88300;88;VOSGES;1
88037;;Basse-sur-le-Rupt;BASSE-SUR-LE-RUPT;88120;88;VOSGES;1
88038;;Battexey;BATTEXEY;88130;88;VOSGES;1
88039;;Baudricourt;BAUDRICOURT;88500;88;VOSGES;1
88040;;Bayecourt;BAYECOURT;88150;88;VOSGES;1
88041;;Bazegney;BAZEGNEY;88270;88;VOSGES;1
88042;;Bazien;BAZIEN;88700;88;VOSGES;1
88043;;Bazoilles-et-Ménil;BAZOILLES-ET-MENIL;88500;88;VOSGES;1
88044;;Bazoilles-sur-Meuse;BAZOILLES-SUR-MEUSE;88300;88;VOSGES;1
88045;;Beaufremont;BEAUFREMONT;88300;88;VOSGES;1
88046;;Beauménil;BEAUMENIL;88600;88;VOSGES;1
88047;;Begnécourt;BEGNECOURT;88270;88;VOSGES;1
88048;;Bellefontaine;BELLEFONTAINE;88370;88;VOSGES;1
88049;;Belmont-lès-Darney;BELMONT-LES-DARNEY;88260;88;VOSGES;1
88050;;Belmont-sur-Buttant;BELMONT-SUR-BUTTANT;88600;88;VOSGES;1
88051;;Belmont-sur-Vair;BELMONT-SUR-VAIR;88800;88;VOSGES;1
88052;;Belrupt;BELRUPT;88260;88;VOSGES;1
88053;;Belval;BELVAL;88210;88;VOSGES;1
88054;;Bertrimoutier;BERTRIMOUTIER;88520;88;VOSGES;1
88055;;Bettegney-Saint-Brice;BETTEGNEY-SAINT-BRICE;88450;88;VOSGES;1
88056;;Bettoncourt;BETTONCOURT;88500;88;VOSGES;1
88057;Le;Beulay;BEULAY;88490;88;VOSGES;1
88058;;Biécourt;BIECOURT;88170;88;VOSGES;1
88059;;Biffontaine;BIFFONTAINE;88430;88;VOSGES;1
88060;;Blémerey;BLEMEREY;88500;88;VOSGES;1
88061;;Bleurville;BLEURVILLE;88410;88;VOSGES;1
88062;;Blevaincourt;BLEVAINCOURT;88320;88;VOSGES;1
88063;;Bocquegney;BOCQUEGNEY;88270;88;VOSGES;1
88064;;Bois-de-Champ;BOIS-DE-CHAMP;88600;88;VOSGES;1
88065;;Bonvillet;BONVILLET;88260;88;VOSGES;1
88066;;Boulaincourt;BOULAINCOURT;88500;88;VOSGES;1
88068;La;Bourgonce;BOURGONCE;88470;88;VOSGES;1
88069;;Bouxières-aux-Bois;BOUXIERES-AUX-BOIS;88270;88;VOSGES;1
88070;;Bouxurulles;BOUXURULLES;88130;88;VOSGES;1
88071;;Bouzemont;BOUZEMONT;88270;88;VOSGES;1
88073;;Brantigny;BRANTIGNY;88130;88;VOSGES;1
88074;;Brechainville;BRECHAINVILLE;88350;88;VOSGES;1
88075;La;Bresse;BRESSE;88250;88;VOSGES;1
88076;;Brouvelieures;BROUVELIEURES;88600;88;VOSGES;1
88077;;Brû;BRU;88700;88;VOSGES;1
88078;;Bruyères;BRUYERES;88600;88;VOSGES;1
88079;;Bulgnéville;BULGNEVILLE;88140;88;VOSGES;1
88080;;Bult;BULT;88700;88;VOSGES;1
88081;;Bussang;BUSSANG;88540;88;VOSGES;1
88082;;Celles-sur-Plaine;CELLES-SUR-PLAINE;88110;88;VOSGES;1
88083;;Certilleux;CERTILLEUX;88300;88;VOSGES;1
88084;;Chamagne;CHAMAGNE;88130;88;VOSGES;1
88085;;Champdray;CHAMPDRAY;88640;88;VOSGES;1
88086;;Champ-le-Duc;CHAMP-LE-DUC;88600;88;VOSGES;1
88087;;Chantraine;CHANTRAINE;88000;88;VOSGES;1
88088;La;Chapelle-aux-Bois;CHAPELLE-AUX-BOIS;88240;88;VOSGES;1
88089;La;Chapelle-devant-Bruyères;CHAPELLE-DEVANT-BRUYERES;88600;88;VOSGES;1
88090;;Charmes;CHARMES;88130;88;VOSGES;1
88091;;Charmois-devant-Bruyères;CHARMOIS-DEVANT-BRUYERES;88460;88;VOSGES;1
88092;;Charmois-l'Orgueilleux;CHARMOIS-L'ORGUEILLEUX;88270;88;VOSGES;1
88093;;Châtas;CHATAS;88210;88;VOSGES;1
88094;;Châtel-sur-Moselle;CHATEL-SUR-MOSELLE;88330;88;VOSGES;1
88095;;Châtenois;CHATENOIS;88170;88;VOSGES;1
88096;;Châtillon-sur-Saône;CHATILLON-SUR-SAONE;88410;88;VOSGES;1
88097;;Chauffecourt;CHAUFFECOURT;88500;88;VOSGES;1
88098;;Chaumousey;CHAUMOUSEY;88390;88;VOSGES;1
88099;;Chavelot;CHAVELOT;88150;88;VOSGES;1
88100;;Chef-Haut;CHEF-HAUT;88500;88;VOSGES;1
88101;;Cheniménil;CHENIMENIL;88460;88;VOSGES;1
88102;;Chermisey;CHERMISEY;88630;88;VOSGES;1
88103;;Circourt;CIRCOURT;88270;88;VOSGES;1
88104;;Circourt-sur-Mouzon;CIRCOURT-SUR-MOUZON;88300;88;VOSGES;1
88105;;Claudon;CLAUDON;88410;88;VOSGES;1
88106;;Ban-sur-Meurthe-Clefcy;BAN-SUR-MEURTHE-CLEFCY;88230;88;VOSGES;1
88107;;Clérey-la-Côte;CLEREY-LA-COTE;88630;88;VOSGES;1
88108;Le;Clerjus;CLERJUS;88240;88;VOSGES;1
88109;;Cleurie;CLEURIE;88120;88;VOSGES;1
88110;;Clézentaine;CLEZENTAINE;88700;88;VOSGES;1
88111;;Coinches;COINCHES;88100;88;VOSGES;1
88112;;Colroy-la-Grande;COLROY-LA-GRANDE;88490;88;VOSGES;1
88113;;Combrimont;COMBRIMONT;88490;88;VOSGES;1
88114;;Contrexéville;CONTREXEVILLE;88140;88;VOSGES;1
88115;;Corcieux;CORCIEUX;88430;88;VOSGES;1
88116;;Cornimont;CORNIMONT;88310;88;VOSGES;1
88117;;Courcelles-sous-Châtenois;COURCELLES-SOUS-CHATENOIS;88170;88;VOSGES;1
88118;;Coussey;COUSSEY;88630;88;VOSGES;1
88119;;Crainvilliers;CRAINVILLIERS;88140;88;VOSGES;1
88120;La;Croix-aux-Mines;CROIX-AUX-MINES;88520;88;VOSGES;1
88121;;Damas-aux-Bois;DAMAS-AUX-BOIS;88330;88;VOSGES;1
88122;;Damas-et-Bettegney;DAMAS-ET-BETTEGNEY;88270;88;VOSGES;1
88123;;Damblain;DAMBLAIN;88320;88;VOSGES;1
88124;;Darney;DARNEY;88260;88;VOSGES;1
88125;;Darney-aux-Chênes;DARNEY-AUX-CHENES;88170;88;VOSGES;1
88126;;Darnieulles;DARNIEULLES;88390;88;VOSGES;1
88127;;Deinvillers;DEINVILLERS;88700;88;VOSGES;1
88128;;Denipaire;DENIPAIRE;88210;88;VOSGES;1
88129;;Derbamont;DERBAMONT;88270;88;VOSGES;1
88130;;Destord;DESTORD;88600;88;VOSGES;1
88131;;Deycimont;DEYCIMONT;88600;88;VOSGES;1
88132;;Deyvillers;DEYVILLERS;88000;88;VOSGES;1
88133;;Dignonville;DIGNONVILLE;88000;88;VOSGES;1
88134;;Dinozé;DINOZE;88000;88;VOSGES;1
88135;;Docelles;DOCELLES;88460;88;VOSGES;1
88136;;Dogneville;DOGNEVILLE;88000;88;VOSGES;1
88137;;Dolaincourt;DOLAINCOURT;88170;88;VOSGES;1
88138;;Dombasle-devant-Darney;DOMBASLE-DEVANT-DARNEY;88260;88;VOSGES;1
88139;;Dombasle-en-Xaintois;DOMBASLE-EN-XAINTOIS;88500;88;VOSGES;1
88140;;Dombrot-le-Sec;DOMBROT-LE-SEC;88140;88;VOSGES;1
88141;;Dombrot-sur-Vair;DOMBROT-SUR-VAIR;88170;88;VOSGES;1
88142;;Domèvre-sur-Avière;DOMEVRE-SUR-AVIERE;88390;88;VOSGES;1
88143;;Domèvre-sur-Durbion;DOMEVRE-SUR-DURBION;88330;88;VOSGES;1
88144;;Domèvre-sous-Montfort;DOMEVRE-SOUS-MONTFORT;88500;88;VOSGES;1
88145;;Domfaing;DOMFAING;88600;88;VOSGES;1
88146;;Domjulien;DOMJULIEN;88800;88;VOSGES;1
88147;;Dommartin-aux-Bois;DOMMARTIN-AUX-BOIS;88390;88;VOSGES;1
88148;;Dommartin-lès-Remiremont;DOMMARTIN-LES-REMIREMONT;88200;88;VOSGES;1
88149;;Dommartin-lès-Vallois;DOMMARTIN-LES-VALLOIS;88260;88;VOSGES;1
88150;;Dommartin-sur-Vraine;DOMMARTIN-SUR-VRAINE;88170;88;VOSGES;1
88151;;Dompaire;DOMPAIRE;88270;88;VOSGES;1
88152;;Dompierre;DOMPIERRE;88600;88;VOSGES;1
88153;;Domptail;DOMPTAIL;88700;88;VOSGES;1
88154;;Domrémy-la-Pucelle;DOMREMY-LA-PUCELLE;88630;88;VOSGES;1
88155;;Domvallier;DOMVALLIER;88500;88;VOSGES;1
88156;;Doncières;DONCIERES;88700;88;VOSGES;1
88157;;Dounoux;DOUNOUX;88220;88;VOSGES;1
88158;;Éloyes;ELOYES;88510;88;VOSGES;1
88159;;Entre-deux-Eaux;ENTRE-DEUX-EAUX;88650;88;VOSGES;1
88160;;Épinal;EPINAL;88000;88;VOSGES;1
88161;;Escles;ESCLES;88260;88;VOSGES;1
88162;;Esley;ESLEY;88260;88;VOSGES;1
88163;;Essegney;ESSEGNEY;88130;88;VOSGES;1
88164;;Estrennes;ESTRENNES;88500;88;VOSGES;1
88165;;Étival-Clairefontaine;ETIVAL-CLAIREFONTAINE;88480;88;VOSGES;1
88166;;Évaux-et-Ménil;EVAUX-ET-MENIL;88450;88;VOSGES;1
88167;;Faucompierre;FAUCOMPIERRE;88460;88;VOSGES;1
88168;;Fauconcourt;FAUCONCOURT;88700;88;VOSGES;1
88169;;Fays;FAYS;88600;88;VOSGES;1
88170;;Ferdrupt;FERDRUPT;88360;88;VOSGES;1
88171;;Fignévelle;FIGNEVELLE;88410;88;VOSGES;1
88172;;Fiménil;FIMENIL;88600;88;VOSGES;1
88173;;Florémont;FLOREMONT;88130;88;VOSGES;1
88174;;Fomerey;FOMEREY;88390;88;VOSGES;1
88175;;Fontenay;FONTENAY;88600;88;VOSGES;1
88176;;Fontenoy-le-Château;FONTENOY-LE-CHATEAU;88240;88;VOSGES;1
88177;La;Forge;FORGE;88530;88;VOSGES;1
88178;Les;Forges;FORGES;88390;88;VOSGES;1
88179;;Fouchécourt;FOUCHECOURT;88320;88;VOSGES;1
88180;;Frain;FRAIN;88320;88;VOSGES;1
88181;;Fraize;FRAIZE;88230;88;VOSGES;1
88182;;Frapelle;FRAPELLE;88490;88;VOSGES;1
88183;;Frebécourt;FREBECOURT;88630;88;VOSGES;1
88184;;Fremifontaine;FREMIFONTAINE;88600;88;VOSGES;1
88185;;Frenelle-la-Grande;FRENELLE-LA-GRANDE;88500;88;VOSGES;1
88186;;Frenelle-la-Petite;FRENELLE-LA-PETITE;88500;88;VOSGES;1
88187;;Frénois;FRENOIS;88270;88;VOSGES;1
88188;;Fresse-sur-Moselle;FRESSE-SUR-MOSELLE;88160;88;VOSGES;1
88189;;Fréville;FREVILLE;88350;88;VOSGES;1
88190;;Frizon;FRIZON;88440;88;VOSGES;1
88192;;Gelvécourt-et-Adompt;GELVECOURT-ET-ADOMPT;88270;88;VOSGES;1
88193;;Gemaingoutte;GEMAINGOUTTE;88520;88;VOSGES;1
88194;;Gemmelaincourt;GEMMELAINCOURT;88170;88;VOSGES;1
88195;;Gendreville;GENDREVILLE;88140;88;VOSGES;1
88196;;Gérardmer;GERARDMER;88400;88;VOSGES;1
88197;;Gerbamont;GERBAMONT;88120;88;VOSGES;1
88198;;Gerbépal;GERBEPAL;88430;88;VOSGES;1
88199;;Gignéville;GIGNEVILLE;88320;88;VOSGES;1
88200;;Gigney;GIGNEY;88390;88;VOSGES;1
88201;;Girancourt;GIRANCOURT;88390;88;VOSGES;1
88202;;Gircourt-lès-Viéville;GIRCOURT-LES-VIEVILLE;88500;88;VOSGES;1
88203;;Girecourt-sur-Durbion;GIRECOURT-SUR-DURBION;88600;88;VOSGES;1
88204;;Girmont;GIRMONT;88150;88;VOSGES;1
88205;;Girmont-Val-d'Ajol;GIRMONT-VAL-D'AJOL;88340;88;VOSGES;1
88206;;Gironcourt-sur-Vraine;GIRONCOURT-SUR-VRAINE;88170;88;VOSGES;1
88208;;Godoncourt;GODONCOURT;88410;88;VOSGES;1
88209;;Golbey;GOLBEY;88190;88;VOSGES;1
88210;;Gorhey;GORHEY;88270;88;VOSGES;1
88212;;Grand;GRAND;88350;88;VOSGES;1
88213;La;Grande-Fosse;GRANDE-FOSSE;88490;88;VOSGES;1
88214;;Grandrupt-de-Bains;GRANDRUPT-DE-BAINS;88240;88;VOSGES;1
88215;;Grandrupt;GRANDRUPT;88210;88;VOSGES;1
88216;;Grandvillers;GRANDVILLERS;88600;88;VOSGES;1
88218;;Granges-sur-Vologne;GRANGES-SUR-VOLOGNE;88640;88;VOSGES;1
88219;;Greux;GREUX;88630;88;VOSGES;1
88220;;Grignoncourt;GRIGNONCOURT;88410;88;VOSGES;1
88221;;Gruey-lès-Surance;GRUEY-LES-SURANCE;88240;88;VOSGES;1
88222;;Gugnécourt;GUGNECOURT;88600;88;VOSGES;1
88223;;Gugney-aux-Aulx;GUGNEY-AUX-AULX;88450;88;VOSGES;1
88224;;Hadigny-les-Verrières;HADIGNY-LES-VERRIERES;88330;88;VOSGES;1
88225;;Hadol;HADOL;88220;88;VOSGES;1
88226;;Hagécourt;HAGECOURT;88270;88;VOSGES;1
88227;;Hagnéville-et-Roncourt;HAGNEVILLE-ET-RONCOURT;88300;88;VOSGES;1
88228;;Haillainville;HAILLAINVILLE;88330;88;VOSGES;1
88229;;Harchéchamp;HARCHECHAMP;88300;88;VOSGES;1
88230;;Hardancourt;HARDANCOURT;88700;88;VOSGES;1
88231;;Haréville;HAREVILLE;88800;88;VOSGES;1
88232;;Harmonville;HARMONVILLE;88300;88;VOSGES;1
88233;;Harol;HAROL;88270;88;VOSGES;1
88234;;Harsault;HARSAULT;88240;88;VOSGES;1
88235;;Hautmougey;HAUTMOUGEY;88240;88;VOSGES;1
88236;La;Haye;HAYE;88240;88;VOSGES;1
88237;;Hennecourt;HENNECOURT;88270;88;VOSGES;1
88238;;Hennezel;HENNEZEL;88260;88;VOSGES;1
88239;;Hergugney;HERGUGNEY;88130;88;VOSGES;1
88240;;Herpelmont;HERPELMONT;88600;88;VOSGES;1
88241;;Houécourt;HOUECOURT;88170;88;VOSGES;1
88242;;Houéville;HOUEVILLE;88300;88;VOSGES;1
88243;;Housseras;HOUSSERAS;88700;88;VOSGES;1
88244;La;Houssière;HOUSSIERE;88430;88;VOSGES;1
88245;;Hurbache;HURBACHE;88210;88;VOSGES;1
88246;;Hymont;HYMONT;88500;88;VOSGES;1
88247;;Igney;IGNEY;88150;88;VOSGES;1
88248;;Isches;ISCHES;88320;88;VOSGES;1
88249;;Jainvillotte;JAINVILLOTTE;88300;88;VOSGES;1
88250;;Jarménil;JARMENIL;88550;88;VOSGES;1
88251;;Jeanménil;JEANMENIL;88700;88;VOSGES;1
88252;;Jésonville;JESONVILLE;88260;88;VOSGES;1
88253;;Jeuxey;JEUXEY;88000;88;VOSGES;1
88254;;Jorxey;JORXEY;88500;88;VOSGES;1
88255;;Jubainville;JUBAINVILLE;88630;88;VOSGES;1
88256;;Jussarupt;JUSSARUPT;88640;88;VOSGES;1
88257;;Juvaincourt;JUVAINCOURT;88500;88;VOSGES;1
88258;;Lamarche;LAMARCHE;88320;88;VOSGES;1
88259;;Landaville;LANDAVILLE;88300;88;VOSGES;1
88260;;Langley;LANGLEY;88130;88;VOSGES;1
88261;;Laval-sur-Vologne;LAVAL-SUR-VOLOGNE;88600;88;VOSGES;1
88262;;Laveline-devant-Bruyères;LAVELINE-DEVANT-BRUYERES;88600;88;VOSGES;1
88263;;Laveline-du-Houx;LAVELINE-DU-HOUX;88640;88;VOSGES;1
88264;;Légéville-et-Bonfays;LEGEVILLE-ET-BONFAYS;88270;88;VOSGES;1
88265;;Lemmecourt;LEMMECOURT;88300;88;VOSGES;1
88266;;Lépanges-sur-Vologne;LEPANGES-SUR-VOLOGNE;88600;88;VOSGES;1
88267;;Lerrain;LERRAIN;88260;88;VOSGES;1
88268;;Lesseux;LESSEUX;88490;88;VOSGES;1
88269;;Liézey;LIEZEY;88400;88;VOSGES;1
88270;;Liffol-le-Grand;LIFFOL-LE-GRAND;88350;88;VOSGES;1
88271;;Lignéville;LIGNEVILLE;88800;88;VOSGES;1
88272;;Lironcourt;LIRONCOURT;88410;88;VOSGES;1
88273;;Longchamp;LONGCHAMP;88000;88;VOSGES;1
88274;;Longchamp-sous-Châtenois;LONGCHAMP-SOUS-CHATENOIS;88170;88;VOSGES;1
88275;;Lubine;LUBINE;88490;88;VOSGES;1
88276;;Lusse;LUSSE;88490;88;VOSGES;1
88277;;Luvigny;LUVIGNY;88110;88;VOSGES;1
88278;;Maconcourt;MACONCOURT;88170;88;VOSGES;1
88279;;Madecourt;MADECOURT;88270;88;VOSGES;1
88280;;Madegney;MADEGNEY;88450;88;VOSGES;1
88281;;Madonne-et-Lamerey;MADONNE-ET-LAMEREY;88270;88;VOSGES;1
88282;Le;Magny;MAGNY;88240;88;VOSGES;1
88283;;Malaincourt;MALAINCOURT;88140;88;VOSGES;1
88284;;Mandray;MANDRAY;88650;88;VOSGES;1
88285;;Mandres-sur-Vair;MANDRES-SUR-VAIR;88800;88;VOSGES;1
88286;;Marainville-sur-Madon;MARAINVILLE-SUR-MADON;88130;88;VOSGES;1
88287;;Marey;MAREY;88320;88;VOSGES;1
88288;;Maroncourt;MARONCOURT;88270;88;VOSGES;1
88289;;Martigny-les-Bains;MARTIGNY-LES-BAINS;88320;88;VOSGES;1
88290;;Martigny-les-Gerbonvaux;MARTIGNY-LES-GERBONVAUX;88300;88;VOSGES;1
88291;;Martinvelle;MARTINVELLE;88410;88;VOSGES;1
88292;;Mattaincourt;MATTAINCOURT;88500;88;VOSGES;1
88293;;Maxey-sur-Meuse;MAXEY-SUR-MEUSE;88630;88;VOSGES;1
88294;;Mazeley;MAZELEY;88150;88;VOSGES;1
88295;;Mazirot;MAZIROT;88500;88;VOSGES;1
88296;;Médonville;MEDONVILLE;88140;88;VOSGES;1
88297;;Méménil;MEMENIL;88600;88;VOSGES;1
88298;;Ménarmont;MENARMONT;88700;88;VOSGES;1
88299;;Ménil-en-Xaintois;MENIL-EN-XAINTOIS;88500;88;VOSGES;1
88300;;Ménil-de-Senones;MENIL-DE-SENONES;88210;88;VOSGES;1
88301;;Ménil-sur-Belvitte;MENIL-SUR-BELVITTE;88700;88;VOSGES;1
88302;Le;Ménil;MENIL;88160;88;VOSGES;1
88303;;Midrevaux;MIDREVAUX;88630;88;VOSGES;1
88304;;Mirecourt;MIRECOURT;88500;88;VOSGES;1
88305;;Moncel-sur-Vair;MONCEL-SUR-VAIR;88630;88;VOSGES;1
88306;Le;Mont;MONT;88210;88;VOSGES;1
88307;;Mont-lès-Lamarche;MONT-LES-LAMARCHE;88320;88;VOSGES;1
88308;;Mont-lès-Neufchâteau;MONT-LES-NEUFCHATEAU;88300;88;VOSGES;1
88309;;Monthureux-le-Sec;MONTHUREUX-LE-SEC;88800;88;VOSGES;1
88310;;Monthureux-sur-Saône;MONTHUREUX-SUR-SAONE;88410;88;VOSGES;1
88311;;Montmotier;MONTMOTIER;88240;88;VOSGES;1
88312;;Morelmaison;MORELMAISON;88170;88;VOSGES;1
88313;;Moriville;MORIVILLE;88330;88;VOSGES;1
88314;;Morizécourt;MORIZECOURT;88320;88;VOSGES;1
88315;;Mortagne;MORTAGNE;88600;88;VOSGES;1
88316;;Morville;MORVILLE;88140;88;VOSGES;1
88317;;Moussey;MOUSSEY;88210;88;VOSGES;1
88318;;Moyemont;MOYEMONT;88700;88;VOSGES;1
88319;;Moyenmoutier;MOYENMOUTIER;88420;88;VOSGES;1
88320;;Nayemont-les-Fosses;NAYEMONT-LES-FOSSES;88100;88;VOSGES;1
88321;;Neufchâteau;NEUFCHATEAU;88300;88;VOSGES;1
88322;La;Neuveville-devant-Lépanges;NEUVEVILLE-DEVANT-LEPANGES;88600;88;VOSGES;1
88324;La;Neuveville-sous-Châtenois;NEUVEVILLE-SOUS-CHATENOIS;88170;88;VOSGES;1
88325;La;Neuveville-sous-Montfort;NEUVEVILLE-SOUS-MONTFORT;88800;88;VOSGES;1
88326;;Neuvillers-sur-Fave;NEUVILLERS-SUR-FAVE;88100;88;VOSGES;1
88327;;Nomexy;NOMEXY;88440;88;VOSGES;1
88328;;Nompatelize;NOMPATELIZE;88470;88;VOSGES;1
88330;;Nonville;NONVILLE;88260;88;VOSGES;1
88331;;Nonzeville;NONZEVILLE;88600;88;VOSGES;1
88332;;Norroy;NORROY;88800;88;VOSGES;1
88333;;Nossoncourt;NOSSONCOURT;88700;88;VOSGES;1
88334;;Oëlleville;OELLEVILLE;88500;88;VOSGES;1
88335;;Offroicourt;OFFROICOURT;88500;88;VOSGES;1
88336;;Ollainville;OLLAINVILLE;88170;88;VOSGES;1
88337;;Oncourt;ONCOURT;88150;88;VOSGES;1
88338;;Ortoncourt;ORTONCOURT;88700;88;VOSGES;1
88340;;Padoux;PADOUX;88700;88;VOSGES;1
88341;;Pair-et-Grandrupt;PAIR-ET-GRANDRUPT;88100;88;VOSGES;1
88342;;Pallegney;PALLEGNEY;88330;88;VOSGES;1
88343;;Parey-sous-Montfort;PAREY-SOUS-MONTFORT;88800;88;VOSGES;1
88344;;Pargny-sous-Mureau;PARGNY-SOUS-MUREAU;88350;88;VOSGES;1
88345;La;Petite-Fosse;PETITE-FOSSE;88490;88;VOSGES;1
88346;La;Petite-Raon;PETITE-RAON;88210;88;VOSGES;1
88347;;Pierrefitte;PIERREFITTE;88270;88;VOSGES;1
88348;;Pierrepont-sur-l'Arentèle;PIERREPONT-SUR-L'ARENTELE;88600;88;VOSGES;1
88349;;Plainfaing;PLAINFAING;88230;88;VOSGES;1
88350;;Pleuvezain;PLEUVEZAIN;88170;88;VOSGES;1
88351;;Plombières-les-Bains;PLOMBIERES-LES-BAINS;88370;88;VOSGES;1
88352;;Pompierre;POMPIERRE;88300;88;VOSGES;1
88353;;Pont-lès-Bonfays;PONT-LES-BONFAYS;88260;88;VOSGES;1
88354;;Pont-sur-Madon;PONT-SUR-MADON;88500;88;VOSGES;1
88355;;Portieux;PORTIEUX;88330;88;VOSGES;1
88356;Les;Poulières;POULIERES;88600;88;VOSGES;1
88357;;Poussay;POUSSAY;88500;88;VOSGES;1
88358;;Pouxeux;POUXEUX;88550;88;VOSGES;1
88359;;Prey;PREY;88600;88;VOSGES;1
88360;;Provenchères-lès-Darney;PROVENCHERES-LES-DARNEY;88260;88;VOSGES;1
88361;;Provenchères-sur-Fave;PROVENCHERES-SUR-FAVE;88490;88;VOSGES;1
88362;Le;Puid;PUID;88210;88;VOSGES;1
88363;;Punerot;PUNEROT;88630;88;VOSGES;1
88364;;Puzieux;PUZIEUX;88500;88;VOSGES;1
88365;;Racécourt;RACECOURT;88270;88;VOSGES;1
88366;;Rainville;RAINVILLE;88170;88;VOSGES;1
88367;;Rambervillers;RAMBERVILLERS;88700;88;VOSGES;1
88368;;Ramecourt;RAMECOURT;88500;88;VOSGES;1
88369;;Ramonchamp;RAMONCHAMP;88160;88;VOSGES;1
88370;;Rancourt;RANCOURT;88270;88;VOSGES;1
88371;;Raon-aux-Bois;RAON-AUX-BOIS;88220;88;VOSGES;1
88372;;Raon-l'Étape;RAON-L'ETAPE;88110;88;VOSGES;1
88373;;Raon-sur-Plaine;RAON-SUR-PLAINE;88110;88;VOSGES;1
88374;;Rapey;RAPEY;88130;88;VOSGES;1
88375;;Raves;RAVES;88520;88;VOSGES;1
88376;;Rebeuville;REBEUVILLE;88300;88;VOSGES;1
88377;;Regnévelle;REGNEVELLE;88410;88;VOSGES;1
88378;;Regney;REGNEY;88450;88;VOSGES;1
88379;;Rehaincourt;REHAINCOURT;88330;88;VOSGES;1
88380;;Rehaupal;REHAUPAL;88640;88;VOSGES;1
88381;;Relanges;RELANGES;88260;88;VOSGES;1
88382;;Remicourt;REMICOURT;88500;88;VOSGES;1
88383;;Remiremont;REMIREMONT;88200;88;VOSGES;1
88385;;Remoncourt;REMONCOURT;88800;88;VOSGES;1
88386;;Remomeix;REMOMEIX;88100;88;VOSGES;1
88387;;Removille;REMOVILLE;88170;88;VOSGES;1
88388;;Renauvoid;RENAUVOID;88390;88;VOSGES;1
88389;;Repel;REPEL;88500;88;VOSGES;1
88390;;Robécourt;ROBECOURT;88320;88;VOSGES;1
88391;;Rochesson;ROCHESSON;88120;88;VOSGES;1
88392;;Rocourt;ROCOURT;88320;88;VOSGES;1
88393;;Rollainville;ROLLAINVILLE;88300;88;VOSGES;1
88394;;Romain-aux-Bois;ROMAIN-AUX-BOIS;88320;88;VOSGES;1
88395;;Romont;ROMONT;88700;88;VOSGES;1
88398;Les;Rouges-Eaux;ROUGES-EAUX;88600;88;VOSGES;1
88399;Le;Roulier;ROULIER;88460;88;VOSGES;1
88400;;Rouvres-en-Xaintois;ROUVRES-EN-XAINTOIS;88500;88;VOSGES;1
88401;;Rouvres-la-Chétive;ROUVRES-LA-CHETIVE;88170;88;VOSGES;1
88402;;Roville-aux-Chênes;ROVILLE-AUX-CHENES;88700;88;VOSGES;1
88403;;Rozerotte;ROZEROTTE;88500;88;VOSGES;1
88404;;Rozières-sur-Mouzon;ROZIERES-SUR-MOUZON;88320;88;VOSGES;1
88406;;Rugney;RUGNEY;88130;88;VOSGES;1
88407;;Ruppes;RUPPES;88630;88;VOSGES;1
88408;;Rupt-sur-Moselle;RUPT-SUR-MOSELLE;88360;88;VOSGES;1
88409;;Saint-Amé;SAINT-AME;88120;88;VOSGES;1
88410;;Sainte-Barbe;SAINTE-BARBE;88700;88;VOSGES;1
88411;;Saint-Baslemont;SAINT-BASLEMONT;88260;88;VOSGES;1
88412;;Saint-Benoît-la-Chipotte;SAINT-BENOIT-LA-CHIPOTTE;88700;88;VOSGES;1
88413;;Saint-Dié-des-Vosges;SAINT-DIE-DES-VOSGES;88100;88;VOSGES;1
88415;;Saint-Étienne-lès-Remiremont;SAINT-ETIENNE-LES-REMIREMONT;88200;88;VOSGES;1
88416;;Saint-Genest;SAINT-GENEST;88700;88;VOSGES;1
88417;;Saint-Gorgon;SAINT-GORGON;88700;88;VOSGES;1
88418;;Sainte-Hélène;SAINTE-HELENE;88700;88;VOSGES;1
88419;;Saint-Jean-d'Ormont;SAINT-JEAN-D'ORMONT;88210;88;VOSGES;1
88421;;Saint-Julien;SAINT-JULIEN;88410;88;VOSGES;1
88423;;Saint-Léonard;SAINT-LEONARD;88650;88;VOSGES;1
88424;;Sainte-Marguerite;SAINTE-MARGUERITE;88100;88;VOSGES;1
88425;;Saint-Maurice-sur-Mortagne;SAINT-MAURICE-SUR-MORTAGNE;88700;88;VOSGES;1
88426;;Saint-Maurice-sur-Moselle;SAINT-MAURICE-SUR-MOSELLE;88560;88;VOSGES;1
88427;;Saint-Menge;SAINT-MENGE;88170;88;VOSGES;1
88428;;Saint-Michel-sur-Meurthe;SAINT-MICHEL-SUR-MEURTHE;88470;88;VOSGES;1
88429;;Saint-Nabord;SAINT-NABORD;88200;88;VOSGES;1
88430;;Saint-Ouen-lès-Parey;SAINT-OUEN-LES-PAREY;88140;88;VOSGES;1
88431;;Saint-Paul;SAINT-PAUL;88170;88;VOSGES;1
88432;;Saint-Pierremont;SAINT-PIERREMONT;88700;88;VOSGES;1
88433;;Saint-Prancher;SAINT-PRANCHER;88500;88;VOSGES;1
88434;;Saint-Remimont;SAINT-REMIMONT;88800;88;VOSGES;1
88435;;Saint-Remy;SAINT-REMY;88480;88;VOSGES;1
88436;;Saint-Stail;SAINT-STAIL;88210;88;VOSGES;1
88437;;Saint-Vallier;SAINT-VALLIER;88270;88;VOSGES;1
88438;La;Salle;SALLE;88470;88;VOSGES;1
88439;;Sanchey;SANCHEY;88390;88;VOSGES;1
88440;;Sandaucourt;SANDAUCOURT;88170;88;VOSGES;1
88441;;Sans-Vallois;SANS-VALLOIS;88260;88;VOSGES;1
88442;;Sapois;SAPOIS;88120;88;VOSGES;1
88443;;Sartes;SARTES;88300;88;VOSGES;1
88444;Le;Saulcy;SAULCY;88210;88;VOSGES;1
88445;;Saulcy-sur-Meurthe;SAULCY-SUR-MEURTHE;88580;88;VOSGES;1
88446;;Saulxures-lès-Bulgnéville;SAULXURES-LES-BULGNEVILLE;88140;88;VOSGES;1
88447;;Saulxures-sur-Moselotte;SAULXURES-SUR-MOSELOTTE;88290;88;VOSGES;1
88448;;Sauville;SAUVILLE;88140;88;VOSGES;1
88449;;Savigny;SAVIGNY;88130;88;VOSGES;1
88450;;Senaide;SENAIDE;88320;88;VOSGES;1
88451;;Senones;SENONES;88210;88;VOSGES;1
88452;;Senonges;SENONGES;88260;88;VOSGES;1
88453;;Seraumont;SERAUMONT;88630;88;VOSGES;1
88454;;Sercœur;SERCOEUR;88600;88;VOSGES;1
88455;;Serécourt;SERECOURT;88320;88;VOSGES;1
88456;;Serocourt;SEROCOURT;88320;88;VOSGES;1
88457;;Sionne;SIONNE;88630;88;VOSGES;1
88458;;Socourt;SOCOURT;88130;88;VOSGES;1
88459;;Soncourt;SONCOURT;88170;88;VOSGES;1
88460;;Soulosse-sous-Saint-Élophe;SOULOSSE-SOUS-SAINT-ELOPHE;88630;88;VOSGES;1
88461;;Suriauville;SURIAUVILLE;88140;88;VOSGES;1
88462;Le;Syndicat;SYNDICAT;88120;88;VOSGES;1
88463;;Taintrux;TAINTRUX;88100;88;VOSGES;1
88464;;Tendon;TENDON;88460;88;VOSGES;1
88465;;Thaon-les-Vosges;THAON-LES-VOSGES;88150;88;VOSGES;1
88466;;They-sous-Montfort;THEY-SOUS-MONTFORT;88800;88;VOSGES;1
88467;;Thiéfosse;THIEFOSSE;88290;88;VOSGES;1
88468;Le;Thillot;THILLOT;88160;88;VOSGES;1
88469;;Thiraucourt;THIRAUCOURT;88500;88;VOSGES;1
88470;Le;Tholy;THOLY;88530;88;VOSGES;1
88471;Les;Thons;THONS;88410;88;VOSGES;1
88472;;Thuillières;THUILLIERES;88260;88;VOSGES;1
88473;;Tignécourt;TIGNECOURT;88320;88;VOSGES;1
88474;;Tilleux;TILLEUX;88300;88;VOSGES;1
88475;;Tollaincourt;TOLLAINCOURT;88320;88;VOSGES;1
88476;;Totainville;TOTAINVILLE;88500;88;VOSGES;1
88477;;Trampot;TRAMPOT;88350;88;VOSGES;1
88478;;Tranqueville-Graux;TRANQUEVILLE-GRAUX;88300;88;VOSGES;1
88479;;Trémonzey;TREMONZEY;88240;88;VOSGES;1
88480;;Ubexy;UBEXY;88130;88;VOSGES;1
88481;;Uriménil;URIMENIL;88220;88;VOSGES;1
88482;;Urville;URVILLE;88140;88;VOSGES;1
88483;;Uxegney;UXEGNEY;88390;88;VOSGES;1
88484;;Uzemain;UZEMAIN;88220;88;VOSGES;1
88485;La;Vacheresse-et-la-Rouillie;VACHERESSE-ET-LA-ROUILLIE;88140;88;VOSGES;1
88486;;Vagney;VAGNEY;88120;88;VOSGES;1
88487;Le;Val-d'Ajol;VAL-D'AJOL;88340;88;VOSGES;1
88488;;Valfroicourt;VALFROICOURT;88270;88;VOSGES;1
88489;;Valleroy-aux-Saules;VALLEROY-AUX-SAULES;88270;88;VOSGES;1
88490;;Valleroy-le-Sec;VALLEROY-LE-SEC;88800;88;VOSGES;1
88491;Les;Vallois;VALLOIS;88260;88;VOSGES;1
88492;Le;Valtin;VALTIN;88230;88;VOSGES;1
88493;;Varmonzey;VARMONZEY;88450;88;VOSGES;1
88494;;Vaubexy;VAUBEXY;88500;88;VOSGES;1
88495;;Vaudéville;VAUDEVILLE;88000;88;VOSGES;1
88496;;Vaudoncourt;VAUDONCOURT;88140;88;VOSGES;1
88497;;Vaxoncourt;VAXONCOURT;88330;88;VOSGES;1
88498;;Vecoux;VECOUX;88200;88;VOSGES;1
88499;;Velotte-et-Tatignécourt;VELOTTE-ET-TATIGNECOURT;88270;88;VOSGES;1
88500;;Ventron;VENTRON;88310;88;VOSGES;1
88501;Le;Vermont;VERMONT;88210;88;VOSGES;1
88502;;Vervezelle;VERVEZELLE;88600;88;VOSGES;1
88503;;Vexaincourt;VEXAINCOURT;88110;88;VOSGES;1
88504;;Vicherey;VICHEREY;88170;88;VOSGES;1
88505;;Vienville;VIENVILLE;88430;88;VOSGES;1
88506;;Vieux-Moulin;VIEUX-MOULIN;88210;88;VOSGES;1
88507;;Villers;VILLERS;88500;88;VOSGES;1
88508;;Ville-sur-Illon;VILLE-SUR-ILLON;88270;88;VOSGES;1
88509;;Villoncourt;VILLONCOURT;88150;88;VOSGES;1
88510;;Villotte;VILLOTTE;88320;88;VOSGES;1
88511;;Villouxel;VILLOUXEL;88350;88;VOSGES;1
88512;;Viménil;VIMENIL;88600;88;VOSGES;1
88513;;Vincey;VINCEY;88450;88;VOSGES;1
88514;;Viocourt;VIOCOURT;88170;88;VOSGES;1
88515;;Vioménil;VIOMENIL;88260;88;VOSGES;1
88516;;Vittel;VITTEL;88800;88;VOSGES;1
88517;;Viviers-le-Gras;VIVIERS-LE-GRAS;88260;88;VOSGES;1
88518;;Viviers-lès-Offroicourt;VIVIERS-LES-OFFROICOURT;88500;88;VOSGES;1
88519;La;Voivre;VOIVRE;88470;88;VOSGES;1
88520;Les;Voivres;VOIVRES;88240;88;VOSGES;1
88521;;Vomécourt;VOMECOURT;88700;88;VOSGES;1
88522;;Vomécourt-sur-Madon;VOMECOURT-SUR-MADON;88500;88;VOSGES;1
88523;;Vouxey;VOUXEY;88170;88;VOSGES;1
88524;;Vrécourt;VRECOURT;88140;88;VOSGES;1
88525;;Vroville;VROVILLE;88500;88;VOSGES;1
88526;;Wisembach;WISEMBACH;88520;88;VOSGES;1
88527;;Xaffévillers;XAFFEVILLERS;88700;88;VOSGES;1
88528;;Xamontarupt;XAMONTARUPT;88460;88;VOSGES;1
88529;;Xaronval;XARONVAL;88130;88;VOSGES;1
88530;;Xertigny;XERTIGNY;88220;88;VOSGES;1
88531;;Xonrupt-Longemer;XONRUPT-LONGEMER;88400;88;VOSGES;1
88532;;Zincourt;ZINCOURT;88330;88;VOSGES;1
89001;;Accolay;ACCOLAY;89460;89;YONNE;1
89002;;Aigremont;AIGREMONT;89800;89;YONNE;1
89003;;Aillant-sur-Tholon;AILLANT-SUR-THOLON;89110;89;YONNE;1
89004;;Aisy-sur-Armançon;AISY-SUR-ARMANCON;89390;89;YONNE;1
89005;;Ancy-le-Franc;ANCY-LE-FRANC;89160;89;YONNE;1
89006;;Ancy-le-Libre;ANCY-LE-LIBRE;89160;89;YONNE;1
89007;;Andryes;ANDRYES;89480;89;YONNE;1
89008;;Angely;ANGELY;89440;89;YONNE;1
89009;;Annay-la-Côte;ANNAY-LA-COTE;89200;89;YONNE;1
89010;;Annay-sur-Serein;ANNAY-SUR-SEREIN;89310;89;YONNE;1
89011;;Annéot;ANNEOT;89200;89;YONNE;1
89012;;Annoux;ANNOUX;89440;89;YONNE;1
89013;;Appoigny;APPOIGNY;89380;89;YONNE;1
89014;;Arces-Dilo;ARCES-DILO;89320;89;YONNE;1
89015;;Arcy-sur-Cure;ARCY-SUR-CURE;89270;89;YONNE;1
89016;;Argentenay;ARGENTENAY;89160;89;YONNE;1
89017;;Argenteuil-sur-Armançon;ARGENTEUIL-SUR-ARMANCON;89160;89;YONNE;1
89018;;Armeau;ARMEAU;89500;89;YONNE;1
89019;;Arthonnay;ARTHONNAY;89740;89;YONNE;1
89020;;Asnières-sous-Bois;ASNIERES-SOUS-BOIS;89660;89;YONNE;1
89021;;Asquins;ASQUINS;89450;89;YONNE;1
89022;;Athie;ATHIE;89440;89;YONNE;1
89023;;Augy;AUGY;89290;89;YONNE;1
89024;;Auxerre;AUXERRE;89000;89;YONNE;1
89025;;Avallon;AVALLON;89200;89;YONNE;1
89027;;Bagneaux;BAGNEAUX;89190;89;YONNE;1
89028;;Baon;BAON;89430;89;YONNE;1
89029;;Bassou;BASSOU;89400;89;YONNE;1
89030;;Bazarnes;BAZARNES;89460;89;YONNE;1
89031;;Beaumont;BEAUMONT;89250;89;YONNE;1
89032;;Beauvilliers;BEAUVILLIERS;89630;89;YONNE;1
89033;;Beauvoir;BEAUVOIR;89240;89;YONNE;1
89034;;Beine;BEINE;89800;89;YONNE;1
89035;;Bellechaume;BELLECHAUME;89210;89;YONNE;1
89036;La;Belliole;BELLIOLE;89150;89;YONNE;1
89037;;Béon;BEON;89410;89;YONNE;1
89038;;Bernouil;BERNOUIL;89360;89;YONNE;1
89039;;Béru;BERU;89700;89;YONNE;1
89040;;Bessy-sur-Cure;BESSY-SUR-CURE;89270;89;YONNE;1
89041;;Beugnon;BEUGNON;89570;89;YONNE;1
89042;;Bierry-les-Belles-Fontaines;BIERRY-LES-BELLES-FONTAINES;89420;89;YONNE;1
89043;;Blacy;BLACY;89440;89;YONNE;1
89044;;Blannay;BLANNAY;89200;89;YONNE;1
89045;;Bleigny-le-Carreau;BLEIGNY-LE-CARREAU;89230;89;YONNE;1
89046;;Bléneau;BLENEAU;89220;89;YONNE;1
89048;;Bœurs-en-Othe;BOEURS-EN-OTHE;89770;89;YONNE;1
89049;;Bois-d'Arcy;BOIS-D'ARCY;89660;89;YONNE;1
89050;;Bonnard;BONNARD;89400;89;YONNE;1
89051;Les;Bordes;BORDES;89500;89;YONNE;1
89053;;Branches;BRANCHES;89113;89;YONNE;1
89054;;Brannay;BRANNAY;89150;89;YONNE;1
89055;;Brienon-sur-Armançon;BRIENON-SUR-ARMANCON;89210;89;YONNE;1
89056;;Brion;BRION;89400;89;YONNE;1
89057;;Brosses;BROSSES;89660;89;YONNE;1
89058;;Bussières;BUSSIERES;89630;89;YONNE;1
89059;;Bussy-en-Othe;BUSSY-EN-OTHE;89400;89;YONNE;1
89060;;Bussy-le-Repos;BUSSY-LE-REPOS;89500;89;YONNE;1
89061;;Butteaux;BUTTEAUX;89360;89;YONNE;1
89062;;Carisey;CARISEY;89360;89;YONNE;1
89063;La;Celle-Saint-Cyr;CELLE-SAINT-CYR;89116;89;YONNE;1
89064;;Censy;CENSY;89310;89;YONNE;1
89065;;Cérilly;CERILLY;89320;89;YONNE;1
89066;;Cerisiers;CERISIERS;89320;89;YONNE;1
89067;;Cézy;CEZY;89410;89;YONNE;1
89068;;Chablis;CHABLIS;89800;89;YONNE;1
89069;;Chailley;CHAILLEY;89770;89;YONNE;1
89070;;Chambeugle;CHAMBEUGLE;89120;89;YONNE;1
89071;;Chamoux;CHAMOUX;89660;89;YONNE;1
89072;;Champcevrais;CHAMPCEVRAIS;89220;89;YONNE;1
89073;;Champignelles;CHAMPIGNELLES;89350;89;YONNE;1
89074;;Champigny;CHAMPIGNY;89370;89;YONNE;1
89075;;Champlay;CHAMPLAY;89300;89;YONNE;1
89076;;Champlost;CHAMPLOST;89210;89;YONNE;1
89077;;Champs-sur-Yonne;CHAMPS-SUR-YONNE;89290;89;YONNE;1
89078;;Champvallon;CHAMPVALLON;89710;89;YONNE;1
89079;;Chamvres;CHAMVRES;89300;89;YONNE;1
89080;La;Chapelle-sur-Oreuse;CHAPELLE-SUR-OREUSE;89260;89;YONNE;1
89081;La;Chapelle-Vaupelteigne;CHAPELLE-VAUPELTEIGNE;89800;89;YONNE;1
89083;;Charbuy;CHARBUY;89113;89;YONNE;1
89084;;Charentenay;CHARENTENAY;89580;89;YONNE;1
89085;;Charmoy;CHARMOY;89400;89;YONNE;1
89086;;Charny;CHARNY;89120;89;YONNE;1
89087;;Chassignelles;CHASSIGNELLES;89160;89;YONNE;1
89088;;Chassy;CHASSY;89110;89;YONNE;1
89089;;Chastellux-sur-Cure;CHASTELLUX-SUR-CURE;89630;89;YONNE;1
89091;;Châtel-Censoir;CHATEL-CENSOIR;89660;89;YONNE;1
89092;;Châtel-Gérard;CHATEL-GERARD;89310;89;YONNE;1
89093;;Chaumont;CHAUMONT;89370;89;YONNE;1
89094;;Chaumot;CHAUMOT;89500;89;YONNE;1
89095;;Chemilly-sur-Serein;CHEMILLY-SUR-SEREIN;89800;89;YONNE;1
89096;;Chemilly-sur-Yonne;CHEMILLY-SUR-YONNE;89250;89;YONNE;1
89097;;Chêne-Arnoult;CHENE-ARNOULT;89120;89;YONNE;1
89098;;Cheney;CHENEY;89700;89;YONNE;1
89099;;Cheny;CHENY;89400;89;YONNE;1
89100;;Chéroy;CHEROY;89690;89;YONNE;1
89101;;Chéu;CHEU;89600;89;YONNE;1
89102;;Chevannes;CHEVANNES;89240;89;YONNE;1
89103;;Chevillon;CHEVILLON;89120;89;YONNE;1
89104;;Chichée;CHICHEE;89800;89;YONNE;1
89105;;Chichery;CHICHERY;89400;89;YONNE;1
89107;;Chigy;CHIGY;89190;89;YONNE;1
89108;;Chitry;CHITRY;89530;89;YONNE;1
89109;;Cisery;CISERY;89420;89;YONNE;1
89111;Les;Clérimois;CLERIMOIS;89190;89;YONNE;1
89112;;Collan;COLLAN;89700;89;YONNE;1
89113;;Collemiers;COLLEMIERS;89100;89;YONNE;1
89115;;Compigny;COMPIGNY;89140;89;YONNE;1
89116;;Cornant;CORNANT;89500;89;YONNE;1
89117;;Coulangeron;COULANGERON;89580;89;YONNE;1
89118;;Coulanges-la-Vineuse;COULANGES-LA-VINEUSE;89580;89;YONNE;1
89119;;Coulanges-sur-Yonne;COULANGES-SUR-YONNE;89480;89;YONNE;1
89120;;Coulours;COULOURS;89320;89;YONNE;1
89122;;Courgenay;COURGENAY;89190;89;YONNE;1
89123;;Courgis;COURGIS;89800;89;YONNE;1
89124;;Courlon-sur-Yonne;COURLON-SUR-YONNE;89140;89;YONNE;1
89125;;Courson-les-Carrières;COURSON-LES-CARRIERES;89560;89;YONNE;1
89126;;Courtoin;COURTOIN;89150;89;YONNE;1
89127;;Courtois-sur-Yonne;COURTOIS-SUR-YONNE;89100;89;YONNE;1
89128;;Coutarnoux;COUTARNOUX;89440;89;YONNE;1
89129;;Crain;CRAIN;89480;89;YONNE;1
89130;;Cravant;CRAVANT;89460;89;YONNE;1
89131;;Cruzy-le-Châtel;CRUZY-LE-CHATEL;89740;89;YONNE;1
89132;;Cry;CRY;89390;89;YONNE;1
89133;;Cudot;CUDOT;89116;89;YONNE;1
89134;;Cussy-les-Forges;CUSSY-LES-FORGES;89420;89;YONNE;1
89136;;Cuy;CUY;89140;89;YONNE;1
89137;;Dannemoine;DANNEMOINE;89700;89;YONNE;1
89138;;Dicy;DICY;89120;89;YONNE;1
89139;;Diges;DIGES;89240;89;YONNE;1
89141;;Dissangis;DISSANGIS;89440;89;YONNE;1
89142;;Dixmont;DIXMONT;89500;89;YONNE;1
89143;;Dollot;DOLLOT;89150;89;YONNE;1
89144;;Domats;DOMATS;89150;89;YONNE;1
89145;;Domecy-sur-Cure;DOMECY-SUR-CURE;89450;89;YONNE;1
89146;;Domecy-sur-le-Vault;DOMECY-SUR-LE-VAULT;89200;89;YONNE;1
89147;;Dracy;DRACY;89130;89;YONNE;1
89148;;Druyes-les-Belles-Fontaines;DRUYES-LES-BELLES-FONTAINES;89560;89;YONNE;1
89149;;Dyé;DYE;89360;89;YONNE;1
89150;;Égleny;EGLENY;89240;89;YONNE;1
89151;;Égriselles-le-Bocage;EGRISELLES-LE-BOCAGE;89500;89;YONNE;1
89152;;Épineau-les-Voves;EPINEAU-LES-VOVES;89400;89;YONNE;1
89153;;Épineuil;EPINEUIL;89700;89;YONNE;1
89154;;Escamps;ESCAMPS;89240;89;YONNE;1
89155;;Escolives-Sainte-Camille;ESCOLIVES-SAINTE-CAMILLE;89290;89;YONNE;1
89156;;Esnon;ESNON;89210;89;YONNE;1
89158;;Étais-la-Sauvin;ETAIS-LA-SAUVIN;89480;89;YONNE;1
89159;;Étaule;ETAULE;89200;89;YONNE;1
89160;;Étigny;ETIGNY;89510;89;YONNE;1
89161;;Étivey;ETIVEY;89310;89;YONNE;1
89162;;Évry;EVRY;89140;89;YONNE;1
89163;La;Ferté-Loupière;FERTE-LOUPIERE;89110;89;YONNE;1
89164;;Festigny;FESTIGNY;89480;89;YONNE;1
89165;;Flacy;FLACY;89190;89;YONNE;1
89167;;Fleury-la-Vallée;FLEURY-LA-VALLEE;89113;89;YONNE;1
89168;;Fleys;FLEYS;89800;89;YONNE;1
89169;;Flogny-la-Chapelle;FLOGNY-LA-CHAPELLE;89360;89;YONNE;1
89170;;Foissy-lès-Vézelay;FOISSY-LES-VEZELAY;89450;89;YONNE;1
89171;;Foissy-sur-Vanne;FOISSY-SUR-VANNE;89190;89;YONNE;1
89172;;Fontaine-la-Gaillarde;FONTAINE-LA-GAILLARDE;89100;89;YONNE;1
89173;;Fontaines;FONTAINES;89130;89;YONNE;1
89174;;Fontenailles;FONTENAILLES;89560;89;YONNE;1
89175;;Fontenay-près-Chablis;FONTENAY-PRES-CHABLIS;89800;89;YONNE;1
89176;;Fontenay-près-Vézelay;FONTENAY-PRES-VEZELAY;89450;89;YONNE;1
89177;;Fontenay-sous-Fouronnes;FONTENAY-SOUS-FOURONNES;89660;89;YONNE;1
89178;;Fontenouilles;FONTENOUILLES;89120;89;YONNE;1
89179;;Fontenoy;FONTENOY;89520;89;YONNE;1
89180;;Fouchères;FOUCHERES;89150;89;YONNE;1
89181;;Fournaudin;FOURNAUDIN;89320;89;YONNE;1
89182;;Fouronnes;FOURONNES;89560;89;YONNE;1
89183;;Fresnes;FRESNES;89310;89;YONNE;1
89184;;Fulvy;FULVY;89160;89;YONNE;1
89186;;Germigny;GERMIGNY;89600;89;YONNE;1
89187;;Gigny;GIGNY;89160;89;YONNE;1
89188;;Girolles;GIROLLES;89200;89;YONNE;1
89189;;Gisy-les-Nobles;GISY-LES-NOBLES;89140;89;YONNE;1
89190;;Givry;GIVRY;89200;89;YONNE;1
89191;;Gland;GLAND;89740;89;YONNE;1
89192;;Grandchamp;GRANDCHAMP;89350;89;YONNE;1
89194;;Grimault;GRIMAULT;89310;89;YONNE;1
89195;;Gron;GRON;89100;89;YONNE;1
89196;;Guerchy;GUERCHY;89113;89;YONNE;1
89197;;Guillon;GUILLON;89420;89;YONNE;1
89198;;Gurgy;GURGY;89250;89;YONNE;1
89199;;Gy-l'Évêque;GY-L'EVEQUE;89580;89;YONNE;1
89200;;Hauterive;HAUTERIVE;89250;89;YONNE;1
89201;;Héry;HERY;89550;89;YONNE;1
89202;;Irancy;IRANCY;89290;89;YONNE;1
89203;;Island;ISLAND;89200;89;YONNE;1
89204;L';Isle-sur-Serein;ISLE-SUR-SEREIN;89440;89;YONNE;1
89205;;Jaulges;JAULGES;89360;89;YONNE;1
89206;;Joigny;JOIGNY;89300;89;YONNE;1
89207;;Jouancy;JOUANCY;89310;89;YONNE;1
89208;;Joux-la-Ville;JOUX-LA-VILLE;89440;89;YONNE;1
89209;;Jouy;JOUY;89150;89;YONNE;1
89210;;Jully;JULLY;89160;89;YONNE;1
89211;;Junay;JUNAY;89700;89;YONNE;1
89212;;Jussy;JUSSY;89290;89;YONNE;1
89213;;Laduz;LADUZ;89110;89;YONNE;1
89214;;Lailly;LAILLY;89190;89;YONNE;1
89215;;Lain;LAIN;89560;89;YONNE;1
89216;;Lainsecq;LAINSECQ;89520;89;YONNE;1
89217;;Lalande;LALANDE;89130;89;YONNE;1
89218;;Laroche-Saint-Cydroine;LAROCHE-SAINT-CYDROINE;89400;89;YONNE;1
89219;;Lasson;LASSON;89570;89;YONNE;1
89220;;Lavau;LAVAU;89170;89;YONNE;1
89221;;Leugny;LEUGNY;89130;89;YONNE;1
89222;;Levis;LEVIS;89520;89;YONNE;1
89223;;Lézinnes;LEZINNES;89160;89;YONNE;1
89224;;Lichères-près-Aigremont;LICHERES-PRES-AIGREMONT;89800;89;YONNE;1
89225;;Lichères-sur-Yonne;LICHERES-SUR-YONNE;89660;89;YONNE;1
89226;;Lignorelles;LIGNORELLES;89800;89;YONNE;1
89227;;Ligny-le-Châtel;LIGNY-LE-CHATEL;89144;89;YONNE;1
89228;;Lindry;LINDRY;89240;89;YONNE;1
89229;;Lixy;LIXY;89140;89;YONNE;1
89230;;Looze;LOOZE;89300;89;YONNE;1
89232;;Lucy-le-Bois;LUCY-LE-BOIS;89200;89;YONNE;1
89233;;Lucy-sur-Cure;LUCY-SUR-CURE;89270;89;YONNE;1
89234;;Lucy-sur-Yonne;LUCY-SUR-YONNE;89480;89;YONNE;1
89235;;Magny;MAGNY;89200;89;YONNE;1
89236;;Maillot;MAILLOT;89100;89;YONNE;1
89237;;Mailly-la-Ville;MAILLY-LA-VILLE;89270;89;YONNE;1
89238;;Mailly-le-Château;MAILLY-LE-CHATEAU;89660;89;YONNE;1
89239;;Malay-le-Grand;MALAY-LE-GRAND;89100;89;YONNE;1
89240;;Malay-le-Petit;MALAY-LE-PETIT;89100;89;YONNE;1
89241;;Malicorne;MALICORNE;89120;89;YONNE;1
89242;;Maligny;MALIGNY;89800;89;YONNE;1
89243;;Marchais-Beton;MARCHAIS-BETON;89120;89;YONNE;1
89244;;Marmeaux;MARMEAUX;89420;89;YONNE;1
89245;;Marsangy;MARSANGY;89500;89;YONNE;1
89246;;Massangis;MASSANGIS;89440;89;YONNE;1
89247;;Mélisey;MELISEY;89430;89;YONNE;1
89248;;Menades;MENADES;89450;89;YONNE;1
89249;;Mercy;MERCY;89210;89;YONNE;1
89250;;Méré;MERE;89144;89;YONNE;1
89251;;Merry-la-Vallée;MERRY-LA-VALLEE;89110;89;YONNE;1
89252;;Merry-Sec;MERRY-SEC;89560;89;YONNE;1
89253;;Merry-sur-Yonne;MERRY-SUR-YONNE;89660;89;YONNE;1
89254;;Mézilles;MEZILLES;89130;89;YONNE;1
89255;;Michery;MICHERY;89140;89;YONNE;1
89256;;Migé;MIGE;89580;89;YONNE;1
89257;;Migennes;MIGENNES;89400;89;YONNE;1
89259;;Môlay;MOLAY;89310;89;YONNE;1
89260;;Molesmes;MOLESMES;89560;89;YONNE;1
89261;;Molinons;MOLINONS;89190;89;YONNE;1
89262;;Molosmes;MOLOSMES;89700;89;YONNE;1
89263;;Monéteau;MONETEAU;89470;89;YONNE;1
89264;;Montacher-Villegardin;MONTACHER-VILLEGARDIN;89150;89;YONNE;1
89265;;Montigny-la-Resle;MONTIGNY-LA-RESLE;89230;89;YONNE;1
89266;;Montillot;MONTILLOT;89660;89;YONNE;1
89267;;Montréal;MONTREAL;89420;89;YONNE;1
89268;;Mont-Saint-Sulpice;MONT-SAINT-SULPICE;89250;89;YONNE;1
89270;;Mouffy;MOUFFY;89560;89;YONNE;1
89271;;Moulins-en-Tonnerrois;MOULINS-EN-TONNERROIS;89310;89;YONNE;1
89272;;Moulins-sur-Ouanne;MOULINS-SUR-OUANNE;89130;89;YONNE;1
89273;;Moutiers-en-Puisaye;MOUTIERS-EN-PUISAYE;89520;89;YONNE;1
89274;;Nailly;NAILLY;89100;89;YONNE;1
89275;;Neuilly;NEUILLY;89113;89;YONNE;1
89276;;Neuvy-Sautour;NEUVY-SAUTOUR;89570;89;YONNE;1
89277;;Nitry;NITRY;89310;89;YONNE;1
89278;;Noé;NOE;89760;89;YONNE;1
89279;;Noyers;NOYERS;89310;89;YONNE;1
89280;;Nuits;NUITS;89390;89;YONNE;1
89281;Les;Ormes;ORMES;89110;89;YONNE;1
89282;;Ormoy;ORMOY;89400;89;YONNE;1
89283;;Ouanne;OUANNE;89560;89;YONNE;1
89284;;Pacy-sur-Armançon;PACY-SUR-ARMANCON;89160;89;YONNE;1
89285;;Pailly;PAILLY;89140;89;YONNE;1
89286;;Parly;PARLY;89240;89;YONNE;1
89287;;Paron;PARON;89100;89;YONNE;1
89288;;Paroy-en-Othe;PAROY-EN-OTHE;89210;89;YONNE;1
89289;;Paroy-sur-Tholon;PAROY-SUR-THOLON;89300;89;YONNE;1
89290;;Pasilly;PASILLY;89310;89;YONNE;1
89291;;Passy;PASSY;89510;89;YONNE;1
89292;;Percey;PERCEY;89360;89;YONNE;1
89294;;Perreux;PERREUX;89120;89;YONNE;1
89295;;Perrigny;PERRIGNY;89000;89;YONNE;1
89296;;Perrigny-sur-Armançon;PERRIGNY-SUR-ARMANCON;89390;89;YONNE;1
89297;;Pierre-Perthuis;PIERRE-PERTHUIS;89450;89;YONNE;1
89298;;Piffonds;PIFFONDS;89330;89;YONNE;1
89299;;Pimelles;PIMELLES;89740;89;YONNE;1
89300;;Pisy;PISY;89420;89;YONNE;1
89302;;Plessis-Saint-Jean;PLESSIS-SAINT-JEAN;89140;89;YONNE;1
89303;;Poilly-sur-Serein;POILLY-SUR-SEREIN;89310;89;YONNE;1
89304;;Poilly-sur-Tholon;POILLY-SUR-THOLON;89110;89;YONNE;1
89306;;Pontaubert;PONTAUBERT;89200;89;YONNE;1
89307;;Pontigny;PONTIGNY;89230;89;YONNE;1
89308;;Pont-sur-Vanne;PONT-SUR-VANNE;89190;89;YONNE;1
89309;;Pont-sur-Yonne;PONT-SUR-YONNE;89140;89;YONNE;1
89310;La;Postolle;POSTOLLE;89260;89;YONNE;1
89311;;Pourrain;POURRAIN;89240;89;YONNE;1
89312;;Précy-le-Sec;PRECY-LE-SEC;89440;89;YONNE;1
89313;;Précy-sur-Vrin;PRECY-SUR-VRIN;89116;89;YONNE;1
89314;;Prégilbert;PREGILBERT;89460;89;YONNE;1
89315;;Préhy;PREHY;89800;89;YONNE;1
89316;;Provency;PROVENCY;89200;89;YONNE;1
89317;;Prunoy;PRUNOY;89120;89;YONNE;1
89318;;Quarré-les-Tombes;QUARRE-LES-TOMBES;89630;89;YONNE;1
89319;;Quenne;QUENNE;89290;89;YONNE;1
89320;;Quincerot;QUINCEROT;89740;89;YONNE;1
89321;;Ravières;RAVIERES;89390;89;YONNE;1
89323;;Roffey;ROFFEY;89700;89;YONNE;1
89324;;Rogny-les-Sept-Écluses;ROGNY-LES-SEPT-ECLUSES;89220;89;YONNE;1
89325;;Ronchères;RONCHERES;89170;89;YONNE;1
89326;;Rosoy;ROSOY;89100;89;YONNE;1
89327;;Rousson;ROUSSON;89500;89;YONNE;1
89328;;Rouvray;ROUVRAY;89230;89;YONNE;1
89329;;Rugny;RUGNY;89430;89;YONNE;1
89330;;Sacy;SACY;89270;89;YONNE;1
89331;;Sainpuits;SAINPUITS;89520;89;YONNE;1
89332;;Saint-Agnan;SAINT-AGNAN;89340;89;YONNE;1
89333;;Saint-André-en-Terre-Plaine;SAINT-ANDRE-EN-TERRE-PLAINE;89420;89;YONNE;1
89334;;Saint-Aubin-Château-Neuf;SAINT-AUBIN-CHATEAU-NEUF;89110;89;YONNE;1
89335;;Saint-Aubin-sur-Yonne;SAINT-AUBIN-SUR-YONNE;89300;89;YONNE;1
89336;;Saint-Brancher;SAINT-BRANCHER;89630;89;YONNE;1
89337;;Saint-Bris-le-Vineux;SAINT-BRIS-LE-VINEUX;89530;89;YONNE;1
89338;;Saint-Clément;SAINT-CLEMENT;89100;89;YONNE;1
89339;;Sainte-Colombe;SAINTE-COLOMBE;89440;89;YONNE;1
89340;;Sainte-Colombe-sur-Loing;SAINTE-COLOMBE-SUR-LOING;89520;89;YONNE;1
89341;;Saint-Cyr-les-Colons;SAINT-CYR-LES-COLONS;89800;89;YONNE;1
89342;;Saint-Denis;SAINT-DENIS;89100;89;YONNE;1
89343;;Saint-Denis-sur-Ouanne;SAINT-DENIS-SUR-OUANNE;89120;89;YONNE;1
89344;;Saint-Fargeau;SAINT-FARGEAU;89170;89;YONNE;1
89345;;Saint-Florentin;SAINT-FLORENTIN;89600;89;YONNE;1
89346;;Saint-Georges-sur-Baulche;SAINT-GEORGES-SUR-BAULCHE;89000;89;YONNE;1
89347;;Saint-Germain-des-Champs;SAINT-GERMAIN-DES-CHAMPS;89630;89;YONNE;1
89348;;Saint-Julien-du-Sault;SAINT-JULIEN-DU-SAULT;89330;89;YONNE;1
89349;;Saint-Léger-Vauban;SAINT-LEGER-VAUBAN;89630;89;YONNE;1
89350;;Saint-Loup-d'Ordon;SAINT-LOUP-D'ORDON;89330;89;YONNE;1
89351;;Sainte-Magnance;SAINTE-MAGNANCE;89420;89;YONNE;1
89352;;Saint-Martin-des-Champs;SAINT-MARTIN-DES-CHAMPS;89170;89;YONNE;1
89353;;Saint-Martin-d'Ordon;SAINT-MARTIN-D'ORDON;89330;89;YONNE;1
89354;;Saint-Martin-du-Tertre;SAINT-MARTIN-DU-TERTRE;89100;89;YONNE;1
89355;;Saint-Martin-sur-Armançon;SAINT-MARTIN-SUR-ARMANCON;89700;89;YONNE;1
89356;;Saint-Martin-sur-Ocre;SAINT-MARTIN-SUR-OCRE;89110;89;YONNE;1
89358;;Saint-Martin-sur-Ouanne;SAINT-MARTIN-SUR-OUANNE;89120;89;YONNE;1
89359;;Saint-Maurice-aux-Riches-Hommes;SAINT-MAURICE-AUX-RICHES-HOMMES;89190;89;YONNE;1
89360;;Saint-Maurice-le-Vieil;SAINT-MAURICE-LE-VIEIL;89110;89;YONNE;1
89361;;Saint-Maurice-Thizouaille;SAINT-MAURICE-THIZOUAILLE;89110;89;YONNE;1
89362;;Saint-Moré;SAINT-MORE;89270;89;YONNE;1
89363;;Sainte-Pallaye;SAINTE-PALLAYE;89460;89;YONNE;1
89364;;Saint-Père;SAINT-PERE;89450;89;YONNE;1
89365;;Saint-Privé;SAINT-PRIVE;89220;89;YONNE;1
89366;;Saint-Romain-le-Preux;SAINT-ROMAIN-LE-PREUX;89116;89;YONNE;1
89367;;Saints;SAINTS;89520;89;YONNE;1
89368;;Saint-Sauveur-en-Puisaye;SAINT-SAUVEUR-EN-PUISAYE;89520;89;YONNE;1
89369;;Saint-Sérotin;SAINT-SEROTIN;89140;89;YONNE;1
89370;;Saint-Valérien;SAINT-VALERIEN;89150;89;YONNE;1
89371;;Sainte-Vertu;SAINTE-VERTU;89310;89;YONNE;1
89373;;Saligny;SALIGNY;89100;89;YONNE;1
89374;;Sambourg;SAMBOURG;89160;89;YONNE;1
89375;;Santigny;SANTIGNY;89420;89;YONNE;1
89376;;Sarry;SARRY;89310;89;YONNE;1
89377;;Sauvigny-le-Beuréal;SAUVIGNY-LE-BEUREAL;89420;89;YONNE;1
89378;;Sauvigny-le-Bois;SAUVIGNY-LE-BOIS;89200;89;YONNE;1
89379;;Savigny-en-Terre-Plaine;SAVIGNY-EN-TERRE-PLAINE;89420;89;YONNE;1
89380;;Savigny-sur-Clairis;SAVIGNY-SUR-CLAIRIS;89150;89;YONNE;1
89381;;Sceaux;SCEAUX;89420;89;YONNE;1
89382;;Seignelay;SEIGNELAY;89250;89;YONNE;1
89383;;Sementron;SEMENTRON;89560;89;YONNE;1
89384;;Senan;SENAN;89710;89;YONNE;1
89385;;Sennevoy-le-Bas;SENNEVOY-LE-BAS;89160;89;YONNE;1
89386;;Sennevoy-le-Haut;SENNEVOY-LE-HAUT;89160;89;YONNE;1
89387;;Sens;SENS;89100;89;YONNE;1
89388;;Sépeaux;SEPEAUX;89116;89;YONNE;1
89390;;Serbonnes;SERBONNES;89140;89;YONNE;1
89391;;Sergines;SERGINES;89140;89;YONNE;1
89392;;Sermizelles;SERMIZELLES;89200;89;YONNE;1
89393;;Serrigny;SERRIGNY;89700;89;YONNE;1
89394;;Sery;SERY;89270;89;YONNE;1
89395;Les;Sièges;SIEGES;89190;89;YONNE;1
89397;;Sommecaise;SOMMECAISE;89110;89;YONNE;1
89398;;Sormery;SORMERY;89570;89;YONNE;1
89399;;Soucy;SOUCY;89100;89;YONNE;1
89400;;Sougères-en-Puisaye;SOUGERES-EN-PUISAYE;89520;89;YONNE;1
89402;;Soumaintrain;SOUMAINTRAIN;89570;89;YONNE;1
89403;;Stigny;STIGNY;89160;89;YONNE;1
89404;;Subligny;SUBLIGNY;89100;89;YONNE;1
89405;;Taingy;TAINGY;89560;89;YONNE;1
89406;;Talcy;TALCY;89420;89;YONNE;1
89407;;Tanlay;TANLAY;89430;89;YONNE;1
89408;;Tannerre-en-Puisaye;TANNERRE-EN-PUISAYE;89350;89;YONNE;1
89409;;Tharoiseau;THAROISEAU;89450;89;YONNE;1
89410;;Tharot;THAROT;89200;89;YONNE;1
89411;;Theil-sur-Vanne;THEIL-SUR-VANNE;89760;89;YONNE;1
89412;;Thizy;THIZY;89420;89;YONNE;1
89413;;Thorey;THOREY;89430;89;YONNE;1
89414;;Thorigny-sur-Oreuse;THORIGNY-SUR-OREUSE;89260;89;YONNE;1
89415;;Thory;THORY;89200;89;YONNE;1
89416;;Thury;THURY;89520;89;YONNE;1
89417;;Tissey;TISSEY;89700;89;YONNE;1
89418;;Tonnerre;TONNERRE;89700;89;YONNE;1
89419;;Toucy;TOUCY;89130;89;YONNE;1
89420;;Treigny;TREIGNY;89520;89;YONNE;1
89421;;Trévilly;TREVILLY;89420;89;YONNE;1
89422;;Trichey;TRICHEY;89430;89;YONNE;1
89423;;Tronchoy;TRONCHOY;89700;89;YONNE;1
89424;;Trucy-sur-Yonne;TRUCY-SUR-YONNE;89460;89;YONNE;1
89425;;Turny;TURNY;89570;89;YONNE;1
89426;;Val-de-Mercy;VAL-DE-MERCY;89580;89;YONNE;1
89427;;Vallan;VALLAN;89580;89;YONNE;1
89428;;Vallery;VALLERY;89150;89;YONNE;1
89429;;Vareilles;VAREILLES;89760;89;YONNE;1
89430;;Varennes;VARENNES;89144;89;YONNE;1
89431;;Vassy-sous-Pisy;VASSY-SOUS-PISY;89420;89;YONNE;1
89432;;Vaudeurs;VAUDEURS;89320;89;YONNE;1
89433;;Vault-de-Lugny;VAULT-DE-LUGNY;89200;89;YONNE;1
89434;;Vaumort;VAUMORT;89320;89;YONNE;1
89436;;Venizy;VENIZY;89210;89;YONNE;1
89437;;Venouse;VENOUSE;89230;89;YONNE;1
89438;;Venoy;VENOY;89290;89;YONNE;1
89439;;Vergigny;VERGIGNY;89600;89;YONNE;1
89440;;Verlin;VERLIN;89330;89;YONNE;1
89441;;Vermenton;VERMENTON;89270;89;YONNE;1
89442;;Vernoy;VERNOY;89150;89;YONNE;1
89443;;Véron;VERON;89510;89;YONNE;1
89445;;Vézannes;VEZANNES;89700;89;YONNE;1
89446;;Vézelay;VEZELAY;89450;89;YONNE;1
89447;;Vézinnes;VEZINNES;89700;89;YONNE;1
89448;;Vignes;VIGNES;89420;89;YONNE;1
89449;;Villeblevin;VILLEBLEVIN;89720;89;YONNE;1
89450;;Villebougis;VILLEBOUGIS;89150;89;YONNE;1
89451;;Villechétive;VILLECHETIVE;89320;89;YONNE;1
89452;;Villecien;VILLECIEN;89300;89;YONNE;1
89453;;Villefargeau;VILLEFARGEAU;89240;89;YONNE;1
89454;;Villefranche;VILLEFRANCHE;89120;89;YONNE;1
89456;;Villemanoche;VILLEMANOCHE;89140;89;YONNE;1
89457;;Villemer;VILLEMER;89113;89;YONNE;1
89458;;Villenavotte;VILLENAVOTTE;89140;89;YONNE;1
89459;;Villeneuve-la-Dondagre;VILLENEUVE-LA-DONDAGRE;89150;89;YONNE;1
89460;;Villeneuve-la-Guyard;VILLENEUVE-LA-GUYARD;89340;89;YONNE;1
89461;;Villeneuve-l'Archevêque;VILLENEUVE-L'ARCHEVEQUE;89190;89;YONNE;1
89462;;Villeneuve-les-Genêts;VILLENEUVE-LES-GENETS;89350;89;YONNE;1
89463;;Villeneuve-Saint-Salves;VILLENEUVE-SAINT-SALVES;89230;89;YONNE;1
89464;;Villeneuve-sur-Yonne;VILLENEUVE-SUR-YONNE;89500;89;YONNE;1
89465;;Villeperrot;VILLEPERROT;89140;89;YONNE;1
89466;;Villeroy;VILLEROY;89100;89;YONNE;1
89467;;Villethierry;VILLETHIERRY;89140;89;YONNE;1
89468;;Villevallier;VILLEVALLIER;89330;89;YONNE;1
89469;;Perceneige;PERCENEIGE;89260;89;YONNE;1
89470;;Villiers-les-Hauts;VILLIERS-LES-HAUTS;89160;89;YONNE;1
89471;;Villiers-Louis;VILLIERS-LOUIS;89760;89;YONNE;1
89472;;Villiers-Saint-Benoît;VILLIERS-SAINT-BENOIT;89130;89;YONNE;1
89473;;Villiers-sur-Tholon;VILLIERS-SUR-THOLON;89110;89;YONNE;1
89474;;Villiers-Vineux;VILLIERS-VINEUX;89360;89;YONNE;1
89475;;Villon;VILLON;89740;89;YONNE;1
89477;;Villy;VILLY;89800;89;YONNE;1
89478;;Vincelles;VINCELLES;89290;89;YONNE;1
89479;;Vincelottes;VINCELOTTES;89290;89;YONNE;1
89480;;Vinneuf;VINNEUF;89140;89;YONNE;1
89481;;Vireaux;VIREAUX;89160;89;YONNE;1
89482;;Viviers;VIVIERS;89700;89;YONNE;1
89483;;Voisines;VOISINES;89260;89;YONNE;1
89484;;Volgré;VOLGRE;89710;89;YONNE;1
89485;;Voutenay-sur-Cure;VOUTENAY-SUR-CURE;89270;89;YONNE;1
89486;;Yrouerre;YROUERRE;89700;89;YONNE;1
90001;;Andelnans;ANDELNANS;90400;90;TERRITOIRE DE BELFORT;1
90002;;Angeot;ANGEOT;90150;90;TERRITOIRE DE BELFORT;1
90003;;Anjoutey;ANJOUTEY;90170;90;TERRITOIRE DE BELFORT;1
90004;;Argiésans;ARGIESANS;90800;90;TERRITOIRE DE BELFORT;1
90005;;Auxelles-Bas;AUXELLES-BAS;90200;90;TERRITOIRE DE BELFORT;1
90006;;Auxelles-Haut;AUXELLES-HAUT;90200;90;TERRITOIRE DE BELFORT;1
90007;;Banvillars;BANVILLARS;90800;90;TERRITOIRE DE BELFORT;1
90008;;Bavilliers;BAVILLIERS;90800;90;TERRITOIRE DE BELFORT;1
90009;;Beaucourt;BEAUCOURT;90500;90;TERRITOIRE DE BELFORT;1
90010;;Belfort;BELFORT;90000;90;TERRITOIRE DE BELFORT;1
90011;;Bermont;BERMONT;90400;90;TERRITOIRE DE BELFORT;1
90012;;Bessoncourt;BESSONCOURT;90160;90;TERRITOIRE DE BELFORT;1
90013;;Bethonvilliers;BETHONVILLIERS;90150;90;TERRITOIRE DE BELFORT;1
90014;;Boron;BORON;90100;90;TERRITOIRE DE BELFORT;1
90015;;Botans;BOTANS;90400;90;TERRITOIRE DE BELFORT;1
90016;;Bourg-sous-Châtelet;BOURG-SOUS-CHATELET;90110;90;TERRITOIRE DE BELFORT;1
90017;;Bourogne;BOUROGNE;90140;90;TERRITOIRE DE BELFORT;1
90018;;Brebotte;BREBOTTE;90140;90;TERRITOIRE DE BELFORT;1
90019;;Bretagne;BRETAGNE;90130;90;TERRITOIRE DE BELFORT;1
90020;;Buc;BUC;90800;90;TERRITOIRE DE BELFORT;1
90021;;Charmois;CHARMOIS;90140;90;TERRITOIRE DE BELFORT;1
90022;;Châtenois-les-Forges;CHATENOIS-LES-FORGES;90700;90;TERRITOIRE DE BELFORT;1
90023;;Chaux;CHAUX;90330;90;TERRITOIRE DE BELFORT;1
90024;;Chavanatte;CHAVANATTE;90100;90;TERRITOIRE DE BELFORT;1
90025;;Chavannes-les-Grands;CHAVANNES-LES-GRANDS;90100;90;TERRITOIRE DE BELFORT;1
90026;;Chèvremont;CHEVREMONT;90340;90;TERRITOIRE DE BELFORT;1
90027;;Courcelles;COURCELLES;90100;90;TERRITOIRE DE BELFORT;1
90028;;Courtelevant;COURTELEVANT;90100;90;TERRITOIRE DE BELFORT;1
90029;;Cravanche;CRAVANCHE;90300;90;TERRITOIRE DE BELFORT;1
90030;;Croix;CROIX;90100;90;TERRITOIRE DE BELFORT;1
90031;;Cunelières;CUNELIERES;90150;90;TERRITOIRE DE BELFORT;1
90032;;Danjoutin;DANJOUTIN;90400;90;TERRITOIRE DE BELFORT;1
90033;;Delle;DELLE;90100;90;TERRITOIRE DE BELFORT;1
90034;;Denney;DENNEY;90160;90;TERRITOIRE DE BELFORT;1
90035;;Dorans;DORANS;90400;90;TERRITOIRE DE BELFORT;1
90036;;Eguenigue;EGUENIGUE;90150;90;TERRITOIRE DE BELFORT;1
90037;;Éloie;ELOIE;90300;90;TERRITOIRE DE BELFORT;1
90039;;Essert;ESSERT;90850;90;TERRITOIRE DE BELFORT;1
90041;;Étueffont;ETUEFFONT;90170;90;TERRITOIRE DE BELFORT;1
90042;;Évette-Salbert;EVETTE-SALBERT;90350;90;TERRITOIRE DE BELFORT;1
90043;;Faverois;FAVEROIS;90100;90;TERRITOIRE DE BELFORT;1
90044;;Felon;FELON;90110;90;TERRITOIRE DE BELFORT;1
90045;;Fêche-l'Église;FECHE-L'EGLISE;90100;90;TERRITOIRE DE BELFORT;1
90046;;Florimont;FLORIMONT;90100;90;TERRITOIRE DE BELFORT;1
90047;;Fontaine;FONTAINE;90150;90;TERRITOIRE DE BELFORT;1
90048;;Fontenelle;FONTENELLE;90340;90;TERRITOIRE DE BELFORT;1
90049;;Foussemagne;FOUSSEMAGNE;90150;90;TERRITOIRE DE BELFORT;1
90050;;Frais;FRAIS;90150;90;TERRITOIRE DE BELFORT;1
90051;;Froidefontaine;FROIDEFONTAINE;90140;90;TERRITOIRE DE BELFORT;1
90052;;Giromagny;GIROMAGNY;90200;90;TERRITOIRE DE BELFORT;1
90053;;Grandvillars;GRANDVILLARS;90600;90;TERRITOIRE DE BELFORT;1
90054;;Grosmagny;GROSMAGNY;90200;90;TERRITOIRE DE BELFORT;1
90055;;Grosne;GROSNE;90100;90;TERRITOIRE DE BELFORT;1
90056;;Joncherey;JONCHEREY;90100;90;TERRITOIRE DE BELFORT;1
90057;;Lachapelle-sous-Chaux;LACHAPELLE-SOUS-CHAUX;90300;90;TERRITOIRE DE BELFORT;1
90058;;Lachapelle-sous-Rougemont;LACHAPELLE-SOUS-ROUGEMONT;90360;90;TERRITOIRE DE BELFORT;1
90059;;Lacollonge;LACOLLONGE;90150;90;TERRITOIRE DE BELFORT;1
90060;;Lagrange;LAGRANGE;90150;90;TERRITOIRE DE BELFORT;1
90061;;Lamadeleine-Val-des-Anges;LAMADELEINE-VAL-DES-ANGES;90170;90;TERRITOIRE DE BELFORT;1
90062;;Larivière;LARIVIERE;90150;90;TERRITOIRE DE BELFORT;1
90063;;Lebetain;LEBETAIN;90100;90;TERRITOIRE DE BELFORT;1
90064;;Lepuix-Neuf;LEPUIX-NEUF;90100;90;TERRITOIRE DE BELFORT;1
90065;;Lepuix;LEPUIX;90200;90;TERRITOIRE DE BELFORT;1
90066;;Leval;LEVAL;90110;90;TERRITOIRE DE BELFORT;1
90067;;Menoncourt;MENONCOURT;90150;90;TERRITOIRE DE BELFORT;1
90068;;Meroux;MEROUX;90400;90;TERRITOIRE DE BELFORT;1
90069;;Méziré;MEZIRE;90120;90;TERRITOIRE DE BELFORT;1
90070;;Montbouton;MONTBOUTON;90500;90;TERRITOIRE DE BELFORT;1
90071;;Montreux-Château;MONTREUX-CHATEAU;90130;90;TERRITOIRE DE BELFORT;1
90072;;Morvillars;MORVILLARS;90120;90;TERRITOIRE DE BELFORT;1
90073;;Moval;MOVAL;90400;90;TERRITOIRE DE BELFORT;1
90074;;Novillard;NOVILLARD;90340;90;TERRITOIRE DE BELFORT;1
90075;;Offemont;OFFEMONT;90300;90;TERRITOIRE DE BELFORT;1
90076;;Pérouse;PEROUSE;90160;90;TERRITOIRE DE BELFORT;1
90077;;Petit-Croix;PETIT-CROIX;90130;90;TERRITOIRE DE BELFORT;1
90078;;Petitefontaine;PETITEFONTAINE;90360;90;TERRITOIRE DE BELFORT;1
90079;;Petitmagny;PETITMAGNY;90170;90;TERRITOIRE DE BELFORT;1
90080;;Phaffans;PHAFFANS;90150;90;TERRITOIRE DE BELFORT;1
90081;;Réchésy;RECHESY;90370;90;TERRITOIRE DE BELFORT;1
90082;;Autrechêne;AUTRECHENE;90140;90;TERRITOIRE DE BELFORT;1
90083;;Recouvrance;RECOUVRANCE;90140;90;TERRITOIRE DE BELFORT;1
90084;;Reppe;REPPE;90150;90;TERRITOIRE DE BELFORT;1
90085;;Riervescemont;RIERVESCEMONT;90200;90;TERRITOIRE DE BELFORT;1
90086;;Romagny-sous-Rougemont;ROMAGNY-SOUS-ROUGEMONT;90110;90;TERRITOIRE DE BELFORT;1
90087;;Roppe;ROPPE;90380;90;TERRITOIRE DE BELFORT;1
90088;;Rougegoutte;ROUGEGOUTTE;90200;90;TERRITOIRE DE BELFORT;1
90089;;Rougemont-le-Château;ROUGEMONT-LE-CHATEAU;90110;90;TERRITOIRE DE BELFORT;1
90090;;Saint-Dizier-l'Évêque;SAINT-DIZIER-L'EVEQUE;90100;90;TERRITOIRE DE BELFORT;1
90091;;Saint-Germain-le-Châtelet;SAINT-GERMAIN-LE-CHATELET;90110;90;TERRITOIRE DE BELFORT;1
90093;;Sermamagny;SERMAMAGNY;90300;90;TERRITOIRE DE BELFORT;1
90094;;Sevenans;SEVENANS;90400;90;TERRITOIRE DE BELFORT;1
90095;;Suarce;SUARCE;90100;90;TERRITOIRE DE BELFORT;1
90096;;Thiancourt;THIANCOURT;90100;90;TERRITOIRE DE BELFORT;1
90097;;Trévenans;TREVENANS;90400;90;TERRITOIRE DE BELFORT;1
90098;;Urcerey;URCEREY;90800;90;TERRITOIRE DE BELFORT;1
90099;;Valdoie;VALDOIE;90300;90;TERRITOIRE DE BELFORT;1
90100;;Vauthiermont;VAUTHIERMONT;90150;90;TERRITOIRE DE BELFORT;1
90101;;Vellescot;VELLESCOT;90100;90;TERRITOIRE DE BELFORT;1
90102;;Vescemont;VESCEMONT;90200;90;TERRITOIRE DE BELFORT;1
90103;;Vétrigne;VETRIGNE;90300;90;TERRITOIRE DE BELFORT;1
90104;;Vézelois;VEZELOIS;90400;90;TERRITOIRE DE BELFORT;1
90105;;Villars-le-Sec;VILLARS-LE-SEC;90100;90;TERRITOIRE DE BELFORT;1
91001;;Abbéville-la-Rivière;ABBEVILLE-LA-RIVIERE;91150;91;ESSONNE;1
91016;;Angerville;ANGERVILLE;91670;91;ESSONNE;1
91017;;Angervilliers;ANGERVILLIERS;91470;91;ESSONNE;1
91021;;Arpajon;ARPAJON;91290;91;ESSONNE;1
91022;;Arrancourt;ARRANCOURT;91690;91;ESSONNE;1
91027;;Athis-Mons;ATHIS-MONS;91200;91;ESSONNE;1
91035;;Authon-la-Plaine;AUTHON-LA-PLAINE;91410;91;ESSONNE;1
91037;;Auvernaux;AUVERNAUX;91830;91;ESSONNE;1
91038;;Auvers-Saint-Georges;AUVERS-SAINT-GEORGES;91580;91;ESSONNE;1
91041;;Avrainville;AVRAINVILLE;91630;91;ESSONNE;1
91044;;Ballainvilliers;BALLAINVILLIERS;91160;91;ESSONNE;1
91045;;Ballancourt-sur-Essonne;BALLANCOURT-SUR-ESSONNE;91610;91;ESSONNE;1
91047;;Baulne;BAULNE;91590;91;ESSONNE;1
91064;;Bièvres;BIEVRES;91570;91;ESSONNE;1
91067;;Blandy;BLANDY;91150;91;ESSONNE;1
91069;;Boigneville;BOIGNEVILLE;91720;91;ESSONNE;1
91075;;Bois-Herpin;BOIS-HERPIN;91150;91;ESSONNE;1
91079;;Boissy-la-Rivière;BOISSY-LA-RIVIERE;91690;91;ESSONNE;1
91080;;Boissy-le-Cutté;BOISSY-LE-CUTTE;91590;91;ESSONNE;1
91081;;Boissy-le-Sec;BOISSY-LE-SEC;91870;91;ESSONNE;1
91085;;Boissy-sous-Saint-Yon;BOISSY-SOUS-SAINT-YON;91790;91;ESSONNE;1
91086;;Bondoufle;BONDOUFLE;91070;91;ESSONNE;1
91093;;Boullay-les-Troux;BOULLAY-LES-TROUX;91470;91;ESSONNE;1
91095;;Bouray-sur-Juine;BOURAY-SUR-JUINE;91850;91;ESSONNE;1
91097;;Boussy-Saint-Antoine;BOUSSY-SAINT-ANTOINE;91800;91;ESSONNE;1
91098;;Boutervilliers;BOUTERVILLIERS;91150;91;ESSONNE;1
91099;;Boutigny-sur-Essonne;BOUTIGNY-SUR-ESSONNE;91820;91;ESSONNE;1
91100;;Bouville;BOUVILLE;91880;91;ESSONNE;1
91103;;Brétigny-sur-Orge;BRETIGNY-SUR-ORGE;91220;91;ESSONNE;1
91105;;Breuillet;BREUILLET;91650;91;ESSONNE;1
91106;;Breux-Jouy;BREUX-JOUY;91650;91;ESSONNE;1
91109;;Brières-les-Scellés;BRIERES-LES-SCELLES;91150;91;ESSONNE;1
91111;;Briis-sous-Forges;BRIIS-SOUS-FORGES;91640;91;ESSONNE;1
91112;;Brouy;BROUY;91150;91;ESSONNE;1
91114;;Brunoy;BRUNOY;91800;91;ESSONNE;1
91115;;Bruyères-le-Châtel;BRUYERES-LE-CHATEL;91680;91;ESSONNE;1
91121;;Buno-Bonnevaux;BUNO-BONNEVAUX;91720;91;ESSONNE;1
91122;;Bures-sur-Yvette;BURES-SUR-YVETTE;91440;91;ESSONNE;1
91129;;Cerny;CERNY;91590;91;ESSONNE;1
91130;;Chalo-Saint-Mars;CHALO-SAINT-MARS;91780;91;ESSONNE;1
91131;;Chalou-Moulineux;CHALOU-MOULINEUX;91740;91;ESSONNE;1
91132;;Chamarande;CHAMARANDE;91730;91;ESSONNE;1
91135;;Champcueil;CHAMPCUEIL;91750;91;ESSONNE;1
91136;;Champlan;CHAMPLAN;91160;91;ESSONNE;1
91137;;Champmotteux;CHAMPMOTTEUX;91150;91;ESSONNE;1
91145;;Chatignonville;CHATIGNONVILLE;91410;91;ESSONNE;1
91148;;Chauffour-lès-Étréchy;CHAUFFOUR-LES-ETRECHY;91580;91;ESSONNE;1
91156;;Cheptainville;CHEPTAINVILLE;91630;91;ESSONNE;1
91159;;Chevannes;CHEVANNES;91750;91;ESSONNE;1
91161;;Chilly-Mazarin;CHILLY-MAZARIN;91380;91;ESSONNE;1
91174;;Corbeil-Essonnes;CORBEIL-ESSONNES;91100;91;ESSONNE;1
91175;;Corbreuse;CORBREUSE;91410;91;ESSONNE;1
91179;Le;Coudray-Montceaux;COUDRAY-MONTCEAUX;91830;91;ESSONNE;1
91180;;Courances;COURANCES;91490;91;ESSONNE;1
91182;;Courcouronnes;COURCOURONNES;91080;91;ESSONNE;1
91184;;Courdimanche-sur-Essonne;COURDIMANCHE-SUR-ESSONNE;91720;91;ESSONNE;1
91186;;Courson-Monteloup;COURSON-MONTELOUP;91680;91;ESSONNE;1
91191;;Crosne;CROSNE;91560;91;ESSONNE;1
91195;;Dannemois;DANNEMOIS;91490;91;ESSONNE;1
91198;;D'Huison-Longueville;D'HUISON-LONGUEVILLE;91590;91;ESSONNE;1
91200;;Dourdan;DOURDAN;91410;91;ESSONNE;1
91201;;Draveil;DRAVEIL;91210;91;ESSONNE;1
91204;;Écharcon;ECHARCON;91540;91;ESSONNE;1
91207;;Égly;EGLY;91520;91;ESSONNE;1
91215;;Épinay-sous-Sénart;EPINAY-SOUS-SENART;91860;91;ESSONNE;1
91216;;Épinay-sur-Orge;EPINAY-SUR-ORGE;91360;91;ESSONNE;1
91222;;Estouches;ESTOUCHES;91660;91;ESSONNE;1
91223;;Étampes;ETAMPES;91150;91;ESSONNE;1
91225;;Étiolles;ETIOLLES;91450;91;ESSONNE;1
91226;;Étréchy;ETRECHY;91580;91;ESSONNE;1
91228;;Évry;EVRY;91000;91;ESSONNE;1
91232;La;Ferté-Alais;FERTE-ALAIS;91590;91;ESSONNE;1
91235;;Fleury-Mérogis;FLEURY-MEROGIS;91700;91;ESSONNE;1
91240;;Fontaine-la-Rivière;FONTAINE-LA-RIVIERE;91690;91;ESSONNE;1
91243;;Fontenay-lès-Briis;FONTENAY-LES-BRIIS;91640;91;ESSONNE;1
91244;;Fontenay-le-Vicomte;FONTENAY-LE-VICOMTE;91540;91;ESSONNE;1
91247;La;Forêt-le-Roi;FORET-LE-ROI;91410;91;ESSONNE;1
91248;La;Forêt-Sainte-Croix;FORET-SAINTE-CROIX;91150;91;ESSONNE;1
91249;;Forges-les-Bains;FORGES-LES-BAINS;91470;91;ESSONNE;1
91272;;Gif-sur-Yvette;GIF-SUR-YVETTE;91190;91;ESSONNE;1
91273;;Gironville-sur-Essonne;GIRONVILLE-SUR-ESSONNE;91720;91;ESSONNE;1
91274;;Gometz-la-Ville;GOMETZ-LA-VILLE;91400;91;ESSONNE;1
91275;;Gometz-le-Châtel;GOMETZ-LE-CHATEL;91940;91;ESSONNE;1
91284;Les;Granges-le-Roi;GRANGES-LE-ROI;91410;91;ESSONNE;1
91286;;Grigny;GRIGNY;91350;91;ESSONNE;1
91292;;Guibeville;GUIBEVILLE;91630;91;ESSONNE;1
91293;;Guigneville-sur-Essonne;GUIGNEVILLE-SUR-ESSONNE;91590;91;ESSONNE;1
91294;;Guillerval;GUILLERVAL;91690;91;ESSONNE;1
91312;;Igny;IGNY;91430;91;ESSONNE;1
91315;;Itteville;ITTEVILLE;91760;91;ESSONNE;1
91318;;Janville-sur-Juine;JANVILLE-SUR-JUINE;91510;91;ESSONNE;1
91319;;Janvry;JANVRY;91640;91;ESSONNE;1
91326;;Juvisy-sur-Orge;JUVISY-SUR-ORGE;91260;91;ESSONNE;1
91330;;Lardy;LARDY;91510;91;ESSONNE;1
91332;;Leudeville;LEUDEVILLE;91630;91;ESSONNE;1
91333;;Leuville-sur-Orge;LEUVILLE-SUR-ORGE;91310;91;ESSONNE;1
91338;;Limours;LIMOURS;91470;91;ESSONNE;1
91339;;Linas;LINAS;91310;91;ESSONNE;1
91340;;Lisses;LISSES;91090;91;ESSONNE;1
91345;;Longjumeau;LONGJUMEAU;91160;91;ESSONNE;1
91347;;Longpont-sur-Orge;LONGPONT-SUR-ORGE;91310;91;ESSONNE;1
91359;;Maisse;MAISSE;91720;91;ESSONNE;1
91363;;Marcoussis;MARCOUSSIS;91460;91;ESSONNE;1
91374;;Marolles-en-Beauce;MAROLLES-EN-BEAUCE;91150;91;ESSONNE;1
91376;;Marolles-en-Hurepoix;MAROLLES-EN-HUREPOIX;91630;91;ESSONNE;1
91377;;Massy;MASSY;91300;91;ESSONNE;1
91378;;Mauchamps;MAUCHAMPS;91730;91;ESSONNE;1
91386;;Mennecy;MENNECY;91540;91;ESSONNE;1
91390;;Méréville;MEREVILLE;91660;91;ESSONNE;1
91393;;Mérobert;MEROBERT;91780;91;ESSONNE;1
91399;;Mespuits;MESPUITS;91150;91;ESSONNE;1
91405;;Milly-la-Forêt;MILLY-LA-FORET;91490;91;ESSONNE;1
91408;;Moigny-sur-École;MOIGNY-SUR-ECOLE;91490;91;ESSONNE;1
91411;Les;Molières;MOLIERES;91470;91;ESSONNE;1
91412;;Mondeville;MONDEVILLE;91590;91;ESSONNE;1
91414;;Monnerville;MONNERVILLE;91930;91;ESSONNE;1
91421;;Montgeron;MONTGERON;91230;91;ESSONNE;1
91425;;Montlhéry;MONTLHERY;91310;91;ESSONNE;1
91432;;Morangis;MORANGIS;91420;91;ESSONNE;1
91433;;Morigny-Champigny;MORIGNY-CHAMPIGNY;91150;91;ESSONNE;1
91434;;Morsang-sur-Orge;MORSANG-SUR-ORGE;91390;91;ESSONNE;1
91435;;Morsang-sur-Seine;MORSANG-SUR-SEINE;91250;91;ESSONNE;1
91441;;Nainville-les-Roches;NAINVILLE-LES-ROCHES;91750;91;ESSONNE;1
91457;La;Norville;NORVILLE;91290;91;ESSONNE;1
91458;;Nozay;NOZAY;91620;91;ESSONNE;1
91461;;Ollainville;OLLAINVILLE;91290;91;ESSONNE;1
91463;;Oncy-sur-École;ONCY-SUR-ECOLE;91490;91;ESSONNE;1
91468;;Ormoy;ORMOY;91540;91;ESSONNE;1
91469;;Ormoy-la-Rivière;ORMOY-LA-RIVIERE;91150;91;ESSONNE;1
91471;;Orsay;ORSAY;91400;91;ESSONNE;1
91473;;Orveau;ORVEAU;91590;91;ESSONNE;1
91477;;Palaiseau;PALAISEAU;91120;91;ESSONNE;1
91479;;Paray-Vieille-Poste;PARAY-VIEILLE-POSTE;91550;91;ESSONNE;1
91482;;Pecqueuse;PECQUEUSE;91470;91;ESSONNE;1
91494;Le;Plessis-Pâté;PLESSIS-PATE;91220;91;ESSONNE;1
91495;;Plessis-Saint-Benoist;PLESSIS-SAINT-BENOIST;91410;91;ESSONNE;1
91507;;Prunay-sur-Essonne;PRUNAY-SUR-ESSONNE;91720;91;ESSONNE;1
91508;;Puiselet-le-Marais;PUISELET-LE-MARAIS;91150;91;ESSONNE;1
91511;;Pussay;PUSSAY;91740;91;ESSONNE;1
91514;;Quincy-sous-Sénart;QUINCY-SOUS-SENART;91480;91;ESSONNE;1
91519;;Richarville;RICHARVILLE;91410;91;ESSONNE;1
91521;;Ris-Orangis;RIS-ORANGIS;91130;91;ESSONNE;1
91525;;Roinville;ROINVILLE;91410;91;ESSONNE;1
91526;;Roinvilliers;ROINVILLIERS;91150;91;ESSONNE;1
91533;;Saclas;SACLAS;91690;91;ESSONNE;1
91534;;Saclay;SACLAY;91400;91;ESSONNE;1
91538;;Saint-Aubin;SAINT-AUBIN;91190;91;ESSONNE;1
91540;;Saint-Chéron;SAINT-CHERON;91530;91;ESSONNE;1
91544;;Saint-Cyr-la-Rivière;SAINT-CYR-LA-RIVIERE;91690;91;ESSONNE;1
91546;;Saint-Cyr-sous-Dourdan;SAINT-CYR-SOUS-DOURDAN;91410;91;ESSONNE;1
91547;;Saint-Escobille;SAINT-ESCOBILLE;91410;91;ESSONNE;1
91549;;Sainte-Geneviève-des-Bois;SAINTE-GENEVIEVE-DES-BOIS;91700;91;ESSONNE;1
91552;;Saint-Germain-lès-Arpajon;SAINT-GERMAIN-LES-ARPAJON;91180;91;ESSONNE;1
91553;;Saint-Germain-lès-Corbeil;SAINT-GERMAIN-LES-CORBEIL;91250;91;ESSONNE;1
91556;;Saint-Hilaire;SAINT-HILAIRE;91780;91;ESSONNE;1
91560;;Saint-Jean-de-Beauregard;SAINT-JEAN-DE-BEAUREGARD;91940;91;ESSONNE;1
91568;;Saint-Maurice-Montcouronne;SAINT-MAURICE-MONTCOURONNE;91530;91;ESSONNE;1
91570;;Saint-Michel-sur-Orge;SAINT-MICHEL-SUR-ORGE;91240;91;ESSONNE;1
91573;;Saint-Pierre-du-Perray;SAINT-PIERRE-DU-PERRAY;91280;91;ESSONNE;1
91577;;Saintry-sur-Seine;SAINTRY-SUR-SEINE;91250;91;ESSONNE;1
91578;;Saint-Sulpice-de-Favières;SAINT-SULPICE-DE-FAVIERES;91910;91;ESSONNE;1
91579;;Saint-Vrain;SAINT-VRAIN;91770;91;ESSONNE;1
91581;;Saint-Yon;SAINT-YON;91650;91;ESSONNE;1
91587;;Saulx-les-Chartreux;SAULX-LES-CHARTREUX;91160;91;ESSONNE;1
91589;;Savigny-sur-Orge;SAVIGNY-SUR-ORGE;91600;91;ESSONNE;1
91593;;Sermaise;SERMAISE;91530;91;ESSONNE;1
91599;;Soisy-sur-École;SOISY-SUR-ECOLE;91840;91;ESSONNE;1
91600;;Soisy-sur-Seine;SOISY-SUR-SEINE;91450;91;ESSONNE;1
91602;;Souzy-la-Briche;SOUZY-LA-BRICHE;91580;91;ESSONNE;1
91613;;Congerville-Thionville;CONGERVILLE-THIONVILLE;91740;91;ESSONNE;1
91617;;Tigery;TIGERY;91250;91;ESSONNE;1
91619;;Torfou;TORFOU;91730;91;ESSONNE;1
91629;;Valpuiseaux;VALPUISEAUX;91720;91;ESSONNE;1
91630;Le;Val-Saint-Germain;VAL-SAINT-GERMAIN;91530;91;ESSONNE;1
91631;;Varennes-Jarcy;VARENNES-JARCY;91480;91;ESSONNE;1
91634;;Vaugrigneuse;VAUGRIGNEUSE;91640;91;ESSONNE;1
91635;;Vauhallan;VAUHALLAN;91430;91;ESSONNE;1
91639;;Vayres-sur-Essonne;VAYRES-SUR-ESSONNE;91820;91;ESSONNE;1
91645;;Verrières-le-Buisson;VERRIERES-LE-BUISSON;91370;91;ESSONNE;1
91648;;Vert-le-Grand;VERT-LE-GRAND;91810;91;ESSONNE;1
91649;;Vert-le-Petit;VERT-LE-PETIT;91710;91;ESSONNE;1
91654;;Videlles;VIDELLES;91890;91;ESSONNE;1
91657;;Vigneux-sur-Seine;VIGNEUX-SUR-SEINE;91270;91;ESSONNE;1
91659;;Villabé;VILLABE;91100;91;ESSONNE;1
91661;;Villebon-sur-Yvette;VILLEBON-SUR-YVETTE;91140;91;ESSONNE;1
91662;;Villeconin;VILLECONIN;91580;91;ESSONNE;1
91665;La;Ville-du-Bois;VILLE-DU-BOIS;91620;91;ESSONNE;1
91666;;Villejust;VILLEJUST;91140;91;ESSONNE;1
91667;;Villemoisson-sur-Orge;VILLEMOISSON-SUR-ORGE;91360;91;ESSONNE;1
91671;;Villeneuve-sur-Auvers;VILLENEUVE-SUR-AUVERS;91580;91;ESSONNE;1
91679;;Villiers-le-Bâcle;VILLIERS-LE-BACLE;91190;91;ESSONNE;1
91685;;Villiers-sur-Orge;VILLIERS-SUR-ORGE;91700;91;ESSONNE;1
91687;;Viry-Châtillon;VIRY-CHATILLON;91170;91;ESSONNE;1
91689;;Wissous;WISSOUS;91320;91;ESSONNE;1
91691;;Yerres;YERRES;91330;91;ESSONNE;1
91692;Les;Ulis;ULIS;91940;91;ESSONNE;1
92002;;Antony;ANTONY;92160;92;HAUTS DE SEINE;1
92004;;Asnières-sur-Seine;ASNIERES-SUR-SEINE;92600;92;HAUTS DE SEINE;1
92007;;Bagneux;BAGNEUX;92220;92;HAUTS DE SEINE;1
92009;;Bois-Colombes;BOIS-COLOMBES;92270;92;HAUTS DE SEINE;1
92012;;Boulogne-Billancourt;BOULOGNE-BILLANCOURT;92100;92;HAUTS DE SEINE;1
92014;;Bourg-la-Reine;BOURG-LA-REINE;92340;92;HAUTS DE SEINE;1
92019;;Châtenay-Malabry;CHATENAY-MALABRY;92290;92;HAUTS DE SEINE;1
92020;;Châtillon;CHATILLON;92320;92;HAUTS DE SEINE;1
92022;;Chaville;CHAVILLE;92370;92;HAUTS DE SEINE;1
92023;;Clamart;CLAMART;92140;92;HAUTS DE SEINE;1
92024;;Clichy;CLICHY;92110;92;HAUTS DE SEINE;1
92025;;Colombes;COLOMBES;92700;92;HAUTS DE SEINE;1
92026;;Courbevoie;COURBEVOIE;92400;92;HAUTS DE SEINE;1
92032;;Fontenay-aux-Roses;FONTENAY-AUX-ROSES;92260;92;HAUTS DE SEINE;1
92033;;Garches;GARCHES;92380;92;HAUTS DE SEINE;1
92035;La;Garenne-Colombes;GARENNE-COLOMBES;92250;92;HAUTS DE SEINE;1
92036;;Gennevilliers;GENNEVILLIERS;92230;92;HAUTS DE SEINE;1
92040;;Issy-les-Moulineaux;ISSY-LES-MOULINEAUX;92130;92;HAUTS DE SEINE;1
92044;;Levallois-Perret;LEVALLOIS-PERRET;92300;92;HAUTS DE SEINE;1
92046;;Malakoff;MALAKOFF;92240;92;HAUTS DE SEINE;1
92047;;Marnes-la-Coquette;MARNES-LA-COQUETTE;92430;92;HAUTS DE SEINE;1
92048;;Meudon;MEUDON;92190;92;HAUTS DE SEINE;1
92049;;Montrouge;MONTROUGE;92120;92;HAUTS DE SEINE;1
92050;;Nanterre;NANTERRE;92000;92;HAUTS DE SEINE;1
92051;;Neuilly-sur-Seine;NEUILLY-SUR-SEINE;92200;92;HAUTS DE SEINE;1
92060;Le;Plessis-Robinson;PLESSIS-ROBINSON;92350;92;HAUTS DE SEINE;1
92062;;Puteaux;PUTEAUX;92800;92;HAUTS DE SEINE;1
92063;;Rueil-Malmaison;RUEIL-MALMAISON;92500;92;HAUTS DE SEINE;1
92064;;Saint-Cloud;SAINT-CLOUD;92210;92;HAUTS DE SEINE;1
92071;;Sceaux;SCEAUX;92330;92;HAUTS DE SEINE;1
92072;;Sèvres;SEVRES;92310;92;HAUTS DE SEINE;1
92073;;Suresnes;SURESNES;92150;92;HAUTS DE SEINE;1
92075;;Vanves;VANVES;92170;92;HAUTS DE SEINE;1
92076;;Vaucresson;VAUCRESSON;92420;92;HAUTS DE SEINE;1
92077;;Ville-d'Avray;VILLE-D'AVRAY;92410;92;HAUTS DE SEINE;1
92078;;Villeneuve-la-Garenne;VILLENEUVE-LA-GARENNE;92390;92;HAUTS DE SEINE;1
93001;;Aubervilliers;AUBERVILLIERS;93300;93;SEINE SAINT DENIS;1
93005;;Aulnay-sous-Bois;AULNAY-SOUS-BOIS;93600;93;SEINE SAINT DENIS;1
93006;;Bagnolet;BAGNOLET;93170;93;SEINE SAINT DENIS;1
93007;Le;Blanc-Mesnil;BLANC-MESNIL;93150;93;SEINE SAINT DENIS;1
93008;;Bobigny;BOBIGNY;93000;93;SEINE SAINT DENIS;1
93010;;Bondy;BONDY;93140;93;SEINE SAINT DENIS;1
93013;Le;Bourget;BOURGET;93350;93;SEINE SAINT DENIS;1
93014;;Clichy-sous-Bois;CLICHY-SOUS-BOIS;93390;93;SEINE SAINT DENIS;1
93015;;Coubron;COUBRON;93470;93;SEINE SAINT DENIS;1
93027;La;Courneuve;COURNEUVE;93120;93;SEINE SAINT DENIS;1
93029;;Drancy;DRANCY;93700;93;SEINE SAINT DENIS;1
93030;;Dugny;DUGNY;93440;93;SEINE SAINT DENIS;1
93031;;Épinay-sur-Seine;EPINAY-SUR-SEINE;93800;93;SEINE SAINT DENIS;1
93032;;Gagny;GAGNY;93220;93;SEINE SAINT DENIS;1
93033;;Gournay-sur-Marne;GOURNAY-SUR-MARNE;93460;93;SEINE SAINT DENIS;1
93039;L';Île-Saint-Denis;ILE-SAINT-DENIS;93450;93;SEINE SAINT DENIS;1
93045;Les;Lilas;LILAS;93260;93;SEINE SAINT DENIS;1
93046;;Livry-Gargan;LIVRY-GARGAN;93190;93;SEINE SAINT DENIS;1
93047;;Montfermeil;MONTFERMEIL;93370;93;SEINE SAINT DENIS;1
93048;;Montreuil;MONTREUIL;93100;93;SEINE SAINT DENIS;1
93049;;Neuilly-Plaisance;NEUILLY-PLAISANCE;93360;93;SEINE SAINT DENIS;1
93050;;Neuilly-sur-Marne;NEUILLY-SUR-MARNE;93330;93;SEINE SAINT DENIS;1
93051;;Noisy-le-Grand;NOISY-LE-GRAND;93160;93;SEINE SAINT DENIS;1
93053;;Noisy-le-Sec;NOISY-LE-SEC;93130;93;SEINE SAINT DENIS;1
93055;;Pantin;PANTIN;93500;93;SEINE SAINT DENIS;1
93057;Les;Pavillons-sous-Bois;PAVILLONS-SOUS-BOIS;93320;93;SEINE SAINT DENIS;1
93059;;Pierrefitte-sur-Seine;PIERREFITTE-SUR-SEINE;93380;93;SEINE SAINT DENIS;1
93061;Le;Pré-Saint-Gervais;PRE-SAINT-GERVAIS;93310;93;SEINE SAINT DENIS;1
93062;Le;Raincy;RAINCY;93340;93;SEINE SAINT DENIS;1
93063;;Romainville;ROMAINVILLE;93230;93;SEINE SAINT DENIS;1
93064;;Rosny-sous-Bois;ROSNY-SOUS-BOIS;93110;93;SEINE SAINT DENIS;1
93066;;Saint-Denis;SAINT-DENIS;93200;93;SEINE SAINT DENIS;1
93070;;Saint-Ouen;SAINT-OUEN;93400;93;SEINE SAINT DENIS;1
93071;;Sevran;SEVRAN;93270;93;SEINE SAINT DENIS;1
93072;;Stains;STAINS;93240;93;SEINE SAINT DENIS;1
93073;;Tremblay-en-France;TREMBLAY-EN-FRANCE;93290;93;SEINE SAINT DENIS;1
93074;;Vaujours;VAUJOURS;93410;93;SEINE SAINT DENIS;1
93077;;Villemomble;VILLEMOMBLE;93250;93;SEINE SAINT DENIS;1
93078;;Villepinte;VILLEPINTE;93420;93;SEINE SAINT DENIS;1
93079;;Villetaneuse;VILLETANEUSE;93430;93;SEINE SAINT DENIS;1
94001;;Ablon-sur-Seine;ABLON-SUR-SEINE;94480;94;VAL DE MARNE;1
94002;;Alfortville;ALFORTVILLE;94140;94;VAL DE MARNE;1
94003;;Arcueil;ARCUEIL;94110;94;VAL DE MARNE;1
94004;;Boissy-Saint-Léger;BOISSY-SAINT-LEGER;94470;94;VAL DE MARNE;1
94011;;Bonneuil-sur-Marne;BONNEUIL-SUR-MARNE;94380;94;VAL DE MARNE;1
94015;;Bry-sur-Marne;BRY-SUR-MARNE;94360;94;VAL DE MARNE;1
94016;;Cachan;CACHAN;94230;94;VAL DE MARNE;1
94017;;Champigny-sur-Marne;CHAMPIGNY-SUR-MARNE;94500;94;VAL DE MARNE;1
94018;;Charenton-le-Pont;CHARENTON-LE-PONT;94220;94;VAL DE MARNE;1
94019;;Chennevières-sur-Marne;CHENNEVIERES-SUR-MARNE;94430;94;VAL DE MARNE;1
94021;;Chevilly-Larue;CHEVILLY-LARUE;94550;94;VAL DE MARNE;1
94022;;Choisy-le-Roi;CHOISY-LE-ROI;94600;94;VAL DE MARNE;1
94028;;Créteil;CRETEIL;94000;94;VAL DE MARNE;1
94033;;Fontenay-sous-Bois;FONTENAY-SOUS-BOIS;94120;94;VAL DE MARNE;1
94034;;Fresnes;FRESNES;94260;94;VAL DE MARNE;1
94037;;Gentilly;GENTILLY;94250;94;VAL DE MARNE;1
94038;L';Haÿ-les-Roses;HAY-LES-ROSES;94240;94;VAL DE MARNE;1
94041;;Ivry-sur-Seine;IVRY-SUR-SEINE;94200;94;VAL DE MARNE;1
94042;;Joinville-le-Pont;JOINVILLE-LE-PONT;94340;94;VAL DE MARNE;1
94043;Le;Kremlin-Bicêtre;KREMLIN-BICETRE;94270;94;VAL DE MARNE;1
94044;;Limeil-Brévannes;LIMEIL-BREVANNES;94450;94;VAL DE MARNE;1
94046;;Maisons-Alfort;MAISONS-ALFORT;94700;94;VAL DE MARNE;1
94047;;Mandres-les-Roses;MANDRES-LES-ROSES;94520;94;VAL DE MARNE;1
94048;;Marolles-en-Brie;MAROLLES-EN-BRIE;94440;94;VAL DE MARNE;1
94052;;Nogent-sur-Marne;NOGENT-SUR-MARNE;94130;94;VAL DE MARNE;1
94053;;Noiseau;NOISEAU;94880;94;VAL DE MARNE;1
94054;;Orly;ORLY;94310;94;VAL DE MARNE;1
94055;;Ormesson-sur-Marne;ORMESSON-SUR-MARNE;94490;94;VAL DE MARNE;1
94056;;Périgny;PERIGNY;94520;94;VAL DE MARNE;1
94058;Le;Perreux-sur-Marne;PERREUX-SUR-MARNE;94170;94;VAL DE MARNE;1
94059;Le;Plessis-Trévise;PLESSIS-TREVISE;94420;94;VAL DE MARNE;1
94060;La;Queue-en-Brie;QUEUE-EN-BRIE;94510;94;VAL DE MARNE;1
94065;;Rungis;RUNGIS;94150;94;VAL DE MARNE;1
94067;;Saint-Mandé;SAINT-MANDE;94160;94;VAL DE MARNE;1
94068;;Saint-Maur-des-Fossés;SAINT-MAUR-DES-FOSSES;94100;94;VAL DE MARNE;1
94069;;Saint-Maurice;SAINT-MAURICE;94410;94;VAL DE MARNE;1
94070;;Santeny;SANTENY;94440;94;VAL DE MARNE;1
94071;;Sucy-en-Brie;SUCY-EN-BRIE;94370;94;VAL DE MARNE;1
94073;;Thiais;THIAIS;94320;94;VAL DE MARNE;1
94074;;Valenton;VALENTON;94460;94;VAL DE MARNE;1
94075;;Villecresnes;VILLECRESNES;94440;94;VAL DE MARNE;1
94076;;Villejuif;VILLEJUIF;94800;94;VAL DE MARNE;1
94077;;Villeneuve-le-Roi;VILLENEUVE-LE-ROI;94290;94;VAL DE MARNE;1
94078;;Villeneuve-Saint-Georges;VILLENEUVE-SAINT-GEORGES;94190;94;VAL DE MARNE;1
94079;;Villiers-sur-Marne;VILLIERS-SUR-MARNE;94350;94;VAL DE MARNE;1
94080;;Vincennes;VINCENNES;94300;94;VAL DE MARNE;1
94081;;Vitry-sur-Seine;VITRY-SUR-SEINE;94400;94;VAL DE MARNE;1
95002;;Ableiges;ABLEIGES;95450;95;VAL D'OISE;1
95008;;Aincourt;AINCOURT;95510;95;VAL D'OISE;1
95011;;Ambleville;AMBLEVILLE;95710;95;VAL D'OISE;1
95012;;Amenucourt;AMENUCOURT;95510;95;VAL D'OISE;1
95014;;Andilly;ANDILLY;95580;95;VAL D'OISE;1
95018;;Argenteuil;ARGENTEUIL;95100;95;VAL D'OISE;1
95019;;Arnouville;ARNOUVILLE;95400;95;VAL D'OISE;1
95023;;Arronville;ARRONVILLE;95810;95;VAL D'OISE;1
95024;;Arthies;ARTHIES;95420;95;VAL D'OISE;1
95026;;Asnières-sur-Oise;ASNIERES-SUR-OISE;95270;95;VAL D'OISE;1
95028;;Attainville;ATTAINVILLE;95570;95;VAL D'OISE;1
95039;;Auvers-sur-Oise;AUVERS-SUR-OISE;95430;95;VAL D'OISE;1
95040;;Avernes;AVERNES;95450;95;VAL D'OISE;1
95042;;Baillet-en-France;BAILLET-EN-FRANCE;95560;95;VAL D'OISE;1
95046;;Banthelu;BANTHELU;95420;95;VAL D'OISE;1
95051;;Beauchamp;BEAUCHAMP;95250;95;VAL D'OISE;1
95052;;Beaumont-sur-Oise;BEAUMONT-SUR-OISE;95260;95;VAL D'OISE;1
95054;Le;Bellay-en-Vexin;BELLAY-EN-VEXIN;95750;95;VAL D'OISE;1
95055;;Bellefontaine;BELLEFONTAINE;95270;95;VAL D'OISE;1
95056;;Belloy-en-France;BELLOY-EN-FRANCE;95270;95;VAL D'OISE;1
95058;;Bernes-sur-Oise;BERNES-SUR-OISE;95340;95;VAL D'OISE;1
95059;;Berville;BERVILLE;95810;95;VAL D'OISE;1
95060;;Bessancourt;BESSANCOURT;95550;95;VAL D'OISE;1
95061;;Béthemont-la-Forêt;BETHEMONT-LA-FORET;95840;95;VAL D'OISE;1
95063;;Bezons;BEZONS;95870;95;VAL D'OISE;1
95074;;Boisemont;BOISEMONT;95000;95;VAL D'OISE;1
95078;;Boissy-l'Aillerie;BOISSY-L'AILLERIE;95650;95;VAL D'OISE;1
95088;;Bonneuil-en-France;BONNEUIL-EN-FRANCE;95500;95;VAL D'OISE;1
95091;;Bouffémont;BOUFFEMONT;95570;95;VAL D'OISE;1
95094;;Bouqueval;BOUQUEVAL;95720;95;VAL D'OISE;1
95101;;Bray-et-Lû;BRAY-ET-LU;95710;95;VAL D'OISE;1
95102;;Bréançon;BREANCON;95640;95;VAL D'OISE;1
95110;;Brignancourt;BRIGNANCOURT;95640;95;VAL D'OISE;1
95116;;Bruyères-sur-Oise;BRUYERES-SUR-OISE;95820;95;VAL D'OISE;1
95119;;Buhy;BUHY;95770;95;VAL D'OISE;1
95120;;Butry-sur-Oise;BUTRY-SUR-OISE;95430;95;VAL D'OISE;1
95127;;Cergy;CERGY;95000;95;VAL D'OISE;1
95134;;Champagne-sur-Oise;CHAMPAGNE-SUR-OISE;95660;95;VAL D'OISE;1
95139;La;Chapelle-en-Vexin;CHAPELLE-EN-VEXIN;95420;95;VAL D'OISE;1
95141;;Charmont;CHARMONT;95420;95;VAL D'OISE;1
95142;;Chars;CHARS;95750;95;VAL D'OISE;1
95144;;Châtenay-en-France;CHATENAY-EN-FRANCE;95190;95;VAL D'OISE;1
95149;;Chaumontel;CHAUMONTEL;95270;95;VAL D'OISE;1
95150;;Chaussy;CHAUSSY;95710;95;VAL D'OISE;1
95151;;Chauvry;CHAUVRY;95560;95;VAL D'OISE;1
95154;;Chennevières-lès-Louvres;CHENNEVIERES-LES-LOUVRES;95380;95;VAL D'OISE;1
95157;;Chérence;CHERENCE;95510;95;VAL D'OISE;1
95166;;Cléry-en-Vexin;CLERY-EN-VEXIN;95420;95;VAL D'OISE;1
95169;;Commeny;COMMENY;95450;95;VAL D'OISE;1
95170;;Condécourt;CONDECOURT;95450;95;VAL D'OISE;1
95176;;Cormeilles-en-Parisis;CORMEILLES-EN-PARISIS;95240;95;VAL D'OISE;1
95177;;Cormeilles-en-Vexin;CORMEILLES-EN-VEXIN;95830;95;VAL D'OISE;1
95181;;Courcelles-sur-Viosne;COURCELLES-SUR-VIOSNE;95650;95;VAL D'OISE;1
95183;;Courdimanche;COURDIMANCHE;95800;95;VAL D'OISE;1
95197;;Deuil-la-Barre;DEUIL-LA-BARRE;95170;95;VAL D'OISE;1
95199;;Domont;DOMONT;95330;95;VAL D'OISE;1
95203;;Eaubonne;EAUBONNE;95600;95;VAL D'OISE;1
95205;;Écouen;ECOUEN;95440;95;VAL D'OISE;1
95210;;Enghien-les-Bains;ENGHIEN-LES-BAINS;95880;95;VAL D'OISE;1
95211;;Ennery;ENNERY;95300;95;VAL D'OISE;1
95212;;Épiais-lès-Louvres;EPIAIS-LES-LOUVRES;95380;95;VAL D'OISE;1
95213;;Épiais-Rhus;EPIAIS-RHUS;95810;95;VAL D'OISE;1
95214;;Épinay-Champlâtreux;EPINAY-CHAMPLATREUX;95270;95;VAL D'OISE;1
95218;;Éragny;ERAGNY;95610;95;VAL D'OISE;1
95219;;Ermont;ERMONT;95120;95;VAL D'OISE;1
95229;;Ézanville;EZANVILLE;95460;95;VAL D'OISE;1
95241;;Fontenay-en-Parisis;FONTENAY-EN-PARISIS;95190;95;VAL D'OISE;1
95250;;Fosses;FOSSES;95470;95;VAL D'OISE;1
95252;;Franconville;FRANCONVILLE;95130;95;VAL D'OISE;1
95253;;Frémainville;FREMAINVILLE;95450;95;VAL D'OISE;1
95254;;Frémécourt;FREMECOURT;95830;95;VAL D'OISE;1
95256;;Frépillon;FREPILLON;95740;95;VAL D'OISE;1
95257;La;Frette-sur-Seine;FRETTE-SUR-SEINE;95530;95;VAL D'OISE;1
95258;;Frouville;FROUVILLE;95690;95;VAL D'OISE;1
95259;;Gadancourt;GADANCOURT;95450;95;VAL D'OISE;1
95268;;Garges-lès-Gonesse;GARGES-LES-GONESSE;95140;95;VAL D'OISE;1
95270;;Genainville;GENAINVILLE;95420;95;VAL D'OISE;1
95271;;Génicourt;GENICOURT;95650;95;VAL D'OISE;1
95277;;Gonesse;GONESSE;95500;95;VAL D'OISE;1
95280;;Goussainville;GOUSSAINVILLE;95190;95;VAL D'OISE;1
95282;;Gouzangrez;GOUZANGREZ;95450;95;VAL D'OISE;1
95287;;Grisy-les-Plâtres;GRISY-LES-PLATRES;95810;95;VAL D'OISE;1
95288;;Groslay;GROSLAY;95410;95;VAL D'OISE;1
95295;;Guiry-en-Vexin;GUIRY-EN-VEXIN;95450;95;VAL D'OISE;1
95298;;Haravilliers;HARAVILLIERS;95640;95;VAL D'OISE;1
95301;;Haute-Isle;HAUTE-ISLE;95780;95;VAL D'OISE;1
95303;Le;Heaulme;HEAULME;95640;95;VAL D'OISE;1
95304;;Hédouville;HEDOUVILLE;95690;95;VAL D'OISE;1
95306;;Herblay;HERBLAY;95220;95;VAL D'OISE;1
95308;;Hérouville;HEROUVILLE;95300;95;VAL D'OISE;1
95309;;Hodent;HODENT;95420;95;VAL D'OISE;1
95313;L';Isle-Adam;ISLE-ADAM;95290;95;VAL D'OISE;1
95316;;Jagny-sous-Bois;JAGNY-SOUS-BOIS;95850;95;VAL D'OISE;1
95323;;Jouy-le-Moutier;JOUY-LE-MOUTIER;95280;95;VAL D'OISE;1
95328;;Labbeville;LABBEVILLE;95690;95;VAL D'OISE;1
95331;;Lassy;LASSY;95270;95;VAL D'OISE;1
95341;;Livilliers;LIVILLIERS;95300;95;VAL D'OISE;1
95348;;Longuesse;LONGUESSE;95450;95;VAL D'OISE;1
95351;;Louvres;LOUVRES;95380;95;VAL D'OISE;1
95352;;Luzarches;LUZARCHES;95270;95;VAL D'OISE;1
95353;;Maffliers;MAFFLIERS;95560;95;VAL D'OISE;1
95355;;Magny-en-Vexin;MAGNY-EN-VEXIN;95420;95;VAL D'OISE;1
95365;;Mareil-en-France;MAREIL-EN-FRANCE;95850;95;VAL D'OISE;1
95369;;Margency;MARGENCY;95580;95;VAL D'OISE;1
95370;;Marines;MARINES;95640;95;VAL D'OISE;1
95371;;Marly-la-Ville;MARLY-LA-VILLE;95670;95;VAL D'OISE;1
95379;;Maudétour-en-Vexin;MAUDETOUR-EN-VEXIN;95420;95;VAL D'OISE;1
95387;;Menouville;MENOUVILLE;95810;95;VAL D'OISE;1
95388;;Menucourt;MENUCOURT;95180;95;VAL D'OISE;1
95392;;Mériel;MERIEL;95630;95;VAL D'OISE;1
95394;;Méry-sur-Oise;MERY-SUR-OISE;95540;95;VAL D'OISE;1
95395;Le;Mesnil-Aubry;MESNIL-AUBRY;95720;95;VAL D'OISE;1
95409;;Moisselles;MOISSELLES;95570;95;VAL D'OISE;1
95422;;Montgeroult;MONTGEROULT;95650;95;VAL D'OISE;1
95424;;Montigny-lès-Cormeilles;MONTIGNY-LES-CORMEILLES;95370;95;VAL D'OISE;1
95426;;Montlignon;MONTLIGNON;95680;95;VAL D'OISE;1
95427;;Montmagny;MONTMAGNY;95360;95;VAL D'OISE;1
95428;;Montmorency;MONTMORENCY;95160;95;VAL D'OISE;1
95429;;Montreuil-sur-Epte;MONTREUIL-SUR-EPTE;95770;95;VAL D'OISE;1
95430;;Montsoult;MONTSOULT;95560;95;VAL D'OISE;1
95436;;Mours;MOURS;95260;95;VAL D'OISE;1
95438;;Moussy;MOUSSY;95640;95;VAL D'OISE;1
95445;;Nerville-la-Forêt;NERVILLE-LA-FORET;95590;95;VAL D'OISE;1
95446;;Nesles-la-Vallée;NESLES-LA-VALLEE;95690;95;VAL D'OISE;1
95447;;Neuilly-en-Vexin;NEUILLY-EN-VEXIN;95640;95;VAL D'OISE;1
95450;;Neuville-sur-Oise;NEUVILLE-SUR-OISE;95000;95;VAL D'OISE;1
95452;;Nointel;NOINTEL;95590;95;VAL D'OISE;1
95456;;Noisy-sur-Oise;NOISY-SUR-OISE;95270;95;VAL D'OISE;1
95459;;Nucourt;NUCOURT;95420;95;VAL D'OISE;1
95462;;Omerville;OMERVILLE;95420;95;VAL D'OISE;1
95476;;Osny;OSNY;95520;95;VAL D'OISE;1
95480;;Parmain;PARMAIN;95620;95;VAL D'OISE;1
95483;Le;Perchay;PERCHAY;95450;95;VAL D'OISE;1
95487;;Persan;PERSAN;95340;95;VAL D'OISE;1
95488;;Pierrelaye;PIERRELAYE;95480;95;VAL D'OISE;1
95489;;Piscop;PISCOP;95350;95;VAL D'OISE;1
95491;Le;Plessis-Bouchard;PLESSIS-BOUCHARD;95130;95;VAL D'OISE;1
95492;Le;Plessis-Gassot;PLESSIS-GASSOT;95720;95;VAL D'OISE;1
95493;Le;Plessis-Luzarches;PLESSIS-LUZARCHES;95270;95;VAL D'OISE;1
95500;;Pontoise;PONTOISE;95000;95;VAL D'OISE;1
95504;;Presles;PRESLES;95590;95;VAL D'OISE;1
95509;;Puiseux-en-France;PUISEUX-EN-FRANCE;95380;95;VAL D'OISE;1
95510;;Puiseux-Pontoise;PUISEUX-PONTOISE;95650;95;VAL D'OISE;1
95523;La;Roche-Guyon;ROCHE-GUYON;95780;95;VAL D'OISE;1
95527;;Roissy-en-France;ROISSY-EN-FRANCE;95700;95;VAL D'OISE;1
95529;;Ronquerolles;RONQUEROLLES;95340;95;VAL D'OISE;1
95535;;Sagy;SAGY;95450;95;VAL D'OISE;1
95539;;Saint-Brice-sous-Forêt;SAINT-BRICE-SOUS-FORET;95350;95;VAL D'OISE;1
95541;;Saint-Clair-sur-Epte;SAINT-CLAIR-SUR-EPTE;95770;95;VAL D'OISE;1
95543;;Saint-Cyr-en-Arthies;SAINT-CYR-EN-ARTHIES;95510;95;VAL D'OISE;1
95554;;Saint-Gervais;SAINT-GERVAIS;95420;95;VAL D'OISE;1
95555;;Saint-Gratien;SAINT-GRATIEN;95210;95;VAL D'OISE;1
95563;;Saint-Leu-la-Forêt;SAINT-LEU-LA-FORET;95320;95;VAL D'OISE;1
95566;;Saint-Martin-du-Tertre;SAINT-MARTIN-DU-TERTRE;95270;95;VAL D'OISE;1
95572;;Saint-Ouen-l'Aumône;SAINT-OUEN-L'AUMONE;95310;95;VAL D'OISE;1
95574;;Saint-Prix;SAINT-PRIX;95390;95;VAL D'OISE;1
95580;;Saint-Witz;SAINT-WITZ;95470;95;VAL D'OISE;1
95582;;Sannois;SANNOIS;95110;95;VAL D'OISE;1
95584;;Santeuil;SANTEUIL;95640;95;VAL D'OISE;1
95585;;Sarcelles;SARCELLES;95200;95;VAL D'OISE;1
95592;;Seraincourt;SERAINCOURT;95450;95;VAL D'OISE;1
95594;;Seugy;SEUGY;95270;95;VAL D'OISE;1
95598;;Soisy-sous-Montmorency;SOISY-SOUS-MONTMORENCY;95230;95;VAL D'OISE;1
95604;;Survilliers;SURVILLIERS;95470;95;VAL D'OISE;1
95607;;Taverny;TAVERNY;95150;95;VAL D'OISE;1
95610;;Théméricourt;THEMERICOURT;95450;95;VAL D'OISE;1
95611;;Theuville;THEUVILLE;95810;95;VAL D'OISE;1
95612;Le;Thillay;THILLAY;95500;95;VAL D'OISE;1
95625;;Us;US;95450;95;VAL D'OISE;1
95627;;Vallangoujard;VALLANGOUJARD;95810;95;VAL D'OISE;1
95628;;Valmondois;VALMONDOIS;95760;95;VAL D'OISE;1
95633;;Vaudherland;VAUDHERLAND;95500;95;VAL D'OISE;1
95637;;Vauréal;VAUREAL;95490;95;VAL D'OISE;1
95641;;Vémars;VEMARS;95470;95;VAL D'OISE;1
95651;;Vétheuil;VETHEUIL;95510;95;VAL D'OISE;1
95652;;Viarmes;VIARMES;95270;95;VAL D'OISE;1
95656;;Vienne-en-Arthies;VIENNE-EN-ARTHIES;95510;95;VAL D'OISE;1
95658;;Vigny;VIGNY;95450;95;VAL D'OISE;1
95660;;Villaines-sous-Bois;VILLAINES-SOUS-BOIS;95570;95;VAL D'OISE;1
95675;;Villeron;VILLERON;95380;95;VAL D'OISE;1
95676;;Villers-en-Arthies;VILLERS-EN-ARTHIES;95510;95;VAL D'OISE;1
95678;;Villiers-Adam;VILLIERS-ADAM;95840;95;VAL D'OISE;1
95680;;Villiers-le-Bel;VILLIERS-LE-BEL;95400;95;VAL D'OISE;1
95682;;Villiers-le-Sec;VILLIERS-LE-SEC;95720;95;VAL D'OISE;1
95690;;Wy-dit-Joli-Village;WY-DIT-JOLI-VILLAGE;95420;95;VAL D'OISE;1
97101;Les;Abymes;ABYMES;97139;971;GUADELOUPE;1
97102;;Anse-Bertrand;ANSE-BERTRAND;97121;971;GUADELOUPE;1
97103;;Baie-Mahault;BAIE-MAHAULT;97122;971;GUADELOUPE;1
97104;;Baillif;BAILLIF;97123;971;GUADELOUPE;1
97105;;Basse-Terre;BASSE-TERRE;97100;971;GUADELOUPE;1
97106;;Bouillante;BOUILLANTE;97125;971;GUADELOUPE;1
97107;;Capesterre-Belle-Eau;CAPESTERRE-BELLE-EAU;97130;971;GUADELOUPE;1
97108;;Capesterre-de-Marie-Galante;CAPESTERRE-DE-MARIE-GALANTE;97140;971;GUADELOUPE;1
97109;;Gourbeyre;GOURBEYRE;97113;971;GUADELOUPE;1
97110;La;Désirade;DESIRADE;97127;971;GUADELOUPE;1
97111;;Deshaies;DESHAIES;97126;971;GUADELOUPE;1
97112;;Grand-Bourg;GRAND-BOURG;97112;971;GUADELOUPE;1
97113;Le;Gosier;GOSIER;97190;971;GUADELOUPE;1
97114;;Goyave;GOYAVE;97128;971;GUADELOUPE;1
97115;;Lamentin;LAMENTIN;97129;971;GUADELOUPE;1
97116;;Morne-à-l'Eau;MORNE-A-L'EAU;97111;971;GUADELOUPE;1
97117;Le;Moule;MOULE;97160;971;GUADELOUPE;1
97118;;Petit-Bourg;PETIT-BOURG;97170;971;GUADELOUPE;1
97119;;Petit-Canal;PETIT-CANAL;97131;971;GUADELOUPE;1
97120;;Pointe-à-Pitre;POINTE-A-PITRE;97110;971;GUADELOUPE;1
97121;;Pointe-Noire;POINTE-NOIRE;97116;971;GUADELOUPE;1
97122;;Port-Louis;PORT-LOUIS;97117;971;GUADELOUPE;1
97124;;Saint-Claude;SAINT-CLAUDE;97120;971;GUADELOUPE;1
97125;;Saint-François;SAINT-FRANCOIS;97118;971;GUADELOUPE;1
97126;;Saint-Louis;SAINT-LOUIS;97134;971;GUADELOUPE;1
97128;;Sainte-Anne;SAINTE-ANNE;97180;971;GUADELOUPE;1
97129;;Sainte-Rose;SAINTE-ROSE;97115;971;GUADELOUPE;1
97130;;Terre-de-Bas;TERRE-DE-BAS;97136;971;GUADELOUPE;1
97131;;Terre-de-Haut;TERRE-DE-HAUT;97137;971;GUADELOUPE;1
97132;;Trois-Rivières;TROIS-RIVIERES;97114;971;GUADELOUPE;1
97133;;Vieux-Fort;VIEUX-FORT;97141;971;GUADELOUPE;1
97134;;Vieux-Habitants;VIEUX-HABITANTS;97119;971;GUADELOUPE;1
97201;L';Ajoupa-Bouillon;AJOUPA-BOUILLON;97216;972;MARTINIQUE;1
97202;Les;Anses-d'Arlet;ANSES-D'ARLET;97217;972;MARTINIQUE;1
97203;;Basse-Pointe;BASSE-POINTE;97218;972;MARTINIQUE;1
97204;Le;Carbet;CARBET;97221;972;MARTINIQUE;1
97205;;Case-Pilote;CASE-PILOTE;97222;972;MARTINIQUE;1
97206;Le;Diamant;DIAMANT;97223;972;MARTINIQUE;1
97207;;Ducos;DUCOS;97224;972;MARTINIQUE;1
97208;;Fonds-Saint-Denis;FONDS-SAINT-DENIS;97250;972;MARTINIQUE;1
97209;;Fort-de-France;FORT-DE-FRANCE;97200;972;MARTINIQUE;1
97210;Le;François;FRANCOIS;97240;972;MARTINIQUE;1
97211;;Grand'Rivière;GRAND'RIVIERE;97218;972;MARTINIQUE;1
97212;;Gros-Morne;GROS-MORNE;97213;972;MARTINIQUE;1
97213;Le;Lamentin;LAMENTIN;97232;972;MARTINIQUE;1
97214;Le;Lorrain;LORRAIN;97214;972;MARTINIQUE;1
97215;;Macouba;MACOUBA;97218;972;MARTINIQUE;1
97216;Le;Marigot;MARIGOT;97225;972;MARTINIQUE;1
97217;Le;Marin;MARIN;97290;972;MARTINIQUE;1
97218;Le;Morne-Rouge;MORNE-ROUGE;97260;972;MARTINIQUE;1
97219;Le;Prêcheur;PRECHEUR;97250;972;MARTINIQUE;1
97220;;Rivière-Pilote;RIVIERE-PILOTE;97211;972;MARTINIQUE;1
97221;;Rivière-Salée;RIVIERE-SALEE;97215;972;MARTINIQUE;1
97222;Le;Robert;ROBERT;97231;972;MARTINIQUE;1
97223;;Saint-Esprit;SAINT-ESPRIT;97270;972;MARTINIQUE;1
97224;;Saint-Joseph;SAINT-JOSEPH;97212;972;MARTINIQUE;1
97225;;Saint-Pierre;SAINT-PIERRE;97250;972;MARTINIQUE;1
97226;;Sainte-Anne;SAINTE-ANNE;97227;972;MARTINIQUE;1
97227;;Sainte-Luce;SAINTE-LUCE;97228;972;MARTINIQUE;1
97228;;Sainte-Marie;SAINTE-MARIE;97230;972;MARTINIQUE;1
97229;;Schœlcher;SCHOELCHER;97233;972;MARTINIQUE;1
97230;La;Trinité;TRINITE;97220;972;MARTINIQUE;1
97231;Les;Trois-Îlets;TROIS-ILETS;97229;972;MARTINIQUE;1
97232;Le;Vauclin;VAUCLIN;97280;972;MARTINIQUE;1
97233;Le;Morne-Vert;MORNE-VERT;97226;972;MARTINIQUE;1
97234;;Bellefontaine;BELLEFONTAINE;97222;972;MARTINIQUE;1
97301;;Régina;REGINA;97390;973;GUYANE;1
97302;;Cayenne;CAYENNE;97300;973;GUYANE;1
97303;;Iracoubo;IRACOUBO;97350;973;GUYANE;1
97304;;Kourou;KOUROU;97310;973;GUYANE;1
97305;;Macouria;MACOURIA;97355;973;GUYANE;1
97306;;Mana;MANA;97360;973;GUYANE;1
97307;;Matoury;MATOURY;97351;973;GUYANE;1
97308;;Saint-Georges;SAINT-GEORGES;97313;973;GUYANE;1
97309;;Remire-Montjoly;REMIRE-MONTJOLY;97354;973;GUYANE;1
97310;;Roura;ROURA;97311;973;GUYANE;1
97311;;Saint-Laurent-du-Maroni;SAINT-LAURENT-DU-MARONI;97320;973;GUYANE;1
97312;;Sinnamary;SINNAMARY;97315;973;GUYANE;1
97313;;Montsinéry-Tonnegrande;MONTSINERY-TONNEGRANDE;97300;973;GUYANE;1
97314;;Ouanary;OUANARY;97380;973;GUYANE;1
97352;;Saül;SAUL;97314;973;GUYANE;1
97353;;Maripasoula;MARIPASOULA;97370;973;GUYANE;1
97356;;Camopi;CAMOPI;97330;973;GUYANE;1
97357;;Grand-Santi;GRAND-SANTI;97340;973;GUYANE;1
97358;;Saint-Élie;SAINT-ELIE;97312;973;GUYANE;1
97360;;Apatou;APATOU;97317;973;GUYANE;1
97361;;Awala-Yalimapo;AWALA-YALIMAPO;;973;;
97362;;Papaichton;PAPAICHTON;;973;;
97401;Les;Avirons;AVIRONS;97425;974;REUNION;1
97402;;Bras-Panon;BRAS-PANON;97412;974;REUNION;1
97403;;Entre-Deux;ENTRE-DEUX;97414;974;REUNION;1
97404;L';Étang-Salé;ETANG-SALE;97427;974;REUNION;1
97405;;Petite-Île;PETITE-ILE;97429;974;REUNION;1
97406;La;Plaine-des-Palmistes;PLAINE-DES-PALMISTES;97431;974;REUNION;1
97407;Le;Port;PORT;97420;974;REUNION;1
97408;La;Possession;POSSESSION;97419;974;REUNION;1
97409;;Saint-André;SAINT-ANDRE;97440;974;REUNION;1
97410;;Saint-Benoît;SAINT-BENOIT;97470;974;REUNION;1
97411;;Saint-Denis;SAINT-DENIS;97400;974;REUNION;1
97412;;Saint-Joseph;SAINT-JOSEPH;97480;974;REUNION;1
97413;;Saint-Leu;SAINT-LEU;97436;974;REUNION;1
97414;;Saint-Louis;SAINT-LOUIS;97134;974;REUNION;1
97415;;Saint-Paul;SAINT-PAUL;97460;974;REUNION;1
97416;;Saint-Pierre;SAINT-PIERRE;97410;974;REUNION;1
97417;;Saint-Philippe;SAINT-PHILIPPE;97442;974;REUNION;1
97418;;Sainte-Marie;SAINTE-MARIE;97438;974;REUNION;1
97419;;Sainte-Rose;SAINTE-ROSE;97439;974;REUNION;1
97420;;Sainte-Suzanne;SAINTE-SUZANNE;97441;974;REUNION;1
97421;;Salazie;SALAZIE;97433;974;REUNION;1
97422;Le;Tampon;TAMPON;97430;974;REUNION;1
97423;Les;Trois-Bassins;TROIS-BASSINS;97426;974;REUNION;1
97424;;Cilaos;CILAOS;97413;974;REUNION;1
97601;;Acoua;ACOUA;;976;;
97602;;Bandraboua;BANDRABOUA;;976;;
97603;;Bandrele;BANDRELE;;976;;
97604;;Bouéni;BOUENI;;976;;
97605;;Chiconi;CHICONI;;976;;
97606;;Chirongui;CHIRONGUI;;976;;
97607;;Dembeni;DEMBENI;;976;;
97608;;Dzaoudzi;DZAOUDZI;;976;;
97609;;Kani-Kéli;KANI-KELI;;976;;
97610;;Koungou;KOUNGOU;;976;;
97611;;Mamoudzou;MAMOUDZOU;;976;;
97612;;Mtsamboro;MTSAMBORO;;976;;
97613;;M'Tsangamouji;M'TSANGAMOUJI;;976;;
97614;;Ouangani;OUANGANI;;976;;
97615;;Pamandzi;PAMANDZI;;976;;
97616;;Sada;SADA;;976;;
97617;;Tsingoni;TSINGONI;;976;;
